@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,18 +21,21 @@
 
 /*! \file auth.h
  * \brief A header for the ident functions.
- * \version $Id: auth.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: auth.h 7007 2016-01-01 00:09:08Z michael $
  */
 
-#ifndef INCLUDED_s_auth_h
-#define INCLUDED_s_auth_h
+#ifndef INCLUDED_auth_h
+#define INCLUDED_auth_h
 
-#define RFC1413_BUFSIZ  512  /**< rfc1413 says we MUST accept 512 bytes */
-#define RFC1413_PORT    113  /**< As defined per rfc1413, IDENT server listens on TCP port 113 */
+enum { RFC1413_BUFSIZ = 512 };  /**< rfc1413 says we MUST accept 512 bytes */
+enum { RFC1413_PORT   = 113 };  /**< As defined per rfc1413, IDENT server listens on TCP port 113 */
 
-#define AM_IN_AUTH      0x00000001U
-#define AM_DOING_AUTH   0x00000002U
-#define AM_DNS_PENDING  0x00000004U
+enum
+{
+  AM_IN_AUTH     = 0x00000001U,
+  AM_DOING_AUTH  = 0x00000002U,
+  AM_DNS_PENDING = 0x00000004U
+};
 
 #define SetInAuth(x)         ((x)->flags |= AM_IN_AUTH)
 #define ClearInAuth(x)       ((x)->flags &= ~AM_IN_AUTH)
