@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel.h
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.h 5758 2015-04-02 18:26:29Z michael $
+ * \version $Id: channel.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_channel_h
@@ -36,12 +36,15 @@
 #define AddMemberFlag(x, y) ((x)->flags |=  (y))
 #define DelMemberFlag(x, y) ((x)->flags &= ~(y))
 
-#define FLOOD_NOTICED           1
-#define JOIN_FLOOD_NOTICED      2
+enum
+{
+  MSG_FLOOD_NOTICED  = 0x00000001U,
+  JOIN_FLOOD_NOTICED = 0x00000002U
+};
 
-#define SetFloodNoticed(x)   ((x)->flags |= FLOOD_NOTICED)
-#define IsSetFloodNoticed(x) ((x)->flags & FLOOD_NOTICED)
-#define ClearFloodNoticed(x) ((x)->flags &= ~FLOOD_NOTICED)
+#define SetFloodNoticed(x)   ((x)->flags |= MSG_FLOOD_NOTICED)
+#define IsSetFloodNoticed(x) ((x)->flags & MSG_FLOOD_NOTICED)
+#define ClearFloodNoticed(x) ((x)->flags &= ~MSG_FLOOD_NOTICED)
 
 #define SetJoinFloodNoticed(x)   ((x)->flags |= JOIN_FLOOD_NOTICED)
 #define IsSetJoinFloodNoticed(x) ((x)->flags & JOIN_FLOOD_NOTICED)
@@ -66,11 +69,12 @@ struct Channel
   struct Mode mode;
 
   char topic[TOPICLEN + 1];
-  char topic_info[USERHOST_REPLYLEN];
+  char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];
 
   time_t creationtime;
   time_t topic_time;
   time_t last_knock;  /**< Don't allow knock to flood */
+  time_t last_invite;
   time_t last_join_time;
   time_t first_received_message_time; /*!< channel flood control */
   unsigned int flags;
@@ -86,6 +90,7 @@ struct Channel
   float number_joined;
 
   char name[CHANNELLEN + 1];
+  size_t name_len;
 };
 
 /*! \brief Membership structure */
@@ -115,12 +120,10 @@ struct Ban
 };
 
 extern dlink_list channel_list;
-extern struct event splitmode_event;
 
-extern int check_channel_name(const char *, const int);
-extern int can_send(struct Channel *, struct Client *, struct Membership *, const char *);
+extern int channel_check_name(const char *, const int);
+extern int can_send(struct Channel *, struct Client *, struct Membership *, const char *, int);
 extern int is_banned(const struct Channel *, const struct Client *);
-extern int can_join(struct Client *, const struct Channel *, const char *);
 extern int has_member_flags(const struct Membership *, const unsigned int);
 
 extern void channel_do_join(struct Client *, char *, char *);
@@ -133,17 +136,16 @@ extern void remove_user_from_channel(struct Membership *);
 extern void channel_member_names(struct Client *, struct Channel *, int);
 extern void add_invite(struct Channel *, struct Client *);
 extern void del_invite(struct Channel *, struct Client *);
-extern void clear_invites(struct Channel *);
-extern void send_channel_modes(struct Client *, struct Channel *);
+extern void clear_invites_channel(struct Channel *);
+extern void clear_invites_client(struct Client *);
+extern void channel_send_modes(struct Client *, struct Channel *);
 extern void channel_modes(struct Channel *, struct Client *, char *, char *);
 extern void check_spambot_warning(struct Client *, const char *);
-extern void check_splitmode(void *);
-extern void free_channel_list(dlink_list *);
-extern void destroy_channel(struct Channel *);
+extern void channel_free(struct Channel *);
 extern void channel_set_topic(struct Channel *, const char *, const char *, time_t, int);
 
 extern const char *get_member_status(const struct Membership *, const int);
 
-extern struct Channel *make_channel(const char *);
+extern struct Channel *channel_make(const char *);
 extern struct Membership *find_channel_link(struct Client *, struct Channel *);
 #endif
