@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id: client.h 5773 2015-04-04 15:42:35Z michael $
+ * \version $Id: client.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 
@@ -41,21 +41,26 @@ struct MaskItem;
 /*
  * status macros.
  */
-#define STAT_CONNECTING  0x00000001U
-#define STAT_HANDSHAKE   0x00000002U
-#define STAT_ME          0x00000004U
-#define STAT_UNKNOWN     0x00000008U
-#define STAT_SERVER      0x00000010U
-#define STAT_CLIENT      0x00000020U
+enum
+{
+  STAT_CONNECTING = 0x00000001U,
+  STAT_HANDSHAKE  = 0x00000002U,
+  STAT_ME         = 0x00000004U,
+  STAT_UNKNOWN    = 0x00000008U,
+  STAT_SERVER     = 0x00000010U,
+  STAT_CLIENT     = 0x00000020U
+};
 
-#define REG_NEED_USER    0x00000001U  /**< User must send USER command */
-#define REG_NEED_NICK    0x00000002U  /**< User must send NICK command */
-#define REG_NEED_CAP     0x00000004U  /**< In middle of CAP negotiations */
-#define REG_INIT  (REG_NEED_USER|REG_NEED_NICK)
+enum
+{
+  REG_NEED_USER = 0x00000001U,  /**< User must send USER command */
+  REG_NEED_NICK = 0x00000002U,  /**< User must send NICK command */
+  REG_NEED_CAP  = 0x00000004U,  /**< In middle of CAP negotiations */
+  REG_INIT      = REG_NEED_USER | REG_NEED_NICK
+};
 
 #define ID_or_name(x,client_p)  ((IsServer(client_p->from) && (x)->id[0]) ? (x)->id : (x)->name)
 
-#define IsRegistered(x)         ((x)->status  > STAT_UNKNOWN)
 #define IsConnecting(x)         ((x)->status == STAT_CONNECTING)
 #define IsHandshake(x)          ((x)->status == STAT_HANDSHAKE)
 #define IsMe(x)                 ((x)->status == STAT_ME)
@@ -79,8 +84,7 @@ struct MaskItem;
                                  (x)->handler = SERVER_HANDLER; }
 
 #define SetClient(x)            {(x)->status = STAT_CLIENT; \
-                                 (x)->handler = HasUMode(x, UMODE_OPER) ? \
-                                 OPER_HANDLER : CLIENT_HANDLER; }
+                                 (x)->handler = CLIENT_HANDLER; }
 
 #define MyConnect(x)            ((x)->connection != NULL)
 #define MyClient(x)             (MyConnect(x) && IsClient(x))
@@ -88,117 +92,134 @@ struct MaskItem;
 /*
  * ts stuff
  */
-#define TS_CURRENT      6  /**< Current TS protocol version */
-#define TS_MIN          6  /**< Minimum supported TS protocol version */
+enum
+{
+  TS_CURRENT = 6,  /**< Current TS protocol version */
+  TS_MIN     = 6   /**< Minimum supported TS protocol version */
+};
 
-
-#define CAP_MULTI_PREFIX  0x00000001U
-#define CAP_AWAY_NOTIFY   0x00000002U
-#define CAP_UHNAMES       0x00000004U
-#define CAP_EXTENDED_JOIN 0x00000008U
+enum
+{
+  CAP_MULTI_PREFIX   = 0x00000001U,  /**< ircv3.1 multi-prefix client capability */
+  CAP_AWAY_NOTIFY    = 0x00000002U,  /**< ircv3.1 away-notify client capability */
+  CAP_UHNAMES        = 0x00000004U,  /**< ircv3.2 userhost-in-names client capability */
+  CAP_EXTENDED_JOIN  = 0x00000008U,  /**< ircv3.1 extended-join client capability */
+  CAP_ACCOUNT_NOTIFY = 0x00000010U,  /**< ircv3.1 account-notify client capability */
+  CAP_INVITE_NOTIFY  = 0x00000020U,  /**< ircv3.2 invite-notify client capability */
+  CAP_CHGHOST        = 0x00000040U   /**< ircv3.2 chghost client capability */
+};
 
 #define HasCap(x, y) ((x)->connection->cap_active & (y))
 
 
 /* housekeeping flags */
-#define FLAGS_PINGSENT       0x00000001U  /**< Unreplied ping sent */
-#define FLAGS_DEADSOCKET     0x00000002U  /**< Local socket is dead--Exiting soon */
-#define FLAGS_KILLED         0x00000004U  /**< Prevents "QUIT" from being sent for this */
-#define FLAGS_CLOSING        0x00000008U  /**< Set when closing to suppress errors */
-#define FLAGS_GOTID          0x00000010U  /**< Successful ident lookup achieved */
-#define FLAGS_SENDQEX        0x00000020U  /**< Sendq exceeded */
-#define FLAGS_IPHASH         0x00000040U  /**< Iphashed this client */
-#define FLAGS_MARK           0x00000080U  /**< Marked client */
-#define FLAGS_CANFLOOD       0x00000100U  /**< Client has the ability to flood */
-#define FLAGS_EXEMPTGLINE    0x00000200U  /**< Client can't be G-lined */
-#define FLAGS_EXEMPTKLINE    0x00000400U  /**< Client is exempt from kline */
-#define FLAGS_NOLIMIT        0x00000800U  /**< Client is exempt from limits */
-#define FLAGS_PING_COOKIE    0x00001000U  /**< PING Cookie */
-#define FLAGS_FLOODDONE      0x00002000U  /**< Flood grace period has been ended. */
-#define FLAGS_EOB            0x00004000U  /**< Server has sent us an EOB */
-#define FLAGS_HIDDEN         0x00008000U  /**< A hidden server. Not shown in /links */
-#define FLAGS_BLOCKED        0x00010000U  /**< Must wait for COMM_SELECT_WRITE */
-#define FLAGS_USERHOST       0x00020000U  /**< Client is in userhost hash */
-#define FLAGS_BURSTED        0x00040000U  /**< User was already bursted */
-#define FLAGS_EXEMPTRESV     0x00080000U  /**< Client is exempt from RESV */
-#define FLAGS_GOTUSER        0x00100000U  /**< If we received a USER command */
-#define FLAGS_FINISHED_AUTH  0x00200000U  /**< Client has been released from auth */
-#define FLAGS_FLOOD_NOTICED  0x00400000U  /**< Notice to opers about this flooder has been sent */
-#define FLAGS_SERVICE        0x00800000U  /**< Client/server is a network service */
-#define FLAGS_SSL            0x01000000U  /**< User is connected via TLS/SSL */
-#define FLAGS_SQUIT          0x02000000U
+enum
+{
+  FLAGS_PINGSENT      = 0x00000001U,  /**< Unreplied ping sent */
+  FLAGS_DEADSOCKET    = 0x00000002U,  /**< Local socket is dead--Exiting soon */
+  FLAGS_KILLED        = 0x00000004U,  /**< Prevents "QUIT" from being sent for this */
+  FLAGS_CLOSING       = 0x00000008U,  /**< Set when closing to suppress errors */
+  FLAGS_GOTID         = 0x00000010U,  /**< Successful ident lookup achieved */
+  FLAGS_SENDQEX       = 0x00000020U,  /**< Sendq exceeded */
+  FLAGS_IPHASH        = 0x00000040U,  /**< Iphashed this client */
+  FLAGS_MARK          = 0x00000080U,  /**< Marked client */
+  FLAGS_CANFLOOD      = 0x00000100U,  /**< Client has the ability to flood */
+  FLAGS_EXEMPTKLINE   = 0x00000200U,  /**< Client is exempt from k-lines */
+  FLAGS_NOLIMIT       = 0x00000400U,  /**< Client is exempt from limits */
+  FLAGS_PING_COOKIE   = 0x00000800U,  /**< PING Cookie */
+  FLAGS_FLOODDONE     = 0x00001000U,  /**< Flood grace period has been ended. */
+  FLAGS_EOB           = 0x00002000U,  /**< Server has sent us an EOB */
+  FLAGS_HIDDEN        = 0x00004000U,  /**< A hidden server. Not shown in /links */
+  FLAGS_BLOCKED       = 0x00008000U,  /**< Must wait for COMM_SELECT_WRITE */
+  FLAGS_USERHOST      = 0x00010000U,  /**< Client is in userhost hash */
+  FLAGS_BURSTED       = 0x00020000U,  /**< User was already bursted */
+  FLAGS_EXEMPTRESV    = 0x00040000U,  /**< Client is exempt from RESV */
+  FLAGS_GOTUSER       = 0x00080000U,  /**< If we received a USER command */
+  FLAGS_FINISHED_AUTH = 0x00100000U,  /**< Client has been released from auth */
+  FLAGS_FLOOD_NOTICED = 0x00200000U,  /**< Notice to opers about this flooder has been sent */
+  FLAGS_SERVICE       = 0x00400000U,  /**< Client/server is a network service */
+  FLAGS_SSL           = 0x00800000U,  /**< User is connected via TLS/SSL */
+  FLAGS_SQUIT         = 0x01000000U,
+  FLAGS_EXEMPTXLINE   = 0x02000000U   /**< Client is exempt from x-lines */
+};
 
 #define HasFlag(x, y) ((x)->flags &   (y))
 #define AddFlag(x, y) ((x)->flags |=  (y))
 #define DelFlag(x, y) ((x)->flags &= ~(y))
 
 
-
 /* umodes, settable flags */
-#define UMODE_SERVNOTICE   0x00000001U  /**< Server notices such as kill */
-#define UMODE_CCONN        0x00000002U  /**< Can see client connection notices */
-#define UMODE_REJ          0x00000004U  /**< Bot Rejections */
-#define UMODE_SKILL        0x00000008U  /**< Server Killed */
-#define UMODE_FULL         0x00000010U  /**< Full messages */
-#define UMODE_SPY          0x00000020U  /**< See STATS / LINKS */
-#define UMODE_DEBUG        0x00000040U  /**< 'debugging' info */
-#define UMODE_NCHANGE      0x00000080U  /**< Nick change notice */
-#define UMODE_WALLOP       0x00000100U  /**< Send wallops to them */
-#define UMODE_INVISIBLE    0x00000200U  /**< Makes user invisible */
-#define UMODE_BOTS         0x00000400U  /**< Shows bots */
-#define UMODE_EXTERNAL     0x00000800U  /**< Show servers introduced and splitting */
-#define UMODE_CALLERID     0x00001000U  /**< Block unless caller id's */
-#define UMODE_SOFTCALLERID 0x00002000U  /**< Block unless on common channel */
-#define UMODE_UNAUTH       0x00004000U  /**< Show unauth connects here */
-#define UMODE_LOCOPS       0x00008000U  /**< Can see LOCOPS messages */
-#define UMODE_DEAF         0x00010000U  /**< Don't receive channel messages */
-#define UMODE_REGISTERED   0x00020000U  /**< User has identified for that nick. */
-#define UMODE_REGONLY      0x00040000U  /**< Only registered nicks may PM */
-#define UMODE_HIDDEN       0x00080000U  /**< IRC operator status is hidden */
-#define UMODE_OPER         0x00100000U  /**< IRC operator */
-#define UMODE_ADMIN        0x00200000U  /**< Admin on server */
-#define UMODE_FARCONNECT   0x00400000U  /**< Can see remote client connects/exits */
-#define UMODE_HIDDENHOST   0x00800000U  /**< User's host is hidden */
-#define UMODE_SSL          0x01000000U  /**< User is connected via TLS/SSL */
-#define UMODE_WEBIRC       0x02000000U  /**< User connected via a webirc gateway */
-#define UMODE_HIDEIDLE     0x04000000U  /**< Hides idle and signon time in WHOIS */
-#define UMODE_HIDECHANS    0x08000000U  /**< Hides channel list in WHOIS */
-
-#define UMODE_ALL          UMODE_SERVNOTICE
+enum
+{
+  UMODE_SERVNOTICE   = 0x00000001U,  /**< Server notices such as kill */
+  UMODE_CCONN        = 0x00000002U,  /**< Can see client connection notices */
+  UMODE_REJ          = 0x00000004U,  /**< Bot Rejections */
+  UMODE_SKILL        = 0x00000008U,  /**< Server Killed */
+  UMODE_FULL         = 0x00000010U,  /**< Full messages */
+  UMODE_SPY          = 0x00000020U,  /**< See STATS / LINKS */
+  UMODE_DEBUG        = 0x00000040U,  /**< 'debugging' info */
+  UMODE_NCHANGE      = 0x00000080U,  /**< Nick change notice */
+  UMODE_WALLOP       = 0x00000100U,  /**< Send wallops to them */
+  UMODE_INVISIBLE    = 0x00000200U,  /**< Makes user invisible */
+  UMODE_BOTS         = 0x00000400U,  /**< Shows bots */
+  UMODE_EXTERNAL     = 0x00000800U,  /**< Show servers introduced and splitting */
+  UMODE_CALLERID     = 0x00001000U,  /**< Block unless caller id's */
+  UMODE_SOFTCALLERID = 0x00002000U,  /**< Block unless on common channel */
+  UMODE_UNAUTH       = 0x00004000U,  /**< Show unauth connects here */
+  UMODE_LOCOPS       = 0x00008000U,  /**< Can see LOCOPS messages */
+  UMODE_DEAF         = 0x00010000U,  /**< Don't receive channel messages */
+  UMODE_REGISTERED   = 0x00020000U,  /**< User has identified for that nick. */
+  UMODE_REGONLY      = 0x00040000U,  /**< Only registered nicks may PM */
+  UMODE_HIDDEN       = 0x00080000U,  /**< IRC operator status is hidden */
+  UMODE_OPER         = 0x00100000U,  /**< IRC operator */
+  UMODE_ADMIN        = 0x00200000U,  /**< Admin on server */
+  UMODE_FARCONNECT   = 0x00400000U,  /**< Can see remote client connects/exits */
+  UMODE_HIDDENHOST   = 0x00800000U,  /**< User's host is hidden */
+  UMODE_SSL          = 0x01000000U,  /**< User is connected via TLS/SSL */
+  UMODE_WEBIRC       = 0x02000000U,  /**< User connected via a webirc gateway */
+  UMODE_HIDEIDLE     = 0x04000000U,  /**< Hides idle and signon time in WHOIS */
+  UMODE_HIDECHANS    = 0x08000000U   /**< Hides channel list in WHOIS */
+};
 
 #define HasUMode(x, y) ((x)->umodes &   (y))
 #define AddUMode(x, y) ((x)->umodes |=  (y))
 #define DelUMode(x, y) ((x)->umodes &= ~(y))
 
 
-/* oper priv flags */
-#define OPER_FLAG_KILL_REMOTE    0x00000001U  /**< Oper can KILL remote users */
-#define OPER_FLAG_KILL           0x00000002U  /**< Oper can KILL local users */
-#define OPER_FLAG_UNKLINE        0x00000004U  /**< Oper can use UNKLINE command */
-#define OPER_FLAG_GLINE          0x00000008U  /**< Oper can use GLINE command */
-#define OPER_FLAG_KLINE          0x00000010U  /**< Oper can use KLINE command */
-#define OPER_FLAG_XLINE          0x00000020U  /**< Oper can use XLINE command */
-#define OPER_FLAG_DIE            0x00000040U  /**< Oper can use DIE command */
-#define OPER_FLAG_REHASH         0x00000080U  /**< Oper can use REHASH command */
-#define OPER_FLAG_ADMIN          0x00000100U  /**< Oper can set user mode +a */
-#define OPER_FLAG_REMOTEBAN      0x00000200U  /**< Oper can set remote bans */
-#define OPER_FLAG_GLOBOPS        0x00000400U  /**< Oper can use GLOBOPS command */
-#define OPER_FLAG_MODULE         0x00000800U  /**< Oper can use MODULE command */
-#define OPER_FLAG_RESTART        0x00001000U  /**< Oper can use RESTART command */
-#define OPER_FLAG_DLINE          0x00002000U  /**< Oper can use DLINE command */
-#define OPER_FLAG_UNDLINE        0x00004000U  /**< Oper can use UNDLINE command */
-#define OPER_FLAG_SET            0x00008000U  /**< Oper can use SET command */
-#define OPER_FLAG_SQUIT          0x00010000U  /**< Oper can do local SQUIT */
-#define OPER_FLAG_SQUIT_REMOTE   0x00020000U  /**< Oper can do remote SQUIT */
-#define OPER_FLAG_CONNECT        0x00040000U  /**< Oper can do local CONNECT */
-#define OPER_FLAG_CONNECT_REMOTE 0x00080000U  /**< Oper can do remote CONNECT */
-#define OPER_FLAG_WALLOPS        0x00100000U  /**< Oper can use WALLOPS command */
-#define OPER_FLAG_LOCOPS         0x00200000U  /**< Oper can use LOCOPS command */
-#define OPER_FLAG_UNXLINE        0x00400000U  /**< Oper can use UNXLINE command */
-#define OPER_FLAG_OPME           0x00800000U  /**< Oper can use OPME command */
+/** irc-operator privilege flags */
+enum
+{
+  OPER_FLAG_ADMIN          = 0x00000001U,  /**< Oper can set user mode +a */
+  OPER_FLAG_CLOSE          = 0x00000002U,  /**< Oper can use CLOSE command */
+  OPER_FLAG_CONNECT        = 0x00000004U,  /**< Oper can do local CONNECT */
+  OPER_FLAG_CONNECT_REMOTE = 0x00000008U,  /**< Oper can do remote CONNECT */
+  OPER_FLAG_DIE            = 0x00000010U,  /**< Oper can use DIE command */
+  OPER_FLAG_DLINE          = 0x00000020U,  /**< Oper can use DLINE command */
+  OPER_FLAG_GLOBOPS        = 0x00000040U,  /**< Oper can use GLOBOPS command */
+  OPER_FLAG_JOIN_RESV      = 0x00000080U,  /**< Oper can use JOIN on resv {} channels */
+  OPER_FLAG_KILL           = 0x00000100U,  /**< Oper can KILL local users */
+  OPER_FLAG_KILL_REMOTE    = 0x00000200U,  /**< Oper can KILL remote users */
+  OPER_FLAG_KLINE          = 0x00000400U,  /**< Oper can use KLINE command */
+  OPER_FLAG_LOCOPS         = 0x00000800U,  /**< Oper can use LOCOPS command */
+  OPER_FLAG_MODULE         = 0x00001000U,  /**< Oper can use MODULE command */
+  OPER_FLAG_NICK_RESV      = 0x00002000U,  /**< Oper can use NICK on resv {} nicks */
+  OPER_FLAG_OPME           = 0x00004000U,  /**< Oper can use OPME command */
+  OPER_FLAG_REHASH         = 0x00008000U,  /**< Oper can use REHASH command */
+  OPER_FLAG_REMOTEBAN      = 0x00010000U,  /**< Oper can set remote bans */
+  OPER_FLAG_RESTART        = 0x00020000U,  /**< Oper can use RESTART command */
+  OPER_FLAG_RESV           = 0x00040000U,  /**< Oper can use RESV command */
+  OPER_FLAG_SET            = 0x00080000U,  /**< Oper can use SET command */
+  OPER_FLAG_SQUIT          = 0x00100000U,  /**< Oper can do local SQUIT */
+  OPER_FLAG_SQUIT_REMOTE   = 0x00200000U,  /**< Oper can do remote SQUIT */
+  OPER_FLAG_UNDLINE        = 0x00400000U,  /**< Oper can use UNDLINE command */
+  OPER_FLAG_UNKLINE        = 0x00800000U,  /**< Oper can use UNKLINE command */
+  OPER_FLAG_UNRESV         = 0x01000000U,  /**< Oper can use UNRESV command */
+  OPER_FLAG_UNXLINE        = 0x02000000U,  /**< Oper can use UNXLINE command */
+  OPER_FLAG_WALLOPS        = 0x04000000U,  /**< Oper can use WALLOPS command */
+  OPER_FLAG_XLINE          = 0x08000000U   /**< Oper can use XLINE command */
+};
 
-
-#define HasOFlag(x, y) (MyConnect(x) ? (x)->connection->operflags & (y) : 0)
+#define HasOFlag(x, y) ((x)->connection->operflags &   (y))
 #define AddOFlag(x, y) ((x)->connection->operflags |=  (y))
 #define DelOFlag(x, y) ((x)->connection->operflags &= ~(y))
 #define ClrOFlag(x)    ((x)->connection->operflags = 0)
@@ -206,53 +227,20 @@ struct MaskItem;
 
 
 /* flags macros. */
-#define IsAuthFinished(x)       ((x)->flags & FLAGS_FINISHED_AUTH)
 #define IsDead(x)               ((x)->flags & FLAGS_DEADSOCKET)
 #define SetDead(x)              ((x)->flags |= FLAGS_DEADSOCKET)
-#define IsClosing(x)            ((x)->flags & FLAGS_CLOSING)
-#define SetClosing(x)           ((x)->flags |= FLAGS_CLOSING)
-#define SetCanFlood(x)          ((x)->flags |= FLAGS_CANFLOOD)
-#define IsCanFlood(x)           ((x)->flags & FLAGS_CANFLOOD)
 #define IsDefunct(x)            ((x)->flags & (FLAGS_DEADSOCKET|FLAGS_CLOSING|FLAGS_KILLED))
 
 /* oper flags */
-#define MyOper(x)               (MyConnect(x) && HasUMode(x, UMODE_OPER))
-
 #define SetOper(x)              {(x)->umodes |= UMODE_OPER; \
-                                 if (!IsServer((x))) (x)->handler = OPER_HANDLER;}
+                                 if (MyClient((x))) (x)->handler = OPER_HANDLER;}
 
 #define ClearOper(x)            {(x)->umodes &= ~(UMODE_OPER|UMODE_ADMIN); \
-                                 if (!HasUMode(x, UMODE_OPER) && !IsServer((x))) \
+                                 if (MyClient((x))) \
                                   (x)->handler = CLIENT_HANDLER; }
 
-#define SetSendQExceeded(x)     ((x)->flags |= FLAGS_SENDQEX)
-#define IsSendQExceeded(x)      ((x)->flags &  FLAGS_SENDQEX)
-
-#define SetUserHost(x)          ((x)->flags |= FLAGS_USERHOST)
-#define IsUserHostIp(x)         ((x)->flags & FLAGS_USERHOST)
-
-#define SetPingSent(x)          ((x)->flags |= FLAGS_PINGSENT)
-#define IsPingSent(x)           ((x)->flags & FLAGS_PINGSENT)
-#define ClearPingSent(x)        ((x)->flags &= ~FLAGS_PINGSENT)
-
-#define SetGotId(x)             ((x)->flags |= FLAGS_GOTID)
-#define IsGotId(x)              ((x)->flags & FLAGS_GOTID)
-
-#define IsExemptKline(x)        ((x)->flags & FLAGS_EXEMPTKLINE)
-#define SetExemptKline(x)       ((x)->flags |= FLAGS_EXEMPTKLINE)
-#define IsExemptLimits(x)       ((x)->flags & FLAGS_NOLIMIT)
-#define SetExemptLimits(x)      ((x)->flags |= FLAGS_NOLIMIT)
-#define IsExemptGline(x)        ((x)->flags & FLAGS_EXEMPTGLINE)
-#define SetExemptGline(x)       ((x)->flags |= FLAGS_EXEMPTGLINE)
-#define IsExemptResv(x)         ((x)->flags & FLAGS_EXEMPTRESV)
-#define SetExemptResv(x)        ((x)->flags |= FLAGS_EXEMPTRESV)
-
 #define IsFloodDone(x)          ((x)->flags &  FLAGS_FLOODDONE)
-#define SetFloodDone(x)         ((x)->flags |= FLAGS_FLOODDONE)
-#define HasPingCookie(x)        ((x)->flags & FLAGS_PING_COOKIE)
-#define SetPingCookie(x)        ((x)->flags |= FLAGS_PING_COOKIE)
 #define IsHidden(x)             ((x)->flags &  FLAGS_HIDDEN)
-#define SetHidden(x)            ((x)->flags |= FLAGS_HIDDEN)
 
 
 /*! \brief addr_mask_type enumeration */
@@ -282,6 +270,7 @@ struct Server
 /*! \brief ListTask structure */
 struct ListTask
 {
+  dlink_node node;  /**< Embedded list node used to link into listing_client_list */
   dlink_list show_mask; /**< Channels to show */
   dlink_list hide_mask; /**< Channels to hide */
 
@@ -312,9 +301,9 @@ struct Connection
   unsigned int operflags;     /**< IRC Operator privilege flags */
   unsigned int random_ping; /**< Holding a 32bit value used for PING cookies */
 
-  uint64_t serial;     /**< Used to enforce 1 send per nick */
+  uintmax_t serial;     /**< Used to enforce 1 send per nick */
 
-  time_t       lasttime;   /**< ...should be only LOCAL clients? --msa */
+  time_t       lasttime;   /**< Last time data read from socket */
   time_t       firsttime;  /**< Time client was created */
   time_t       since;      /**< Last time we parsed something */
   time_t       last_join_time;   /**< When this client last joined a channel */
@@ -337,7 +326,7 @@ struct Connection
   struct
   {
     unsigned int messages;      /**< Statistics: protocol messages sent/received */
-    uint64_t bytes;             /**< Statistics: total bytes sent/received */
+    uintmax_t bytes;             /**< Statistics: total bytes sent/received */
   } recv, send;
 
   struct
@@ -367,8 +356,6 @@ struct Connection
   int sent_parsed;      /**< How many messages we've parsed in this second */
 
   char *password;  /**< Password supplied by the client/server */
-  char *challenge_response;  /**< Expected CHALLENGE response from client */
-  char *challenge_operator;  /**< Operator to become if they supply the response */
 };
 
 /*! \brief Client structure */
@@ -377,7 +364,7 @@ struct Client
   dlink_node node;
   dlink_node lnode;             /**< Used for Server->servers/users */
 
-  struct Connection *connection;
+  struct Connection *connection;  /**< Connection structure associated with this client */
   struct Client    *hnext;      /**< For client hash table lookups by name */
   struct Client    *idhnext;    /**< For SID hash table lookups by sid */
   struct Server    *serv;       /**< ...defined, if this is a server */
@@ -387,7 +374,7 @@ struct Client
   time_t            tsinfo;     /**< TS on the nick, SVINFO on server */
 
   unsigned int      flags;      /**< Client flags */
-  unsigned int      umodes;     /**< Opers, normal users subset */
+  unsigned int      umodes;     /**< User modes this client has set */
   unsigned int      hopcount;   /**< Number of servers to this 0 = local */
   unsigned int      status;     /**< Client type */
   unsigned int      handler;    /**< Handler index */
@@ -431,7 +418,7 @@ struct Client
    */
   char              sockhost[HOSTIPLEN + 1]; /* This is the host name from the
                                                 socket ip address as string */
-  char             *certfp;
+  char             *certfp;  /**< SSL certificate fingerprint */
 };
 
 
