@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,17 +21,17 @@
 
 /*! \file dbuf.h
  * \brief A header for the dynamic buffers functions.
- * \version $Id: dbuf.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: dbuf.h 7007 2016-01-01 00:09:08Z michael $
  */
 
-#ifndef __DBUF_H_INCLUDED
-#define __DBUF_H_INCLUDED
-
-#define DBUF_BLOCK_SIZE 1024
+#ifndef INCLUDED_dbuf_h
+#define INCLUDED_dbuf_h
 
 #define dbuf_length(x) ((x)->total_size)
 #define dbuf_clear(x) dbuf_delete(x, dbuf_length(x))
 
+enum { DBUF_BLOCK_SIZE = 1024 };
+
 struct dbuf_block
 {
   int refs;
