@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file defaults.h
  * \brief The ircd defaults header for values and paths.
- * \version $Id: defaults.h 5645 2015-03-06 17:09:33Z michael $
+ * \version $Id: defaults.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_defaults_h
@@ -55,21 +55,20 @@
 #define HPATH        DATADIR "/" PACKAGE "/help"
 #define AUTOMODPATH  MODPATH "/autoload/"
 #define ETCPATH      SYSCONFDIR
+#define LIBPATH      LOCALSTATEDIR "/lib"
 #define LOGPATH      LOCALSTATEDIR "/log"
 #define RUNPATH      LOCALSTATEDIR "/run"
 
 /* files */
 #define SPATH     BINPATH "/ircd"  /* ircd executable */
 #define CPATH     ETCPATH "/ircd.conf"  /* ircd.conf file */
-#define KPATH     ETCPATH "/kline.db"  /* kline file */
-#define RESVPATH  ETCPATH "/resv.db"  /* resv file */
-#define DLPATH    ETCPATH "/dline.db"  /* dline file */
-#define XPATH     ETCPATH "/xline.db"  /* xline file */
-#define GPATH     ETCPATH "/gline.db"  /* gline file */
+#define KPATH     LIBPATH "/kline.db"  /* kline file */
+#define RESVPATH  LIBPATH "/resv.db"  /* resv file */
+#define DLPATH    LIBPATH "/dline.db"  /* dline file */
+#define XPATH     LIBPATH "/xline.db"  /* xline file */
 #define MPATH     ETCPATH "/ircd.motd"  /* MOTD file */
 #define LPATH     LOGPATH "/ircd.log"  /* ircd logfile */
 #define PPATH     RUNPATH "/ircd.pid"  /* pid file */
-#define LIPATH    ETCPATH "/links.txt"  /* cached links file */
 
 /*
  * This file is included to supply default values for things which
@@ -98,19 +97,10 @@
 #define CLIENT_FLOOD_MAX     8000
 #define CLIENT_FLOOD_MIN     512
 
-#define WATCHSIZE_MIN 1
-#define WATCHSIZE_DEFAULT 32
-#define TS_MAX_DELTA_MIN      1         /* min value for ts_max_delta */
-#define TS_MAX_DELTA_DEFAULT  600       /* default for ts_max_delta */
-#define TS_WARN_DELTA_MIN     1         /* min value for ts_warn_delta */
-#define TS_WARN_DELTA_DEFAULT 30        /* default for ts_warn_delta */
-
 /* ConfigServerInfo default values */
 #define NETWORK_NAME_DEFAULT "EFnet"             /* default for network_name */
 #define NETWORK_DESC_DEFAULT "Eris Free Network" /* default for network_desc */
 
-#define GLINE_REQUEST_EXPIRE_DEFAULT 600
-
 /* General defaults */
 #define MAXIMUM_LINKS_DEFAULT 0         /* default for maximum_links */
 
