@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2015 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file event.h
  * \brief Timer based event execution
- * \version $Id: event.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: event.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_event_h
@@ -29,9 +29,6 @@
 
 #include "list.h"
 
-struct Client;
-struct event;
-
 struct event
 {
   /* public */
@@ -43,14 +40,14 @@ struct event
   /* private */
   time_t next;
   void *data;
-  unsigned int enabled;
+  unsigned int active;
   dlink_node node;
 };
 
+extern const dlink_list *event_get_list(void);
 extern void event_add(struct event *, void *);
 extern void event_addish(struct event *, void *);
 extern void event_delete(struct event *);
 extern void event_run(void);
-extern void set_back_events(time_t);
-extern void show_events(struct Client *);
+extern void event_set_back_events(time_t);
 #endif /* INCLUDED_event_h */
