@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file fdlist.h
  * \brief The file descriptor list header.
- * \version $Id: fdlist.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: fdlist.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_fdlist_h
@@ -29,7 +29,10 @@
 #define FILEIO_V2
 
 #include "ircd_defs.h"
-#define FD_DESC_SZ 128  /* hostlen + comment */
+
+
+enum { FD_DESC_SIZE = 128 };  /* hostlen + comment */
+enum { FD_HASH_SIZE = 1024 };
 
 enum
 {
@@ -55,7 +58,7 @@ typedef struct _fde
   int fd;  /* So we can use the fde_t as a callback ptr */
   int comm_index;  /* where in the poll list we live */
   int evcache;          /* current fd events as set up by the underlying I/O */
-  char desc[FD_DESC_SZ];
+  char desc[FD_DESC_SIZE];
   void (*read_handler)(struct _fde *, void *);
   void *read_data;
   void (*write_handler)(struct _fde *, void *);
@@ -88,8 +91,6 @@ typedef struct _fde
   struct _fde *hnext;
 } fde_t;
 
-#define FD_HASH_SIZE 1024
-
 extern int number_fd;
 extern int hard_fdlimit;
 extern fde_t *fd_hash[];
