@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2015 ircd-hybrid development team
+ *  Copyright (c) 2001-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,14 +21,13 @@
 
 /*! \file hostmask.h
  * \brief A header for the hostmask code.
- * \version $Id: hostmask.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: hostmask.h 7007 2016-01-01 00:09:08Z michael $
  */
 
-#ifndef INCLUDE_hostmask_h
-#define INCLUDE_hostmask_h
-
-#define ATABLE_SIZE 0x1000
+#ifndef INCLUDED_hostmask_h
+#define INCLUDED_hostmask_h
 
+enum { ATABLE_SIZE = 0x1000 };
 
 enum hostmask_type
 {
@@ -78,9 +77,9 @@ extern void delete_one_address_conf(const char *, struct MaskItem *);
 extern void clear_out_address_conf(void);
 extern void hostmask_expire_temporary(void);
 
-extern struct MaskItem *find_address_conf(const char *, const char *,
-                                          struct irc_ssaddr *, int, const char *);
-extern struct MaskItem *find_dline_conf(struct irc_ssaddr *, int);
-extern struct MaskItem *find_conf_by_address(const char *, struct irc_ssaddr *,
+extern struct MaskItem *find_address_conf(const char *, const char *, const struct irc_ssaddr *,
+                                          int, const char *);
+extern struct MaskItem *find_dline_conf(const struct irc_ssaddr *, int);
+extern struct MaskItem *find_conf_by_address(const char *, const struct irc_ssaddr *,
                                              unsigned int, int, const char *, const char *, int);
-#endif /* INCLUDE_hostmask_h */
+#endif /* INCLUDED_hostmask_h */
