@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ipcache.h
  * \brief Routines to count connections from particular IP addresses.
- * \version $Id: ipcache.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: ipcache.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_ipcache_h
@@ -33,7 +33,7 @@
  * but in this case I am dealing with ip addresses,
  * not ascii strings.
  */
-#define IP_HASH_SIZE 0x1000
+enum { IP_HASH_SIZE = 0x1000 };
 
 struct ip_entry
 {
@@ -44,8 +44,8 @@ struct ip_entry
   time_t last_attempt;            /**< The last time someone connected from this IP */
 };
 
-extern struct ip_entry *ipcache_find_or_add_address(struct irc_ssaddr *);
-extern void ipcache_remove_address(struct irc_ssaddr *);
-extern void ipcache_get_stats(unsigned int *const, uint64_t *const);
+extern struct ip_entry *ipcache_find_or_add_address(const struct irc_ssaddr *);
+extern void ipcache_remove_address(const struct irc_ssaddr *);
+extern void ipcache_get_stats(unsigned int *const, size_t *const);
 extern void ipcache_init(void);
 #endif
