@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2015 ircd-hybrid development team
+ *  Copyright (c) 1999-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file irc_string.h
  * \brief A header for the ircd string functions.
- * \version $Id: irc_string.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: irc_string.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_irc_string_h
@@ -75,7 +75,7 @@ extern void strip_tabs(char *, const char *, size_t);
 #define EmptyString(x) (!(x) || (*(x) == '\0'))
 
 #ifndef HAVE_STRTOK_R
-extern char *strtoken(char **, char *, const char *);
+extern char *strtok_r(char *, const char *, char **);
 #endif
 
 /*
