@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.h
  * \brief A header for the ircd startup routines.
- * \version $Id: ircd.h 5613 2015-02-24 19:41:11Z michael $
+ * \version $Id: ircd.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 
@@ -49,10 +49,10 @@ struct SetOptions
  */
 struct ServerStatistics
 {
-  uint64_t        is_cbs;  /* bytes sent to clients */
-  uint64_t        is_cbr;  /* bytes received from clients */
-  uint64_t        is_sbs;  /* bytes sent to servers */
-  uint64_t        is_sbr;  /* bytes received from servers */
+  uintmax_t        is_cbs;  /* bytes sent to clients */
+  uintmax_t        is_cbr;  /* bytes received from clients */
+  uintmax_t        is_sbs;  /* bytes sent to servers */
+  uintmax_t        is_sbr;  /* bytes received from servers */
 
   time_t          is_cti;  /* time spent connected by clients */
   time_t          is_sti;  /* time spent connected by servers */
@@ -74,7 +74,7 @@ struct ServerStatistics
 
 struct Counter
 {
-  uint64_t totalrestartcount; /* Total client count ever */
+  uintmax_t totalrestartcount; /* Total client count ever */
   unsigned int myserver;      /* my servers          */
   unsigned int oper;          /* Opers               */
   unsigned int local;         /* Local Clients       */
@@ -110,11 +110,6 @@ extern struct ServerState_t server_state;
 extern struct event event_write_links_file;
 extern struct timeval SystemTime;
 #define CurrentTime SystemTime.tv_sec
-extern unsigned int default_server_capabs;
-extern unsigned int splitmode;
-extern unsigned int splitchecking;
-extern unsigned int split_users;
-extern unsigned int split_servers;
 
 extern void set_time(void);
 #endif
