@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd_defs.h
  * \brief A header for ircd global definitions.
- * \version $Id: ircd_defs.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: ircd_defs.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 /* ircd_defs.h - Global size definitions for record entries used
@@ -36,9 +36,13 @@
 #define IRCD_BUFSIZE    512     /* WARNING: *DONT* CHANGE THIS!!!!         */
 #define HOSTLEN          63     /* Length of hostname. Updated to comply
                                    with RFC 1123 */
+/*
+ * NICKLEN: do not change this; if you want to change the maximum
+ * allowed nickname length, you can do this in the ircd.conf
+ */
 #define NICKLEN         30
 #define USERLEN         10
-#define SVIDLEN         30
+#define ACCOUNTLEN      NICKLEN
 #define PORTNAMELEN 6  /* ":31337" */
 
 #define HOSTIPLEN       45 /* sizeof("ffff:ffff:ffff:ffff:ffff:ffff:255.255.255.255") */
@@ -48,17 +52,13 @@
 #define REALLEN         50
 #define CHANNELLEN      50
 #define TOPICLEN        300
-#define KILLLEN         180
-#define REASONLEN       180
+#define KILLLEN         240
+#define REASONLEN       240
 #define KICKLEN         180
 #define AWAYLEN         180
 #define KEYLEN          23
 
-#define USERHOST_REPLYLEN       (NICKLEN+HOSTLEN+USERLEN+5)
 #define MAX_DATE_STRING 32      /* maximum string length for a date string */
-#define IRCD_MAXNS      3       /* Maximum number of nameservers in
-                                   /etc/resolv.conf we care about */
-
 #define LOWEST_SAFE_FD  4  /* skip stdin, stdout, stderr, and profiler */
 
 /* This is to get around the fact that some implementations have ss_len and
