@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,13 +21,13 @@
 
 /*! \file log.h
  * \brief A header for the logger functions.
- * \version $Id: log.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: log.h 7007 2016-01-01 00:09:08Z michael $
  */
 
-#ifndef INCLUDED_s_log_h
-#define INCLUDED_s_log_h
+#ifndef INCLUDED_log_h
+#define INCLUDED_log_h
 
-#define LOG_BUFSIZE 1024
+enum { LOG_BUFSIZE = 1024 };
 
 enum log_type
 {
@@ -35,7 +35,6 @@ enum log_type
   LOG_TYPE_KILL,
   LOG_TYPE_KLINE,
   LOG_TYPE_DLINE,
-  LOG_TYPE_GLINE,
   LOG_TYPE_XLINE,
   LOG_TYPE_RESV,
   LOG_TYPE_OPER,
