@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,18 +21,16 @@
 
 /*! \file memory.h
  * \brief A header for the memory functions.
- * \version $Id: memory.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: memory.h 7033 2016-01-03 14:37:29Z michael $
  */
 
-#ifndef _I_MEMORY_H
-#define _I_MEMORY_H
-
-#include "ircd_defs.h"
+#ifndef INCLUDED_memory_h
+#define INCLUDED_memory_h
 
 extern void outofmemory(void);
-extern void *MyCalloc(size_t);
-extern void *MyRealloc(void *, size_t);
-extern void MyFree(void *);
+extern void *xcalloc(size_t);
+extern void *xrealloc(void *, size_t);
+extern void xfree(void *);
 extern void *xstrdup(const char *);
 extern void *xstrndup(const char *, size_t);
-#endif /* _I_MEMORY_H */
+#endif /* INCLUDED_memory_h */
