@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007-2012, The Tor Project, Inc.
- * Copyright (c) 2012-2015 ircd-hybrid development team
+ * Copyright (c) 2012-2016 ircd-hybrid development team
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -33,11 +33,11 @@
 
 /*! \file mempool.h
  * \brief Pooling allocator
- * \version $Id: mempool.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: mempool.h 7007 2016-01-01 00:09:08Z michael $
  */
 
-#ifndef TOR_MEMPOOL_H
-#define TOR_MEMPOOL_H
+#ifndef INCLUDED_mempool_h
+#define INCLUDED_mempool_h
 
 /** A memory pool is a context in which a large number of fixed-sized
 * objects can be allocated efficiently.  See mempool.c for implementation
