@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,15 +21,16 @@
 
 /*! \file misc.h
  * \brief A header for the miscellaneous functions.
- * \version $Id: misc.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: misc.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_misc_h
 #define INCLUDED_misc_h
 
 extern const char *date(time_t);
-extern const char *smalldate(time_t);
-extern const char *myctime(time_t);
+extern const char *date_iso8601(time_t);
+extern const char *date_ctime(time_t);
+extern const char *time_dissect(time_t);
 #ifdef HAVE_LIBCRYPTO
 extern const char *ssl_get_cipher(const SSL *);
 #endif
