@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file numeric.h
  * \brief Declarations of numeric replies.
- * \version $Id: numeric.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: numeric.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_numeric_h
@@ -47,7 +47,6 @@ enum irc_numerics
   RPL_MAP                  = 15,
   RPL_MAPMORE              = 16,
   RPL_MAPEND               = 17,
-  RPL_YOURID               = 42,
 
   /*
    * Numeric replies from server commands.
@@ -158,7 +157,6 @@ enum irc_numerics
   RPL_WHOISMODES           = 379,
   RPL_YOUREOPER            = 381,
   RPL_REHASHING            = 382,
-  RPL_RSACHALLENGE         = 386,
   RPL_TIME                 = 391,
   RPL_VISIBLEHOST          = 396,
 
@@ -188,7 +186,6 @@ enum irc_numerics
   ERR_ERRONEUSNICKNAME     = 432,
   ERR_NICKNAMEINUSE        = 433,
   ERR_NICKCOLLISION        = 436,
-  ERR_UNAVAILRESOURCE      = 437,
   ERR_NICKTOOFAST          = 438,
   ERR_SERVICESDOWN         = 440,
   ERR_USERNOTINCHANNEL     = 441,
@@ -203,7 +200,6 @@ enum irc_numerics
   ERR_PASSWDMISMATCH       = 464,
   ERR_YOUREBANNEDCREEP     = 465,
   ERR_ONLYSERVERSCANCHANGE = 468,
-  ERR_OPERONLYCHAN         = 470,
   ERR_CHANNELISFULL        = 471,
   ERR_UNKNOWNMODE          = 472,
   ERR_INVITEONLYCHAN       = 473,
@@ -212,20 +208,20 @@ enum irc_numerics
   ERR_NEEDREGGEDNICK       = 477,
   ERR_BANLISTFULL          = 478,
   ERR_BADCHANNAME          = 479,
-  ERR_SSLONLYCHAN          = 480,
   ERR_NOPRIVILEGES         = 481,
   ERR_CHANOPRIVSNEEDED     = 482,
   ERR_CANTKILLSERVER       = 483,
-  ERR_RESTRICTED           = 484,
   ERR_CHANBANREASON        = 485,
   ERR_NONONREG             = 486,
+  ERR_SSLONLYCHAN          = 489,
   ERR_NOOPERHOST           = 491,
+  ERR_NOCTCP               = 492,
   ERR_UMODEUNKNOWNFLAG     = 501,
   ERR_USERSDONTMATCH       = 502,
-  ERR_GHOSTEDCLIENT        = 503,
   ERR_USERNOTONSERV        = 504,
   ERR_TOOMANYWATCH         = 512,
   ERR_WRONGPONG            = 513,
+  ERR_OPERONLYCHAN         = 520,
   ERR_LISTSYNTAX           = 521,
   ERR_WHOLIMEXCEED         = 523,
   ERR_HELPNOTFOUND         = 524,
