@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file packet.h
  * \brief A header for the packet functions.
- * \version $Id: packet.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: packet.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_packet_h
@@ -45,8 +45,11 @@
  * just connected.  this allows clients to rejoin multiple channels
  * without being so heavily penalised they excess flood.
  */
-#define MAX_FLOOD 5
-#define MAX_FLOOD_BURST MAX_FLOOD * 8
+enum
+{
+  MAX_FLOOD = 5,
+  MAX_FLOOD_BURST = MAX_FLOOD * 8
+};
 
 extern void read_packet(fde_t *, void *);
 extern void flood_recalc(fde_t *, void *);
