@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file parse.h
  * \brief A header for the message parser.
- * \version $Id: parse.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: parse.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_parse_h
@@ -62,12 +62,9 @@ typedef enum HandlerType
   SERVER_HANDLER,
   ENCAP_HANDLER,
   OPER_HANDLER,
-  DUMMY_HANDLER,
   LAST_HANDLER_TYPE
 } HandlerType;
 
-typedef int (*MessageHandler)(struct Client *, int, char *[]);
-
 /*
  * Message table structure
  */
@@ -82,25 +79,19 @@ struct Message
                              * before the m_func is even called
                              */
   unsigned int args_max;    /* maximum permitted parameters */
-  unsigned int flags;      /* bit 0 set means that this command is allowed
-                             * to be used only on the average of once per 2
-                             * seconds -SRB
-                             */
-  uint64_t bytes;  /* bytes received for this message */
+  unsigned int flags;
+  uintmax_t bytes;  /* bytes received for this message */
 
   /* handlers:
-   * UNREGISTERED, CLIENT, SERVER, ENCAP, OPER, DUMMY, LAST
+   * UNREGISTERED, CLIENT, SERVER, ENCAP, OPER, LAST
    */
-  MessageHandler handlers[LAST_HANDLER_TYPE];
+  int (*handlers[LAST_HANDLER_TYPE])(struct Client *, int, char *[]);
 };
 
 /*
  * Constants
  */
-#define   MFLG_SLOW             0x001   /* Command can be executed roughly
-                                         * once per 2 seconds.
-                                         */
-#define MFLG_EXTRA 0x002
+#define MFLG_EXTRA 0x00000001U
 #define MAXPARA    15
 
 extern void parse(struct Client *, char *, char *);
