@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,17 +21,14 @@
 
 /*! \file res.h
  * \brief ircd resolver functions
- * \version $Id: res.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: res.h 7007 2016-01-01 00:09:08Z michael $
  */
 
-#ifndef INCLUDED_irc_res_h
-#define INCLUDED_irc_res_h
+#ifndef INCLUDED_res_h
+#define INCLUDED_res_h
 
 #include "config.h"
 
-struct Client; /* XXX */
-
-
 /*
  * From RFC 1035:
  *
@@ -118,7 +115,6 @@ typedef void (*dns_callback_fnc)(void *, const struct irc_ssaddr *, const char *
 extern void init_resolver(void);
 extern void restart_resolver(void);
 extern void delete_resolver_queries(const void *);
-extern void report_dns_servers(struct Client *);
 extern void gethost_byname_type(dns_callback_fnc , void *, const char *, int);
 extern void gethost_byaddr(dns_callback_fnc, void *, const struct irc_ssaddr *);
 #endif
