@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,11 +21,17 @@
 
 /*! \file restart.h
  * \brief A header for the restart/die functions.
- * \version $Id: restart.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: restart.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_restart_h
 #define INCLUDED_restart_h
 
+enum
+{
+  SERVER_SHUTDOWN,
+  SERVER_RESTART
+};
+
 extern void server_die(const char *, int);
 #endif
