@@ -40,12 +40,12 @@
    http://www.math.sci.hiroshima-u.ac.jp/~m-mat/MT/emt.html
    email: m-mat @ math.sci.hiroshima-u.ac.jp (remove space)
 
-   $Id: rng_mt.h 1662 2012-11-17 20:11:33Z michael $
+   $Id: rng_mt.h 6364 2015-08-19 09:59:43Z michael $
 */
 
 
-#ifndef __include_rng_mt_header__
-#define __include_rng_mt_header__
+#ifndef INCLUDED_rng_mt_h
+#define INCLUDED_rng_mt_h
 
 extern void init_genrand(uint32_t);
 extern void init_by_array(uint32_t[], int);
