@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2015 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file rsa.h
  * \brief A header for the RSA functions.
- * \version $Id: rsa.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: rsa.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_rsa_h
@@ -32,8 +32,5 @@
 #ifdef HAVE_LIBCRYPTO
 extern void binary_to_hex(const unsigned char *, char *, unsigned int);
 extern void report_crypto_errors(void);
-extern int generate_challenge(char **, char **, RSA *);
-extern int get_randomness(unsigned char *, int);
 #endif
 #endif /* INCLUDED_rsa_h */
-
