@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd.h
  * \brief A header for the network subsystem.
- * \version $Id: s_bsd.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: s_bsd.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_s_bsd_h
@@ -31,14 +31,16 @@
 #include "fdlist.h"
 
 /* Type of IO */
-#define COMM_SELECT_READ  1
-#define COMM_SELECT_WRITE 2
+enum
+{
+  COMM_SELECT_READ  = 1,
+  COMM_SELECT_WRITE = 2
+};
 
 /* How long can comm_select() wait for network events [milliseconds] */
-#define SELECT_DELAY    500
+enum { SELECT_DELAY = 500 };
 
 struct Client;
-struct MaskItem;
 struct Listener;
 
 extern void add_connection(struct Listener *, struct irc_ssaddr *, int);
@@ -52,11 +54,10 @@ extern void comm_settimeout(fde_t *, time_t, void (*)(fde_t *, void *), void *);
 extern void comm_setflush(fde_t *, time_t, void (*)(fde_t *, void *), void *);
 extern void comm_checktimeouts(void *);
 extern void comm_connect_tcp(fde_t *, const char *, unsigned short, struct sockaddr *, int,
-                             void (struct _fde *, int, void *), void *, int, int);
-extern const char *comm_errstr(int status);
-extern int comm_open(fde_t *F, int family, int sock_type, int proto,
-                     const char *note);
-extern int comm_accept(struct Listener *, struct irc_ssaddr *pn);
+                             void (struct _fde *, int, void *), void *, int, time_t);
+extern const char *comm_errstr(int);
+extern int comm_open(fde_t *, int, int, int, const char *);
+extern int comm_accept(struct Listener *, struct irc_ssaddr *);
 
 /* These must be defined in the network IO loop code of your choice */
 extern void init_netio(void);
