@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.h
  * \brief A header for the message sending functions.
- * \version $Id: send.h 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: send.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_send_h
@@ -67,12 +67,10 @@ extern void sendto_one_notice(struct Client *, struct Client *, const char *, ..
 extern void sendto_channel_butone(struct Client *, struct Client *,
                                   struct Channel *, unsigned int,
                                   const char *, ...) AFP(5,6);
-extern void sendto_common_channels_local(struct Client *, int, unsigned int,
-                                         const char *, ...) AFP(4,5);
-extern void sendto_channel_local(unsigned int, struct Channel *,
-                                 const char *, ...) AFP(3,4);
-extern void sendto_channel_local_butone(struct Client *, unsigned int, unsigned int, struct Channel *,
-                                        const char *, ...) AFP(5,6);
+extern void sendto_common_channels_local(struct Client *, int, unsigned int, unsigned int,
+                                         const char *, ...) AFP(5,6);
+extern void sendto_channel_local(const struct Client *, struct Channel *, unsigned int,
+                                 unsigned int, unsigned int, const char *, ...)  AFP(6,7);
 extern void sendto_server(struct Client *,
                           const unsigned int,
                           const unsigned int, const char *, ...) AFP(4,5);
