@@ -1,5 +1,5 @@
 /*
- *  ircd-hybrid: an advanced Internet Relay Chat Daemon(ircd).
+ *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *  stdinc.h: Pull in all of the necessary system headers
  *
  *  Copyright (C) 2002 Aaron Sethman <androsyn@ratbox.org>
@@ -19,12 +19,12 @@
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  *  USA
  *
- * $Id: stdinc.h 4564 2014-08-24 10:24:47Z michael $
+ * $Id: stdinc.h 6952 2015-12-15 19:30:05Z michael $
  *
  */
 
-#ifndef STDINC_H /* prevent multiple #includes */
-#define STDINC_H
+#ifndef INCLUDED_stdinc_h /* prevent multiple #includes */
+#define INCLUDED_stdinc_h
 
 #include "config.h"
 
@@ -35,11 +35,6 @@
 #include <string.h>
 #include <stdint.h>
 #include <errno.h>
-
-#ifdef HAVE_STRTOK_R
-# define strtoken(x, y, z) strtok_r(y, z, x)
-#endif
-
 #include <sys/types.h>
 
 #ifdef HAVE_CRYPT_H
@@ -73,6 +68,7 @@
 #include <sys/file.h>
 
 #include <limits.h>
+#include <inttypes.h>
 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
