@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1997 Jukka Santala (Donwulff)
- *  Copyright (c) 2005-2014 ircd-hybrid development team
+ *  Copyright (c) 2005-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file watch.h
  * \brief Header including structures and prototypes for WATCH support
- * \version $Id: watch.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: watch.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_watch_h
@@ -42,8 +42,8 @@ struct Watch
 extern void watch_init(void);
 extern void watch_add_to_hash_table(const char *, struct Client *);
 extern void watch_del_from_hash_table(const char *, struct Client *);
-extern void watch_check_hash(struct Client *, const enum irc_numerics);
+extern void watch_check_hash(const struct Client *, const enum irc_numerics);
 extern void watch_del_watch_list(struct Client *);
-extern void watch_count_memory(unsigned int *const, uint64_t *const);
+extern void watch_count_memory(unsigned int *const, size_t *const);
 extern struct Watch *watch_find_hash(const char *);
 #endif
