@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file whowas.h
  * \brief A header for the whowas functions.
- * \version $Id: whowas.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: whowas.h 7007 2016-01-01 00:09:08Z michael $
  */
 
 #ifndef INCLUDED_whowas_h
@@ -32,14 +32,18 @@
 #include "config.h"
 
 
+enum { NICKNAMEHISTORYLENGTH = 32768 };
+
 struct Whowas
 {
   int hashv;
   int shide;
   time_t logoff;
+  char account[ACCOUNTLEN + 1];  /**< Services account */
   char name[NICKLEN + 1];
   char username[USERLEN + 1];
   char hostname[HOSTLEN + 1];
+  char sockhost[HOSTIPLEN + 1];  /**< This is the host name from the socket ip address as string */
   char realname[REALLEN + 1];
   char servername[HOSTLEN + 1];
   struct Client *online; /* Pointer to new nickname for chasing or NULL */
@@ -80,6 +84,6 @@ extern struct Client *whowas_get_history(const char *, time_t);
 /*
 ** for debugging...counts related structures stored in whowas array.
 */
-extern void whowas_count_memory(unsigned int *const, uint64_t *const);
+extern void whowas_count_memory(unsigned int *const, size_t *const);
 extern dlink_list WHOWASHASH[];
 #endif /* INCLUDED_whowas_h */
