@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_bmask.c
  * \brief Includes required functions for processing the BMASK command.
- * \version $Id: m_bmask.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_bmask.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -32,14 +32,10 @@
 #include "hash.h"
 #include "irc_string.h"
 #include "ircd.h"
-#include "numeric.h"
-#include "user.h"
 #include "conf.h"
-#include "server.h"
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
-#include "packet.h"
 
 
 /*! \brief BMASK command handler
@@ -72,7 +68,7 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   /* TS is higher, drop it. */
-  if (atol(parv[1]) > chptr->channelts)
+  if (strtoimax(parv[1], NULL, 10) > chptr->creationtime)
     return 0;
 
   switch (*parv[3])
@@ -95,7 +91,7 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
 
   mlen = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s +",
                   (IsHidden(source_p) || ConfigServerHide.hide_servers) ? me.name : source_p->name,
-                  chptr->chname);
+                  chptr->name);
   mbuf = modebuf + mlen;
   pbuf = parabuf;
 
@@ -111,13 +107,16 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
 
     if (tlen && *s != ':' && add_id(source_p, chptr, s, mode_type))
     {
+      /* add_id can modify 's' */
+      tlen = strlen(s);
+
       /* this new one wont fit.. */
       if (mbuf - modebuf + 2 + pbuf - parabuf + tlen > IRCD_BUFSIZE - 2 ||
           modecount >= MAXMODEPARAMS)
       {
         *mbuf = *(pbuf - 1) = '\0';
 
-        sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s", modebuf, parabuf);
+        sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
         mbuf = modebuf + mlen;
         pbuf = parabuf;
         modecount = 0;
@@ -134,19 +133,25 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
   if (modecount)
   {
     *mbuf = *(pbuf - 1) = '\0';
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s", modebuf, parabuf);
+    sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
   }
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s BMASK %lu %s %s :%s",
-                source_p->id, (unsigned long)chptr->channelts, chptr->chname,
+  sendto_server(source_p, 0, 0, ":%s BMASK %ju %s %s :%s",
+                source_p->id, chptr->creationtime, chptr->name,
                 parv[3], parv[4]);
   return 0;
 }
 
 static struct Message bmask_msgtab =
 {
-  "BMASK", NULL, 0, 0, 5, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_bmask, m_ignore, m_ignore, m_ignore }
+  .cmd = "BMASK",
+  .args_min = 5,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_bmask,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -163,10 +168,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
