@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_die.c
  * \brief Includes required functions for processing the DIE command.
- * \version $Id: m_die.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_die.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -33,7 +33,6 @@
 #include "parse.h"
 #include "modules.h"
 #include "restart.h"
-#include "conf.h"
 
 
 /*! \brief DIE command handler
@@ -51,6 +50,7 @@ static int
 mo_die(struct Client *source_p, int parc, char *parv[])
 {
   char buf[IRCD_BUFSIZE] = "";
+  const char *const name = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_DIE))
   {
@@ -58,13 +58,13 @@ mo_die(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(name))
   {
     sendto_one_notice(source_p, &me, ":Need server name /die %s", me.name);
     return 0;
   }
 
-  if (irccmp(parv[1], me.name))
+  if (irccmp(name, me.name))
   {
     sendto_one_notice(source_p, &me, ":Mismatch on /die %s", me.name);
     return 0;
@@ -72,14 +72,19 @@ mo_die(struct Client *source_p, int parc, char *parv[])
 
   snprintf(buf, sizeof(buf), "received DIE command from %s",
            get_client_name(source_p, HIDE_IP));
-  server_die(buf, 0);
+  server_die(buf, SERVER_SHUTDOWN);
   return 0;
 }
 
 static struct Message die_msgtab =
 {
-  "DIE", NULL, 0, 0, 1, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_die, m_ignore }
+  .cmd = "DIE",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_die
 };
 
 static void
@@ -96,10 +101,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
