@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_kick.c
  * \brief Includes required functions for processing the KICK command.
- * \version $Id: m_kick.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_kick.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -29,6 +29,7 @@
 #include "channel.h"
 #include "channel_mode.h"
 #include "client.h"
+#include "conf.h"
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
@@ -40,11 +41,18 @@
 #include "server.h"
 
 
-/* m_kick()
- *  parv[0] = command
- *  parv[1] = channel
- *  parv[2] = client to kick
- *  parv[3] = kick comment
+/*! \brief KICK command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = channel name
+ *      - parv[2] = client to kick
+ *      - parv[3] = reason
  */
 static int
 m_kick(struct Client *source_p, int parc, char *parv[])
@@ -52,8 +60,8 @@ m_kick(struct Client *source_p, int parc, char *parv[])
   char reason[KICKLEN + 1] = "";
   struct Client *target_p = NULL;
   struct Channel *chptr = NULL;
-  struct Membership *ms_source = NULL;
-  struct Membership *ms_target = NULL;
+  struct Membership *member_source = NULL;
+  struct Membership *member_target = NULL;
 
   if (EmptyString(parv[2]))
   {
@@ -70,32 +78,32 @@ m_kick(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if ((ms_source = find_channel_link(source_p, chptr)) == NULL)
+  if ((member_source = find_channel_link(source_p, chptr)) == NULL)
   {
-    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
     return 0;
   }
 
-  if (!has_member_flags(ms_source, CHFL_CHANOP|CHFL_HALFOP))
+  if (!has_member_flags(member_source, CHFL_CHANOP|CHFL_HALFOP))
   {
-    sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->name);
     return 0;
   }
 
   if ((target_p = find_chasing(source_p, parv[2])) == NULL)
     return 0;  /* find_chasing sends ERR_NOSUCHNICK */
 
-  if (!(ms_target = find_channel_link(target_p, chptr)))
+  if (!(member_target = find_channel_link(target_p, chptr)))
   {
-    sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->name);
     return 0;
   }
 
-  if (has_member_flags(ms_source, CHFL_HALFOP) && !has_member_flags(ms_source, CHFL_CHANOP))
+  if (has_member_flags(member_source, CHFL_HALFOP) && !has_member_flags(member_source, CHFL_CHANOP))
   {
-    if (has_member_flags(ms_target, CHFL_CHANOP|CHFL_HALFOP))
+    if (has_member_flags(member_target, CHFL_CHANOP|CHFL_HALFOP))
     {
-      sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->name);
       return 0;
     }
   }
@@ -105,22 +113,29 @@ m_kick(struct Client *source_p, int parc, char *parv[])
   else
     strlcpy(reason, source_p->name, sizeof(reason));
 
-  sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s KICK %s %s :%s",
+  sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s KICK %s %s :%s",
                        source_p->name, source_p->username,
-                       source_p->host, chptr->chname,
+                       source_p->host, chptr->name,
                        target_p->name, reason);
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s KICK %s %s :%s",
-                source_p->id, chptr->chname,
+  sendto_server(source_p, 0, 0, ":%s KICK %s %s :%s",
+                source_p->id, chptr->name,
                 target_p->id, reason);
-  remove_user_from_channel(ms_target);
+  remove_user_from_channel(member_target);
   return 0;
 }
 
-/* ms_kick()
- *  parv[0] = command
- *  parv[1] = channel
- *  parv[2] = client to kick
- *  parv[3] = kick comment
+/*! \brief KICK command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = channel name
+ *      - parv[2] = client to kick
+ *      - parv[3] = reason
  */
 static int
 ms_kick(struct Client *source_p, int parc, char *parv[])
@@ -128,7 +143,7 @@ ms_kick(struct Client *source_p, int parc, char *parv[])
   char reason[KICKLEN + 1] = "";
   struct Client *target_p = NULL;
   struct Channel *chptr = NULL;
-  struct Membership *ms_target = NULL;
+  struct Membership *member_target = NULL;
 
   if (EmptyString(parv[2]))
     return 0;
@@ -139,7 +154,7 @@ ms_kick(struct Client *source_p, int parc, char *parv[])
   if ((target_p = find_person(source_p, parv[2])) == NULL)
     return 0;
 
-  if ((ms_target = find_channel_link(target_p, chptr)) == NULL)
+  if ((member_target = find_channel_link(target_p, chptr)) == NULL)
     return 0;
 
   if (!EmptyString(parv[3]))
@@ -147,27 +162,33 @@ ms_kick(struct Client *source_p, int parc, char *parv[])
   else
     strlcpy(reason, source_p->name, sizeof(reason));
 
-  if (IsServer(source_p))
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s KICK %s %s :%s",
-                         source_p->name, chptr->chname,
+  if (IsClient(source_p))
+    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s KICK %s %s :%s",
+                         source_p->name, source_p->username,
+                         source_p->host, chptr->name,
                          target_p->name, reason);
   else
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s KICK %s %s :%s",
-                         source_p->name, source_p->username,
-                         source_p->host, chptr->chname,
-                         target_p->name, reason);
+    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s KICK %s %s :%s",
+                         IsHidden(source_p) || ConfigServerHide.hide_servers ? me.name : source_p->name,
+                         chptr->name, target_p->name, reason);
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s KICK %s %s :%s",
-                source_p->id, chptr->chname,
+  sendto_server(source_p, 0, 0, ":%s KICK %s %s :%s",
+                source_p->id, chptr->name,
                 target_p->id, reason);
-  remove_user_from_channel(ms_target);
+  remove_user_from_channel(member_target);
   return 0;
 }
 
 static struct Message kick_msgtab =
 {
-  "KICK", NULL, 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_kick, ms_kick, m_ignore, m_kick, m_ignore }
+  .cmd = "KICK",
+  .args_min = 3,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_kick,
+  .handlers[SERVER_HANDLER] = ms_kick,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_kick
 };
 
 static void
@@ -184,10 +205,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
