@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_message.c
  * \brief Includes required functions for processing the PRIVMSG/NOTICE command.
- * \version $Id: m_message.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_message.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -49,20 +49,25 @@ enum
 
 enum
 {
-  ENTITY_NONE               = 0,
-  ENTITY_CHANNEL            = 1,
-  ENTITY_CHANOPS_ON_CHANNEL = 2,
-  ENTITY_CLIENT             = 3
+  ENTITY_NONE    = 0,
+  ENTITY_CHANNEL = 1,
+  ENTITY_CLIENT  = 2
+};
+
+static const char *const command[] =
+{
+  [PRIVMSG] = "PRIVMSG",
+  [NOTICE] = "NOTICE"
 };
 
 static struct
 {
   void *ptr;
-  int type;
-  int flags;
+  unsigned int type;
+  unsigned int flags;
 } targets[IRCD_BUFSIZE];
 
-static int unsigned ntargets = 0;
+static unsigned int ntargets;
 
 
 /*
@@ -115,27 +120,30 @@ duplicate_ptr(const void *const ptr)
 static int
 flood_attack_client(int p_or_n, struct Client *source_p, struct Client *target_p)
 {
-  int delta = 0;
+  assert(MyClient(target_p));
+  assert(IsClient(source_p));
 
-  if (GlobalSetOptions.floodcount && MyConnect(target_p) &&
-      IsClient(source_p) && !IsCanFlood(source_p))
+  if (HasUMode(source_p, UMODE_OPER) || HasFlag(source_p, FLAGS_SERVICE))
+    return 0;
+
+  if (GlobalSetOptions.floodcount && !HasFlag(source_p, FLAGS_CANFLOOD))
   {
-    if ((target_p->localClient->first_received_message_time + 1)
+    if ((target_p->connection->first_received_message_time + 1)
         < CurrentTime)
     {
-      delta =
-        CurrentTime - target_p->localClient->first_received_message_time;
-      target_p->localClient->received_number_of_privmsgs -= delta;
-      target_p->localClient->first_received_message_time = CurrentTime;
+      const int delta =
+        CurrentTime - target_p->connection->first_received_message_time;
+      target_p->connection->received_number_of_privmsgs -= delta;
+      target_p->connection->first_received_message_time = CurrentTime;
 
-      if (target_p->localClient->received_number_of_privmsgs <= 0)
+      if (target_p->connection->received_number_of_privmsgs <= 0)
       {
-        target_p->localClient->received_number_of_privmsgs = 0;
+        target_p->connection->received_number_of_privmsgs = 0;
         DelFlag(target_p, FLAGS_FLOOD_NOTICED);
       }
     }
 
-    if ((target_p->localClient->received_number_of_privmsgs >=
+    if ((target_p->connection->received_number_of_privmsgs >=
          GlobalSetOptions.floodcount) || HasFlag(target_p, FLAGS_FLOOD_NOTICED))
     {
       if (!HasFlag(target_p, FLAGS_FLOOD_NOTICED))
@@ -146,7 +154,7 @@ flood_attack_client(int p_or_n, struct Client *source_p, struct Client *target_p
                              source_p->servptr->name, target_p->name);
 
         AddFlag(target_p, FLAGS_FLOOD_NOTICED);
-        target_p->localClient->received_number_of_privmsgs += 2;  /* Add a bit of penalty */
+        target_p->connection->received_number_of_privmsgs += 2;  /* Add a bit of penalty */
       }
 
       if (MyClient(source_p) && p_or_n != NOTICE)
@@ -155,7 +163,7 @@ flood_attack_client(int p_or_n, struct Client *source_p, struct Client *target_p
       return 1;
     }
     else
-      target_p->localClient->received_number_of_privmsgs++;
+      target_p->connection->received_number_of_privmsgs++;
   }
 
   return 0;
@@ -173,13 +181,11 @@ flood_attack_client(int p_or_n, struct Client *source_p, struct Client *target_p
 static int
 flood_attack_channel(int p_or_n, struct Client *source_p, struct Channel *chptr)
 {
-  int delta = 0;
-
-  if (GlobalSetOptions.floodcount && !IsCanFlood(source_p))
+  if (GlobalSetOptions.floodcount && !HasFlag(source_p, FLAGS_CANFLOOD))
   {
     if ((chptr->first_received_message_time + 1) < CurrentTime)
     {
-      delta = CurrentTime - chptr->first_received_message_time;
+      const int delta = CurrentTime - chptr->first_received_message_time;
       chptr->received_number_of_privmsgs -= delta;
       chptr->first_received_message_time = CurrentTime;
 
@@ -198,7 +204,7 @@ flood_attack_channel(int p_or_n, struct Client *source_p, struct Channel *chptr)
         sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
                              "Possible Flooder %s on %s target: %s",
                              get_client_name(source_p, HIDE_IP),
-                             source_p->servptr->name, chptr->chname);
+                             source_p->servptr->name, chptr->name);
 
         SetFloodNoticed(chptr);
         chptr->received_number_of_privmsgs += 2;  /* Add a bit of penalty */
@@ -206,7 +212,7 @@ flood_attack_channel(int p_or_n, struct Client *source_p, struct Channel *chptr)
 
       if (MyClient(source_p) && p_or_n != NOTICE)
         sendto_one_notice(source_p, &me, ":*** Message to %s throttled due to flooding",
-                          chptr->chname);
+                          chptr->name);
       return 1;
     }
     else
@@ -216,51 +222,10 @@ flood_attack_channel(int p_or_n, struct Client *source_p, struct Channel *chptr)
   return 0;
 }
 
-/* msg_channel()
- *
- * inputs	- flag privmsg or notice
- * 		- pointer to command "PRIVMSG" or "NOTICE"
- *		- pointer to source_p
- *		- pointer to channel
- * output	- NONE
- * side effects	- message given channel
- */
-static void
-msg_channel(int p_or_n, const char *command, struct Client *source_p,
-            struct Channel *chptr, const char *text)
-{
-  int result = 0;
-
-  /* Chanops and voiced can flood their own channel with impunity */
-  if ((result = can_send(chptr, source_p, NULL, text)) < 0)
-  {
-    if (result == CAN_SEND_OPV ||
-        !flood_attack_channel(p_or_n, source_p, chptr))
-      sendto_channel_butone(source_p, source_p, chptr, 0, "%s %s :%s",
-                            command, chptr->chname, text);
-  }
-  else
-  {
-    if (p_or_n != NOTICE)
-    {
-      if (result == ERR_NOCTRLSONCHAN)
-        sendto_one_numeric(source_p, &me, ERR_NOCTRLSONCHAN,
-                           chptr->chname, text);
-      else if (result == ERR_NEEDREGGEDNICK)
-        sendto_one_numeric(source_p, &me, ERR_NEEDREGGEDNICK,
-                           chptr->chname);
-      else
-        sendto_one_numeric(source_p, &me, ERR_CANNOTSENDTOCHAN,
-                           chptr->chname);
-    }
-  }
-}
-
 /* msg_channel_flags()
  *
  * inputs	- flag 0 if PRIVMSG 1 if NOTICE. RFC
  *		  say NOTICE must not auto reply
- *		- pointer to command, "PRIVMSG" or "NOTICE"
  *		- pointer to source_p
  *		- pointer to channel
  *		- flags
@@ -269,59 +234,45 @@ msg_channel(int p_or_n, const char *command, struct Client *source_p,
  * side effects	- message given channel either chanop or voice
  */
 static void
-msg_channel_flags(int p_or_n, const char *command, struct Client *source_p,
-                  struct Channel *chptr, int flags, const char *text)
+msg_channel(int p_or_n, struct Client *source_p, struct Channel *chptr,
+            unsigned int flags, const char *text)
 {
-  unsigned int type = 0;
   int result = 0;
-  char c = '\0';
+  unsigned int type = 0;
+  const char *prefix = "";
 
   if (flags & CHFL_VOICE)
   {
-    type = CHFL_VOICE|CHFL_HALFOP|CHFL_CHANOP;
-    c = '+';
+    type = CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE;
+    prefix = "+";
   }
   else if (flags & CHFL_HALFOP)
   {
-    type = CHFL_HALFOP|CHFL_CHANOP;
-    c = '%';
-   }
-  else
+    type = CHFL_CHANOP | CHFL_HALFOP;
+    prefix = "%";
+  }
+  else if (flags & CHFL_CHANOP)
   {
     type = CHFL_CHANOP;
-    c = '@';
+    prefix = "@";
   }
 
   /* Chanops and voiced can flood their own channel with impunity */
-  if ((result = can_send(chptr, source_p, NULL, text)) < 0)
+  if ((result = can_send(chptr, source_p, NULL, text, p_or_n == NOTICE)) < 0)
   {
     if (result == CAN_SEND_OPV ||
         !flood_attack_channel(p_or_n, source_p, chptr))
-      sendto_channel_butone(source_p, source_p, chptr, type, "%s %c%s :%s",
-                            command, c, chptr->chname, text);
-  }
-  else
-  {
-    if (p_or_n != NOTICE)
-    {
-      if (result == ERR_NOCTRLSONCHAN)
-        sendto_one_numeric(source_p, &me, ERR_NOCTRLSONCHAN,
-                           chptr->chname, text);
-      else if (result == ERR_NEEDREGGEDNICK)
-        sendto_one_numeric(source_p, &me, ERR_NEEDREGGEDNICK,
-                           chptr->chname);
-      else
-        sendto_one_numeric(source_p, &me, ERR_CANNOTSENDTOCHAN,
-                           chptr->chname);
-    }
+      sendto_channel_butone(source_p, source_p, chptr, type, "%s %s%s :%s",
+                            command[p_or_n], prefix, chptr->name, text);
   }
+  else if (p_or_n != NOTICE)
+    sendto_one_numeric(source_p, &me, result, chptr->name, text);
 }
 
 /* msg_client()
  *
  * inputs	- flag 0 if PRIVMSG 1 if NOTICE. RFC
  *		  say NOTICE must not auto reply
- *		- pointer to command, "PRIVMSG" or "NOTICE"
  * 		- pointer to source_p source (struct Client *)
  *		- pointer to target_p target (struct Client *)
  *		- pointer to text
@@ -329,8 +280,8 @@ msg_channel_flags(int p_or_n, const char *command, struct Client *source_p,
  * side effects	- message given channel either chanop or voice
  */
 static void
-msg_client(int p_or_n, const char *command, struct Client *source_p,
-           struct Client *target_p, const char *text)
+msg_client(int p_or_n, struct Client *source_p, struct Client *target_p,
+           const char *text)
 {
   if (MyClient(source_p))
   {
@@ -339,7 +290,7 @@ msg_client(int p_or_n, const char *command, struct Client *source_p,
 
     if (HasUMode(target_p, UMODE_REGONLY) && target_p != source_p)
     {
-      if (!HasUMode(source_p, UMODE_REGISTERED|UMODE_OPER))
+      if (!HasUMode(source_p, UMODE_REGISTERED | UMODE_OPER))
       {
         if (p_or_n != NOTICE)
           sendto_one_numeric(source_p, &me, ERR_NONONREG, target_p->name);
@@ -348,65 +299,43 @@ msg_client(int p_or_n, const char *command, struct Client *source_p,
     }
   }
 
-  if (MyClient(target_p))
+  if (MyClient(target_p) && IsClient(source_p))
   {
-    if (!IsServer(source_p) && HasUMode(target_p, UMODE_CALLERID|UMODE_SOFTCALLERID))
+    if (HasUMode(target_p, UMODE_CALLERID | UMODE_SOFTCALLERID) &&
+        !accept_message(source_p, target_p))
     {
-      /* Here is the anti-flood bot/spambot code -db */
-      if (HasFlag(source_p, FLAGS_SERVICE) || accept_message(source_p, target_p) ||
-         (HasUMode(source_p, UMODE_OPER) && ConfigGeneral.opers_bypass_callerid))
-      {
-        sendto_one(target_p, ":%s!%s@%s %s %s :%s",
-                   source_p->name, source_p->username,
-                   source_p->host, command, target_p->name, text);
-      }
-      else
-      {
-        int callerid = !!HasUMode(target_p, UMODE_CALLERID);
+      const int callerid = !!HasUMode(target_p, UMODE_CALLERID);
 
-        /* check for accept, flag recipient incoming message */
+      /* check for accept, flag recipient incoming message */
+      if (p_or_n != NOTICE)
+        sendto_one_numeric(source_p, &me, RPL_TARGUMODEG,
+                           target_p->name,
+                           callerid ? "+g" : "+G",
+                           callerid ? "server side ignore" :
+                                      "server side ignore with the exception of common channels");
+
+      if ((target_p->connection->last_caller_id_time +
+           ConfigGeneral.caller_id_wait) < CurrentTime)
+      {
         if (p_or_n != NOTICE)
-          sendto_one_numeric(source_p, &me, RPL_TARGUMODEG,
-                             target_p->name,
-                             callerid ? "+g" : "+G",
-                             callerid ? "server side ignore" :
-                                        "server side ignore with the exception of common channels");
+          sendto_one_numeric(source_p, &me, RPL_TARGNOTIFY, target_p->name);
 
-        if ((target_p->localClient->last_caller_id_time +
-             ConfigGeneral.caller_id_wait) < CurrentTime)
-        {
-          if (p_or_n != NOTICE)
-            sendto_one_numeric(source_p, &me, RPL_TARGNOTIFY, target_p->name);
-
-          sendto_one_numeric(target_p, &me, RPL_UMODEGMSG,
-                             get_client_name(source_p, HIDE_IP),
-                             callerid ? "+g" : "+G");
-
-          target_p->localClient->last_caller_id_time = CurrentTime;
-
-        }
-
-        /* Only so opers can watch for floods */
-        flood_attack_client(p_or_n, source_p, target_p);
+        sendto_one_numeric(target_p, &me, RPL_UMODEGMSG,
+                           source_p->name, source_p->username, source_p->host,
+                           callerid ? "+g" : "+G");
+        target_p->connection->last_caller_id_time = CurrentTime;
       }
+
+      /* Only so opers can watch for floods */
+      flood_attack_client(NOTICE, source_p, target_p);
+      return;
     }
-    else
-    {
-      /*
-       * If the client is remote, we dont perform a special check for
-       * flooding.. as we wouldn't block their message anyway.. this means
-       * we dont give warnings.. we then check if theyre opered
-       * (to avoid flood warnings), lastly if theyre our client
-       * and flooding    -- fl
-       */
-      if (!MyClient(source_p) || HasUMode(source_p, UMODE_OPER) ||
-          !flood_attack_client(p_or_n, source_p, target_p))
-        sendto_anywhere(target_p, source_p, command, ":%s", text);
-    }
+
+    if (flood_attack_client(p_or_n, source_p, target_p))
+      return;
   }
-  else if (!MyClient(source_p) || HasUMode(source_p, UMODE_OPER) ||
-           !flood_attack_client(p_or_n, source_p, target_p))
-    sendto_anywhere(target_p, source_p, command, ":%s", text);
+
+  sendto_anywhere(target_p, source_p, command[p_or_n], ":%s", text);
 }
 
 /* handle_special()
@@ -430,7 +359,7 @@ msg_client(int p_or_n, const char *command, struct Client *source_p,
  *		- Dianora
  */
 static void
-handle_special(int p_or_n, const char *command, struct Client *source_p,
+handle_special(int p_or_n, struct Client *source_p,
                const char *nick, const char *text)
 {
   struct Client *target_p = NULL;
@@ -455,7 +384,7 @@ handle_special(int p_or_n, const char *command, struct Client *source_p,
 
     if (!IsMe(target_p))
     {
-      sendto_one(target_p, ":%s %s %s :%s", source_p->id, command, nick, text);
+      sendto_one(target_p, ":%s %s %s :%s", source_p->id, command[p_or_n], nick, text);
       return;
     }
 
@@ -482,7 +411,7 @@ handle_special(int p_or_n, const char *command, struct Client *source_p,
     else if (MyClient(source_p))
     {
       sendto_one_notice(source_p, &me, ":The command %s %s is no longer supported, please use $%s",
-                        command, nick, nick);
+                        command[p_or_n], nick, nick);
       return;
     }
 
@@ -504,7 +433,7 @@ handle_special(int p_or_n, const char *command, struct Client *source_p,
 
     sendto_match_butone(IsServer(source_p->from) ? source_p->from : NULL, source_p,
                         nick + 1, (*nick == '#') ? MATCH_HOST : MATCH_SERVER,
-                        "%s $%s :%s", command, nick, text);
+                        "%s $%s :%s", command[p_or_n], nick, text);
   }
 }
 
@@ -523,22 +452,17 @@ handle_special(int p_or_n, const char *command, struct Client *source_p,
  *		  to disambiguate.
  *
  */
-static int
-build_target_list(int p_or_n, const char *command, struct Client *source_p,
-                  char *nicks_channels, const char *text)
+static void
+build_target_list(int p_or_n, struct Client *source_p, char *list, const char *text)
 {
-  int type = 0;
-  char *p = NULL, *nick = NULL;
-  char *target_list = NULL;
-  struct Channel *chptr = NULL;
-  struct Client *target_p = NULL;
-
-  target_list = nicks_channels;
+  unsigned int type = 0;
+  char *p = NULL;
+  void *target = NULL;
 
   ntargets = 0;
 
-  for (nick = strtoken(&p, target_list, ","); nick;
-       nick = strtoken(&p,        NULL, ","))
+  for (const char *name = strtok_r(list, ",", &p); name;
+                   name = strtok_r(NULL, ",", &p))
   {
     const char *with_prefix = NULL;
 
@@ -546,45 +470,43 @@ build_target_list(int p_or_n, const char *command, struct Client *source_p,
      * Channels are privmsg'd a lot more than other clients, moved up
      * here plain old channel msg?
      */
-    if (IsChanPrefix(*nick))
+    if (IsChanPrefix(*name))
     {
-      if ((chptr = hash_find_channel(nick)))
+      if ((target = hash_find_channel(name)))
       {
-        if (!duplicate_ptr(chptr))
+        if (!duplicate_ptr(target))
         {
           if (ntargets >= ConfigGeneral.max_targets)
           {
             sendto_one_numeric(source_p, &me, ERR_TOOMANYTARGETS,
-                               nick, ConfigGeneral.max_targets);
-            return 1;
+                               name, ConfigGeneral.max_targets);
+            return;
           }
 
-          targets[ntargets].ptr = chptr;
-          targets[ntargets++].type = ENTITY_CHANNEL;
+          targets[ntargets].ptr = target;
+          targets[ntargets].type = ENTITY_CHANNEL;
+          targets[ntargets++].flags = 0;
         }
       }
-      else
-      {
-        if (p_or_n != NOTICE)
-          sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, nick);
-      }
+      else if (p_or_n != NOTICE)
+        sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, name);
 
       continue;
     }
 
     /* Look for a PRIVMSG/NOTICE to another client */
-    if ((target_p = find_person(source_p, nick)))
+    if ((target = find_person(source_p, name)))
     {
-      if (!duplicate_ptr(target_p))
+      if (!duplicate_ptr(target))
       {
         if (ntargets >= ConfigGeneral.max_targets)
         {
           sendto_one_numeric(source_p, &me, ERR_TOOMANYTARGETS,
-                             nick, ConfigGeneral.max_targets);
-          return 1;
+                             name, ConfigGeneral.max_targets);
+          return;
         }
 
-        targets[ntargets].ptr = target_p;
+        targets[ntargets].ptr = target;
         targets[ntargets].type = ENTITY_CLIENT;
         targets[ntargets++].flags = 0;
       }
@@ -594,97 +516,88 @@ build_target_list(int p_or_n, const char *command, struct Client *source_p,
 
     /* @#channel or +#channel message ? */
     type = 0;
-    with_prefix = nick;
+    with_prefix = name;
 
     /* Allow %+@ if someone wants to do that */
     while (1)
     {
-      if (*nick == '@')
+      if (*name == '@')
         type |= CHFL_CHANOP;
-      else if (*nick == '%')
+      else if (*name == '%')
         type |= CHFL_CHANOP | CHFL_HALFOP;
-      else if (*nick == '+')
+      else if (*name == '+')
         type |= CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE;
       else
         break;
-      ++nick;
+      ++name;
     }
 
     if (type)
     {
-      if (EmptyString(nick))  /* If it's a '\0' dump it, there is no recipient */
+      if (EmptyString(name))  /* If it's a '\0' dump it, there is no recipient */
       {
-        sendto_one_numeric(source_p, &me, ERR_NORECIPIENT, command);
+        sendto_one_numeric(source_p, &me, ERR_NORECIPIENT, command[p_or_n]);
         continue;
       }
 
       /*
-       * At this point, nick+1 should be a channel name i.e. #foo or &foo
+       * At this point, name+1 should be a channel name i.e. #foo or &foo
        * if the channel is found, fine, if not report an error
        */
-      if ((chptr = hash_find_channel(nick)))
+      if ((target = hash_find_channel(name)))
       {
         if (IsClient(source_p) && !HasFlag(source_p, FLAGS_SERVICE))
         {
-          if (!has_member_flags(find_channel_link(source_p, chptr),
+          if (!has_member_flags(find_channel_link(source_p, target),
                                 CHFL_CHANOP|CHFL_HALFOP|CHFL_VOICE))
           {
             sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, with_prefix);
-            return -1;
+            continue;
           }
         }
 
-        if (!duplicate_ptr(chptr))
+        if (!duplicate_ptr(target))
         {
           if (ntargets >= ConfigGeneral.max_targets)
           {
             sendto_one_numeric(source_p, &me, ERR_TOOMANYTARGETS,
-                               nick, ConfigGeneral.max_targets);
-            return 1;
+                               name, ConfigGeneral.max_targets);
+            return;
           }
 
-          targets[ntargets].ptr = chptr;
-          targets[ntargets].type = ENTITY_CHANOPS_ON_CHANNEL;
+          targets[ntargets].ptr = target;
+          targets[ntargets].type = ENTITY_CHANNEL;
           targets[ntargets++].flags = type;
         }
       }
-      else
-      {
-        if (p_or_n != NOTICE)
-          sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, nick);
-      }
+      else if (p_or_n != NOTICE)
+        sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, name);
 
       continue;
     }
 
-    if (*nick == '$' || strchr(nick, '@'))
-      handle_special(p_or_n, command, source_p, nick, text);
-    else
+    if (*name == '$' || strchr(name, '@'))
+      handle_special(p_or_n, source_p, name, text);
+    else if (p_or_n != NOTICE)
     {
-      if (p_or_n != NOTICE)
-      {
-        if (!IsDigit(*nick) || MyClient(source_p))
-          sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, nick);
-      }
+      if (!IsDigit(*name) || MyClient(source_p))
+        sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, name);
     }
   }
-
-  return 1;
 }
 
 /*
  * inputs       - flag privmsg or notice
- *              - pointer to command "PRIVMSG" or "NOTICE"
  *              - pointer to source_p
  *              - pointer to channel
  */
 static void
-m_message(int p_or_n, const char *command, struct Client *source_p, int parc, char *parv[])
+m_message(int p_or_n, struct Client *source_p, int parc, char *parv[])
 {
   if (parc < 2 || EmptyString(parv[1]))
   {
     if (p_or_n != NOTICE)
-      sendto_one_numeric(source_p, &me, ERR_NORECIPIENT, command);
+      sendto_one_numeric(source_p, &me, ERR_NORECIPIENT, command[p_or_n]);
     return;
   }
 
@@ -699,24 +612,18 @@ m_message(int p_or_n, const char *command, struct Client *source_p, int parc, ch
   if (MyClient(source_p) && !IsFloodDone(source_p))
     flood_endgrace(source_p);
 
-  if (build_target_list(p_or_n, command, source_p, parv[1], parv[2]) < 0)
-    return;
+  build_target_list(p_or_n, source_p, parv[1], parv[2]);
 
   for (unsigned int i = 0; i < ntargets; ++i)
   {
     switch (targets[i].type)
     {
       case ENTITY_CLIENT:
-        msg_client(p_or_n, command, source_p, targets[i].ptr, parv[2]);
+        msg_client(p_or_n, source_p, targets[i].ptr, parv[2]);
         break;
 
       case ENTITY_CHANNEL:
-        msg_channel(p_or_n, command, source_p, targets[i].ptr, parv[2]);
-        break;
-
-      case ENTITY_CHANOPS_ON_CHANNEL:
-        msg_channel_flags(p_or_n, command, source_p, targets[i].ptr,
-                          targets[i].flags, parv[2]);
+        msg_channel(p_or_n, source_p, targets[i].ptr, targets[i].flags, parv[2]);
         break;
     }
   }
@@ -733,29 +640,39 @@ m_privmsg(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   if (MyConnect(source_p))
-    source_p->localClient->last_privmsg = CurrentTime;
+    source_p->connection->last_privmsg = CurrentTime;
 
-  m_message(PRIVMSG, "PRIVMSG", source_p, parc, parv);
+  m_message(PRIVMSG, source_p, parc, parv);
   return 0;
 }
 
 static int
 m_notice(struct Client *source_p, int parc, char *parv[])
 {
-  m_message(NOTICE, "NOTICE", source_p, parc, parv);
+  m_message(NOTICE, source_p, parc, parv);
   return 0;
 }
 
 static struct Message privmsg_msgtab =
 {
-  "PRIVMSG", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_privmsg, m_privmsg, m_ignore, m_privmsg, m_ignore }
+  .cmd = "PRIVMSG",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_privmsg,
+  .handlers[SERVER_HANDLER] = m_privmsg,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_privmsg
 };
 
 static struct Message notice_msgtab =
 {
-  "NOTICE", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_notice, m_notice, m_ignore, m_notice, m_ignore }
+  .cmd = "NOTICE",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_notice,
+  .handlers[SERVER_HANDLER] = m_notice,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_notice
 };
 
 static void
@@ -774,10 +691,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
