@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_mode.c
  * \brief Includes required functions for processing the MODE command.
- * \version $Id: m_mode.c 5547 2015-02-12 14:25:58Z michael $
+ * \version $Id: m_mode.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -74,8 +74,8 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
   {
     char buf[IRCD_BUFSIZE] = "";
     char *m = buf;
-    *m++ = '+';
 
+    *m++ = '+';
     for (tab = umode_tab; tab->c; ++tab)
       if (HasUMode(source_p, tab->flag))
         *m++ = tab->c;
@@ -85,7 +85,7 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
     return;
   }
 
-  /* parse mode change string(s) */
+  /* Parse user mode change string */
   for (const char *m = parv[2]; *m; ++m)
   {
     switch (*m)
@@ -167,25 +167,33 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
 
   if (!(setmodes & UMODE_INVISIBLE) && HasUMode(source_p, UMODE_INVISIBLE))
     ++Count.invisi;
-  if ((setmodes & UMODE_INVISIBLE) && !HasUMode(source_p, UMODE_INVISIBLE))
+  else if ((setmodes & UMODE_INVISIBLE) && !HasUMode(source_p, UMODE_INVISIBLE))
     --Count.invisi;
 
   /*
-   * Compare new modes with old modes and send string which
-   * will cause servers to update correctly.
+   * Compare new modes with old modes and send string which will cause
+   * servers to update correctly.
    */
   send_umode_out(source_p, setmodes);
 }
 
-/*
- * m_mode - MODE command handler
- * parv[0] - command
- * parv[1] - channel
+/*! \brief MODE command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = channel or nick name
+ *      - parv[2] = modes to be added or removed
  */
 static int
 m_mode(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
+  struct Membership *member = NULL;
 
   if (EmptyString(parv[1]))
   {
@@ -196,7 +204,7 @@ m_mode(struct Client *source_p, int parc, char *parv[])
   /* Now, try to find the channel in question */
   if (!IsChanPrefix(*parv[1]))
   {
-    /* if here, it has to be a non-channel name */
+    /* If here, it has to be a non-channel name */
     set_user_mode(source_p, parc, parv);
     return 0;
   }
@@ -219,32 +227,29 @@ m_mode(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /*
-   * bounce all modes from people we deop on sjoin
-   * servers have always gotten away with murder,
-   * including telnet servers *g* - Dianora
-   */
-  if (IsServer(source_p) || HasFlag(source_p, FLAGS_SERVICE))
-    set_channel_mode(source_p, chptr, NULL, parc - 2, parv + 2);
-  else
+  if (MyClient(source_p))
   {
-    struct Membership *member = find_channel_link(source_p, chptr);
+    member = find_channel_link(source_p, chptr);
 
-    /* Finish the flood grace period... */
-    if (MyClient(source_p) && !IsFloodDone(source_p))
+    if (!IsFloodDone(source_p))
       if (!((parc == 3) && (parv[2][0] == 'b') && (parv[2][1] == '\0')))
         flood_endgrace(source_p);
-
-    set_channel_mode(source_p, chptr, member, parc - 2, parv + 2);
   }
 
+  set_channel_mode(source_p, chptr, member, parc - 2, parv + 2);
   return 0;
 }
 
 static struct Message mode_msgtab =
 {
-  "MODE", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_mode, m_mode, m_ignore, m_mode, m_ignore }
+  .cmd = "MODE",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_mode,
+  .handlers[SERVER_HANDLER] = m_mode,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_mode
 };
 
 static void
@@ -261,10 +266,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5547 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
