@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 5779 2015-04-04 17:47:27Z michael $
+ * \version $Id: m_nick.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -42,6 +42,7 @@
 #include "packet.h"
 #include "watch.h"
 #include "misc.h"
+#include "id.h"
 
 
 /* check_clean_nick()
@@ -57,35 +58,51 @@
  *                truncated nickname, return 1
  */
 static int
-check_clean_nick(struct Client *source_p, char *nick, struct Client *server_p)
+check_clean_nick(struct Client *source_p, const char *nick)
 {
+  assert(IsServer(source_p) || (IsClient(source_p) && !MyConnect(source_p)));
+
   /*
    * The old code did some wacky stuff here, if the nick is invalid, kill it
    * and don't bother messing at all
    */
-  if (!valid_nickname(nick, 0))
+  if (valid_nickname(nick, 0))
+    return 0;
+
+  ++ServerStats.is_kill;
+  sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE, "Bad/long Nick: %s From: %s(via %s)",
+                       nick, IsServer(source_p) ? source_p->name : source_p->servptr->name,
+                       source_p->from->name);
+  sendto_one(source_p, ":%s KILL %s :%s (Bad Nickname)",
+             me.id, nick, me.name);
+
+  /* Bad nick change */
+  if (!IsServer(source_p))
   {
-    ++ServerStats.is_kill;
-    sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                         "Bad/long Nick: %s From: %s(via %s)",
-                         nick, server_p->name, source_p->from->name);
-
-    sendto_one(source_p, ":%s KILL %s :%s (Bad Nickname)",
-               me.name, nick, me.name);
-
-    /* Bad nick change */
-    if (IsClient(source_p) && !MyConnect(source_p))
-    {
-      sendto_server(source_p, 0, 0, ":%s KILL %s :%s (Bad Nickname)",
-                    me.id, source_p->id, me.name);
-      AddFlag(source_p, FLAGS_KILLED);
-      exit_client(source_p, "Bad Nickname");
-    }
-
-    return 1;
+    sendto_server(source_p, 0, 0, ":%s KILL %s :%s (Bad Nickname)",
+                  me.id, source_p->id, me.name);
+    AddFlag(source_p, FLAGS_KILLED);
+    exit_client(source_p, "Bad Nickname");
   }
 
-  return 0;
+  return 1;
+}
+
+static int
+check_clean_uid(struct Client *source_p, const char *nick, const char *uid)
+{
+  assert(IsServer(source_p));
+
+  if (valid_uid(uid) && strncmp(uid, source_p->id, IRC_MAXSID) == 0)
+    return 0;
+
+  ++ServerStats.is_kill;
+  sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
+                       "Bad UID: %s Nickname: %s From: %s(via %s)",
+                       uid, nick, source_p->name, source_p->from->name);
+  sendto_one(source_p, ":%s KILL %s :%s (Bad UID)",
+             me.id, uid, me.name);
+  return 1;
 }
 
 /* check_clean_user()
@@ -98,21 +115,20 @@ check_clean_nick(struct Client *source_p, char *nick, struct Client *server_p)
  * side effects - if username is erroneous, return 1
  */
 static int
-check_clean_user(struct Client *source_p, char *nick,
-                 char *user, struct Client *server_p)
+check_clean_user(struct Client *source_p, const char *nick, const char *user)
 {
-  if (!valid_username(user, 0))
-  {
-    ++ServerStats.is_kill;
-    sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                         "Bad/Long Username: %s Nickname: %s From: %s(via %s)",
-                         user, nick, server_p->name, source_p->from->name);
-    sendto_one(source_p, ":%s KILL %s :%s (Bad Username)",
-               me.name, nick, me.name);
-    return 1;
-  }
+  assert(IsServer(source_p));
 
-  return 0;
+  if (valid_username(user, 0))
+    return 0;
+
+  ++ServerStats.is_kill;
+  sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
+                       "Bad/Long Username: %s Nickname: %s From: %s(via %s)",
+                       user, nick, source_p->name, source_p->from->name);
+  sendto_one(source_p, ":%s KILL %s :%s (Bad Username)",
+             me.id, nick, me.name);
+  return 1;
 }
 
 /* check_clean_host()
@@ -125,21 +141,20 @@ check_clean_user(struct Client *source_p, char *nick,
  * side effects - if hostname is erroneous, return 1
  */
 static int
-check_clean_host(struct Client *source_p, char *nick,
-                 char *host, struct Client *server_p)
+check_clean_host(struct Client *source_p, const char *nick, const char *host)
 {
-  if (!valid_hostname(host))
-  {
-    ++ServerStats.is_kill;
-    sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                         "Bad/Long Hostname: %s Nickname: %s From: %s(via %s)",
-                         host, nick, server_p->name, source_p->from->name);
-    sendto_one(source_p, ":%s KILL %s :%s (Bad Hostname)",
-               me.name, nick, me.name);
-    return 1;
-  }
+  assert(IsServer(source_p));
 
-  return 0;
+  if (valid_hostname(host))
+    return 0;
+
+  ++ServerStats.is_kill;
+  sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
+                       "Bad/Long Hostname: %s Nickname: %s From: %s(via %s)",
+                       host, nick, source_p->name, source_p->from->name);
+  sendto_one(source_p, ":%s KILL %s :%s (Bad Hostname)",
+             me.id, nick, me.name);
+  return 1;
 }
 
 /* set_initial_nick()
@@ -168,7 +183,7 @@ set_initial_nick(struct Client *source_p, const char *nick)
   hash_add_client(source_p);
 
   /* fd_desc is long enough */
-  fd_note(&source_p->connection->fd, "Nick: %s", nick);
+  fd_note(&source_p->connection->fd, "Nick: %s", source_p->name);
 
   if (!source_p->connection->registration)
     register_local_user(source_p);
@@ -233,13 +248,13 @@ change_local_nick(struct Client *source_p, const char *nick)
   sendto_realops_flags(UMODE_NCHANGE, L_ALL, SEND_NOTICE,
                        "Nick change: From %s to %s [%s@%s]",
                        source_p->name, nick, source_p->username, source_p->host);
-  sendto_common_channels_local(source_p, 1, 0, ":%s!%s@%s NICK :%s",
+  sendto_common_channels_local(source_p, 1, 0, 0, ":%s!%s@%s NICK :%s",
                                source_p->name, source_p->username,
                                source_p->host, nick);
   whowas_add_history(source_p, 1);
 
-  sendto_server(source_p, 0, 0, ":%s NICK %s :%lu",
-                source_p->id, nick, (unsigned long)source_p->tsinfo);
+  sendto_server(source_p, 0, 0, ":%s NICK %s :%ju",
+                source_p->id, nick, source_p->tsinfo);
 
   hash_del_client(source_p);
   strlcpy(source_p->name, nick, sizeof(source_p->name));
@@ -249,7 +264,7 @@ change_local_nick(struct Client *source_p, const char *nick)
     watch_check_hash(source_p, RPL_LOGON);
 
   /* fd_desc is long enough */
-  fd_note(&source_p->connection->fd, "Nick: %s", nick);
+  fd_note(&source_p->connection->fd, "Nick: %s", source_p->name);
 }
 
 /*!
@@ -268,7 +283,7 @@ change_local_nick(struct Client *source_p, const char *nick)
 static void
 change_remote_nick(struct Client *source_p, char *parv[])
 {
-  int samenick = !irccmp(source_p->name, parv[1]);
+  const int samenick = !irccmp(source_p->name, parv[1]);
 
   assert(!EmptyString(parv[1]));
   assert(IsClient(source_p));
@@ -279,17 +294,17 @@ change_remote_nick(struct Client *source_p, char *parv[])
   {
     DelUMode(source_p, UMODE_REGISTERED);
     watch_check_hash(source_p, RPL_LOGOFF);
-    source_p->tsinfo = atol(parv[2]);
+    source_p->tsinfo = strtoimax(parv[2], NULL, 10);
     assert(source_p->tsinfo > 0);
   }
 
-  sendto_common_channels_local(source_p, 1, 0, ":%s!%s@%s NICK :%s",
+  sendto_common_channels_local(source_p, 1, 0, 0, ":%s!%s@%s NICK :%s",
                                source_p->name, source_p->username,
                                source_p->host, parv[1]);
 
   whowas_add_history(source_p, 1);
-  sendto_server(source_p, 0, 0, ":%s NICK %s :%lu",
-                source_p->id, parv[1], (unsigned long)source_p->tsinfo);
+  sendto_server(source_p, 0, 0, ":%s NICK %s :%ju",
+                source_p->id, parv[1], source_p->tsinfo);
 
   /* Set the new nick name */
   hash_del_client(source_p);
@@ -309,19 +324,6 @@ change_remote_nick(struct Client *source_p, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *
- * server introducing new nick/UID (without services support)
- *      - parv[0] = command
- *      - parv[1] = nickname
- *      - parv[2] = hop count
- *      - parv[3] = TS
- *      - parv[4] = umode
- *      - parv[5] = username
- *      - parv[6] = hostname
- *      - parv[7] = ip
- *      - parv[8] = uid
- *      - parv[9] = ircname (gecos)
- *
- * server introducing new nick/UID (with services support)
  *      - parv[ 0] = command
  *      - parv[ 1] = nickname
  *      - parv[ 2] = hop count
@@ -342,9 +344,9 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   client_p = make_client(source_p->from);
   client_p->servptr = source_p;
   client_p->hopcount = atoi(parv[2]);
-  client_p->tsinfo = atol(parv[3]);
+  client_p->tsinfo = strtoimax(parv[3], NULL, 10);
 
-  strlcpy(client_p->account, (parc == 11 ? parv[9] : "*"), sizeof(client_p->account));
+  strlcpy(client_p->account, parv[9], sizeof(client_p->account));
   strlcpy(client_p->name, parv[1], sizeof(client_p->name));
   strlcpy(client_p->id, parv[8], sizeof(client_p->id));
   strlcpy(client_p->sockhost, parv[7], sizeof(client_p->sockhost));
@@ -355,7 +357,7 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   hash_add_client(client_p);
   hash_add_id(client_p);
 
-  /* Parse usermodes */
+  /* Parse user modes */
   for (const char *m = &parv[4][1]; *m; ++m)
   {
     const struct user_modes *tab = umode_map[(unsigned char)*m];
@@ -382,19 +384,6 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *
- * server introducing new nick/UID (without services support)
- *      - parv[0] = command
- *      - parv[1] = nickname
- *      - parv[2] = hop count
- *      - parv[3] = TS
- *      - parv[4] = umode
- *      - parv[5] = username
- *      - parv[6] = hostname
- *      - parv[7] = ip
- *      - parv[8] = uid
- *      - parv[9] = ircname (gecos)
- *
- * server introducing new nick/UID (with services support)
  *      - parv[ 0] = command
  *      - parv[ 1] = nickname
  *      - parv[ 2] = hop count
@@ -412,7 +401,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
                                   int parc, char *parv[])
 {
   const char *uid = parv[8];
-  time_t newts = atol(parv[3]);
+  time_t newts = strtoimax(parv[3], NULL, 10);
   int sameuser = 0;
 
   assert(IsServer(source_p));
@@ -423,7 +412,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   /* If we don't have a TS, or their TS's are the same, kill both */
   if (!newts || !target_p->tsinfo || (newts == target_p->tsinfo))
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(both killed)",
                          target_p->name, target_p->from->name,
                          source_p->from->name);
@@ -442,10 +431,8 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   }
 
   /* The timestamps are different */
-  if (!strcmp(target_p->sockhost, "0")) /* XXX: TBR */
-    sameuser = !irccmp(target_p->username, parv[5]) && !irccmp(target_p->host, parv[6]);
-  else
-    sameuser = !irccmp(target_p->username, parv[5]) && !irccmp(target_p->sockhost, parv[7]);
+  sameuser = !irccmp(target_p->username, parv[5]) &&
+             !irccmp(target_p->sockhost, parv[7]);
 
   /*
    * If the users are the same (loaded a client on a different server)
@@ -461,12 +448,12 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   }
 
   if (sameuser)
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(older killed)",
                          target_p->name, target_p->from->name,
                          source_p->from->name);
   else
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(newer killed)",
                          target_p->name, target_p->from->name,
                          source_p->from->name);
@@ -501,7 +488,7 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
                              int parc, char *parv[])
 {
   int sameuser = 0;
-  time_t newts = atol(parv[2]);
+  time_t newts = strtoimax(parv[2], NULL, 10);
 
   assert(IsClient(source_p));
   assert(IsClient(target_p));
@@ -510,7 +497,7 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
   /* It's a client changing nick and causing a collide */
   if (!newts || !target_p->tsinfo || (newts == target_p->tsinfo))
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                "Nick change collision from %s to %s(%s <- %s)(both killed)",
                source_p->name, target_p->name, target_p->from->name,
                source_p->from->name);
@@ -531,23 +518,19 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
   }
 
   /* The timestamps are different */
-  if (!strcmp(target_p->sockhost, "0") || !strcmp(source_p->sockhost, "0")) /* XXX: TBR */
-    sameuser = !irccmp(target_p->username, source_p->username) &&
-               !irccmp(target_p->host, source_p->host);
-  else
-    sameuser = !irccmp(target_p->username, source_p->username) &&
-               !irccmp(target_p->sockhost, source_p->sockhost);
+  sameuser = !irccmp(target_p->username, source_p->username) &&
+             !irccmp(target_p->sockhost, source_p->sockhost);
 
   if ((sameuser && newts < target_p->tsinfo) ||
       (!sameuser && newts > target_p->tsinfo))
   {
     if (sameuser)
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
            "Nick change collision from %s to %s(%s <- %s)(older killed)",
            source_p->name, target_p->name, target_p->from->name,
            source_p->from->name);
     else
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
            "Nick change collision from %s to %s(%s <- %s)(newer killed)",
              source_p->name, target_p->name, target_p->from->name,
              source_p->from->name);
@@ -566,12 +549,12 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
   }
 
   if (sameuser)
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(older killed)",
                          target_p->name, target_p->from->name,
                          source_p->from->name);
   else
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(newer killed)",
                          target_p->name, target_p->from->name,
                          source_p->from->name);
@@ -681,8 +664,8 @@ m_nick(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!IsExemptResv(source_p) &&
-      !(HasUMode(source_p, UMODE_OPER) && ConfigGeneral.oper_pass_resv) &&
+  if (!HasFlag(source_p, FLAGS_EXEMPTRESV) &&
+      !(HasUMode(source_p, UMODE_OPER) && HasOFlag(source_p, OPER_FLAG_NICK_RESV)) &&
       (conf = find_matching_name_conf(CONF_NRESV, nick, NULL, NULL, 0)))
   {
     ++conf->count;
@@ -743,10 +726,10 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
   if (parc != 3 || EmptyString(parv[parc - 1]))
     return 0;
 
-  if (IsServer(source_p))
-    return 0;  /* Servers can't change nicks.. */
+  if (!IsClient(source_p))
+    return 0;  /* Servers and unknown clients can't change nicks.. */
 
-  if (check_clean_nick(source_p, parv[1], source_p->servptr))
+  if (check_clean_nick(source_p, parv[1]))
     return 0;
 
   /* If the nick doesn't exist, allow it and process like normal */
@@ -777,19 +760,6 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
  *                 pointers.
  * \note Valid arguments for this command are:
  *
- * server introducing new nick/UID (without services support)
- *      - parv[0] = command
- *      - parv[1] = nickname
- *      - parv[2] = hop count
- *      - parv[3] = TS
- *      - parv[4] = umode
- *      - parv[5] = username
- *      - parv[6] = hostname
- *      - parv[7] = ip
- *      - parv[8] = uid
- *      - parv[9] = ircname (gecos)
- *
- * server introducing new nick/UID (with services support)
  *      - parv[ 0] = command
  *      - parv[ 1] = nickname
  *      - parv[ 2] = hop count
@@ -807,12 +777,10 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
 
-  if (parc < 10)
-    return 0;
-
-  if (check_clean_nick(source_p, parv[1], source_p) ||
-      check_clean_user(source_p, parv[1], parv[5], source_p) ||
-      check_clean_host(source_p, parv[1], parv[6], source_p))
+  if (check_clean_nick(source_p, parv[1]) ||
+      check_clean_user(source_p, parv[1], parv[5]) ||
+      check_clean_host(source_p, parv[1], parv[6]) ||
+      check_clean_uid(source_p, parv[1], parv[8]))
     return 0;
 
   /*
@@ -822,7 +790,7 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
    */
   if ((target_p = hash_find_id(parv[8])))
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "ID collision on %s(%s <- %s)(both killed)",
                          target_p->name, target_p->from->name,
                          source_p->from->name);
@@ -850,14 +818,25 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
 
 static struct Message nick_msgtab =
 {
-  "NICK", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { mr_nick, m_nick, ms_nick, m_ignore, m_nick, m_ignore }
+  .cmd = "NICK",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_nick,
+  .handlers[CLIENT_HANDLER] = m_nick,
+  .handlers[SERVER_HANDLER] = ms_nick,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_nick
 };
 
 static struct Message uid_msgtab =
 {
-  "UID", NULL, 0, 0, 10, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_uid, m_ignore, m_ignore, m_ignore }
+  .cmd = "UID",
+  .args_min = 11,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_uid,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -876,10 +855,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5779 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
