@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_quit.c
  * \brief Includes required functions for processing the QUIT command.
- * \version $Id: m_quit.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_quit.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -84,8 +84,13 @@ ms_quit(struct Client *source_p, int parc, char *parv[])
 
 static struct Message quit_msgtab =
 {
-  "QUIT", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_quit, m_quit, ms_quit, m_ignore, m_quit, m_ignore }
+  .cmd = "QUIT",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_quit,
+  .handlers[CLIENT_HANDLER] = m_quit,
+  .handlers[SERVER_HANDLER] = ms_quit,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_quit
 };
 
 static void
@@ -102,10 +107,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
