@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_server.c
  * \brief Includes required functions for processing the SERVER/SID command.
- * \version $Id: m_server.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_server.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -29,6 +29,7 @@
 #include "client.h"
 #include "event.h"
 #include "hash.h"
+#include "id.h"
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
@@ -50,10 +51,10 @@
  *              - pointer to channel
  * output       - NONE
  * side effects - Called on a server burst when
- *                server is CAP_TBURST capable
+ *                server is CAPAB_TBURST capable
  */
 static void
-send_tb(struct Client *client_p, struct Channel *chptr)
+send_tb(struct Client *client_p, const struct Channel *chptr)
 {
   /*
    * We may also send an empty topic here, but only if topic_time isn't 0,
@@ -69,9 +70,9 @@ send_tb(struct Client *client_p, struct Channel *chptr)
    * for further information   -Michael
    */
   if (chptr->topic_time)
-    sendto_one(client_p, ":%s TBURST %lu %s %lu %s :%s", me.id,
-               (unsigned long)chptr->channelts, chptr->chname,
-               (unsigned long)chptr->topic_time,
+    sendto_one(client_p, ":%s TBURST %ju %s %ju %s :%s", me.id,
+               chptr->creationtime, chptr->name,
+               chptr->topic_time,
                chptr->topic_info,
                chptr->topic);
 }
@@ -86,6 +87,7 @@ send_tb(struct Client *client_p, struct Channel *chptr)
 static void
 sendnick_TS(struct Client *client_p, struct Client *target_p)
 {
+  dlink_node *node = NULL;
   char ubuf[IRCD_BUFSIZE] = "";
 
   if (!IsClient(target_p))
@@ -99,23 +101,13 @@ sendnick_TS(struct Client *client_p, struct Client *target_p)
     ubuf[1] = '\0';
   }
 
-  if (IsCapable(client_p, CAP_SVS))
-    sendto_one(client_p, ":%s UID %s %d %lu %s %s %s %s %s %s :%s",
-               target_p->servptr->id,
-               target_p->name, target_p->hopcount + 1,
-               (unsigned long) target_p->tsinfo,
-               ubuf, target_p->username, target_p->host,
-               (MyClient(target_p) && IsIPSpoof(target_p)) ?
-               "0" : target_p->sockhost, target_p->id,
-               target_p->svid, target_p->info);
-  else
-    sendto_one(client_p, ":%s UID %s %d %lu %s %s %s %s %s :%s",
-               target_p->servptr->id,
-               target_p->name, target_p->hopcount + 1,
-               (unsigned long) target_p->tsinfo,
-               ubuf, target_p->username, target_p->host,
-               (MyClient(target_p) && IsIPSpoof(target_p)) ?
-               "0" : target_p->sockhost, target_p->id, target_p->info);
+  sendto_one(client_p, ":%s UID %s %u %ju %s %s %s %s %s %s :%s",
+             target_p->servptr->id,
+             target_p->name, target_p->hopcount + 1,
+             target_p->tsinfo,
+             ubuf, target_p->username, target_p->host,
+             target_p->sockhost, target_p->id,
+             target_p->account, target_p->info);
 
   if (!EmptyString(target_p->certfp))
     sendto_one(client_p, ":%s CERTFP %s", target_p->id, target_p->certfp);
@@ -123,6 +115,20 @@ sendnick_TS(struct Client *client_p, struct Client *target_p)
   if (target_p->away[0])
     sendto_one(client_p, ":%s AWAY :%s", target_p->id, target_p->away);
 
+
+  DLINK_FOREACH(node, target_p->svstags.head)
+  {
+    const struct ServicesTag *svstag = node->data;
+    char *m = ubuf;
+
+    for (const struct user_modes *tab = umode_tab; tab->c; ++tab)
+      if (svstag->umodes & tab->flag)
+        *m++ = tab->c;
+    *m = '\0';
+
+    sendto_one(client_p, ":%s SVSTAG %s %ju %u +%s :%s", me.id, target_p->id,
+               target_p->tsinfo, svstag->numeric, ubuf, svstag->tag);
+  }
 }
 
 /* burst_members()
@@ -136,13 +142,13 @@ static void
 burst_members(struct Client *client_p, struct Channel *chptr)
 {
   struct Client *target_p;
-  struct Membership *ms;
-  dlink_node *ptr;
+  struct Membership *member;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, chptr->members.head)
+  DLINK_FOREACH(node, chptr->members.head)
   {
-    ms       = ptr->data;
-    target_p = ms->client_p;
+    member   = node->data;
+    target_p = member->client_p;
 
     if (!HasFlag(target_p, FLAGS_BURSTED))
     {
@@ -163,36 +169,33 @@ burst_members(struct Client *client_p, struct Channel *chptr)
 static void
 burst_all(struct Client *client_p)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, channel_list.head)
+  DLINK_FOREACH(node, channel_list.head)
   {
-    struct Channel *chptr = ptr->data;
+    struct Channel *chptr = node->data;
 
     if (dlink_list_length(&chptr->members))
     {
       burst_members(client_p, chptr);
-      send_channel_modes(client_p, chptr);
+      channel_send_modes(client_p, chptr);
 
-      if (IsCapable(client_p, CAP_TBURST))
+      if (IsCapable(client_p, CAPAB_TBURST))
         send_tb(client_p, chptr);
     }
   }
 
   /* also send out those that are not on any channel
    */
-  DLINK_FOREACH(ptr, global_client_list.head)
+  DLINK_FOREACH(node, global_client_list.head)
   {
-    struct Client *target_p = ptr->data;
+    struct Client *target_p = node->data;
 
     if (!HasFlag(target_p, FLAGS_BURSTED) && target_p->from != client_p)
       sendnick_TS(client_p, target_p);
 
     DelFlag(target_p, FLAGS_BURSTED);
   }
-
-  if (IsCapable(client_p, CAP_EOB))
-    sendto_one(client_p, ":%s EOB", me.id);
 }
 
 /* server_burst()
@@ -233,67 +236,46 @@ static void
 server_estab(struct Client *client_p)
 {
   struct MaskItem *conf = NULL;
-  char *host;
-  const char *inpath;
-  static char inpath_ip[HOSTLEN * 2 + USERLEN + 6];
-  dlink_node *ptr;
+  dlink_node *node = NULL;
 #if defined(HAVE_LIBCRYPTO) && !defined(OPENSSL_NO_COMP)
   const COMP_METHOD *compression = NULL, *expansion = NULL;
 #endif
 
-  assert(client_p);
-
-  strlcpy(inpath_ip, get_client_name(client_p, SHOW_IP), sizeof(inpath_ip));
-
-  inpath = get_client_name(client_p, MASK_IP); /* "refresh" inpath with host */
-  host   = client_p->name;
-
-  if ((conf = find_conf_name(&client_p->localClient->confs, host, CONF_SERVER))
-      == NULL)
+  if ((conf = find_conf_name(&client_p->connection->confs, client_p->name, CONF_SERVER)) == NULL)
   {
     /* This shouldn't happen, better tell the ops... -A1kmm */
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "Warning: Lost connect{} block "
-                         "for server %s(this shouldn't happen)!", host);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "Warning: lost connect{} block for %s",
+                         get_client_name(client_p, SHOW_IP));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+                         "Warning: lost connect{} block for %s",
+                         get_client_name(client_p, MASK_IP));
     exit_client(client_p, "Lost connect{} block!");
     return;
   }
 
-  MyFree(client_p->localClient->password);
-  client_p->localClient->password = NULL;
+  xfree(client_p->connection->password);
+  client_p->connection->password = NULL;
 
-  /* Its got identd, since it's a server */
-  SetGotId(client_p);
-
-  /* If there is something in the serv_list, it might be this
-   * connecting server..
-   */
-  if (!ConfigServerInfo.hub && local_server_list.head)
+  if (!ConfigServerInfo.hub && dlink_list_length(&local_server_list))
   {
-    if (client_p != local_server_list.head->data || local_server_list.head->next)
-    {
-      ++ServerStats.is_ref;
-      sendto_one(client_p, "ERROR :I'm a leaf not a hub");
-      exit_client(client_p, "I'm a leaf");
-      return;
-    }
+    ++ServerStats.is_ref;
+    exit_client(client_p, "I'm a leaf not a hub");
+    return;
   }
 
   if (IsUnknown(client_p))
   {
     sendto_one(client_p, "PASS %s TS %d %s", conf->spasswd, TS_CURRENT, me.id);
 
-    send_capabilities(client_p, 0);
+    send_capabilities(client_p);
 
     sendto_one(client_p, "SERVER %s 1 :%s%s",
                me.name, ConfigServerHide.hidden ? "(H) " : "", me.info);
   }
 
-  sendto_one(client_p, ":%s SVINFO %d %d 0 :%lu", me.id, TS_CURRENT, TS_MIN,
-             (unsigned long)CurrentTime);
-
-  /* XXX Does this ever happen? I don't think so -db */
-  detach_conf(client_p, CONF_OPER);
+  sendto_one(client_p, ":%s SVINFO %d %d 0 :%ju", me.id, TS_CURRENT, TS_MIN,
+             CurrentTime);
 
   /* *WARNING*
   **    In the following code in place of plain server's
@@ -308,7 +290,7 @@ server_estab(struct Client *client_p)
   */
   client_p->servptr = &me;
 
-  if (IsClosing(client_p))
+  if (HasFlag(client_p, FLAGS_CLOSING))
     return;
 
   SetServer(client_p);
@@ -318,7 +300,7 @@ server_estab(struct Client *client_p)
 
   assert(dlinkFind(&unknown_list, client_p));
 
-  dlink_move_node(&client_p->localClient->lclient_node,
+  dlink_move_node(&client_p->connection->lclient_node,
                   &unknown_list, &local_server_list);
 
   Count.myserver++;
@@ -328,26 +310,26 @@ server_estab(struct Client *client_p)
   hash_add_client(client_p);
   hash_add_id(client_p);
 
-  /* doesnt duplicate client_p->serv if allocated this struct already */
+  /* Doesn't duplicate client_p->serv if allocated this struct already */
   make_server(client_p);
 
-  /* fixing eob timings.. -gnp */
-  client_p->localClient->firsttime = CurrentTime;
+  /* Fixing eob timings.. -gnp */
+  client_p->connection->firsttime = CurrentTime;
 
   if (find_matching_name_conf(CONF_SERVICE, client_p->name, NULL, NULL, 0))
     AddFlag(client_p, FLAGS_SERVICE);
 
   /* Show the real host/IP to admins */
 #ifdef HAVE_LIBCRYPTO
-  if (client_p->localClient->fd.ssl)
+  if (client_p->connection->fd.ssl)
   {
 #ifndef OPENSSL_NO_COMP
-    compression = SSL_get_current_compression(client_p->localClient->fd.ssl);
-    expansion   = SSL_get_current_expansion(client_p->localClient->fd.ssl);
+    compression = SSL_get_current_compression(client_p->connection->fd.ssl);
+    expansion   = SSL_get_current_expansion(client_p->connection->fd.ssl);
 #endif
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link with %s established: [SSL: %s, Compression/Expansion method: %s/%s] (Capabilities: %s)",
-                         inpath_ip, ssl_get_cipher(client_p->localClient->fd.ssl),
+                         get_client_name(client_p, SHOW_IP), ssl_get_cipher(client_p->connection->fd.ssl),
 #ifndef OPENSSL_NO_COMP
                          compression ? SSL_COMP_get_name(compression) : "NONE",
                          expansion ? SSL_COMP_get_name(expansion) : "NONE",
@@ -356,9 +338,9 @@ server_estab(struct Client *client_p)
 #endif
                          show_capabilities(client_p));
     /* Now show the masked hostname/IP to opers */
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link with %s established: [SSL: %s, Compression/Expansion method: %s/%s] (Capabilities: %s)",
-                         inpath, ssl_get_cipher(client_p->localClient->fd.ssl),
+                         get_client_name(client_p, MASK_IP), ssl_get_cipher(client_p->connection->fd.ssl),
 #ifndef OPENSSL_NO_COMP
                          compression ? SSL_COMP_get_name(compression) : "NONE",
                          expansion ? SSL_COMP_get_name(expansion) : "NONE",
@@ -367,7 +349,7 @@ server_estab(struct Client *client_p)
 #endif
                          show_capabilities(client_p));
     ilog(LOG_TYPE_IRCD, "Link with %s established: [SSL: %s, Compression/Expansion method: %s/%s] (Capabilities: %s)",
-         inpath_ip, ssl_get_cipher(client_p->localClient->fd.ssl),
+         get_client_name(client_p, SHOW_IP), ssl_get_cipher(client_p->connection->fd.ssl),
 #ifndef OPENSSL_NO_COMP
          compression ? SSL_COMP_get_name(compression) : "NONE",
          expansion ? SSL_COMP_get_name(expansion) : "NONE",
@@ -379,20 +361,20 @@ server_estab(struct Client *client_p)
   else
 #endif
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link with %s established: (Capabilities: %s)",
-                         inpath_ip, show_capabilities(client_p));
+                         get_client_name(client_p, SHOW_IP), show_capabilities(client_p));
     /* Now show the masked hostname/IP to opers */
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link with %s established: (Capabilities: %s)",
-                         inpath, show_capabilities(client_p));
+                         get_client_name(client_p, MASK_IP), show_capabilities(client_p));
     ilog(LOG_TYPE_IRCD, "Link with %s established: (Capabilities: %s)",
-         inpath_ip, show_capabilities(client_p));
+         get_client_name(client_p, SHOW_IP), show_capabilities(client_p));
   }
 
-  fd_note(&client_p->localClient->fd, "Server: %s", client_p->name);
+  fd_note(&client_p->connection->fd, "Server: %s", client_p->name);
 
-  sendto_server(client_p, NOCAPS, NOCAPS, ":%s SID %s 2 %s :%s%s",
+  sendto_server(client_p, 0, 0, ":%s SID %s 2 %s :%s%s",
                 me.id, client_p->name, client_p->id,
                 IsHidden(client_p) ? "(H) " : "", client_p->info);
 
@@ -409,26 +391,36 @@ server_estab(struct Client *client_p)
    * that at least two servers from my fragment are building
    * up connection this other fragment at the same time, it's
    * a race condition, not the normal way of operation...
-   *
-   * ALSO NOTE: using the get_client_name for server names--
-   *    see previous *WARNING*!!! (Also, original inpath
-   *    is destroyed...)
    */
-  DLINK_FOREACH_PREV(ptr, global_server_list.tail)
+  DLINK_FOREACH_PREV(node, global_server_list.tail)
   {
-    struct Client *target_p = ptr->data;
+    struct Client *target_p = node->data;
 
     /* target_p->from == target_p for target_p == client_p */
     if (IsMe(target_p) || target_p->from == client_p)
       continue;
 
-    sendto_one(client_p, ":%s SID %s %d %s :%s%s",
+    sendto_one(client_p, ":%s SID %s %u %s :%s%s",
                target_p->servptr->id, target_p->name, target_p->hopcount+1,
                target_p->id, IsHidden(target_p) ? "(H) " : "",
                target_p->info);
   }
 
   server_burst(client_p);
+
+  if (IsCapable(client_p, CAPAB_EOB))
+  {
+    DLINK_FOREACH_PREV(node, global_server_list.tail)
+    {
+      struct Client *target_p = node->data;
+
+      if (target_p->from == client_p)
+        continue;
+
+      if (IsMe(target_p) || HasFlag(target_p, FLAGS_EOB))
+        sendto_one(client_p, ":%s EOB", target_p->id);
+    }
+  }
 }
 
 /* set_server_gecos()
@@ -445,7 +437,7 @@ set_server_gecos(struct Client *client_p, const char *info)
   /* check for (H) which is a hidden server */
   if (!strncmp(s, "(H) ", 4))
   {
-    SetHidden(client_p);
+    AddFlag(client_p, FLAGS_HIDDEN);
     s = s + 4;
   }
 
@@ -464,39 +456,21 @@ set_server_gecos(struct Client *client_p, const char *info)
 static int
 mr_server(struct Client *source_p, int parc, char *parv[])
 {
-  char *name = NULL;
+  const char *name = parv[1];
   struct Client *target_p = NULL;
 
-  if (EmptyString(parv[3]))
+  if (EmptyString(parv[parc - 1]))
   {
-    sendto_one(source_p, "ERROR :No servername");
-    exit_client(source_p, "Wrong number of args");
-    return 0;
-  }
-
-  name = parv[1];
-
-  /*
-   * Reject a direct nonTS server connection if we're TS_ONLY -orabidoo
-   */
-  if (!DoesTS(source_p))
-  {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-          "Unauthorized server connection attempt from %s: Non-TS server "
-          "for server %s", get_client_name(source_p, HIDE_IP), name);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
-          "Unauthorized server connection attempt from %s: Non-TS server "
-          "for server %s", get_client_name(source_p, MASK_IP), name);
-    exit_client(source_p, "Non-TS server");
+    exit_client(source_p, "No server description supplied");
     return 0;
   }
 
   if (!valid_servname(name))
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
           "Unauthorized server connection attempt from %s: Bogus server name "
-          "for server %s", get_client_name(source_p, HIDE_IP), name);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+          "for server %s", get_client_name(source_p, SHOW_IP), name);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
           "Unauthorized server connection attempt from %s: Bogus server name "
           "for server %s", get_client_name(source_p, MASK_IP), name);
     exit_client(source_p, "Bogus server name");
@@ -505,14 +479,13 @@ mr_server(struct Client *source_p, int parc, char *parv[])
 
   if (!valid_sid(source_p->id))
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
                          get_client_name(source_p, SHOW_IP), source_p->id);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
                          get_client_name(source_p, MASK_IP), source_p->id);
-    sendto_one(source_p, "ERROR :Bogus server ID introduced");
-    exit_client(source_p, "Bogus server ID intoduced");
+    exit_client(source_p, "Bogus server ID introduced");
     return 0;
   }
 
@@ -524,26 +497,26 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     case -1:
       if (ConfigGeneral.warn_no_connect_block)
       {
-        sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+        sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: No entry for "
-           "servername %s", get_client_name(source_p, HIDE_IP), name);
+           "servername %s", get_client_name(source_p, SHOW_IP), name);
 
-        sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+        sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: No entry for "
            "servername %s", get_client_name(source_p, MASK_IP), name);
       }
 
-      exit_client(source_p, "No connect{} block.");
+      exit_client(source_p, "No connect {} block.");
       return 0;
       /* NOT REACHED */
       break;
 
     case -2:
-      sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Bad password "
-           "for server %s", get_client_name(source_p, HIDE_IP), name);
+           "for server %s", get_client_name(source_p, SHOW_IP), name);
 
-      sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Bad password "
            "for server %s", get_client_name(source_p, MASK_IP), name);
 
@@ -553,22 +526,22 @@ mr_server(struct Client *source_p, int parc, char *parv[])
       break;
 
     case -3:
-      sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid host "
-           "for server %s", get_client_name(source_p, HIDE_IP), name);
+           "for server %s", get_client_name(source_p, SHOW_IP), name);
 
-      sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid host "
            "for server %s", get_client_name(source_p, MASK_IP), name);
 
       exit_client(source_p, "Invalid host.");
       return 0;
     case -4:
-      sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid certificate fingerprint "
-           "for server %s", get_client_name(source_p, HIDE_IP), name);
+           "for server %s", get_client_name(source_p, SHOW_IP), name);
 
-      sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
            "Unauthorized server connection attempt from %s: Invalid certificate fingerprint "
            "for server %s", get_client_name(source_p, MASK_IP), name);
 
@@ -590,28 +563,26 @@ mr_server(struct Client *source_p, int parc, char *parv[])
      * Definitely don't do that here. This is from an unregistered
      * connect - A1kmm.
      */
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Attempt to re-introduce server %s from %s",
-                         name, get_client_name(source_p, HIDE_IP));
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+                         name, get_client_name(source_p, SHOW_IP));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Attempt to re-introduce server %s from %s",
                          name, get_client_name(source_p, MASK_IP));
-    sendto_one(source_p, "ERROR :Server already exists.");
     exit_client(source_p, "Server already exists");
     return 0;
   }
 
   if ((target_p = hash_find_id(source_p->id)))
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Attempt to re-introduce server %s SID %s from %s",
                          name, source_p->id,
-                         get_client_name(source_p, HIDE_IP));
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+                         get_client_name(source_p, SHOW_IP));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Attempt to re-introduce server %s SID %s from %s",
                          name, source_p->id,
                          get_client_name(source_p, MASK_IP));
-    sendto_one(source_p, "ERROR :Server ID already exists.");
     exit_client(source_p, "Server ID already exists");
     return 0;
   }
@@ -628,7 +599,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
    * connect{} block in source_p->name
    */
   strlcpy(source_p->name, name, sizeof(source_p->name));
-  set_server_gecos(source_p, parv[3]);
+  set_server_gecos(source_p, parv[parc - 1]);
   source_p->hopcount = atoi(parv[2]);
   server_estab(source_p);
   return 0;
@@ -644,7 +615,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
 static int
 ms_sid(struct Client *source_p, int parc, char *parv[])
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   struct Client *target_p = NULL;
   struct Client *client_p = source_p->from; /* XXX */
   const struct MaskItem *conf = NULL;
@@ -655,63 +626,59 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   if (!IsServer(source_p))
     return 0;
 
-  if (EmptyString(parv[4]))
+  if (EmptyString(parv[parc - 1]))
   {
-    sendto_one(client_p, "ERROR :No servername");
+    exit_client(client_p, "No server description supplied");
     return 0;
   }
 
   if (!valid_servname(parv[1]))
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server name %s",
                          get_client_name(client_p, SHOW_IP), parv[1]);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced server with bogus server name %s",
                          get_client_name(client_p, MASK_IP), parv[1]);
-    sendto_one(client_p, "ERROR :Bogus server name introduced");
-    exit_client(client_p, "Bogus server name intoduced");
+    exit_client(client_p, "Bogus server name introduced");
     return 0;
   }
 
   if (!valid_sid(parv[3]))
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
                          get_client_name(client_p, SHOW_IP), parv[3]);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
                          get_client_name(client_p, MASK_IP), parv[3]);
-    sendto_one(client_p, "ERROR :Bogus server ID introduced");
-    exit_client(client_p, "Bogus server ID intoduced");
+    exit_client(client_p, "Bogus server ID introduced");
     return 0;
   }
 
   /* collision on SID? */
   if ((target_p = hash_find_id(parv[3])))
   {
-    sendto_one(client_p, "ERROR :SID %s already exists", parv[3]);
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-                         "Link %s cancelled, SID %s already exists",
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "Link %s cancelled, server ID %s already exists",
                          get_client_name(client_p, SHOW_IP), parv[3]);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
-                         "Link %s cancelled, SID %s already exists",
-                         client_p->name, parv[3]);
-    exit_client(client_p, "SID Exists");
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+                         "Link %s cancelled, server ID %s already exists",
+                         get_client_name(client_p, MASK_IP), parv[3]);
+    exit_client(client_p, "Link cancelled, server ID already exists");
     return 0;
   }
 
   /* collision on name? */
   if ((target_p = hash_find_server(parv[1])))
   {
-    sendto_one(client_p, "ERROR :Server %s already exists", parv[1]);
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s cancelled, server %s already exists",
                          get_client_name(client_p, SHOW_IP), parv[1]);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s cancelled, server %s already exists",
-                         client_p->name, parv[1]);
-    exit_client(client_p, "Server Exists");
+                         get_client_name(client_p, MASK_IP), parv[1]);
+    exit_client(client_p, "Server exists");
     return 0;
   }
 
@@ -723,23 +690,23 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     if (target_p != client_p)
       exit_client(target_p, "Overridden");
 
-  conf = client_p->localClient->confs.head->data;
+  conf = client_p->connection->confs.head->data;
 
   /* See if the newly found server is behind a guaranteed
    * leaf. If so, close the link.
    */
-  DLINK_FOREACH(ptr, conf->leaf_list.head)
+  DLINK_FOREACH(node, conf->leaf_list.head)
   {
-    if (!match(ptr->data, parv[1]))
+    if (!match(node->data, parv[1]))
     {
       llined = 1;
       break;
     }
   }
 
-  DLINK_FOREACH(ptr, conf->hub_list.head)
+  DLINK_FOREACH(node, conf->hub_list.head)
   {
-    if (!match(ptr->data, parv[1]))
+    if (!match(node->data, parv[1]))
     {
       hlined = 1;
       break;
@@ -773,10 +740,10 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   if (!hlined)
   {
     /* OOOPs nope can't HUB */
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Non-Hub link %s introduced %s.",
                          get_client_name(client_p, SHOW_IP), parv[1]);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Non-Hub link %s introduced %s.",
                          get_client_name(client_p, MASK_IP), parv[1]);
     exit_client(source_p, "No matching hub_mask.");
@@ -787,13 +754,13 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   if (llined)
   {
     /* OOOPs nope can't HUB this leaf */
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced leafed server %s.",
                          get_client_name(client_p, SHOW_IP), parv[1]);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Link %s introduced leafed server %s.",
                          get_client_name(client_p, MASK_IP), parv[1]);
-    exit_client(client_p, "Leafed Server.");
+    exit_client(client_p, "Leafed server.");
     return 0;
   }
 
@@ -805,10 +772,10 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   strlcpy(target_p->name, parv[1], sizeof(target_p->name));
   strlcpy(target_p->id, parv[3], sizeof(target_p->id));
 
-  set_server_gecos(target_p, parv[4]);
+  set_server_gecos(target_p, parv[parc - 1]);
   SetServer(target_p);
 
-  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_SERVICE, target_p->name, NULL, NULL, 0))
+  if (find_matching_name_conf(CONF_SERVICE, target_p->name, NULL, NULL, 0))
     AddFlag(target_p, FLAGS_SERVICE);
 
   dlinkAdd(target_p, &target_p->node, &global_client_list);
@@ -818,7 +785,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   hash_add_client(target_p);
   hash_add_id(target_p);
 
-  sendto_server(client_p, NOCAPS, NOCAPS, ":%s SID %s %d %s :%s%s",
+  sendto_server(client_p, 0, 0, ":%s SID %s %u %s :%s%s",
                 source_p->id, target_p->name, target_p->hopcount + 1,
                 target_p->id, IsHidden(target_p) ? "(H) " : "", target_p->info);
   sendto_realops_flags(UMODE_EXTERNAL, L_ALL, SEND_NOTICE,
@@ -829,14 +796,26 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
 
 static struct Message server_msgtab =
 {
-  "SERVER", NULL, 0, 0, 4, MAXPARA, MFLG_SLOW, 0,
-  { mr_server, m_registered, m_ignore, m_ignore, m_registered, m_ignore }
+  .cmd = "SERVER",
+  .args_min = 4,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_server,
+  .handlers[CLIENT_HANDLER] = m_registered,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_registered
 };
 
 static struct Message sid_msgtab =
 {
-  "SID", NULL, 0, 0, 5, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_sid, m_ignore, m_ignore, m_ignore }
+  .cmd = "SID",
+  .args_min = 5,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_sid,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -855,10 +834,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7033 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
