@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_squit.c
  * \brief Includes required functions for processing the SQUIT command.
- * \version $Id: m_squit.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_squit.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -39,19 +39,25 @@
 #include "modules.h"
 
 
-/* mo_squit - SQUIT message handler
- *  parv[0] = command
- *  parv[1] = server name
- *  parv[2] = comment
+/*! \brief SQUIT command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = server name
+ *      - parv[2] = comment
  */
 static int
 mo_squit(struct Client *source_p, int parc, char *parv[])
 {
   char comment[REASONLEN + 1] = "";
   struct Client *target_p = NULL;
-  struct Client *p;
-  dlink_node *ptr;
-  const char *server;
+  dlink_node *node = NULL;
+  const char *server = parv[1];
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -59,14 +65,10 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  server = parv[1];
-
-  /* The following allows wild cards in SQUIT. Only
-   * useful when the command is issued by an oper.
-   */
-  DLINK_FOREACH(ptr, global_server_list.head)
+  /* The following allows wild cards in SQUIT. */
+  DLINK_FOREACH(node, global_server_list.head)
   {
-    p = ptr->data;
+    struct Client *p = node->data;
 
     if (IsServer(p) || IsMe(p))
     {
@@ -78,7 +80,7 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  if ((target_p == NULL) || IsMe(target_p))
+  if (!target_p || IsMe(target_p))
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, server);
     return 0;
@@ -103,21 +105,22 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
 
   if (MyConnect(target_p))
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Received SQUIT %s from %s (%s)",
-                         target_p->name, get_client_name(source_p, HIDE_IP), comment);
+                         target_p->name, get_oper_name(source_p), comment);
     ilog(LOG_TYPE_IRCD, "Received SQUIT %s from %s (%s)",
-         target_p->name, get_client_name(source_p, HIDE_IP), comment);
+         target_p->name, get_oper_name(source_p), comment);
 
     /* To them, we are exiting */
     sendto_one(target_p, ":%s SQUIT %s :%s", source_p->id, me.id, comment);
+
     /* Send to everything but target */
-    sendto_server(target_p, NOCAPS, NOCAPS, ":%s SQUIT %s :%s",
+    sendto_server(target_p, 0, 0, ":%s SQUIT %s :%s",
                   source_p->id, target_p->id, comment);
   }
   else
     /* Send to everything */
-    sendto_server(NULL, NOCAPS, NOCAPS, ":%s SQUIT %s :%s",
+    sendto_server(NULL, 0, 0, ":%s SQUIT %s :%s",
                   source_p->id, target_p->id, comment);
 
   AddFlag(target_p, FLAGS_SQUIT);
@@ -126,23 +129,26 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
   return 0;
 }
 
-/** NOTE: I removed wildcard lookups here, because a wildcarded
- **       SQUIT should/can never happen in ms_squit. -Michael
- **/
-
-/* ms_squit - SQUIT message handler
- *  parv[0] = command
- *  parv[1] = server name
- *  parv[2] = comment
+/*! \brief SQUIT command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = server name
+ *      - parv[2] = comment
  */
 static int
 ms_squit(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
   const char *comment = NULL;
-  dlink_node *ptr;
+  dlink_node *node = NULL;
 
-  if (parc < 2 || EmptyString(parv[parc - 1]))
+  if (parc < 2 || EmptyString(parv[1]))
     return 0;
 
   if ((target_p = hash_find_server(parv[1])) == NULL)
@@ -158,10 +164,9 @@ ms_squit(struct Client *source_p, int parc, char *parv[])
 
   if (MyConnect(target_p))
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_GLOBAL, "from %s: Remote SQUIT %s from %s (%s)",
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_GLOBAL, "from %s: Remote SQUIT %s from %s (%s)",
                          me.name, target_p->name, source_p->name, comment);
-    sendto_server(source_p, NOCAPS, NOCAPS,
-                  ":%s GLOBOPS :Remote SQUIT %s from %s (%s)",
+    sendto_server(source_p, 0, 0, ":%s GLOBOPS :Remote SQUIT %s from %s (%s)",
                   me.id, target_p->name, source_p->name, comment);
     ilog(LOG_TYPE_IRCD, "SQUIT From %s : %s (%s)", source_p->name,
          target_p->name, comment);
@@ -170,9 +175,9 @@ ms_squit(struct Client *source_p, int parc, char *parv[])
     sendto_one(target_p, ":%s SQUIT %s :%s", source_p->id, me.id, comment);
 
     /* Send to everything but target and source */
-    DLINK_FOREACH(ptr, local_server_list.head)
+    DLINK_FOREACH(node, local_server_list.head)
     {
-      struct Client *client_p = ptr->data;
+      struct Client *client_p = node->data;
 
       if (client_p == target_p || client_p == source_p->from)
         continue;
@@ -183,7 +188,7 @@ ms_squit(struct Client *source_p, int parc, char *parv[])
   }
   else
     /* Send to everything but source */
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s SQUIT %s :%s",
+    sendto_server(source_p, 0, 0, ":%s SQUIT %s :%s",
                   source_p->id, target_p->id, comment);
 
   AddFlag(target_p, FLAGS_SQUIT);
@@ -194,8 +199,13 @@ ms_squit(struct Client *source_p, int parc, char *parv[])
 
 static struct Message squit_msgtab =
 {
-  "SQUIT", NULL, 0, 0, 1, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, ms_squit, m_ignore, mo_squit, m_ignore }
+  .cmd = "SQUIT",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = ms_squit,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_squit
 };
 
 static void
@@ -212,10 +222,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
