@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_tmode.c
  * \brief Includes required functions for processing the TMODE command.
- * \version $Id: m_tmode.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_tmode.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -54,31 +54,31 @@ ms_tmode(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
 
+  assert(!MyClient(source_p));
+
   if ((chptr = hash_find_channel(parv[2])) == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, parv[2]);
     return 0;
   }
 
-  if (atol(parv[1]) > chptr->creationtime)
+  if (strtoimax(parv[1], NULL, 10) > chptr->creationtime)
     return 0;
 
-  if (IsServer(source_p) || HasFlag(source_p, FLAGS_SERVICE))
-    set_channel_mode(source_p, chptr, NULL, parc - 3, parv + 3);
-  else
-  {
-    struct Membership *member = find_channel_link(source_p, chptr);
-
-    set_channel_mode(source_p, chptr, member, parc - 3, parv + 3);
-  }
-
+  set_channel_mode(source_p, chptr, NULL, parc - 3, parv + 3);
   return 0;
 }
 
 static struct Message tmode_msgtab =
 {
-  "TMODE", NULL, 0, 0, 4, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_tmode, m_ignore, m_ignore, m_ignore }
+  .cmd = "TMODE",
+  .args_min = 4,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_tmode,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -95,10 +95,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
   .flags   = MODULE_FLAG_CORE
