@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2015 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_accept.c
  * \brief Includes required functions for processing the ACCEPT command.
- * \version $Id: m_accept.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_accept.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -91,7 +91,7 @@ list_accepts(struct Client *source_p)
 static void
 add_accept(const struct split_nuh_item *nuh, struct Client *source_p)
 {
-  struct split_nuh_item *const accept_p = MyCalloc(sizeof(*accept_p));
+  struct split_nuh_item *const accept_p = xcalloc(sizeof(*accept_p));
 
   accept_p->nickptr = xstrdup(nuh->nickptr);
   accept_p->userptr = xstrdup(nuh->userptr);
@@ -116,22 +116,22 @@ add_accept(const struct split_nuh_item *nuh, struct Client *source_p)
 static int
 m_accept(struct Client *source_p, int parc, char *parv[])
 {
-  char *mask = NULL;
-  char *p = NULL;
+  struct split_nuh_item nuh;
+  struct split_nuh_item *accept_p = NULL;
   char nick[NICKLEN + 1] = "";
   char user[USERLEN + 1] = "";
   char host[HOSTLEN + 1] = "";
-  struct split_nuh_item nuh;
-  struct split_nuh_item *accept_p = NULL;
+  char *p = NULL;
+  char *mask = collapse(parv[1]);
 
-  if (EmptyString(parv[1]) || !strcmp(parv[1], "*"))
+  if (EmptyString(mask) || !strcmp(mask, "*"))
   {
     list_accepts(source_p);
     return 0;
   }
 
-  for (mask = strtoken(&p, parv[1], ","); mask;
-       mask = strtoken(&p,    NULL, ","))
+  for (mask = strtok_r(mask, ",", &p); mask;
+       mask = strtok_r(NULL, ",", &p))
   {
     if (*mask == '-' && *++mask)
     {
@@ -189,8 +189,13 @@ m_accept(struct Client *source_p, int parc, char *parv[])
 
 static struct Message accept_msgtab =
 {
-  "ACCEPT", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_accept, m_ignore, m_ignore, m_accept, m_ignore }
+  .cmd = "ACCEPT",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_accept,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_accept
 };
 
 static void
@@ -207,11 +212,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7033 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
