@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_away.c
  * \brief Includes required functions for processing the AWAY command.
- * \version $Id: m_away.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_away.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -35,6 +35,7 @@
 #include "conf.h"
 #include "server.h"
 #include "user.h"
+#include "isupport.h"
 
 
 /*! \brief AWAY command handler
@@ -62,7 +63,7 @@ m_away(struct Client *source_p, int parc, char *parv[])
 
       /* We now send this only if they were away before --is */
       sendto_server(source_p, 0, 0, ":%s AWAY", source_p->id);
-      sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY",
+      sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY",
                                    source_p->name, source_p->username,
                                    source_p->host);
     }
@@ -86,7 +87,7 @@ m_away(struct Client *source_p, int parc, char *parv[])
   strlcpy(source_p->away, message, sizeof(source_p->away));
 
   sendto_one_numeric(source_p, &me, RPL_NOWAWAY);
-  sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY :%s",
+  sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY :%s",
                                source_p->name, source_p->username,
                                source_p->host, source_p->away);
   sendto_server(source_p, 0, 0, ":%s AWAY :%s",
@@ -119,7 +120,7 @@ ms_away(struct Client *source_p, int parc, char *parv[])
 
       /* We now send this only if they were away before --is */
       sendto_server(source_p, 0, 0, ":%s AWAY", source_p->id);
-      sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY",
+      sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY",
                                    source_p->name, source_p->username,
                                    source_p->host);
     }
@@ -129,7 +130,7 @@ ms_away(struct Client *source_p, int parc, char *parv[])
 
   strlcpy(source_p->away, message, sizeof(source_p->away));
 
-  sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY :%s",
+  sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY :%s",
                                source_p->name, source_p->username,
                                source_p->host, source_p->away);
   sendto_server(source_p, 0, 0, ":%s AWAY :%s",
@@ -139,31 +140,32 @@ ms_away(struct Client *source_p, int parc, char *parv[])
 
 static struct Message away_msgtab =
 {
-  "AWAY", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_away, ms_away, m_ignore, m_away, m_ignore }
+  .cmd = "AWAY",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_away,
+  .handlers[SERVER_HANDLER] = ms_away,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_away
 };
 
 static void
 module_init(void)
 {
   mod_add_cmd(&away_msgtab);
-  add_isupport("AWAYLEN", NULL, AWAYLEN);
+  isupport_add("AWAYLEN", NULL, AWAYLEN);
 }
 
 static void
 module_exit(void)
 {
   mod_del_cmd(&away_msgtab);
-  delete_isupport("AWAYLEN");
+  isupport_delete("AWAYLEN");
 }
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
