@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 2004 Kevin L. Mitchell <klmitch@mit.edu>
- *  Copyright (c) 2006-2014 ircd-hybrid development team
+ *  Copyright (c) 2006-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,12 +22,11 @@
 
 /*! \file m_cap.c
  * \brief Includes required functions for processing the CAP command.
- * \version $Id: m_cap.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_cap.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
-#include "hash.h"
 #include "ircd.h"
 #include "numeric.h"
 #include "user.h"
@@ -55,7 +54,11 @@ static struct capabilities
     { (cap), (flags), (name), sizeof(name) - 1 }
   _CAP(CAP_UHNAMES, 0, "userhost-in-names"),
   _CAP(CAP_MULTI_PREFIX, 0, "multi-prefix"),
-  _CAP(CAP_AWAY_NOTIFY, 0, "away-notify")
+  _CAP(CAP_AWAY_NOTIFY, 0, "away-notify"),
+  _CAP(CAP_EXTENDED_JOIN, 0, "extended-join"),
+  _CAP(CAP_ACCOUNT_NOTIFY, 0, "account-notify"),
+  _CAP(CAP_INVITE_NOTIFY, 0, "invite-notify"),
+  _CAP(CAP_CHGHOST, 0, "chghost")
 #undef _CAP
 };
 
@@ -76,7 +79,7 @@ capab_search(const char *key, const struct capabilities *cap)
     if (*key++ == '\0')  /* Hit the end, all right... */
       return 0;
     else  /* OK, let's move on... */
-      rb++;
+      ++rb;
 
   /*
    * If the character they differ on happens to be a space, and it happens
@@ -141,12 +144,13 @@ find_cap(const char **caplist_p, int *neg_p)
  * @param[in] subcmd Name of capability subcommand.
  */
 static int
-send_caplist(struct Client *source_p, unsigned int set,
-             unsigned int rem, const char *subcmd)
+send_caplist(struct Client *source_p,
+             const unsigned int *const set,
+             const unsigned int *const rem, const char *subcmd)
 {
   char capbuf[IRCD_BUFSIZE] = "", pfx[16];
   char cmdbuf[IRCD_BUFSIZE] = "";
-  unsigned int i, loc, len, flags, pfx_len, clen;
+  unsigned int i, loc, len, pfx_len, clen;
 
   /* Set up the buffer for the final LS message... */
   clen = snprintf(cmdbuf, sizeof(capbuf), ":%s CAP %s %s ", me.name,
@@ -154,7 +158,7 @@ send_caplist(struct Client *source_p, unsigned int set,
 
   for (i = 0, loc = 0; i < CAPAB_LIST_LEN; ++i)
   {
-    flags = capab_list[i].flags;
+    const struct capabilities *cap = &capab_list[i];
 
     /*
      * This is a little bit subtle, but just involves applying de
@@ -162,9 +166,9 @@ send_caplist(struct Client *source_p, unsigned int set,
      * capability if (and only if) it is set in \a rem or \a set, or
      * if both are null and the capability is hidden.
      */
-    if (!(rem && (rem & capab_list[i].cap)) &&
-        !(set && (set & capab_list[i].cap)) &&
-         (rem || set || (flags & CAPFL_HIDDEN)))
+    if (!(rem && (*rem & cap->cap)) &&
+        !(set && (*set & cap->cap)) &&
+         (rem || set || (cap->flags & CAPFL_HIDDEN)))
       continue;
 
     /* Build the prefix (space separator and any modifiers needed). */
@@ -172,19 +176,19 @@ send_caplist(struct Client *source_p, unsigned int set,
 
     if (loc)
       pfx[pfx_len++] = ' ';
-    if (rem && (rem & capab_list[i].cap))
+    if (rem && (*rem & cap->cap))
       pfx[pfx_len++] = '-';
     else
     {
-      if (flags & CAPFL_PROTO)
+      if (cap->flags & CAPFL_PROTO)
         pfx[pfx_len++] = '~';
-      if (flags & CAPFL_STICKY)
+      if (cap->flags & CAPFL_STICKY)
         pfx[pfx_len++] = '=';
     }
 
     pfx[pfx_len] = '\0';
 
-    len = capab_list[i].namelen + pfx_len;  /* How much we'd add... */
+    len = cap->namelen + pfx_len;  /* How much we'd add... */
 
     if (sizeof(capbuf) < (clen + loc + len + 15))
     {
@@ -194,7 +198,7 @@ send_caplist(struct Client *source_p, unsigned int set,
     }
 
     loc += snprintf(capbuf + loc, sizeof(capbuf) - loc,
-                    "%s%s", pfx, capab_list[i].name);
+                    "%s%s", pfx, cap->name);
   }
 
   sendto_one(source_p, "%s:%s", cmdbuf, capbuf);
@@ -206,9 +210,9 @@ static int
 cap_ls(struct Client *source_p, const char *caplist)
 {
   if (IsUnknown(source_p))  /* Registration hasn't completed; suspend it... */
-    source_p->localClient->registration |= REG_NEED_CAP;
+    source_p->connection->registration |= REG_NEED_CAP;
 
-  return send_caplist(source_p, 0, 0, "LS");  /* Send list of capabilities */
+  return send_caplist(source_p, NULL, NULL, "LS");  /* Send list of capabilities */
 }
 
 static int
@@ -217,12 +221,12 @@ cap_req(struct Client *source_p, const char *caplist)
   const char *cl = caplist;
   struct capabilities *cap = NULL;
   unsigned int set = 0, rem = 0;
-  unsigned int cs = source_p->localClient->cap_client; /* capability set */
-  unsigned int as = source_p->localClient->cap_active; /* active set */
+  unsigned int cs = source_p->connection->cap_client; /* capability set */
+  unsigned int as = source_p->connection->cap_active; /* active set */
   int neg = 0;
 
   if (IsUnknown(source_p))  /* Registration hasn't completed; suspend it... */
-    source_p->localClient->registration |= REG_NEED_CAP;
+    source_p->connection->registration |= REG_NEED_CAP;
 
   while (cl) {  /* Walk through the capabilities list... */
     if (!(cap = find_cap(&cl, &neg))  /* Look up capability... */
@@ -255,10 +259,10 @@ cap_req(struct Client *source_p, const char *caplist)
   }
 
   /* Notify client of accepted changes and copy over results. */
-  send_caplist(source_p, set, rem, "ACK");
+  send_caplist(source_p, &set, &rem, "ACK");
 
-  source_p->localClient->cap_client = cs;
-  source_p->localClient->cap_active = as;
+  source_p->connection->cap_client = cs;
+  source_p->connection->cap_active = as;
 
   return 0;
 }
@@ -279,14 +283,25 @@ cap_ack(struct Client *source_p, const char *caplist)
   {
     /* Walk through the capabilities list... */
     if (!(cap = find_cap(&cl, &neg)) ||  /* Look up capability... */
-        (neg ? (source_p->localClient->cap_active & cap->cap) :
-              !(source_p->localClient->cap_active & cap->cap)))  /* uh... */
+        (neg ? (source_p->connection->cap_client & cap->cap) :
+              !(source_p->connection->cap_client & cap->cap)))  /* uh... */
       continue;
 
-    if (neg)  /* Set or clear the active capability... */
-      source_p->localClient->cap_active &= ~cap->cap;
+    /* Set or clear the active capability... */
+    if (neg)
+    {
+      if (cap->flags & CAPFL_STICKY)
+        continue;  /* but don't clear sticky capabilities */
+
+      source_p->connection->cap_active &= ~cap->cap;
+    }
     else
-      source_p->localClient->cap_active |=  cap->cap;
+    {
+      if (cap->flags & CAPFL_PROHIBIT)
+        continue;  /* and don't set prohibited ones */
+
+      source_p->connection->cap_active |=  cap->cap;
+    }
   }
 
   return 0;
@@ -303,17 +318,17 @@ cap_clear(struct Client *source_p, const char *caplist)
     cap = &capab_list[ii];
 
     /* Only clear active non-sticky capabilities. */
-    if (!(source_p->localClient->cap_active & cap->cap) || (cap->flags & CAPFL_STICKY))
+    if (!(source_p->connection->cap_client & cap->cap) || (cap->flags & CAPFL_STICKY))
       continue;
 
     cleared |= cap->cap;
-    source_p->localClient->cap_client &= ~cap->cap;
+    source_p->connection->cap_client &= ~cap->cap;
 
     if (!(cap->flags & CAPFL_PROTO))
-      source_p->localClient->cap_active &= ~cap->cap;
+      source_p->connection->cap_active &= ~cap->cap;
   }
 
-  return send_caplist(source_p, 0, cleared, "ACK");
+  return send_caplist(source_p, NULL, &cleared, "ACK");
 }
 
 static int
@@ -323,10 +338,10 @@ cap_end(struct Client *source_p, const char *caplist)
     return 0;  /* So just ignore the message... */
 
   /* Capability negotiation is now done... */
-  source_p->localClient->registration &= ~REG_NEED_CAP;
+  source_p->connection->registration &= ~REG_NEED_CAP;
 
   /* If client is now done... */
-  if (!source_p->localClient->registration)
+  if (!source_p->connection->registration)
   {
     register_local_user(source_p);
     return 0;
@@ -339,7 +354,7 @@ static int
 cap_list(struct Client *source_p, const char *caplist)
 {
   /* Send the list of the client's capabilities */
-  return send_caplist(source_p, source_p->localClient->cap_client, 0, "LIST");
+  return send_caplist(source_p, &source_p->connection->cap_client, NULL, "LIST");
 }
 
 static struct subcmd
@@ -405,8 +420,14 @@ m_cap(struct Client *source_p, int parc, char *parv[])
 
 static struct Message cap_msgtab =
 {
-  "CAP", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_cap, m_cap, m_ignore, m_ignore, m_cap, m_ignore }
+  .cmd = "CAP",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_cap,
+  .handlers[CLIENT_HANDLER] = m_cap,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_cap
 };
 
 static void
@@ -425,11 +446,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
