@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2015 ircd-hybrid development team
+ *  Copyright (c) 1998-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_capab.c
  * \brief Includes required functions for processing the CAPAB command.
- * \version $Id: m_capab.c 5474 2015-02-07 19:44:49Z michael $
+ * \version $Id: m_capab.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -50,8 +50,8 @@ mr_capab(struct Client *source_p, int parc, char *parv[])
   char *p = NULL;
   char *s = NULL;
 
-  for (s = strtoken(&p, parv[1], " "); s;
-       s = strtoken(&p,    NULL, " "))
+  for (s = strtok_r(parv[1], " ", &p); s;
+       s = strtok_r(NULL,    " ", &p))
     if ((cap = find_capability(s)))
       SetCapable(source_p, cap);
 
@@ -60,8 +60,14 @@ mr_capab(struct Client *source_p, int parc, char *parv[])
 
 static struct Message capab_msgtab =
 {
-  "CAPAB", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { mr_capab, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore }
+  .cmd = "CAPAB",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_capab,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -78,11 +84,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5474 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
