@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2013-2014 ircd-hybrid development team
+ *  Copyright (c) 2013-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,17 +21,15 @@
 
 /*! \file m_certfp.c
  * \brief Includes required functions for processing the CERTFP command.
- * \version $Id: m_certfp.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_certfp.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
 #include "ircd.h"
-#include "server.h"
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
-#include "irc_string.h"
 #include "memory.h"
 
 
@@ -52,18 +50,24 @@ ms_certfp(struct Client *source_p, int parc, char *parv[])
   if (!IsClient(source_p))
     return 0;
 
-  MyFree(source_p->certfp);
+  xfree(source_p->certfp);
   source_p->certfp = xstrdup(parv[1]);
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s CERTFP %s",
-                source_p->id, parv[1]);
+  sendto_server(source_p, 0, 0, ":%s CERTFP %s",
+                source_p->id, source_p->certfp);
   return 0;
 }
 
 static struct Message certfp_msgtab =
 {
-  "CERTFP", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_certfp, m_ignore, m_ignore, m_ignore }
+  .cmd = "CERTFP",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_certfp,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -80,11 +84,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7033 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
