@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2015 ircd-hybrid development team
+ *  Copyright (c) 2003-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_encap.c
  * \brief Includes required functions for processing the ENCAP command.
- * \version $Id: m_encap.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_encap.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -68,7 +68,7 @@ ms_encap(struct Client *source_p, int parc, char *parv[])
   else
     snprintf(ptr, sizeof(buffer) - cur_len, ":%s", parv[parc - 1]);
 
-  sendto_match_servs(source_p, parv[1], CAP_ENCAP,
+  sendto_match_servs(source_p, parv[1], CAPAB_ENCAP,
                      "ENCAP %s", buffer);
 
   if (match(parv[1], me.name))
@@ -93,15 +93,21 @@ ms_encap(struct Client *source_p, int parc, char *parv[])
 
 static struct Message encap_msgtab =
 {
-  "ENCAP", NULL, 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_encap, m_ignore, m_ignore, m_ignore }
+  .cmd = "ENCAP",
+  .args_min = 3,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_encap,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
 module_init(void)
 {
   mod_add_cmd(&encap_msgtab);
-  add_capability("ENCAP", CAP_ENCAP, 1);
+  add_capability("ENCAP", CAPAB_ENCAP);
 }
 
 static void
@@ -113,11 +119,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
