@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_eob.c
  * \brief Includes required functions for processing the EOB command.
- * \version $Id: m_eob.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_eob.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -36,14 +36,14 @@
 static void
 server_eob(struct Client *server)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   assert(IsServer(server));
 
   AddFlag(server, FLAGS_EOB);
 
-  DLINK_FOREACH(ptr, server->serv->server_list.head)
-    server_eob(ptr->data);
+  DLINK_FOREACH(node, server->serv->server_list.head)
+    server_eob(node->data);
 }
 
 /*! \brief EOB command handler
@@ -62,21 +62,26 @@ ms_eob(struct Client *source_p, int parc, char *parv[])
   assert(IsServer(source_p));
 
   if (MyConnect(source_p))
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "End of burst from %s (%u seconds)",
                          source_p->name,
-                         (unsigned int)(CurrentTime - source_p->localClient->firsttime));
+                         (unsigned int)(CurrentTime - source_p->connection->firsttime));
 
   server_eob(source_p);
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s EOB", source_p->id);
+  sendto_server(source_p, 0, 0, ":%s EOB", source_p->id);
   return 0;
 }
 
 static struct Message eob_msgtab =
 {
-  "EOB", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_ignore, ms_eob, m_ignore, m_ignore, m_ignore }
+  .cmd = "EOB",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_eob,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -93,11 +98,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
