@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2004-2015 ircd-hybrid development team
+ *  Copyright (c) 2004-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_etrace.c
  * \brief Includes required functions for processing the ETRACE command.
- * \version $Id: m_etrace.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_etrace.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -102,12 +102,7 @@ do_etrace(struct Client *source_p, const char *arg)
   {
     const struct Client *target_p = node->data;
 
-    if (wilds)
-    {
-      if (!match(tname, target_p->name))
-        report_this_status(source_p, target_p);
-    }
-    else
+    if (!wilds || !match(tname, target_p->name))
       report_this_status(source_p, target_p);
   }
 
@@ -127,8 +122,13 @@ mo_etrace(struct Client *source_p, int parc, char *parv[])
 
 static struct Message etrace_msgtab =
 {
-  "ETRACE", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_etrace, m_ignore }
+  .cmd = "ETRACE",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_etrace
 };
 
 static void
@@ -145,11 +145,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
