@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_hash.c
  * \brief Includes required functions for processing the HASH command.
- * \version $Id: m_hash.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_hash.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -60,12 +60,12 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 
   for (i = 0; i < HASHSIZE; ++i)
   {
-    if ((cl = hash_get_bucket(HASH_TYPE_CLIENT, i)) != NULL)
+    if ((cl = hash_get_bucket(HASH_TYPE_CLIENT, i)))
     {
       unsigned int len = 0;
 
       ++buckets;
-      for (; cl != NULL; cl = cl->hnext)
+      for (; cl; cl = cl->hnext)
         ++len;
       if (len > max_chain)
         max_chain = len;
@@ -82,12 +82,12 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 
   for (i = 0; i < HASHSIZE; ++i)
   {
-    if ((ch = hash_get_bucket(HASH_TYPE_CHANNEL, i)) != NULL)
+    if ((ch = hash_get_bucket(HASH_TYPE_CHANNEL, i)))
     {
       unsigned int len = 0;
 
       ++buckets;
-      for (; ch != NULL; ch = ch->hnextch)
+      for (; ch; ch = ch->hnextch)
         ++len;
       if (len > max_chain)
         max_chain = len;
@@ -104,12 +104,12 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 
   for (i = 0; i < HASHSIZE; ++i)
   {
-    if ((icl = hash_get_bucket(HASH_TYPE_ID, i)) != NULL)
+    if ((icl = hash_get_bucket(HASH_TYPE_ID, i)))
     {
       unsigned int len = 0;
 
       ++buckets;
-      for (; icl != NULL; icl = icl->idhnext)
+      for (; icl; icl = icl->idhnext)
         ++len;
       if (len > max_chain)
         max_chain = len;
@@ -126,12 +126,12 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 
   for (i = 0; i < HASHSIZE; ++i)
   {
-    if ((ush = hash_get_bucket(HASH_TYPE_USERHOST, i)) != NULL)
+    if ((ush = hash_get_bucket(HASH_TYPE_USERHOST, i)))
     {
       unsigned int len = 0;
 
       ++buckets;
-      for (; ush != NULL; ush = ush->next)
+      for (; ush; ush = ush->next)
         ++len;
       if (len > max_chain)
         max_chain = len;
@@ -146,8 +146,13 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 
 static struct Message hash_msgtab =
 {
-  "HASH", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, m_ignore, m_ignore, mo_hash, m_ignore }
+  .cmd = "HASH",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_hash
 };
 
 static void
@@ -164,11 +169,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
