@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2015 ircd-hybrid development team
+ *  Copyright (c) 1999-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_help.c
  * \brief Includes required functions for processing the HELP command.
- * \version $Id: m_help.c 5770 2015-04-02 19:52:15Z michael $
+ * \version $Id: m_help.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -34,8 +34,8 @@
 #include "modules.h"
 #include "irc_string.h"
 
-#define HELPLEN 400
 
+enum { HELPLEN = 400 };
 
 static void
 sendhelpfile(struct Client *source_p, const char *path, const char *topic)
@@ -78,7 +78,6 @@ static void
 do_help(struct Client *source_p, char *topic)
 {
   char h_index[] = "index";
-  char path[HYB_PATH_MAX + 1];
   struct stat sb;
 
   if (EmptyString(topic))
@@ -93,12 +92,7 @@ do_help(struct Client *source_p, char *topic)
     return;
   }
 
-  if (strlen(HPATH) + strlen(topic) + 1 > HYB_PATH_MAX)
-  {
-    sendto_one_numeric(source_p, &me, ERR_HELPNOTFOUND, topic);
-    return;
-  }
-
+  char path[sizeof(HPATH) + strlen(topic) + 1];  /* +1 for / */
   snprintf(path, sizeof(path), "%s/%s", HPATH, topic);
 
   if (stat(path, &sb) < 0)
@@ -164,8 +158,13 @@ mo_help(struct Client *source_p, int parc, char *parv[])
 
 static struct Message help_msgtab =
 {
-  "HELP", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_help, m_ignore, m_ignore, mo_help, m_ignore }
+  .cmd = "HELP",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_help,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_help
 };
 
 static void
@@ -182,11 +181,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5770 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
