@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 5619 2015-02-27 19:13:12Z michael $
+ * \version $Id: m_info.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -99,12 +99,6 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.klinefile,
     "Path to K-line database file"
   },
-  {
-    "GPATH",
-    OUTPUT_STRING,
-    &ConfigGeneral.glinefile,
-    "Path to G-line database file"
-  },
   {
     "XPATH",
     OUTPUT_STRING,
@@ -171,13 +165,19 @@ static const struct InfoStruct info_table[] =
     &ConfigChannel.invite_client_count,
     "How many INVITE attempts are permitted in invite_client_time"
   },
-
   {
     "invite_client_time",
     OUTPUT_DECIMAL,
     &ConfigChannel.invite_client_time,
     "How many invite_client_count invites are allowed in this time"
   },
+
+  {
+    "invite_delay_channel",
+    OUTPUT_DECIMAL,
+    &ConfigChannel.invite_delay_channel,
+    "Delay between INVITE attempts to a channel"
+  },
   {
     "knock_client_count",
     OUTPUT_DECIMAL,
@@ -208,30 +208,6 @@ static const struct InfoStruct info_table[] =
     &ConfigChannel.max_bans,
     "Total +b/e/I modes allowed in a channel"
   },
-  {
-    "default_split_user_count",
-    OUTPUT_DECIMAL,
-    &ConfigChannel.default_split_user_count,
-    "Startup value of SPLITUSERS"
-  },
-  {
-    "default_split_server_count",
-    OUTPUT_DECIMAL,
-    &ConfigChannel.default_split_server_count,
-    "Startup value of SPLITNUM"
-  },
-  {
-    "no_create_on_split",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigChannel.no_create_on_split,
-    "Disallow creation of channels when split"
-  },
-  {
-    "no_join_on_split",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigChannel.no_join_on_split,
-    "Disallow joining channels when split"
-  },
   {
     "flatten_links",
     OUTPUT_BOOLEAN_YN,
@@ -239,11 +215,17 @@ static const struct InfoStruct info_table[] =
     "Flatten /links list"
   },
   {
-    "links_delay",
+    "flatten_links_delay",
     OUTPUT_DECIMAL,
-    &ConfigServerHide.links_delay,
+    &ConfigServerHide.flatten_links_delay,
     "Links rehash delay"
   },
+  {
+    "flatten_links_file",
+    OUTPUT_STRING,
+    &ConfigServerHide.flatten_links_file,
+    "Path to the flatten links cache file"
+  },
   {
     "hidden",
     OUTPUT_BOOLEAN_YN,
@@ -287,16 +269,28 @@ static const struct InfoStruct info_table[] =
     "How many away_count aways are allowed in this time"
   },
   {
-    "gline_min_cidr",
+    "dline_min_cidr",
     OUTPUT_DECIMAL,
-    &ConfigGeneral.gline_min_cidr,
-    "Minimum required length of a CIDR bitmask for IPv4 G-Lines"
+    &ConfigGeneral.dline_min_cidr,
+    "Minimum required length of a CIDR bitmask for IPv4 D-Lines"
   },
   {
-    "gline_min_cidr6",
+    "dline_min_cidr6",
     OUTPUT_DECIMAL,
-    &ConfigGeneral.gline_min_cidr6,
-    "Minimum required length of a CIDR bitmask for IPv6 G-Lines"
+    &ConfigGeneral.dline_min_cidr6,
+    "Minimum required length of a CIDR bitmask for IPv6 D-Lines"
+  },
+  {
+    "kline_min_cidr",
+    OUTPUT_DECIMAL,
+    &ConfigGeneral.kline_min_cidr,
+    "Minimum required length of a CIDR bitmask for IPv4 K-Lines"
+  },
+  {
+    "kline_min_cidr6",
+    OUTPUT_DECIMAL,
+    &ConfigGeneral.kline_min_cidr6,
+    "Minimum required length of a CIDR bitmask for IPv6 K-Lines"
   },
   {
     "invisible_on_connect",
@@ -362,7 +356,7 @@ static const struct InfoStruct info_table[] =
     "min_nonwildcard",
     OUTPUT_DECIMAL,
     &ConfigGeneral.min_nonwildcard,
-    "Minimum non-wildcard chars in K/G lines"
+    "Minimum non-wildcard chars in K/D lines"
   },
   {
     "min_nonwildcard_simple",
@@ -446,13 +440,13 @@ static const struct InfoStruct info_table[] =
     "stats_P_oper_only",
     OUTPUT_BOOLEAN_YN,
     &ConfigGeneral.stats_P_oper_only,
-    "STATS P is only shown to operators"
+    "STATS P output is only shown to operators"
   },
   {
     "stats_u_oper_only",
     OUTPUT_BOOLEAN_YN,
     &ConfigGeneral.stats_u_oper_only,
-    "STATS u is only shown to operators"
+    "STATS u output is only shown to operators"
   },
   {
     "stats_i_oper_only",
@@ -508,12 +502,6 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.no_oper_flood,
     "Reduce flood control for operators"
   },
-  {
-    "oper_pass_resv",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigGeneral.oper_pass_resv,
-    "Opers can over-ride RESVs"
-  },
   {
     "max_targets",
     OUTPUT_DECIMAL,
@@ -532,24 +520,6 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.throttle_time,
     "Minimum time between client reconnects"
   },
-  {
-    "gline_enable",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigGeneral.glines,
-    "G-line (network-wide K-line) support"
-  },
-  {
-    "gline_duration",
-    OUTPUT_DECIMAL,
-    &ConfigGeneral.gline_time,
-    "Expiry time for G-lines"
-  },
-  {
-    "gline_request_duration",
-    OUTPUT_DECIMAL,
-    &ConfigGeneral.gline_request_time,
-    "Expiry time for pending G-lines"
-  },
 
   /* --[  END OF TABLE  ]---------------------------------------------- */
   {
@@ -571,7 +541,7 @@ send_birthdate_online_time(struct Client *source_p)
 {
   sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                      ":On-line since %s",
-                     myctime(me.connection->firsttime));
+                     date(me.connection->firsttime));
 }
 
 /* send_conf_options()
@@ -617,10 +587,10 @@ send_conf_options(struct Client *source_p)
       /* Output info_table[i].option as a decimal value. */
       case OUTPUT_DECIMAL:
       {
-        const int option = *((const int *const)iptr->option);
+        const unsigned int option = *((const unsigned int *const)iptr->option);
 
         sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
-                           ":%-30s %-5d [%s]",
+                           ":%-30s %-5u [%s]",
                            iptr->name, option, iptr->desc ? iptr->desc : "<none>");
         break;
       }
@@ -628,7 +598,7 @@ send_conf_options(struct Client *source_p)
       /* Output info_table[i].option as "ON" or "OFF" */
       case OUTPUT_BOOLEAN:
       {
-        const int option = *((const int *const)iptr->option);
+        const unsigned int option = *((const unsigned int *const)iptr->option);
 
         sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
@@ -641,7 +611,7 @@ send_conf_options(struct Client *source_p)
       /* Output info_table[i].option as "YES" or "NO" */
       case OUTPUT_BOOLEAN_YN:
       {
-        const int option = *((const int *const)iptr->option);
+        const unsigned int option = *((const unsigned int *const)iptr->option);
 
         sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
@@ -652,7 +622,7 @@ send_conf_options(struct Client *source_p)
 
       case OUTPUT_BOOLEAN2:
       {
-        const int option = *((const int *const)iptr->option);
+        const unsigned int option = *((const unsigned int *const)iptr->option);
 
         sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
@@ -753,8 +723,13 @@ ms_info(struct Client *source_p, int parc, char *parv[])
 
 static struct Message info_msgtab =
 {
-  "INFO", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_info, ms_info, m_ignore, ms_info, m_ignore }
+  .cmd = "INFO",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_info,
+  .handlers[SERVER_HANDLER] = ms_info,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = ms_info
 };
 
 static void
@@ -771,11 +746,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5619 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
