@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_invite.c
  * \brief Includes required functions for processing the INVITE command.
- * \version $Id: m_invite.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_invite.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -35,7 +35,6 @@
 #include "ircd.h"
 #include "numeric.h"
 #include "send.h"
-#include "server.h"
 #include "parse.h"
 #include "modules.h"
 #include "packet.h"
@@ -58,15 +57,16 @@ m_invite(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
   struct Channel *chptr = NULL;
-  struct Membership *ms = NULL;
+  struct Membership *member = NULL;
 
   if (parc < 2)
   {
-    const dlink_node *ptr = NULL;
+    const dlink_node *node = NULL;
 
-    DLINK_FOREACH(ptr, source_p->localClient->invited.head)
+    DLINK_FOREACH(node, source_p->connection->invited.head)
       sendto_one_numeric(source_p, &me, RPL_INVITELIST,
-                         ((struct Channel *)ptr->data)->chname);
+                         ((struct Channel *)node->data)->name);
+
     sendto_one_numeric(source_p, &me, RPL_ENDOFINVITELIST);
     return 0;
   }
@@ -92,63 +92,73 @@ m_invite(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if ((ms = find_channel_link(source_p, chptr)) == NULL)
+  if ((member = find_channel_link(source_p, chptr)) == NULL)
   {
-    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
     return 0;
   }
 
-  if (!has_member_flags(ms, CHFL_CHANOP))
+  if (!has_member_flags(member, CHFL_CHANOP | CHFL_HALFOP))
   {
-    sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->name);
     return 0;
   }
 
   if (IsMember(target_p, chptr))
   {
-    sendto_one_numeric(source_p, &me, ERR_USERONCHANNEL, target_p->name, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_USERONCHANNEL, target_p->name, chptr->name);
     return 0;
   }
 
-  if ((source_p->localClient->invite.last_attempt + ConfigChannel.invite_client_time) < CurrentTime)
-    source_p->localClient->invite.count = 0;
+  if ((source_p->connection->invite.last_attempt + ConfigChannel.invite_client_time) < CurrentTime)
+    source_p->connection->invite.count = 0;
 
-  if (source_p->localClient->invite.count > ConfigChannel.invite_client_count)
+  if (source_p->connection->invite.count > ConfigChannel.invite_client_count)
   {
-    sendto_one_numeric(source_p, &me, ERR_TOOMANYINVITE, chptr->chname, "user");
+    sendto_one_numeric(source_p, &me, ERR_TOOMANYINVITE, chptr->name, "user");
     return 0;
   }
 
-  source_p->localClient->invite.last_attempt = CurrentTime;
-  source_p->localClient->invite.count++;
+  if ((chptr->last_invite + ConfigChannel.invite_delay_channel) > CurrentTime)
+  {
+    sendto_one_numeric(source_p, &me, ERR_TOOMANYINVITE, chptr->name, "channel");
+    return 0;
+  }
 
-  sendto_one_numeric(source_p, &me, RPL_INVITING, target_p->name, chptr->chname);
+  source_p->connection->invite.last_attempt = CurrentTime;
+  source_p->connection->invite.count++;
+
+  sendto_one_numeric(source_p, &me, RPL_INVITING, target_p->name, chptr->name);
 
   if (target_p->away[0])
     sendto_one_numeric(source_p, &me, RPL_AWAY, target_p->name, target_p->away);
 
+  chptr->last_invite = CurrentTime;
+
   if (MyConnect(target_p))
   {
     sendto_one(target_p, ":%s!%s@%s INVITE %s :%s",
                source_p->name, source_p->username,
                source_p->host,
-               target_p->name, chptr->chname);
+               target_p->name, chptr->name);
 
     if (chptr->mode.mode & MODE_INVITEONLY)
-    {
-      sendto_channel_butone(NULL, &me, chptr, CHFL_CHANOP,
-                            "NOTICE @%s :%s is inviting %s to %s.",
-                            chptr->chname, source_p->name,
-                            target_p->name, chptr->chname);
-
-      /* Add the invite if channel is +i */
-      add_invite(chptr, target_p);
-    }
+      add_invite(chptr, target_p);  /* Add the invite if channel is +i */
   }
-  else if (target_p->from != source_p->from)
-    sendto_one(target_p, ":%s INVITE %s %s %lu",
-               source_p->id, target_p->id,
-               chptr->chname, (unsigned long)chptr->channelts);
+
+  if (chptr->mode.mode & MODE_INVITEONLY)
+  {
+    sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, 0, CAP_INVITE_NOTIFY,
+                         ":%s NOTICE %%%s :%s is inviting %s to %s.",
+                         me.name, chptr->name, source_p->name, target_p->name, chptr->name);
+    sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, CAP_INVITE_NOTIFY, 0,
+                         ":%s!%s@%s INVITE %s %s", source_p->name, source_p->username,
+                         source_p->host, target_p->name, chptr->name);
+  }
+
+  sendto_server(source_p, 0, 0, ":%s INVITE %s %s %ju",
+                source_p->id, target_p->id,
+                chptr->name, chptr->creationtime);
   return 0;
 }
 
@@ -184,39 +194,48 @@ ms_invite(struct Client *source_p, int parc, char *parv[])
     return 0;
 
   if (parc > 3 && IsDigit(*parv[3]))
-    if (atoi(parv[3]) > chptr->channelts)
+    if (strtoimax(parv[3], NULL, 10) > chptr->creationtime)
       return 0;
 
+  chptr->last_invite = CurrentTime;
+
   if (MyConnect(target_p))
   {
     sendto_one(target_p, ":%s!%s@%s INVITE %s :%s",
                source_p->name, source_p->username,
                source_p->host,
-               target_p->name, chptr->chname);
+               target_p->name, chptr->name);
 
     if (chptr->mode.mode & MODE_INVITEONLY)
-    {
-      sendto_channel_butone(NULL, &me, chptr, CHFL_CHANOP,
-                            "NOTICE @%s :%s is inviting %s to %s.",
-                            chptr->chname, source_p->name,
-                            target_p->name, chptr->chname);
-
-      /* Add the invite if channel is +i */
-      add_invite(chptr, target_p);
-    }
+      add_invite(chptr, target_p);  /* Add the invite if channel is +i */
   }
-  else if (target_p->from != source_p->from)
-    sendto_one(target_p, ":%s INVITE %s %s %lu",
-               source_p->id, target_p->id,
-               chptr->chname, (unsigned long)chptr->channelts);
+
+  if (chptr->mode.mode & MODE_INVITEONLY)
+  {
+    sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, 0, CAP_INVITE_NOTIFY,
+                         ":%s NOTICE %%%s :%s is inviting %s to %s.",
+                         me.name, chptr->name, source_p->name, target_p->name, chptr->name);
+    sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, CAP_INVITE_NOTIFY, 0,
+                         ":%s!%s@%s INVITE %s %s", source_p->name, source_p->username,
+                         source_p->host, target_p->name, chptr->name);
+  }
+
+  sendto_server(source_p, 0, 0, ":%s INVITE %s %s %ju",
+                source_p->id, target_p->id,
+                chptr->name, chptr->creationtime);
   return 0;
 }
 
 
 static struct Message invite_msgtab =
 {
-  "INVITE", NULL, 0, 0, 1, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_invite, ms_invite, m_ignore, m_invite, m_ignore }
+  .cmd = "INVITE",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_invite,
+  .handlers[SERVER_HANDLER] = ms_invite,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_invite
 };
 
 static void
@@ -233,11 +252,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
