@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_ison.c
  * \brief Includes required functions for processing the ISON command.
- * \version $Id: m_ison.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_ison.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -53,49 +53,31 @@ m_ison(struct Client *source_p, int parc, char *parv[])
   char *p = NULL;
   char *current_insert_point = NULL;
   char buf[IRCD_BUFSIZE];
-  int len;
-  int done = 0;
+  int len, cut = 0;
 
   len = snprintf(buf, sizeof(buf), numeric_form(RPL_ISON), me.name, source_p->name);
   current_insert_point = buf + len;
 
-  /*
-   * rfc1459 is ambigious about how to handle ISON
-   * this should handle both interpretations.
-   */
-  for (int i = 1; i < parc; ++i)
+  for (nick = strtok_r(parv[1], " ", &p); nick;
+       nick = strtok_r(NULL,    " ", &p))
   {
-    for (nick = strtoken(&p, parv[i], " "); nick;
-         nick = strtoken(&p,    NULL, " "))
+    if ((target_p = find_person(source_p, nick)))
     {
-      if ((target_p = find_person(source_p, nick)))
+      len = strlen(target_p->name);
+
+      if ((current_insert_point + (len + 5)) < (buf + sizeof(buf)))
       {
-        len = strlen(target_p->name);
-
-        if ((current_insert_point + (len + 5)) < (buf + sizeof(buf)))
-        {
-          strlcpy(current_insert_point, target_p->name, len);
-          current_insert_point += len;
-          *current_insert_point++ = ' ';
-        }
-        else
-        {
-          done = 1;
-          break;
-        }
+        cut = 1;
+        strlcpy(current_insert_point, target_p->name, len + 1);
+        current_insert_point += len;
+        *current_insert_point++ = ' ';
       }
+      else
+        break;
     }
-
-    if (done)
-      break;
   }
 
-  /*
-   *  current_insert_point--;
-   *  Do NOT take out the trailing space, it breaks ircII
-   *  --Rodder
-   */
-  *current_insert_point  = '\0';
+  *(current_insert_point - cut) = '\0';
 
   sendto_one(source_p, "%s", buf);
   return 0;
@@ -103,8 +85,14 @@ m_ison(struct Client *source_p, int parc, char *parv[])
 
 static struct Message ison_msgtab =
 {
-  "ISON", NULL, 0, 0, 2, 1, MFLG_SLOW, 0,
-  { m_unregistered, m_ison, m_ignore, m_ignore, m_ison, m_ignore }
+  .cmd = "ISON",
+  .args_min = 2,
+  .args_max = 1,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_ison,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ison
 };
 
 static void
@@ -121,11 +109,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
