@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2015 ircd-hybrid development team
+ *  Copyright (c) 1998-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_knock.c
  * \brief Includes required functions for processing the KNOCK command.
- * \version $Id: m_knock.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_knock.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -39,6 +39,7 @@
 #include "modules.h"
 #include "server.h"
 #include "user.h"
+#include "isupport.h"
 
 
 /*! \brief KNOCK command handler
@@ -117,31 +118,36 @@ m_knock(struct Client *source_p, int parc, char *parv[])
   }
 
   chptr->last_knock = CurrentTime;
-
-  sendto_channel_local(CHFL_CHANOP | CHFL_HALFOP, chptr,
+  sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, 0, 0,
                        ":%s NOTICE %%%s :KNOCK: %s (%s [%s@%s] has asked for an invite)",
                        me.name, chptr->name, chptr->name,
                        source_p->name,
                        source_p->username,
                        source_p->host);
 
-  sendto_server(source_p, CAP_KNOCK, 0, ":%s KNOCK %s",
+  sendto_server(source_p, CAPAB_KNOCK, 0, ":%s KNOCK %s",
                 source_p->id, chptr->name);
   return 0;
 }
 
 static struct Message knock_msgtab =
 {
-  "KNOCK", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_knock, m_knock, m_ignore, m_knock, m_ignore }
+  .cmd = "KNOCK",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_knock,
+  .handlers[SERVER_HANDLER] = m_knock,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_knock
 };
 
 static void
 module_init(void)
 {
   mod_add_cmd(&knock_msgtab);
-  add_capability("KNOCK", CAP_KNOCK, 1);
-  add_isupport("KNOCK", NULL, -1);
+  add_capability("KNOCK", CAPAB_KNOCK);
+  isupport_add("KNOCK", NULL, -1);
 }
 
 static void
@@ -149,16 +155,12 @@ module_exit(void)
 {
   mod_del_cmd(&knock_msgtab);
   delete_capability("KNOCK");
-  delete_isupport("KNOCK");
+  isupport_delete("KNOCK");
 }
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
