@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_links.c
  * \brief Includes required functions for processing the LINKS command.
- * \version $Id: m_links.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_links.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -32,7 +32,6 @@
 #include "server.h"
 #include "send.h"
 #include "conf.h"
-#include "motd.h"
 #include "parse.h"
 #include "modules.h"
 
@@ -45,7 +44,7 @@
 static void
 do_links(struct Client *source_p, int parc, char *parv[])
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   sendto_realops_flags(UMODE_SPY, L_ALL, SEND_NOTICE,
                        "LINKS requested by %s (%s@%s) [%s]",
@@ -57,9 +56,9 @@ do_links(struct Client *source_p, int parc, char *parv[])
   {
     const char *mask = (parc > 2 ? parv[2] : parv[1]);
 
-    DLINK_FOREACH(ptr, global_server_list.head)
+    DLINK_FOREACH(node, global_server_list.head)
     {
-      struct Client *target_p = ptr->data;
+      const struct Client *target_p = node->data;
 
       /* skip hidden servers */
       if (IsHidden(target_p))
@@ -93,8 +92,8 @@ do_links(struct Client *source_p, int parc, char *parv[])
      */
     sendto_one_numeric(source_p, &me, RPL_LINKS, me.name, me.name, 0, me.info);
 
-    DLINK_FOREACH(ptr, flatten_links.head)
-      sendto_one_numeric(source_p, &me, RPL_LINKS|SND_EXPLICIT, "%s", ptr->data);
+    DLINK_FOREACH(node, flatten_links.head)
+      sendto_one_numeric(source_p, &me, RPL_LINKS | SND_EXPLICIT, "%s", node->data);
     sendto_one_numeric(source_p, &me, RPL_ENDOFLINKS, "*");
   }
 }
@@ -134,7 +133,7 @@ m_links(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "LINKS");
     return 0;
   }
 
@@ -165,8 +164,7 @@ m_links(struct Client *source_p, int parc, char *parv[])
 static int
 ms_links(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s LINKS %s :%s", 1,
-                  parc, parv) != HUNTED_ISME)
+  if (hunt_server(source_p, ":%s LINKS %s :%s", 1, parc, parv) != HUNTED_ISME)
     return 0;
 
   return m_links(source_p, parc, parv);
@@ -174,8 +172,13 @@ ms_links(struct Client *source_p, int parc, char *parv[])
 
 static struct Message links_msgtab =
 {
-  "LINKS", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_links, ms_links, m_ignore, mo_links, m_ignore }
+  .cmd = "LINKS",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_links,
+  .handlers[SERVER_HANDLER] = ms_links,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_links
 };
 
 static void
@@ -192,11 +195,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
