@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,54 +21,51 @@
 
 /*! \file m_list.c
  * \brief Includes required functions for processing the LIST command.
- * \version $Id: m_list.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_list.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
 #include "list.h"
-#include "channel.h"
-#include "channel_mode.h"
 #include "client.h"
 #include "hash.h"
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
-#include "conf.h"
-#include "server.h"
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
 #include "user.h"
 #include "memory.h"
+#include "isupport.h"
 
 
 static void
-do_list(struct Client *source_p, int parc, char *parv[])
+do_list(struct Client *source_p, char *arg)
 {
   struct ListTask *lt = NULL;
   int no_masked_channels = 1;
 
-  if (source_p->localClient->list_task)
+  if (source_p->connection->list_task)
   {
     free_list_task(source_p);
     sendto_one_numeric(source_p, &me, RPL_LISTEND);
     return;
   }
 
-  lt = MyCalloc(sizeof(struct ListTask));
+  lt = xcalloc(sizeof(struct ListTask));
   lt->users_max = UINT_MAX;
   lt->created_max = UINT_MAX;
   lt->topicts_max = UINT_MAX;
-  source_p->localClient->list_task = lt;
+  source_p->connection->list_task = lt;
 
-  if (parc > 1 && !EmptyString(parv[1]))
+  if (!EmptyString(arg))
   {
     char *opt, *save = NULL;
     dlink_list *list = NULL;
     int i = 0, errors = 0;
 
-    for (opt = strtoken(&save, parv[1], ","); opt;
-         opt = strtoken(&save,    NULL, ","))
+    for (opt = strtok_r(arg,  ",", &save); opt;
+         opt = strtok_r(NULL, ",", &save))
     {
       switch (*opt)
       {
@@ -162,7 +159,7 @@ do_list(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  dlinkAdd(source_p, make_dlink_node(), &listing_client_list);
+  dlinkAdd(source_p, &lt->node, &listing_client_list);
 
   sendto_one_numeric(source_p, &me, RPL_LISTSTART);
   safe_list_channels(source_p, no_masked_channels && lt->show_mask.head != NULL);
@@ -182,39 +179,40 @@ do_list(struct Client *source_p, int parc, char *parv[])
 static int
 m_list(struct Client *source_p, int parc, char *parv[])
 {
-  do_list(source_p, parc, parv);
+  do_list(source_p, parv[1]);
   return 0;
 }
 
 static struct Message list_msgtab =
 {
-  "LIST", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_list, m_ignore, m_ignore, m_list, m_ignore }
+  .cmd = "LIST",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_list,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_list
 };
 
 static void
 module_init(void)
 {
   mod_add_cmd(&list_msgtab);
-  add_isupport("ELIST", "CMNTU", -1);
-  add_isupport("SAFELIST", NULL, -1);
+  isupport_add("ELIST", "CMNTU", -1);
+  isupport_add("SAFELIST", NULL, -1);
 }
 
 static void
 module_exit(void)
 {
   mod_del_cmd(&list_msgtab);
-  delete_isupport("ELIST");
-  delete_isupport("SAFELIST");
+  isupport_delete("ELIST");
+  isupport_delete("SAFELIST");
 }
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7033 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
