@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_motd.c
  * \brief Includes required functions for processing the MOTD command.
- * \version $Id: m_motd.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_motd.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -70,16 +70,14 @@ m_motd(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "MOTD");
     return 0;
   }
 
   last_used = CurrentTime;
 
-  /* This is safe enough to use during non hidden server mode */
-  if (!ConfigServerHide.disable_remote_commands && !ConfigServerHide.hide_servers)
-    if (hunt_server(source_p, ":%s MOTD :%s", 1,
-                    parc, parv) != HUNTED_ISME)
+  if (!ConfigServerHide.disable_remote_commands)
+    if (hunt_server(source_p, ":%s MOTD :%s", 1, parc, parv) != HUNTED_ISME)
       return 0;
 
   do_motd(source_p);
@@ -100,8 +98,7 @@ m_motd(struct Client *source_p, int parc, char *parv[])
 static int
 ms_motd(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s MOTD :%s", 1,
-                  parc, parv) != HUNTED_ISME)
+  if (hunt_server(source_p, ":%s MOTD :%s", 1, parc, parv) != HUNTED_ISME)
     return 0;
 
   do_motd(source_p);
@@ -110,8 +107,13 @@ ms_motd(struct Client *source_p, int parc, char *parv[])
 
 static struct Message motd_msgtab =
 {
-  "MOTD", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_motd, ms_motd, m_ignore, ms_motd, m_ignore }
+  .cmd = "MOTD",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_motd,
+  .handlers[SERVER_HANDLER] = ms_motd,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = ms_motd
 };
 
 static void
@@ -128,11 +130,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
