@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_oper.c
  * \brief Includes required functions for processing the OPER command.
- * \version $Id: m_oper.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_oper.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -39,6 +39,52 @@
 #include "packet.h"
 
 
+/*! \brief Blindly opers up given source_p, using conf info.
+ *         All checks on passwords have already been done.
+ * \param source_p Pointer to given client to oper
+ */
+static void
+oper_up(struct Client *source_p)
+{
+  const unsigned int old = source_p->umodes;
+  const struct MaskItem *const conf = source_p->connection->confs.head->data;
+
+  ++Count.oper;
+  SetOper(source_p);
+
+  if (conf->modes)
+    AddUMode(source_p, conf->modes);
+  else if (ConfigGeneral.oper_umodes)
+    AddUMode(source_p, ConfigGeneral.oper_umodes);
+
+  if (!(old & UMODE_INVISIBLE) && HasUMode(source_p, UMODE_INVISIBLE))
+    ++Count.invisi;
+  else if ((old & UMODE_INVISIBLE) && !HasUMode(source_p, UMODE_INVISIBLE))
+    --Count.invisi;
+
+  assert(dlinkFind(&oper_list, source_p) == NULL);
+  dlinkAdd(source_p, make_dlink_node(), &oper_list);
+
+  AddOFlag(source_p, conf->port);
+
+  if (HasOFlag(source_p, OPER_FLAG_ADMIN))
+    AddUMode(source_p, UMODE_ADMIN);
+
+  if (!EmptyString(conf->whois))
+  {
+    client_attach_svstag(source_p, RPL_WHOISOPERATOR, "+", conf->whois);
+    sendto_server(source_p, 0, 0, ":%s SVSTAG %s %ju %u + :%s",
+                  me.id, source_p->id, source_p->tsinfo,
+                  RPL_WHOISOPERATOR, conf->whois);
+  }
+
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "%s is now an operator",
+                       get_oper_name(source_p));
+  sendto_server(NULL, 0, 0, ":%s GLOBOPS :%s is now an operator",
+                me.id, get_oper_name(source_p));
+  send_umode_out(source_p, old);
+  sendto_one_numeric(source_p, &me, RPL_YOUREOPER);
+}
 
 /*! \brief Notices all opers of the failed oper attempt if enabled
  *
@@ -51,7 +97,7 @@ failed_oper_notice(struct Client *source_p, const char *name,
                    const char *reason)
 {
   if (ConfigGeneral.failed_oper_notice)
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Failed OPER attempt as %s by %s (%s@%s) - %s",
                          name, source_p->name, source_p->username,
                          source_p->host, reason);
@@ -160,8 +206,14 @@ mo_oper(struct Client *source_p, int parc, char *parv[])
 
 static struct Message oper_msgtab =
 {
-  "OPER", NULL, 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_oper, m_ignore, m_ignore, mo_oper, m_ignore }
+  .cmd = "OPER",
+  .args_min = 3,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_oper,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_oper
 };
 
 static void
@@ -178,11 +230,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
