@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_pass.c
  * \brief Includes required functions for processing the PASS command.
- * \version $Id: m_pass.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_pass.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -29,6 +29,7 @@
 #include "irc_string.h"
 #include "send.h"
 #include "numeric.h"
+#include "id.h"
 #include "ircd.h"
 #include "parse.h"
 #include "modules.h"
@@ -48,7 +49,7 @@
  * \note Valid arguments for this command are:
  *      - parv[0] = command
  *      - parv[1] = password
- *      - parv[2] = optional extra version information
+ *      - parv[2] = unused
  *      - parv[3] = TS protocol version
  *      - parv[4] = server ID (SID)
  */
@@ -63,40 +64,27 @@ mr_pass(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  MyFree(source_p->localClient->password);
-  source_p->localClient->password = xstrndup(parv[1], IRCD_MIN(strlen(parv[1]), PASSWDLEN));
-
-  if (parc > 2)
-  {
-    /*
-     * It looks to me as if orabidoo wanted to have more
-     * than one set of option strings possible here...
-     * i.e. ":AABBTS" as long as TS was the last two chars
-     * however, as we are now using CAPAB, I think we can
-     * safely assume if there is a ":TS" then it's a TS server
-     * -Dianora
-     */
-    if (!irccmp(parv[2], "TS") && source_p->tsinfo == 0)
-      source_p->tsinfo = TS_DOESTS;
-  }
+  xfree(source_p->connection->password);
+  source_p->connection->password = xstrndup(parv[1], IRCD_MIN(strlen(parv[1]), PASSWDLEN));
 
   /* Only do this stuff if we are doing ts6 */
   if (parc > 4)
-  {
     if (atoi(parv[3]) >= 6 && valid_sid(parv[4]))
-    {
       strlcpy(source_p->id, parv[4], sizeof(source_p->id));
-      SetCapable(source_p, CAP_TS6);
-    }
-  }
 
   return 0;
 }
 
 static struct Message pass_msgtab =
 {
-  "PASS", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { mr_pass, m_registered, m_ignore, m_ignore, m_registered, mr_pass }
+  .cmd = "PASS",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_pass,
+  .handlers[CLIENT_HANDLER] = m_registered,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_registered
 };
 
 static void
@@ -113,11 +101,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7033 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
