@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_ping.c
  * \brief Includes required functions for processing the PING command.
- * \version $Id: m_ping.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_ping.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -52,8 +52,8 @@
 static int
 m_ping(struct Client *source_p, int parc, char *parv[])
 {
-  struct Client *target_p;
-  char *origin, *destination;
+  struct Client *target_p = NULL;
+  const char *destination = NULL;
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -61,30 +61,27 @@ m_ping(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  origin = parv[1];
   destination = parv[2];  /* Will get NULL or pointer (parc >= 2!!) */
 
   if (ConfigServerHide.disable_remote_commands && !HasUMode(source_p, UMODE_OPER))
   {
     sendto_one(source_p, ":%s PONG %s :%s", me.name,
-              (destination) ? destination : me.name, origin);
+               (destination) ? destination : me.name, parv[1]);
     return 0;
   }
 
   if (!EmptyString(destination) && irccmp(destination, me.name))
   {
-    /* We're sending it across servers.. origin == source_p->name --fl_ */
-    origin = source_p->name;
-
     if ((target_p = hash_find_server(destination)))
-      sendto_one(target_p, ":%s PING %s :%s", source_p->name,
-                 origin, destination);
+      sendto_one(target_p, ":%s PING %s :%s",
+                 ID_or_name(source_p, target_p), source_p->name,
+                 ID_or_name(target_p, target_p));
     else
       sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, destination);
   }
   else
     sendto_one(source_p, ":%s PONG %s :%s", me.name,
-               (destination) ? destination : me.name, origin);
+               (destination) ? destination : me.name, parv[1]);
   return 0;
 }
 
@@ -103,8 +100,8 @@ m_ping(struct Client *source_p, int parc, char *parv[])
 static int
 ms_ping(struct Client *source_p, int parc, char *parv[])
 {
-  struct Client *target_p;
-  const char *origin, *destination;
+  struct Client *target_p = NULL;
+  const char *destination = NULL;
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -112,27 +109,35 @@ ms_ping(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  origin = source_p->name;
   destination = parv[2];  /* Will get NULL or pointer (parc >= 2!!) */
 
   if (!EmptyString(destination) && irccmp(destination, me.name) && irccmp(destination, me.id))
   {
     if ((target_p = hash_find_server(destination)))
-      sendto_one(target_p, ":%s PING %s :%s", source_p->name,
-                 origin, destination);
-    else
+    {
+      if (target_p->from != source_p->from)
+        sendto_one(target_p, ":%s PING %s :%s",
+                   ID_or_name(source_p, target_p), source_p->name,
+                   ID_or_name(target_p, target_p));
+    }
+    else if (!IsDigit(*destination))
       sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, destination);
   }
   else
     sendto_one(source_p, ":%s PONG %s :%s", ID_or_name(&me, source_p),
-               (destination) ? destination : me.name, origin);
+               (destination) ? destination : me.name, ID_or_name(source_p, source_p));
   return 0;
 }
 
 static struct Message ping_msgtab =
 {
-  "PING", NULL, 0, 0, 1, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_ping, ms_ping, m_ignore, m_ping, m_ping }
+  .cmd = "PING",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_ping,
+  .handlers[SERVER_HANDLER] = ms_ping,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ping
 };
 
 static void
@@ -149,11 +154,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
