@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_pong.c
  * \brief Includes required functions for processing the PONG command.
- * \version $Id: m_pong.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_pong.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -35,6 +35,7 @@
 #include "irc_string.h"
 #include "parse.h"
 #include "modules.h"
+#include "server.h"
 
 
 /*! \brief PONG command handler
@@ -52,8 +53,8 @@
 static int
 ms_pong(struct Client *source_p, int parc, char *parv[])
 {
-  struct Client *target_p;
-  const char *origin, *destination;
+  struct Client *target_p = NULL;
+  const char *destination = NULL;
 
   if (parc < 2 || EmptyString(parv[1]))
   {
@@ -61,7 +62,6 @@ ms_pong(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  origin = parv[1];
   destination = parv[2];
 
   /* Now attempt to route the PONG, comstud pointed out routable PING
@@ -74,10 +74,11 @@ ms_pong(struct Client *source_p, int parc, char *parv[])
       irccmp(destination, me.id))
   {
     if ((target_p = hash_find_client(destination)) ||
-        (target_p = hash_find_server(destination)))
+        (target_p = hash_find_id(destination)))
       sendto_one(target_p, ":%s PONG %s %s",
-                 source_p->name, origin, destination);
-    else
+                 ID_or_name(source_p, target_p), parv[1],
+                 ID_or_name(target_p, target_p));
+    else if (!IsDigit(*destination))
       sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, destination);
   }
 
@@ -102,21 +103,20 @@ mr_pong(struct Client *source_p, int parc, char *parv[])
 
   if (parc == 2 && !EmptyString(parv[1]))
   {
-    if (ConfigGeneral.ping_cookie && !source_p->localClient->registration)
+    if (ConfigGeneral.ping_cookie && source_p->connection->random_ping)
     {
       unsigned int incoming_ping = strtoul(parv[1], NULL, 10);
 
-      if (incoming_ping)
+      if (source_p->connection->random_ping == incoming_ping)
       {
-        if (source_p->localClient->random_ping == incoming_ping)
-        {
-          SetPingCookie(source_p);
+        AddFlag(source_p, FLAGS_PING_COOKIE);
+
+        if (!source_p->connection->registration)
           register_local_user(source_p);
-        }
-        else
-          sendto_one_numeric(source_p, &me, ERR_WRONGPONG,
-                             source_p->localClient->random_ping);
       }
+      else
+        sendto_one_numeric(source_p, &me, ERR_WRONGPONG,
+                           source_p->connection->random_ping);
     }
   }
   else
@@ -127,8 +127,13 @@ mr_pong(struct Client *source_p, int parc, char *parv[])
 
 static struct Message pong_msgtab =
 {
-  "PONG", NULL, 0, 0, 1, MAXPARA, MFLG_SLOW, 0,
-  { mr_pong, m_ignore, ms_pong, m_ignore, m_ignore, m_ignore }
+  .cmd = "PONG",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_pong,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_pong,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -145,11 +150,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
