@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2014 ircd-hybrid development team
+ *  Copyright (c) 2001-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_post.c
  * \brief Includes required functions for processing the POST/GET/PUT command.
- * \version $Id: m_post.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_post.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -54,20 +54,35 @@ mr_dumb_proxy(struct Client *source_p, int parc, char *parv[])
 
 static struct Message post_msgtab =
 {
-  "POST", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore }
+  .cmd = "POST",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_dumb_proxy,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static struct Message get_msgtab =
 {
-  "GET", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore }
+  .cmd = "GET",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_dumb_proxy,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static struct Message put_msgtab =
 {
-  "PUT", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { mr_dumb_proxy, m_ignore, m_ignore, m_ignore, m_ignore, m_ignore }
+  .cmd = "PUT",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_dumb_proxy,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -88,11 +103,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
