@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svinfo.c
  * \brief Includes required functions for processing the SVINFO command.
- * \version $Id: m_svinfo.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_svinfo.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -46,13 +46,13 @@
  *      - parv[0] = command
  *      - parv[1] = TS_CURRENT for the server
  *      - parv[2] = TS_MIN for the server
- *      - parv[3] = server is standalone or connected to non-TS only
+ *      - parv[3] = unused
  *      - parv[4] = server's idea of UTC time
  */
 static int
 ms_svinfo(struct Client *source_p, int parc, char *parv[])
 {
-  time_t deltat = 0, theirtime = 0;
+  intmax_t deltat = 0, theirtime = 0;
 
   if (!IsServer(source_p) || !MyConnect(source_p))
     return 0;
@@ -64,12 +64,16 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
      * TS_ONLY we can't fall back to the non-TS protocol so
      * we drop the link  -orabidoo
      */
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-            "Link %s dropped, wrong TS protocol version (%s,%s)",
-            get_client_name(source_p, SHOW_IP), parv[1], parv[2]);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
-                 "Link %s dropped, wrong TS protocol version (%s,%s)",
-                 get_client_name(source_p, MASK_IP), parv[1], parv[2]);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+         "Link %s dropped, wrong TS protocol version (%s,%s)",
+         get_client_name(source_p, SHOW_IP), parv[1], parv[2]);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+         "Link %s dropped, wrong TS protocol version (%s,%s)",
+         get_client_name(source_p, MASK_IP), parv[1], parv[2]);
+    ilog(LOG_TYPE_IRCD,
+         "Link %s dropped, wrong TS protocol version (%s,%s)",
+         get_client_name(source_p, SHOW_IP), parv[1], parv[2]);
+
     exit_client(source_p, "Incompatible TS version");
     return 0;
   }
@@ -79,47 +83,48 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
    */
   set_time();
 
-  theirtime = atol(parv[4]);
-  deltat = abs(theirtime - CurrentTime);
+  theirtime = strtoimax(parv[4], NULL, 10);
+  deltat = imaxabs(theirtime - CurrentTime);
 
   if (deltat > ConfigGeneral.ts_max_delta)
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-          "Link %s dropped, excessive TS delta (my TS=%lu, their TS=%lu, delta=%d)",
-          get_client_name(source_p, SHOW_IP),
-          (unsigned long) CurrentTime,
-          (unsigned long) theirtime,
-          (int) deltat);
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
-          "Link %s dropped, excessive TS delta (my TS=%lu, their TS=%lu, delta=%d)",
-           get_client_name(source_p, MASK_IP),
-           (unsigned long) CurrentTime,
-           (unsigned long) theirtime,
-           (int) deltat);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+          get_client_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
     ilog(LOG_TYPE_IRCD,
-         "Link %s dropped, excessive TS delta (my TS=%lu, their TS=%lu, delta=%d)",
-         get_client_name(source_p, SHOW_IP),
-         (unsigned long) CurrentTime,
-         (unsigned long) theirtime,
-         (int) deltat);
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+
     exit_client(source_p, "Excessive TS delta");
     return 0;
   }
 
   if (deltat > ConfigGeneral.ts_warn_delta)
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                "Link %s notable TS delta (my TS=%lu, their TS=%lu, delta=%d)",
-                source_p->name,
-                (unsigned long) CurrentTime,
-                (unsigned long) theirtime,
-                (int) deltat);
+  {
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+          "Link %s notable TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+          get_client_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+          "Link %s notable TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+          get_client_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
+  }
+
   return 0;
 }
 
 static struct Message svinfo_msgtab =
 {
-  "SVINFO", NULL, 0, 0, 5, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_ignore, ms_svinfo, m_ignore, m_ignore, m_ignore }
+  .cmd = "SVINFO",
+  .args_min = 5,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_svinfo,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -136,11 +141,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
