@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2014-2014 ircd-hybrid development team
+ *  Copyright (c) 2014-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,24 +21,19 @@
 
 /*! \file m_svsjoin.c
  * \brief Includes required functions for processing the SVSJOIN command.
- * \version $Id: m_svsjoin.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_svsjoin.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
 #include "list.h"
 #include "channel.h"
-#include "channel_mode.h"
 #include "client.h"
 #include "hash.h"
 #include "irc_string.h"
 #include "ircd.h"
-#include "numeric.h"
 #include "send.h"
-#include "server.h"
-#include "conf.h"
 #include "parse.h"
 #include "modules.h"
-#include "resv.h"
 
 
 /*! \brief SVSJOIN command handler
@@ -95,8 +90,14 @@ ms_svsjoin(struct Client *source_p, int parc, char *parv[])
 
 static struct Message svsjoin_msgtab =
 {
-  "SVSJOIN", NULL, 0, 0, 3, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_ignore, ms_svsjoin, m_ignore, m_ignore, m_ignore }
+  .cmd = "SVSJOIN",
+  .args_min = 3,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_svsjoin,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -113,11 +114,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
