@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2013-2015 ircd-hybrid development team
+ *  Copyright (c) 2013-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svskill.c
  * \brief Includes required functions for processing the SVSKILL command.
- * \version $Id: m_svskill.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_svskill.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -65,11 +65,11 @@ ms_svskill(struct Client *source_p, int parc, char *parv[])
 
   if (parc > 3)
   {
-    comment = parv[3] ? parv[3] : source_p->name;
-    ts = atol(parv[2]);
+    comment = parv[3] ? parv[3] : CONF_NOREASON;
+    ts = strtoimax(parv[2], NULL, 10);
   }
   else
-    comment = (parc > 2 && parv[2]) ? parv[2] : source_p->name;
+    comment = (parc > 2 && parv[2]) ? parv[2] : CONF_NOREASON;
 
   if ((target_p = find_person(source_p, parv[1])) == NULL)
     return 0;
@@ -98,15 +98,21 @@ ms_svskill(struct Client *source_p, int parc, char *parv[])
     sendto_one(target_p, ":%s SVSKILL %s :%s", source_p->id,
                target_p->id, comment);
   else
-    sendto_one(target_p, ":%s SVSKILL %s %lu :%s", source_p->id,
+    sendto_one(target_p, ":%s SVSKILL %s %ju :%s", source_p->id,
                target_p->id, ts, comment);
   return 0;
 }
 
 static struct Message svskill_msgtab =
 {
-  "SVSKILL", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_svskill, m_ignore, m_ignore, m_ignore }
+  .cmd = "SVSKILL",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_svskill,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -123,11 +129,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
