@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2015 ircd-hybrid development team
+ *  Copyright (c) 2011-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsmode.c
  * \brief Includes required functions for processing the SVSMODE command.
- * \version $Id: m_svsmode.c 5549 2015-02-12 15:51:14Z michael $
+ * \version $Id: m_svsmode.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -64,13 +64,13 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
   if (!HasFlag(source_p, FLAGS_SERVICE))
     return 0;
 
-  ts     = atol(parv[2]);
   modes  = parv[3];
   extarg = (parc > 4) ? parv[4] : NULL;
 
   if ((target_p = find_person(source_p, parv[1])) == NULL)
     return 0;
 
+  ts = strtoimax(parv[2], NULL, 10);
   if (ts && (ts != target_p->tsinfo))
     return 0;
 
@@ -89,7 +89,13 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
 
       case 'd':
         if (!EmptyString(extarg))
+        {
           strlcpy(target_p->account, extarg, sizeof(target_p->account));
+          sendto_common_channels_local(target_p, 1, CAP_ACCOUNT_NOTIFY, 0, ":%s!%s@%s ACCOUNT %s",
+                                       target_p->name, target_p->username,
+                                       target_p->host, target_p->account);
+        }
+
         break;
 
       case 'x':
@@ -124,8 +130,7 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
           AddUMode(target_p, UMODE_INVISIBLE);
           ++Count.invisi;
         }
-
-        if (what == MODE_DEL && HasUMode(target_p, UMODE_INVISIBLE))
+        else if (what == MODE_DEL && HasUMode(target_p, UMODE_INVISIBLE))
         {
           DelUMode(target_p, UMODE_INVISIBLE);
           --Count.invisi;
@@ -151,13 +156,13 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
   }
 
   if (extarg)
-    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %lu %s %s",
+    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %ju %s %s",
                   source_p->id,
-                  target_p->id, (unsigned long)target_p->tsinfo, modes, extarg);
+                  target_p->id, target_p->tsinfo, modes, extarg);
   else
-    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %lu %s",
+    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %ju %s",
                   source_p->id,
-                  target_p->id, (unsigned long)target_p->tsinfo, modes);
+                  target_p->id, target_p->tsinfo, modes);
 
   if (MyConnect(target_p) && (setmodes != target_p->umodes))
   {
@@ -171,8 +176,14 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
 
 static struct Message svsmode_msgtab =
 {
-  "SVSMODE", NULL, 0, 0, 4, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_svsmode, m_ignore, m_ignore, m_ignore }
+  .cmd = "SVSMODE",
+  .args_min = 4,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_svsmode,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -189,11 +200,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5549 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
