@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2015 ircd-hybrid development team
+ *  Copyright (c) 2011-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsnick.c
  * \brief Includes required functions for processing the SVSNICK command.
- * \version $Id: m_svsnick.c 5547 2015-02-12 14:25:58Z michael $
+ * \version $Id: m_svsnick.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 
@@ -97,7 +97,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  target_p->tsinfo = atoi(parv[3]);
+  target_p->tsinfo = strtoimax(parv[3], NULL, 10);
   clear_ban_cache_client(target_p);
   watch_check_hash(target_p, RPL_LOGOFF);
 
@@ -110,28 +110,34 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
     send_umode(target_p, target_p, oldmodes, modebuf);
   }
 
-  sendto_common_channels_local(target_p, 1, 0, ":%s!%s@%s NICK :%s",
+  sendto_common_channels_local(target_p, 1, 0, 0, ":%s!%s@%s NICK :%s",
                                target_p->name, target_p->username,
                                target_p->host, parv[2]);
 
   whowas_add_history(target_p, 1);
 
-  sendto_server(NULL, 0, 0, ":%s NICK %s :%lu",
-                target_p->id, parv[2], (unsigned long)target_p->tsinfo);
+  sendto_server(NULL, 0, 0, ":%s NICK %s :%ju",
+                target_p->id, parv[2], target_p->tsinfo);
   hash_del_client(target_p);
   strlcpy(target_p->name, parv[2], sizeof(target_p->name));
   hash_add_client(target_p);
 
   watch_check_hash(target_p, RPL_LOGON);
 
-  fd_note(&target_p->connection->fd, "Nick: %s", parv[2]);
+  fd_note(&target_p->connection->fd, "Nick: %s", target_p->name);
   return 0;
 }
 
 static struct Message svsnick_msgtab =
 {
-  "SVSNICK", NULL, 0, 0, 4, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_svsnick, m_ignore, m_ignore, m_ignore }
+  .cmd = "SVSNICK",
+  .args_min = 4,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_svsnick,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -148,11 +154,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5547 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
