@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2015-2015 ircd-hybrid development team
+ *  Copyright (c) 2015-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svstag.c
  * \brief Includes required functions for processing the SVSTAG command.
- * \version $Id: m_svstag.c 5559 2015-02-14 19:39:06Z michael $
+ * \version $Id: m_svstag.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -64,16 +64,17 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
   if ((target_p = find_person(source_p, parv[1])) == NULL)
     return 0;
 
-  if ((ts = atol(parv[2])) && ts != target_p->tsinfo)
+  ts = strtoimax(parv[2], NULL, 10);
+  if (ts && (ts != target_p->tsinfo))
     return 0;
 
   if (!strncmp(parv[3], "-", 1))
   {
     /* XXX: possibly allow to remove certain tags by numeric */
     client_clear_svstags(target_p);
-    sendto_server(source_p, 0, 0, ":%s SVSTAG %s %lu %s",
+    sendto_server(source_p, 0, 0, ":%s SVSTAG %s %ju %s",
                   source_p->id,
-                  target_p->id, (unsigned long)target_p->tsinfo, parv[3]);
+                  target_p->id, target_p->tsinfo, parv[3]);
     return 0;
   }
 
@@ -83,17 +84,23 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
   client_attach_svstag(target_p, strtoul(parv[3], NULL, 10),
                        parv[4], parv[5]);
 
-  sendto_server(source_p, 0, 0, ":%s SVSTAG %s %lu %s %s :%s",
+  sendto_server(source_p, 0, 0, ":%s SVSTAG %s %ju %s %s :%s",
                 source_p->id,
-                target_p->id, (unsigned long)target_p->tsinfo,
+                target_p->id, target_p->tsinfo,
                 parv[3], parv[4], parv[5]);
   return 0;
 }
 
 static struct Message svstag_msgtab =
 {
-  "SVSTAG", NULL, 0, 0, 4, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_svstag, m_ignore, m_ignore, m_ignore }
+  .cmd = "SVSTAG",
+  .args_min = 4,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_svstag,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
@@ -110,11 +117,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5559 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
