@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2002-2014 ircd-hybrid development team
+ *  Copyright (c) 2002-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_tburst.c
  * \brief Includes required functions for processing the TBURST command.
- * \version $Id: m_tburst.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_tburst.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -55,8 +55,8 @@ ms_tburst(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
   int accept_remote = 0;
-  time_t remote_channel_ts = atol(parv[1]);
-  time_t remote_topic_ts = atol(parv[3]);
+  time_t remote_channel_ts = strtoimax(parv[1], NULL, 10);
+  time_t remote_topic_ts = strtoimax(parv[3], NULL, 10);
   const char *topic = parv[5];
   const char *setby = parv[4];
 
@@ -86,9 +86,9 @@ ms_tburst(struct Client *source_p, int parc, char *parv[])
    */
   if (HasFlag(source_p, FLAGS_SERVICE))
     accept_remote = 1;
-  else if (remote_channel_ts < chptr->channelts)
+  else if (remote_channel_ts < chptr->creationtime)
     accept_remote = 1;
-  else if (remote_channel_ts == chptr->channelts)
+  else if (remote_channel_ts == chptr->creationtime)
     if (remote_topic_ts > chptr->topic_time)
       accept_remote = 1;
 
@@ -99,14 +99,20 @@ ms_tburst(struct Client *source_p, int parc, char *parv[])
 
     channel_set_topic(chptr, topic, setby, remote_topic_ts, 0);
 
-    sendto_server(source_p, CAP_TBURST, NOCAPS,
-                  ":%s TBURST %s %s %s %s :%s",
+    sendto_server(source_p, CAPAB_TBURST, 0, ":%s TBURST %s %s %s %s :%s",
                   source_p->id, parv[1], parv[2], parv[3], setby, topic);
 
     if (topic_differs)
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s TOPIC %s :%s",
-                           hidden_server ? me.name : source_p->name,
-                           chptr->chname, chptr->topic);
+    {
+      if (!IsClient(source_p))
+        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :%s",
+                             hidden_server ? me.name : source_p->name,
+                             chptr->name, chptr->topic);
+      else
+        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
+                             source_p->name, source_p->username, source_p->host,
+                             chptr->name, chptr->topic);
+    }
   }
 
   return 0;
@@ -114,15 +120,21 @@ ms_tburst(struct Client *source_p, int parc, char *parv[])
 
 static struct Message tburst_msgtab =
 {
-  "TBURST", NULL, 0, 0, 6, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_ignore, ms_tburst, m_ignore, m_ignore, m_ignore }
+  .cmd = "TBURST",
+  .args_min = 6,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_ignore,
+  .handlers[CLIENT_HANDLER] = m_ignore,
+  .handlers[SERVER_HANDLER] = ms_tburst,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_ignore
 };
 
 static void
 module_init(void)
 {
   mod_add_cmd(&tburst_msgtab);
-  add_capability("TBURST", CAP_TBURST, 1);
+  add_capability("TBURST", CAPAB_TBURST);
 }
 
 static void
@@ -134,11 +146,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
