@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_topic.c
  * \brief Includes required functions for processing the TOPIC command.
- * \version $Id: m_topic.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_topic.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -29,6 +29,7 @@
 #include "channel.h"
 #include "channel_mode.h"
 #include "client.h"
+#include "conf.h"
 #include "hash.h"
 #include "irc_string.h"
 #include "ircd.h"
@@ -74,53 +75,52 @@ m_topic(struct Client *source_p, int parc, char *parv[])
   /* setting topic */
   if (parc > 2)
   {
-    const struct Membership *ms = NULL;
+    const struct Membership *member = NULL;
 
-    if ((ms = find_channel_link(source_p, chptr)) == NULL)
+    if ((member = find_channel_link(source_p, chptr)) == NULL)
     {
-      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
       return 0;
     }
 
     if (!(chptr->mode.mode & MODE_TOPICLIMIT) ||
-        has_member_flags(ms, CHFL_CHANOP|CHFL_HALFOP))
+        has_member_flags(member, CHFL_CHANOP|CHFL_HALFOP))
     {
-      char topic_info[USERHOST_REPLYLEN];
+      char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
 
       snprintf(topic_info, sizeof(topic_info), "%s!%s@%s", source_p->name,
                source_p->username, source_p->host);
       channel_set_topic(chptr, parv[2], topic_info, CurrentTime, 1);
 
-      sendto_server(source_p, NOCAPS, NOCAPS, ":%s TOPIC %s :%s",
-                    source_p->id, chptr->chname,
+      sendto_server(source_p, 0, 0, ":%s TOPIC %s :%s",
+                    source_p->id, chptr->name,
                     chptr->topic);
-      sendto_channel_local(ALL_MEMBERS, 0,
-                           chptr, ":%s!%s@%s TOPIC %s :%s",
+      sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
                            source_p->name,
                            source_p->username,
                            source_p->host,
-                           chptr->chname, chptr->topic);
+                           chptr->name, chptr->topic);
     }
     else
-      sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_CHANOPRIVSNEEDED, chptr->name);
   }
   else /* only asking for topic */
   {
     if (!SecretChannel(chptr) || IsMember(source_p, chptr))
     {
       if (chptr->topic[0] == '\0')
-        sendto_one_numeric(source_p, &me, RPL_NOTOPIC, chptr->chname);
+        sendto_one_numeric(source_p, &me, RPL_NOTOPIC, chptr->name);
       else
       {
         sendto_one_numeric(source_p, &me, RPL_TOPIC,
-                           chptr->chname, chptr->topic);
-        sendto_one_numeric(source_p, &me, RPL_TOPICWHOTIME, chptr->chname,
+                           chptr->name, chptr->topic);
+        sendto_one_numeric(source_p, &me, RPL_TOPICWHOTIME, chptr->name,
                            chptr->topic_info,
                            chptr->topic_time);
       }
     }
     else
-      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
   }
 
   return 0;
@@ -143,7 +143,7 @@ static int
 ms_topic(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
-  char topic_info[USERHOST_REPLYLEN];
+  char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];  /* +3 for !, @, \0 */
 
   if (EmptyString(parv[1]))
   {
@@ -164,29 +164,35 @@ ms_topic(struct Client *source_p, int parc, char *parv[])
              source_p->username, source_p->host);
   channel_set_topic(chptr, parv[2], topic_info, CurrentTime, 0);
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s TOPIC %s :%s",
-                source_p->id, chptr->chname,
+  sendto_server(source_p, 0, 0, ":%s TOPIC %s :%s",
+                source_p->id, chptr->name,
                 chptr->topic);
 
   if (!IsClient(source_p))
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s TOPIC %s :%s",
-                         source_p->name,
-                         chptr->chname, chptr->topic);
+    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :%s",
+                         (IsHidden(source_p) || ConfigServerHide.hide_servers) ? me.name : source_p->name,
+                         chptr->name, chptr->topic);
 
   else
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s TOPIC %s :%s",
+    sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
                          source_p->name,
                          source_p->username,
                          source_p->host,
-                         chptr->chname, chptr->topic);
+                         chptr->name, chptr->topic);
   return 0;
 }
 
 
 static struct Message topic_msgtab =
 {
-  "TOPIC", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_topic, ms_topic, m_ignore, m_topic, m_ignore }
+  .cmd = "TOPIC",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_topic,
+  .handlers[SERVER_HANDLER] = ms_topic,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_topic
 };
 
 static void
@@ -203,11 +209,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
