@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unkline.c
  * \brief Includes required functions for processing the UNKLINE command.
- * \version $Id: m_unkline.c 5775 2015-04-04 17:31:06Z michael $
+ * \version $Id: m_unkline.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -38,7 +38,6 @@
 #include "server.h"
 #include "parse.h"
 #include "modules.h"
-#include "conf_db.h"
 #include "memory.h"
 
 
@@ -48,7 +47,7 @@
  * Side effects: Any matching tklines are removed.
  */
 static int
-remove_kline_match(const char *host, const char *user)
+kline_remove(const char *user, const char *host)
 {
   struct irc_ssaddr iphost, *piphost;
   struct MaskItem *conf;
@@ -79,6 +78,24 @@ remove_kline_match(const char *host, const char *user)
   return 0;
 }
 
+static void
+kline_remove_and_notify(struct Client *source_p, const char *user, const char *host)
+{
+  if (kline_remove(user, host))
+  {
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":K-Line for [%s@%s] is removed", user, host);
+
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "%s has removed the K-Line for: [%s@%s]",
+                         get_oper_name(source_p), user, host);
+    ilog(LOG_TYPE_KLINE, "%s removed K-Line for [%s@%s]",
+         get_oper_name(source_p), user, host);
+  }
+  else if (IsClient(source_p))
+    sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found", user, host);
+}
+
 /*! \brief UNKLINE command handler
  *
  * \param source_p Pointer to allocated Client struct from which the message
@@ -116,7 +133,7 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
 
   if (target_server)
   {
-     sendto_match_servs(source_p, target_server, CAP_UNKLN,
+     sendto_match_servs(source_p, target_server, CAPAB_UNKLN,
                         "UNKLINE %s %s %s",
                         target_server, user, host);
 
@@ -125,20 +142,10 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
       return 0;
   }
   else
-    cluster_a_line(source_p, "UNKLINE", CAP_UNKLN, SHARED_UNKLINE,
+    cluster_a_line(source_p, "UNKLINE", CAPAB_UNKLN, SHARED_UNKLINE,
                    "%s %s", user, host);
 
-  if (remove_kline_match(host, user))
-  {
-    sendto_one_notice(source_p, &me, ":K-Line for [%s@%s] is removed", user, host);
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "%s has removed the K-Line for: [%s@%s]",
-                         get_oper_name(source_p), user, host);
-    ilog(LOG_TYPE_KLINE, "%s removed K-Line for [%s@%s]",
-         get_oper_name(source_p), user, host);
-  }
-  else
-    sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found", user, host);
+  kline_remove_and_notify(source_p, user, host);
   return 0;
 }
 
@@ -158,54 +165,46 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
 static int
 ms_unkline(struct Client *source_p, int parc, char *parv[])
 {
-  const char *kuser, *khost;
+  const char *user, *host;
 
   if (parc != 4 || EmptyString(parv[3]))
     return 0;
 
-  sendto_match_servs(source_p, parv[1], CAP_UNKLN, "UNKLINE %s %s %s",
+  sendto_match_servs(source_p, parv[1], CAPAB_UNKLN, "UNKLINE %s %s %s",
                      parv[1], parv[2], parv[3]);
 
-  kuser = parv[2];
-  khost = parv[3];
+  user = parv[2];
+  host = parv[3];
 
   if (match(parv[1], me.name))
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+      find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
                               source_p->username, source_p->host,
                               SHARED_UNKLINE))
-  {
-    if (remove_kline_match(khost, kuser))
-    {
-      if (IsClient(source_p))
-        sendto_one_notice(source_p, &me, ":K-Line for [%s@%s] is removed", kuser, khost);
-
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "%s has removed the K-Line for: [%s@%s]",
-                           get_oper_name(source_p), kuser, khost);
-      ilog(LOG_TYPE_KLINE, "%s removed K-Line for [%s@%s]",
-           get_oper_name(source_p), kuser, khost);
-    }
-    else if (IsClient(source_p))
-      sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found", kuser, khost);
-  }
+    kline_remove_and_notify(source_p, user, host);
 
   return 0;
 }
 
 static struct Message unkline_msgtab =
 {
-  "UNKLINE", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, ms_unkline, m_ignore, mo_unkline, m_ignore }
+  .cmd = "UNKLINE",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = ms_unkline,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_unkline
 };
 
 static void
 module_init(void)
 {
   mod_add_cmd(&unkline_msgtab);
-  add_capability("UNKLN", CAP_UNKLN, 1);
+  add_capability("UNKLN", CAPAB_UNKLN);
 }
 
 static void
@@ -217,11 +216,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5775 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
