@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2014 ircd-hybrid development team
+ *  Copyright (c) 2001-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unresv.c
  * \brief Includes required functions for processing the UNRESV command.
- * \version $Id: m_unresv.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_unresv.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -36,60 +36,47 @@
 #include "conf.h"
 #include "log.h"
 #include "resv.h"
-#include "hash.h"
 
 
 static void
-remove_resv(struct Client *source_p, const char *name)
+resv_remove(struct Client *source_p, const char *name)
 {
+  unsigned int type_int = CONF_CRESV;
+  const char *type_str = "channel";
   struct MaskItem *conf = NULL;
 
-  if (IsChanPrefix(*name))
+  if (!IsChanPrefix(*name))
   {
-    if ((conf = find_exact_name_conf(CONF_CRESV, NULL, name, NULL, NULL)) == NULL)
-    {
-      sendto_one_notice(source_p, &me, ":A RESV does not exist for channel: %s", name);
-      return;
-    }
-
-    if (!IsConfDatabase(conf))
-    {
-      sendto_one_notice(source_p, &me, ":The RESV for channel: %s is in ircd.conf and must be removed by hand.",
-                        name);
-      return;
-    }
-
-    conf_free(conf);
-    sendto_one_notice(source_p, &me, ":The RESV has been removed on channel: %s", name);
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "%s has removed the RESV for channel: %s",
-                         get_oper_name(source_p), name);
-    ilog(LOG_TYPE_RESV, "%s removed RESV for [%s]",
-         get_oper_name(source_p), name);
+    type_int = CONF_NRESV;
+    type_str = "nick";
   }
-  else
+
+  if ((conf = find_exact_name_conf(type_int, NULL, name, NULL, NULL)) == NULL)
   {
-    if ((conf = find_exact_name_conf(CONF_NRESV, NULL, name, NULL, NULL)) == NULL)
-    {
-      sendto_one_notice(source_p, &me, ":A RESV does not exist for nick: %s", name);
-      return;
-    }
+    if (IsClient(source_p))
+     sendto_one_notice(source_p, &me, ":A RESV does not exist for %s: %s", type_str, name);
 
-    if (!IsConfDatabase(conf))
-    {
-      sendto_one_notice(source_p, &me, ":The RESV for nick: %s is in ircd.conf and must be removed by hand.",
-                        name);
-      return;
-    }
-
-    conf_free(conf);
-    sendto_one_notice(source_p, &me, ":The RESV has been removed on nick: %s", name);
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "%s has removed the RESV for nick: %s",
-                         get_oper_name(source_p), name);
-    ilog(LOG_TYPE_RESV, "%s removed RESV for [%s]",
-         get_oper_name(source_p), name);
+    return;
   }
+
+  if (!IsConfDatabase(conf))
+  {
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":The RESV for %s: %s is in ircd.conf and must be removed by hand.",
+                        type_str, name);
+    return;
+  }
+
+  conf_free(conf);
+
+  if (IsClient(source_p))
+    sendto_one_notice(source_p, &me, ":The RESV has been removed on %s: %s", type_str, name);
+
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                       "%s has removed the RESV for %s: %s",
+                       get_oper_name(source_p), type_str, name);
+  ilog(LOG_TYPE_RESV, "%s removed RESV for [%s]",
+       get_oper_name(source_p), name);
 }
 
 /*! \brief UNRESV command handler
@@ -112,16 +99,19 @@ mo_unresv(struct Client *source_p, int parc, char *parv[])
   char *reason = NULL;
   char *target_server = NULL;
 
-  /* UNRESV #channel ON irc.server.com */
-  /* UNRESV kiddie ON irc.server.com */
-  if (parse_aline("UNRESV", source_p, parc, parv, 0, &resv, NULL,
-                  NULL, &target_server, &reason) < 0)
+  if (!HasOFlag(source_p, OPER_FLAG_UNRESV))
+  {
+    sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "unresv");
+    return 0;
+  }
+
+  if (!parse_aline("UNRESV", source_p, parc, parv, 0, &resv, NULL,
+                   NULL, &target_server, &reason))
     return 0;
 
   if (target_server)
   {
-    sendto_match_servs(source_p, target_server, CAP_CLUSTER,
-                       "UNRESV %s %s",
+    sendto_match_servs(source_p, target_server, CAPAB_CLUSTER, "UNRESV %s %s",
                        target_server, resv);
 
     /* Allow ON to apply local unresv as well if it matches */
@@ -129,9 +119,9 @@ mo_unresv(struct Client *source_p, int parc, char *parv[])
       return 0;
   }
   else
-    cluster_a_line(source_p, "UNRESV", CAP_KLN, SHARED_UNRESV, resv);
+    cluster_a_line(source_p, "UNRESV", CAPAB_KLN, SHARED_UNRESV, resv);
 
-  remove_resv(source_p, resv);
+  resv_remove(source_p, resv);
   return 0;
 }
 
@@ -153,25 +143,31 @@ ms_unresv(struct Client *source_p, int parc, char *parv[])
   if (parc != 3 || EmptyString(parv[2]))
     return 0;
 
-  sendto_match_servs(source_p, parv[1], CAP_CLUSTER,
-                     "UNRESV %s %s",
+  sendto_match_servs(source_p, parv[1], CAPAB_CLUSTER, "UNRESV %s %s",
                      parv[1], parv[2]);
 
-  if (!IsClient(source_p) || match(parv[1], me.name))
+  if (match(parv[1], me.name))
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+      find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
                               source_p->username, source_p->host,
                               SHARED_UNRESV))
-    remove_resv(source_p, parv[2]);
+    resv_remove(source_p, parv[2]);
+
   return 0;
 }
 
 static struct Message unresv_msgtab =
 {
-  "UNRESV", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_ignore, m_not_oper, ms_unresv, m_ignore, mo_unresv, m_ignore }
+  .cmd = "UNRESV",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = ms_unresv,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_unresv
 };
 
 static void
@@ -188,11 +184,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
