@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2014 ircd-hybrid development team
+ *  Copyright (c) 2003-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unxline.c
  * \brief Includes required functions for processing the UNXLINE command.
- * \version $Id: m_unxline.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_unxline.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -36,7 +36,6 @@
 #include "server.h"
 #include "parse.h"
 #include "modules.h"
-#include "conf_db.h"
 #include "memory.h"
 
 
@@ -47,13 +46,13 @@
  * Side effects: Any matching tklines are removed.
  */
 static int
-remove_xline_match(const char *gecos)
+xline_remove(const char *gecos)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, xconf_items.head)
+  DLINK_FOREACH(node, gecos_items.head)
   {
-    struct MaskItem *conf = ptr->data;
+    struct MaskItem *conf = node->data;
 
     if (!IsConfDatabase(conf))
       continue;
@@ -69,18 +68,20 @@ remove_xline_match(const char *gecos)
 }
 
 static void
-remove_xline(struct Client *source_p, const char *gecos)
+xline_remove_and_notify(struct Client *source_p, const char *gecos)
 {
-  if (remove_xline_match(gecos))
+  if (xline_remove(gecos))
   {
-    sendto_one_notice(source_p, &me, ":X-Line for [%s] is removed", gecos);
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":X-Line for [%s] is removed", gecos);
+
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "%s has removed the X-Line for: [%s]",
                          get_oper_name(source_p), gecos);
     ilog(LOG_TYPE_XLINE, "%s removed X-Line for [%s]",
          get_oper_name(source_p), gecos);
   }
-  else
+  else if (IsClient(source_p))
     sendto_one_notice(source_p, &me, ":No X-Line for %s", gecos);
 }
 
@@ -109,14 +110,13 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /* UNXLINE bill ON irc.server.com */
-  if (parse_aline("UNXLINE", source_p, parc, parv, 0, &gecos,
-                  NULL, NULL, &target_server, NULL) < 0)
+  if (!parse_aline("UNXLINE", source_p, parc, parv, 0, &gecos,
+                   NULL, NULL, &target_server, NULL))
     return 0;
 
   if (target_server)
   {
-    sendto_match_servs(source_p, target_server, CAP_CLUSTER,
+    sendto_match_servs(source_p, target_server, CAPAB_CLUSTER,
                        "UNXLINE %s %s", target_server, gecos);
 
     /* Allow ON to apply local unxline as well if it matches */
@@ -124,10 +124,9 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
       return 0;
   }
   else
-    cluster_a_line(source_p, "UNXLINE", CAP_CLUSTER, SHARED_UNXLINE,
-                   "%s", gecos);
+    cluster_a_line(source_p, "UNXLINE", CAPAB_CLUSTER, SHARED_UNXLINE, "%s", gecos);
 
-  remove_xline(source_p, gecos);
+  xline_remove_and_notify(source_p, gecos);
   return 0;
 }
 
@@ -146,30 +145,33 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
 static int
 ms_unxline(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc != 3)
+  if (parc != 3 || EmptyString(parv[2]))
     return 0;
 
-  if (!IsClient(source_p) || EmptyString(parv[2]))
-    return 0;
-
-  sendto_match_servs(source_p, parv[1], CAP_CLUSTER, "UNXLINE %s %s",
+  sendto_match_servs(source_p, parv[1], CAPAB_CLUSTER, "UNXLINE %s %s",
                      parv[1], parv[2]);
 
   if (match(parv[1], me.name))
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+      find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
                               source_p->username, source_p->host,
                               SHARED_UNXLINE))
-    remove_xline(source_p, parv[2]);
+    xline_remove_and_notify(source_p, parv[2]);
   return 0;
 }
 
 static struct Message unxline_msgtab =
 {
-  "UNXLINE", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, ms_unxline, m_ignore, mo_unxline, m_ignore }
+  .cmd = "UNXLINE",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = ms_unxline,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_unxline
 };
 
 static void
@@ -186,11 +188,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
