@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_user.c
  * \brief Includes required functions for processing the USER command.
- * \version $Id: m_user.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_user.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -54,7 +54,7 @@ do_user(struct Client *source_p,
 
   strlcpy(source_p->info, realname, sizeof(source_p->info));
 
-  if (!IsGotId(source_p))
+  if (!HasFlag(source_p, FLAGS_GOTID))
     strlcpy(source_p->username, username, sizeof(source_p->username));
 
   if (!source_p->connection->registration)
@@ -101,8 +101,14 @@ mr_user(struct Client *source_p, int parc, char *parv[])
 
 static struct Message user_msgtab =
 {
-  "USER", NULL, 0, 0, 5, MAXPARA, MFLG_SLOW, 0,
-  { mr_user, m_registered, m_ignore, m_ignore, m_registered, m_ignore }
+  .cmd = "USER",
+  .args_min = 5,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_user,
+  .handlers[CLIENT_HANDLER] = m_registered,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_registered
 };
 
 static void
@@ -119,11 +125,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
