@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_userhost.c
  * \brief Includes required functions for processing the USERHOST command.
- * \version $Id: m_userhost.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_userhost.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -59,35 +59,35 @@ m_userhost(struct Client *source_p, int parc, char *parv[])
   cur_len = snprintf(buf, sizeof(buf), numeric_form(RPL_USERHOST), me.name, source_p->name, "");
   t = buf + cur_len;
 
-  for (nick = strtoken(&p, parv[1], " "); nick && i++ < 5;
-       nick = strtoken(&p,    NULL, " "))
+  for (nick = strtok_r(parv[1], " ", &p); nick && i++ < 5;
+       nick = strtok_r(NULL,    " ", &p))
   {
     if ((target_p = find_person(source_p, nick)))
     {
       /*
-       * Show real IP for USERHOST on yourself.
+       * Show real IP address for USERHOST on yourself.
        * This is needed for things like mIRC, which do a server-based
        * lookup (USERHOST) to figure out what the clients' local IP
        * is. Useful for things like NAT, and dynamic dial-up users.
        */
       if (MyClient(target_p) && (target_p == source_p))
       {
-        rl = sprintf(response, "%s%s=%c%s@%s ",
-                     target_p->name,
-                     HasUMode(target_p, UMODE_OPER) ? "*" : "",
-                     (target_p->away[0]) ? '-' : '+',
-                     target_p->username,
-                     target_p->sockhost);
+        rl = snprintf(response, sizeof(response), "%s%s=%c%s@%s ",
+                      target_p->name,
+                      HasUMode(target_p, UMODE_OPER) ? "*" : "",
+                      (target_p->away[0]) ? '-' : '+',
+                      target_p->username,
+                      target_p->sockhost);
       }
       else
       {
-        rl = sprintf(response, "%s%s=%c%s@%s ",
-                     target_p->name, (HasUMode(target_p, UMODE_OPER) &&
-                                      (!HasUMode(target_p, UMODE_HIDDEN) ||
-                                        HasUMode(source_p, UMODE_OPER))) ? "*" : "",
-                     (target_p->away[0]) ? '-' : '+',
-                     target_p->username,
-                     target_p->host);
+        rl = snprintf(response, sizeof(response), "%s%s=%c%s@%s ",
+                      target_p->name, (HasUMode(target_p, UMODE_OPER) &&
+                                       (!HasUMode(target_p, UMODE_HIDDEN) ||
+                                         HasUMode(source_p, UMODE_OPER))) ? "*" : "",
+                      (target_p->away[0]) ? '-' : '+',
+                      target_p->username,
+                      target_p->host);
       }
 
       if ((rl + cur_len) < (IRCD_BUFSIZE - 10))
@@ -107,8 +107,14 @@ m_userhost(struct Client *source_p, int parc, char *parv[])
 
 static struct Message userhost_msgtab =
 {
-  "USERHOST", NULL, 0, 0, 2, 1, MFLG_SLOW, 0,
-  { m_unregistered, m_userhost, m_userhost, m_ignore, m_userhost, m_ignore }
+  .cmd = "USERHOST",
+  .args_min = 2,
+  .args_max = 1,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_userhost,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_userhost
 };
 
 static void
@@ -125,11 +131,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
