@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_version.c
  * \brief Includes required functions for processing the VERSION command.
- * \version $Id: m_version.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: m_version.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -34,6 +34,7 @@
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
+#include "isupport.h"
 
 
 /* Option string. */
@@ -81,7 +82,7 @@ m_version(struct Client *source_p, int parc, char *parv[])
 
   sendto_one_numeric(source_p, &me, RPL_VERSION, ircd_version, serno,
                      me.name, serveropts);
-  show_isupport(source_p);
+  isupport_show(source_p);
   return 0;
 }
 
@@ -104,14 +105,19 @@ ms_version(struct Client *source_p, int parc, char *parv[])
 
   sendto_one_numeric(source_p, &me, RPL_VERSION, ircd_version, serno,
                      me.name, serveropts);
-  show_isupport(source_p);
+  isupport_show(source_p);
   return 0;
 }
 
 static struct Message version_msgtab =
 {
-  "VERSION", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_version, ms_version, m_ignore, ms_version, m_ignore }
+  .cmd = "VERSION",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_version,
+  .handlers[SERVER_HANDLER] = ms_version,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = ms_version
 };
 
 static void
@@ -128,11 +134,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5346 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
