@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1997 Jukka Santala (Donwulff)
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_watch.c
  * \brief Includes required functions for processing the WATCH command.
- * \version $Id: m_watch.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_watch.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -36,6 +36,7 @@
 #include "modules.h"
 #include "user.h"
 #include "watch.h"
+#include "isupport.h"
 
 
 /*
@@ -72,7 +73,7 @@ show_watch(struct Client *source_p, const char *name,
 static int
 m_watch(struct Client *source_p, int parc, char *parv[])
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   char *s = NULL;
   char *p = NULL;
   char *user;
@@ -85,8 +86,8 @@ m_watch(struct Client *source_p, int parc, char *parv[])
   if (parc < 2)
     parv[1] = def;
 
-  for (s = strtoken(&p, parv[1], ", "); s;
-       s = strtoken(&p,    NULL, ", "))
+  for (s = strtok_r(parv[1], ", ", &p); s;
+       s = strtok_r(NULL,    ", ", &p))
   {
     if ((user = strchr(s, '!')))
       *user++ = '\0'; /* Not used */
@@ -99,7 +100,7 @@ m_watch(struct Client *source_p, int parc, char *parv[])
     {
       if (*(s + 1))
       {
-        if (dlink_list_length(&source_p->localClient->watches) >=
+        if (dlink_list_length(&source_p->connection->watches) >=
             ConfigGeneral.max_watch)
         {
           sendto_one_numeric(source_p, &me, ERR_TOOMANYWATCH, s + 1, ConfigGeneral.max_watch);
@@ -143,7 +144,7 @@ m_watch(struct Client *source_p, int parc, char *parv[])
     if (*s == 'S' || *s == 's')
     {
       char buf[IRCD_BUFSIZE] = "";
-      const struct Watch *anptr = NULL;
+      const struct Watch *watch = NULL;
       unsigned int count = 0;
 
       if (list_requested & 0x1)
@@ -155,33 +156,33 @@ m_watch(struct Client *source_p, int parc, char *parv[])
        * Send a list of how many users they have on their WATCH list
        * and how many WATCH lists they are on.
        */
-      if ((anptr = watch_find_hash(source_p->name)))
-        count = dlink_list_length(&anptr->watched_by);
+      if ((watch = watch_find_hash(source_p->name)))
+        count = dlink_list_length(&watch->watched_by);
 
       sendto_one_numeric(source_p, &me, RPL_WATCHSTAT,
-                 dlink_list_length(&source_p->localClient->watches), count);
+                 dlink_list_length(&source_p->connection->watches), count);
 
       /*
        * Send a list of everybody in their WATCH list. Be careful
        * not to buffer overflow.
        */
-      if ((ptr = source_p->localClient->watches.head) == NULL)
+      if ((node = source_p->connection->watches.head) == NULL)
       {
         sendto_one_numeric(source_p, &me, RPL_ENDOFWATCHLIST, *s);
         continue;
       }
 
-      anptr = ptr->data;
-      strlcpy(buf, anptr->nick, sizeof(buf));
+      watch = node->data;
+      strlcpy(buf, watch->nick, sizeof(buf));
 
       count = strlen(source_p->name) + strlen(me.name) + 10 +
               strlen(buf);
 
-      while ((ptr = ptr->next))
+      while ((node = node->next))
       {
-        anptr = ptr->data;
+        watch = node->data;
 
-        if (count + strlen(anptr->nick) + 1 > IRCD_BUFSIZE - 2)
+        if (count + strlen(watch->nick) + 1 > IRCD_BUFSIZE - 2)
         {
           sendto_one_numeric(source_p, &me, RPL_WATCHLIST, buf);
           buf[0] = '\0';
@@ -189,8 +190,8 @@ m_watch(struct Client *source_p, int parc, char *parv[])
         }
 
         strlcat(buf, " ", sizeof(buf));
-        strlcat(buf, anptr->nick, sizeof(buf));
-        count += (strlen(anptr->nick) + 1);
+        strlcat(buf, watch->nick, sizeof(buf));
+        count += (strlen(watch->nick) + 1);
       }
 
       sendto_one_numeric(source_p, &me, RPL_WATCHLIST, buf);
@@ -212,11 +213,11 @@ m_watch(struct Client *source_p, int parc, char *parv[])
 
       list_requested |= 0x2;
 
-      DLINK_FOREACH(ptr, source_p->localClient->watches.head)
+      DLINK_FOREACH(node, source_p->connection->watches.head)
       {
-        const struct Watch *anptr = ptr->data;
+        const struct Watch *watch = node->data;
 
-        if ((target_p = find_person(source_p, anptr->nick)))
+        if ((target_p = find_person(source_p, watch->nick)))
           sendto_one_numeric(source_p, &me, RPL_NOWON,
                              target_p->name, target_p->username,
                              target_p->host, target_p->tsinfo);
@@ -226,8 +227,8 @@ m_watch(struct Client *source_p, int parc, char *parv[])
          * 'L' (full list wanted).
          */
         else if (*s == 'L')
-          sendto_one_numeric(source_p, &me, RPL_NOWOFF, anptr->nick,
-                             "*", "*", anptr->lasttime);
+          sendto_one_numeric(source_p, &me, RPL_NOWOFF, watch->nick,
+                             "*", "*", watch->lasttime);
       }
 
       sendto_one_numeric(source_p, &me, RPL_ENDOFWATCHLIST, *s);
@@ -242,31 +243,32 @@ m_watch(struct Client *source_p, int parc, char *parv[])
 
 static struct Message watch_msgtab =
 {
-  "WATCH", NULL, 0, 0, 0, 1, MFLG_SLOW, 0,
-  { m_unregistered, m_watch, m_ignore, m_ignore, m_watch, m_ignore }
+  .cmd = "WATCH",
+  .args_max = 1,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_watch,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_watch
 };
 
 static void
 module_init(void)
 {
   mod_add_cmd(&watch_msgtab);
-  add_isupport("WATCH", NULL, ConfigGeneral.max_watch);
+  isupport_add("WATCH", NULL, ConfigGeneral.max_watch);
 }
 
 static void
 module_exit(void)
 {
   mod_del_cmd(&watch_msgtab);
-  delete_isupport("WATCH");
+  isupport_delete("WATCH");
 }
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
