@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2012-2014 ircd-hybrid development team
+ *  Copyright (c) 2012-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_webirc.c
  * \brief Includes required functions for processing the WEBIRC command.
- * \version $Id: m_webirc.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_webirc.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -66,9 +66,9 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
   }
 
   conf = find_address_conf(source_p->host,
-                           IsGotId(source_p) ? source_p->username : "webirc",
-                           &source_p->localClient->ip,
-                           source_p->localClient->aftype, parv[1]);
+                           HasFlag(source_p, FLAGS_GOTID) ? source_p->username : "webirc",
+                           &source_p->connection->ip,
+                           source_p->connection->aftype, parv[1]);
   if (conf == NULL || !IsConfClient(conf))
     return 0;
 
@@ -104,18 +104,18 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
 
   assert(res);
 
-  memcpy(&source_p->localClient->ip, res->ai_addr, res->ai_addrlen);
-  source_p->localClient->ip.ss_len = res->ai_addrlen;
-  source_p->localClient->ip.ss.ss_family = res->ai_family;
-  source_p->localClient->aftype = res->ai_family;
+  memcpy(&source_p->connection->ip, res->ai_addr, res->ai_addrlen);
+  source_p->connection->ip.ss_len = res->ai_addrlen;
+  source_p->connection->ip.ss.ss_family = res->ai_family;
+  source_p->connection->aftype = res->ai_family;
   freeaddrinfo(res);
 
   strlcpy(source_p->sockhost, parv[4], sizeof(source_p->sockhost));
   strlcpy(source_p->host, parv[3], sizeof(source_p->host));
 
-  /* Check dlines now, k/glines will be checked on registration */
-  if ((conf = find_dline_conf(&source_p->localClient->ip,
-                               source_p->localClient->aftype)))
+  /* Check dlines now, k-lines will be checked on registration */
+  if ((conf = find_dline_conf(&source_p->connection->ip,
+                               source_p->connection->aftype)))
   {
     if (!(conf->type == CONF_EXEMPT))
     {
@@ -132,8 +132,14 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
 
 static struct Message webirc_msgtab =
 {
-  "WEBIRC", NULL, 0, 0, 5, MAXPARA, MFLG_SLOW, 0,
-  { mr_webirc, m_registered, m_ignore, m_ignore, m_registered, m_ignore }
+  .cmd = "WEBIRC",
+  .args_min = 5,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = mr_webirc,
+  .handlers[CLIENT_HANDLER] = m_registered,
+  .handlers[SERVER_HANDLER] = m_ignore,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = m_registered
 };
 
 static void
@@ -150,11 +156,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
