@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whois.c
  * \brief Includes required functions for processing the WHOIS command.
- * \version $Id: m_whois.c 5630 2015-03-01 12:18:47Z michael $
+ * \version $Id: m_whois.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -92,7 +92,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
 
     if (show)
     {
-      if ((cur_len + 4 + strlen(member->chptr->name) + 1) > (IRCD_BUFSIZE - 2))
+      if ((cur_len + 4 + member->chptr->name_len + 1) > (IRCD_BUFSIZE - 2))
       {
         *(t - 1) = '\0';
         sendto_one(source_p, "%s", buf);
@@ -126,7 +126,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
   if (HasUMode(target_p, UMODE_REGISTERED))
     sendto_one_numeric(source_p, &me, RPL_WHOISREGNICK, target_p->name);
 
-  if (!IsDigit(target_p->account[0]) && target_p->account[0] != '*')
+  if (strcmp(target_p->account, "*"))
     sendto_one_numeric(source_p, &me, RPL_WHOISACCOUNT, target_p->name,
                        target_p->account, "is");
 
@@ -185,10 +185,9 @@ whois_person(struct Client *source_p, struct Client *target_p)
   }
 
   if (HasUMode(source_p, UMODE_OPER) || source_p == target_p)
-    if (strcmp(target_p->sockhost, "0")) /* XXX: TBR */
-      sendto_one_numeric(source_p, &me, RPL_WHOISACTUALLY, target_p->name,
-                         target_p->username, target_p->host,
-                         target_p->sockhost);
+    sendto_one_numeric(source_p, &me, RPL_WHOISACTUALLY, target_p->name,
+                       target_p->username, target_p->host,
+                       target_p->sockhost);
 
   if (HasUMode(target_p, UMODE_SSL))
     sendto_one_numeric(source_p, &me, RPL_WHOISSECURE, target_p->name);
@@ -218,9 +217,9 @@ do_whois(struct Client *source_p, const char *name)
 {
   struct Client *target_p = NULL;
 
-  if ((target_p = find_person(source_p, name)))
+  if ((target_p = hash_find_client(name)) && IsClient(target_p))
     whois_person(source_p, target_p);
-  else if (!IsDigit(*name))
+  else
     sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, name);
 
   sendto_one_numeric(source_p, &me, RPL_ENDOFWHOIS, name);
@@ -315,8 +314,13 @@ mo_whois(struct Client *source_p, int parc, char *parv[])
 
 static struct Message whois_msgtab =
 {
-  "WHOIS", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_whois, mo_whois, m_ignore, mo_whois, m_ignore }
+  .cmd = "WHOIS",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_whois,
+  .handlers[SERVER_HANDLER] = mo_whois,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_whois
 };
 
 static void
@@ -333,11 +337,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 5630 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
