@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whowas.c
  * \brief Includes required functions for processing the WHOWAS command.
- * \version $Id: m_whowas.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_whowas.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -31,7 +31,6 @@
 #include "hash.h"
 #include "irc_string.h"
 #include "ircd.h"
-#include "ircd_defs.h"
 #include "numeric.h"
 #include "misc.h"
 #include "server.h"
@@ -41,33 +40,45 @@
 #include "modules.h"
 
 
+enum { WHOWAS_MAX_REPLIES = 20 };  /* Only applies to remote clients */
+
 static void
 do_whowas(struct Client *source_p, const int parc, char *parv[])
 {
   int cur = 0;
   int max = -1;
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
   if (parc > 2 && !EmptyString(parv[2]))
-    if ((max = atoi(parv[2])) > 20 && !MyConnect(source_p))
-      max = 20;
+    max = atoi(parv[2]);
 
-  DLINK_FOREACH(ptr, WHOWASHASH[strhash(parv[1])].head)
+  if (!MyConnect(source_p) && (max <= 0 || max > WHOWAS_MAX_REPLIES))
+    max = WHOWAS_MAX_REPLIES;
+
+  DLINK_FOREACH(node, WHOWASHASH[strhash(parv[1])].head)
   {
-    const struct Whowas *temp = ptr->data;
+    const struct Whowas *whowas = node->data;
 
-    if (!irccmp(parv[1], temp->name))
+    if (!irccmp(parv[1], whowas->name))
     {
-      sendto_one_numeric(source_p, &me, RPL_WHOWASUSER, temp->name,
-                         temp->username, temp->hostname,
-                         temp->realname);
+      sendto_one_numeric(source_p, &me, RPL_WHOWASUSER, whowas->name,
+                         whowas->username, whowas->hostname,
+                         whowas->realname);
 
-      if ((temp->shide || ConfigServerHide.hide_servers) && !HasUMode(source_p, UMODE_OPER))
-        sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, temp->name,
-                           ConfigServerInfo.network_name, myctime(temp->logoff));
+      if (HasUMode(source_p, UMODE_OPER))
+        sendto_one_numeric(source_p, &me, RPL_WHOISACTUALLY, whowas->name,
+                           whowas->username, whowas->hostname,
+                           whowas->sockhost);
+
+      if (strcmp(whowas->account, "*"))
+        sendto_one_numeric(source_p, &me, RPL_WHOISACCOUNT, whowas->name, whowas->account, "was");
+
+      if ((whowas->shide || ConfigServerHide.hide_servers) && !HasUMode(source_p, UMODE_OPER))
+        sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, whowas->name,
+                           ConfigServerInfo.network_name, date_ctime(whowas->logoff));
       else
-        sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, temp->name,
-                           temp->servername, myctime(temp->logoff));
+        sendto_one_numeric(source_p, &me, RPL_WHOISSERVER, whowas->name,
+                           whowas->servername, date_ctime(whowas->logoff));
       ++cur;
     }
 
@@ -107,15 +118,14 @@ m_whowas(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "WHOWAS");
     return 0;
   }
 
   last_used = CurrentTime;
 
-  if (parc > 3 && !ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s WHOWAS %s %s :%s", 3,
-                    parc, parv) != HUNTED_ISME)
+  if (!ConfigServerHide.disable_remote_commands)
+    if (hunt_server(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv) != HUNTED_ISME)
       return 0;
 
   do_whowas(source_p, parc, parv);
@@ -144,10 +154,8 @@ ms_whowas(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (parc > 3)
-    if (hunt_server(source_p, ":%s WHOWAS %s %s :%s", 3,
-                    parc, parv) != HUNTED_ISME)
-      return 0;
+  if (hunt_server(source_p, ":%s WHOWAS %s %s :%s", 3, parc, parv) != HUNTED_ISME)
+    return 0;
 
   do_whowas(source_p, parc, parv);
   return 0;
@@ -155,8 +163,13 @@ ms_whowas(struct Client *source_p, int parc, char *parv[])
 
 static struct Message whowas_msgtab =
 {
-  "WHOWAS", NULL, 0, 0, 0, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_whowas, ms_whowas, m_ignore, ms_whowas, m_ignore }
+  .cmd = "WHOWAS",
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_whowas,
+  .handlers[SERVER_HANDLER] = ms_whowas,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = ms_whowas
 };
 
 static void
@@ -173,11 +186,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
