@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2014 ircd-hybrid development team
+ *  Copyright (c) 2003-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_xline.c
  * \brief Includes required functions for processing the XLINE command.
- * \version $Id: m_xline.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_xline.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -32,22 +32,22 @@
 #include "conf.h"
 #include "numeric.h"
 #include "log.h"
+#include "misc.h"
 #include "send.h"
 #include "server.h"
 #include "parse.h"
 #include "modules.h"
-#include "conf_db.h"
 #include "memory.h"
 
 
 static void
-check_xline(struct MaskItem *conf)
+xline_check(struct MaskItem *conf)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, local_client_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, local_client_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
     if (IsDead(client_p))
       continue;
@@ -64,96 +64,94 @@ check_xline(struct MaskItem *conf)
  * side effects - complains to client, when warn != 0
  */
 static int
-valid_xline(struct Client *source_p, const char *gecos, const char *reason)
+valid_xline(struct Client *source_p, const char *gecos)
 {
-  if (EmptyString(reason))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "XLINE");
-    return 0;
-  }
-
   if (!valid_wild_card_simple(gecos))
   {
-    sendto_one_notice(source_p, &me, ":Please include at least %u non-wildcard characters with the xline",
-                      ConfigGeneral.min_nonwildcard_simple);
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":Please include at least %u non-wildcard characters with the xline",
+                        ConfigGeneral.min_nonwildcard_simple);
     return 0;
   }
 
   return 1;
 }
 
-/* write_xline()
+/* xline_add()
  *
  * inputs       - client taking credit for xline, gecos, reason, xline type
  * outputs      - none
  * side effects - when successful, adds an xline to the conf
  */
 static void
-write_xline(struct Client *source_p, char *gecos, char *reason,
-            time_t tkline_time)
+xline_add(struct Client *source_p, const char *gecos, const char *reason,
+          time_t duration)
 {
-  struct MaskItem *conf = conf_make(CONF_XLINE);
+  char buf[IRCD_BUFSIZE];
+  struct MaskItem *conf;
 
+  if (duration)
+    snprintf(buf, sizeof(buf), "Temporary X-line %ju min. - %.*s (%s)",
+             duration / 60, REASONLEN, reason, date_iso8601(0));
+  else
+    snprintf(buf, sizeof(buf), "%.*s (%s)", REASONLEN, reason, date_iso8601(0));
+
+  conf = conf_make(CONF_XLINE);
   conf->name = xstrdup(gecos);
-  conf->reason = xstrdup(reason);
+  conf->reason = xstrdup(buf);
   conf->setat = CurrentTime;
-
   SetConfDatabase(conf);
 
-  if (tkline_time)
+  if (duration)
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "%s added temporary %d min. X-Line for [%s] [%s]",
-                         get_oper_name(source_p), (int)tkline_time/60,
+    conf->until = CurrentTime + duration;
+
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":Added temporary %ju min. X-Line [%s]",
+                        duration / 60, conf->name);
+
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "%s added temporary %ju min. X-Line for [%s] [%s]",
+                         get_oper_name(source_p), duration / 60,
                          conf->name, conf->reason);
-    sendto_one_notice(source_p, &me, ":Added temporary %d min. X-Line [%s]",
-                      (int)tkline_time/60, conf->name);
-    ilog(LOG_TYPE_XLINE, "%s added temporary %d min. X-Line for [%s] [%s]",
-         source_p->name, (int)tkline_time/60, conf->name, conf->reason);
-    conf->until = CurrentTime + tkline_time;
+    ilog(LOG_TYPE_XLINE, "%s added temporary %ju min. X-Line for [%s] [%s]",
+         get_oper_name(source_p), duration / 60, conf->name, conf->reason);
   }
   else
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":Added X-Line [%s] [%s]",
+                        conf->name, conf->reason);
+
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "%s added X-Line for [%s] [%s]",
                          get_oper_name(source_p), conf->name,
                          conf->reason);
-    sendto_one_notice(source_p, &me, ":Added X-Line [%s] [%s]",
-                      conf->name, conf->reason);
     ilog(LOG_TYPE_XLINE, "%s added X-Line for [%s] [%s]",
          get_oper_name(source_p), conf->name, conf->reason);
   }
 
-  check_xline(conf);
+  xline_check(conf);
 }
 
 static void
 relay_xline(struct Client *source_p, char *parv[])
 {
   struct MaskItem *conf = NULL;
-  int t_sec;
 
-  t_sec = atoi(parv[3]);
-
-  sendto_match_servs(source_p, parv[1], CAP_CLUSTER,
-                     "XLINE %s %s %s :%s",
-                     parv[1], parv[2], parv[3], parv[4]);
-
-  if (match(parv[1], me.name))
-    return;
-
-  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+  if (HasFlag(source_p, FLAGS_SERVICE) || find_matching_name_conf(CONF_SHARED, source_p->servptr->name,
                               source_p->username, source_p->host,
                               SHARED_XLINE))
   {
     if ((conf = find_matching_name_conf(CONF_XLINE, parv[2], NULL, NULL, 0)))
     {
-      sendto_one_notice(source_p, &me, ":[%s] already X-Lined by [%s] - %s",
-                        parv[2], conf->name, conf->reason);
+      if (IsClient(source_p))
+        sendto_one_notice(source_p, &me, ":[%s] already X-Lined by [%s] - %s",
+                          parv[2], conf->name, conf->reason);
       return;
     }
 
-    write_xline(source_p, parv[2], parv[4], t_sec);
+    xline_add(source_p, parv[2], parv[4], atoi(parv[3]));
   }
 }
 
@@ -174,7 +172,7 @@ mo_xline(struct Client *source_p, int parc, char *parv[])
   char *gecos = NULL;
   struct MaskItem *conf = NULL;
   char *target_server = NULL;
-  time_t tkline_time = 0;
+  time_t duration = 0;
 
   if (!HasOFlag(source_p, OPER_FLAG_XLINE))
   {
@@ -182,41 +180,24 @@ mo_xline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /*
-   * XLINE <gecos> <time> ON <mask> :<reason>
-   * XLINE <gecos> ON <mask> :<reason>
-   */
-  if (parse_aline("XLINE", source_p, parc, parv, 0, &gecos, NULL,
-                  &tkline_time, &target_server, &reason) < 0)
+  if (!parse_aline("XLINE", source_p, parc, parv, 0, &gecos, NULL,
+                   &duration, &target_server, &reason))
     return 0;
 
   if (target_server)
   {
-    /* if a given expire time is given, ENCAP it */
-    if (tkline_time)
-      sendto_match_servs(source_p, target_server, CAP_ENCAP,
-                         "ENCAP %s XLINE %d %s 0 :%s",
-                         target_server, (int)tkline_time, gecos, reason);
-    else
-      sendto_match_servs(source_p, target_server, CAP_CLUSTER,
-                         "XLINE %s %s %d :%s",
-                         target_server, gecos, (int)tkline_time, reason);
+    sendto_match_servs(source_p, target_server, CAPAB_CLUSTER, "XLINE %s %s %ju :%s",
+                       target_server, gecos, duration, reason);
 
     /* Allow ON to apply local xline as well if it matches */
     if (match(target_server, me.name))
       return 0;
   }
   else
-  {
-    if (tkline_time)
-      cluster_a_line(source_p, "ENCAP", CAP_ENCAP, SHARED_XLINE,
-                     "XLINE %d %s 0 :%s", (int)tkline_time, gecos, reason);
-    else
-      cluster_a_line(source_p, "XLINE", CAP_KLN, SHARED_XLINE,
-                     "%s 0 :%s", gecos, reason);
-  }
+    cluster_a_line(source_p, "XLINE", CAPAB_CLUSTER, SHARED_XLINE, "%s %ju :%s",
+                   gecos, duration, reason);
 
-  if (!valid_xline(source_p, gecos, reason))
+  if (!valid_xline(source_p, gecos))
     return 0;
 
   if ((conf = find_matching_name_conf(CONF_XLINE, gecos, NULL, NULL, 0)))
@@ -226,16 +207,23 @@ mo_xline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  write_xline(source_p, gecos, reason, tkline_time);
+  xline_add(source_p, gecos, reason, duration);
   return 0;
 }
 
-/* ms_xline()
+/*! \brief XLINE command handler
  *
- * inputs	- oper, target server, xline, {type}, reason
- *
- * outputs	- none
- * side effects	- propagates xline, applies it if we are a target
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = target server
+ *      - parv[2] = gecos
+ *      - parv[3] = time
+ *      - parv[4] = reason
  */
 static int
 ms_xline(struct Client *source_p, int parc, char *parv[])
@@ -243,35 +231,13 @@ ms_xline(struct Client *source_p, int parc, char *parv[])
   if (parc != 5 || EmptyString(parv[4]))
     return 0;
 
-  if (!IsClient(source_p))
+  sendto_match_servs(source_p, parv[1], CAPAB_CLUSTER, "XLINE %s %s %s :%s",
+                     parv[1], parv[2], parv[3], parv[4]);
+
+  if (match(parv[1], me.name))
     return 0;
 
-  if (!valid_xline(source_p, parv[2], parv[4]))
-    return 0;
-
-  relay_xline(source_p, parv);
-  return 0;
-}
-
-/* me_xline()
- *
- * inputs	- server
- *		- client (oper)
- *		- parc number of arguments
- *		- parv list of arguments
- * via parv[]
- * parv[1] = target server
- * parv[2] = xline
- * parv[3] = time
- * parv[4] = reason
- *
- * outputs	- none
- * side effects	-
- */
-static int
-me_xline(struct Client *source_p, int parc, char *parv[])
-{
-  if (!IsClient(source_p) || parc != 5)
+  if (!valid_xline(source_p, parv[2]))
     return 0;
 
   relay_xline(source_p, parv);
@@ -280,8 +246,14 @@ me_xline(struct Client *source_p, int parc, char *parv[])
 
 static struct Message xline_msgtab =
 {
-  "XLINE", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, ms_xline, me_xline, mo_xline, m_ignore }
+  .cmd = "XLINE",
+  .args_min = 2,
+  .args_max = MAXPARA,
+  .handlers[UNREGISTERED_HANDLER] = m_unregistered,
+  .handlers[CLIENT_HANDLER] = m_not_oper,
+  .handlers[SERVER_HANDLER] = ms_xline,
+  .handlers[ENCAP_HANDLER] = m_ignore,
+  .handlers[OPER_HANDLER] = mo_xline
 };
 
 static void
@@ -298,11 +270,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .node    = { NULL, NULL, NULL },
-  .name    = NULL,
-  .version = "$Revision: 4564 $",
-  .handle  = NULL,
+  .version = "$Revision: 7007 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = 0
 };
