@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file auth.c
  * \brief Functions for querying a users ident.
- * \version $Id: auth.c 5721 2015-03-22 11:50:46Z michael $
+ * \version $Id: auth.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 /*
@@ -53,18 +53,6 @@
 #include "mempool.h"
 
 
-static const char *const HeaderMessages[] =
-{
-  ":*** Looking up your hostname",
-  ":*** Found your hostname",
-  ":*** Couldn't look up your hostname",
-  ":*** Checking Ident",
-  ":*** Got Ident response",
-  ":*** No Ident response",
-  ":*** Your forward and reverse DNS do not match, ignoring hostname",
-  ":*** Your hostname is too long, ignoring hostname"
-};
-
 enum
 {
   REPORT_DO_DNS,
@@ -77,9 +65,21 @@ enum
   REPORT_HOST_TOOLONG
 };
 
+static const char *const HeaderMessages[] =
+{
+  [REPORT_DO_DNS] = ":*** Looking up your hostname",
+  [REPORT_FIN_DNS] = ":*** Found your hostname",
+  [REPORT_FAIL_DNS] = ":*** Couldn't look up your hostname",
+  [REPORT_DO_ID] = ":*** Checking Ident",
+  [REPORT_FIN_ID] = ":*** Got Ident response",
+  [REPORT_FAIL_ID] = ":*** No Ident response",
+  [REPORT_IP_MISMATCH] = ":*** Your forward and reverse DNS do not match, ignoring hostname",
+  [REPORT_HOST_TOOLONG] = ":*** Your hostname is too long, ignoring hostname"
+};
+
 #define sendheader(c, i) sendto_one_notice((c), &me, "%s", HeaderMessages[(i)])
 
-static dlink_list auth_pending_list;
+static dlink_list auth_list;
 static void read_auth_reply(fde_t *, void *);
 static void auth_connect_callback(fde_t *, int, void *);
 
@@ -90,14 +90,14 @@ static void auth_connect_callback(fde_t *, int, void *);
 static struct AuthRequest *
 make_auth_request(struct Client *client)
 {
-  struct AuthRequest *const request = &client->connection->auth;
+  struct AuthRequest *const auth = &client->connection->auth;
 
-  memset(request, 0, sizeof(*request));
+  memset(auth, 0, sizeof(*auth));
 
-  request->client  = client;
-  request->timeout = CurrentTime + CONNECTTIMEOUT;
+  auth->client = client;
+  auth->timeout = CurrentTime + CONNECTTIMEOUT;
 
-  return request;
+  return auth;
 }
 
 /*
@@ -115,7 +115,7 @@ release_auth_client(struct AuthRequest *auth)
 
   if (IsInAuth(auth))
   {
-    dlinkDelete(&auth->node, &auth_pending_list);
+    dlinkDelete(&auth->node, &auth_list);
     ClearInAuth(auth);
   }
 
@@ -156,7 +156,7 @@ auth_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, s
       const struct sockaddr_in6 *const v6 = (const struct sockaddr_in6 *)&auth->client->connection->ip;
       const struct sockaddr_in6 *const v6dns = (const struct sockaddr_in6 *)addr;
 
-      if (memcmp(&v6->sin6_addr, &v6dns->sin6_addr, sizeof(struct in6_addr)) != 0)
+      if (memcmp(&v6->sin6_addr, &v6dns->sin6_addr, sizeof(struct in6_addr)))
       {
         sendheader(auth->client, REPORT_IP_MISMATCH);
         release_auth_client(auth);
@@ -215,7 +215,7 @@ auth_error(struct AuthRequest *auth)
  * identifing process fail, it is aborted and the user is given a username
  * of "unknown".
  */
-static int
+static void
 start_auth_query(struct AuthRequest *auth)
 {
   struct irc_ssaddr localaddr;
@@ -229,9 +229,10 @@ start_auth_query(struct AuthRequest *auth)
     report_error(L_ALL, "creating auth stream socket %s:%s",
                  get_client_name(auth->client, SHOW_IP), errno);
     ++ServerStats.is_abad;
-    return 0;
+    return;
   }
 
+  SetDoingAuth(auth);
   sendheader(auth->client, REPORT_DO_ID);
 
   /*
@@ -251,7 +252,6 @@ start_auth_query(struct AuthRequest *auth)
       (struct sockaddr *)&localaddr, localaddr.ss_len, auth_connect_callback,
       auth, auth->client->connection->ip.ss.ss_family,
       GlobalSetOptions.ident_timeout);
-  return 1; /* We suceed here for now */
 }
 
 /*
@@ -267,17 +267,14 @@ start_auth(struct Client *client_p)
   struct AuthRequest *const auth = make_auth_request(client_p);
 
   SetInAuth(auth);
-  dlinkAddTail(auth, &auth->node, &auth_pending_list);
+  dlinkAddTail(auth, &auth->node, &auth_list);
 
   sendheader(client_p, REPORT_DO_DNS);
 
   SetDNSPending(auth);
 
   if (ConfigGeneral.disable_auth == 0)
-  {
-    SetDoingAuth(auth);
     start_auth_query(auth);
-  }
 
   gethost_byaddr(auth_dns_callback, auth, &client_p->connection->ip);
 }
@@ -291,7 +288,7 @@ timeout_auth_queries_event(void *notused)
 {
   dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(node, node_next, auth_pending_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, auth_list.head)
   {
     struct AuthRequest *auth = node->data;
 
@@ -360,8 +357,6 @@ auth_connect_callback(fde_t *fd, int error, void *data)
   uport = ntohs(v6->sin6_port);
   v6 = (struct sockaddr_in6 *)&them;
   tport = ntohs(v6->sin6_port);
-  remove_ipv6_mapping(&us);
-  remove_ipv6_mapping(&them);
 
   len = snprintf(authbuf, sizeof(authbuf), "%u, %u\r\n", tport, uport);
 
@@ -498,7 +493,7 @@ read_auth_reply(fde_t *fd, void *data)
     strlcpy(auth->client->username, username, sizeof(auth->client->username));
     sendheader(auth->client, REPORT_FIN_ID);
     ++ServerStats.is_asuc;
-    SetGotId(auth->client);
+    AddFlag(auth->client, FLAGS_GOTID);
   }
 
   release_auth_client(auth);
@@ -518,7 +513,7 @@ delete_auth(struct AuthRequest *auth)
 
   if (IsInAuth(auth))
   {
-    dlinkDelete(&auth->node, &auth_pending_list);
+    dlinkDelete(&auth->node, &auth_list);
     ClearInAuth(auth);
   }
 }
