@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.c
  * \brief Controls modes on channels.
- * \version $Id: channel_mode.c 5758 2015-04-02 18:26:29Z michael $
+ * \version $Id: channel_mode.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -68,6 +68,7 @@ const struct mode_letter chan_modes[] =
   { MODE_OPERONLY,   'O' },
   { MODE_REGONLY,    'R' },
   { MODE_SSLONLY,    'S' },
+  { MODE_NONOTICE,   'T' },
   { 0, '\0' }
 };
 
@@ -297,7 +298,7 @@ channel_modes(struct Channel *chptr, struct Client *client_p, char *mbuf, char *
   {
     *mbuf++ = 'l';
 
-    if (IsServer(client_p) || HasFlag(client_p, FLAGS_SERVICE) || IsMember(client_p, chptr))
+    if (IsServer(client_p) || IsMember(client_p, chptr))
       pbuf += sprintf(pbuf, "%d ", chptr->mode.limit);
   }
 
@@ -305,7 +306,7 @@ channel_modes(struct Channel *chptr, struct Client *client_p, char *mbuf, char *
   {
     *mbuf++ = 'k';
 
-    if (IsServer(client_p) || HasFlag(client_p, FLAGS_SERVICE) || IsMember(client_p, chptr))
+    if (IsServer(client_p) || IsMember(client_p, chptr))
       sprintf(pbuf, "%s ", chptr->mode.key);
   }
 
@@ -790,22 +791,26 @@ chm_voice(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
     return;
 
-  /* no redundant mode changes */
-  if (dir == MODE_ADD &&  has_member_flags(member, CHFL_VOICE))
-    return;
+  switch (dir)
+  {
+    case MODE_ADD:
+      if (has_member_flags(member, CHFL_VOICE))
+        return;  /* No redundant mode changes */
 
-  if (dir == MODE_DEL && !has_member_flags(member, CHFL_VOICE))
-    return;
+      AddMemberFlag(member, CHFL_VOICE);
+      break;
+    case MODE_DEL:
+      if (!has_member_flags(member, CHFL_VOICE))
+        return;  /* No redundant mode changes */
+
+      DelMemberFlag(member, CHFL_VOICE);
+      break;
+  }
 
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
   mode_changes[mode_count++].dir = dir;
-
-  if (dir == MODE_ADD)
-    AddMemberFlag(member, CHFL_VOICE);
-  else
-    DelMemberFlag(member, CHFL_VOICE);
 }
 
 static void
@@ -844,22 +849,26 @@ chm_hop(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
     return;
 
-  /* no redundant mode changes */
-  if (dir == MODE_ADD &&  has_member_flags(member, CHFL_HALFOP))
-    return;
+  switch (dir)
+  {
+    case MODE_ADD:
+      if (has_member_flags(member, CHFL_HALFOP))
+        return;  /* No redundant mode changes */
 
-  if (dir == MODE_DEL && !has_member_flags(member, CHFL_HALFOP))
-    return;
+      AddMemberFlag(member, CHFL_HALFOP);
+      break;
+    case MODE_DEL:
+      if (!has_member_flags(member, CHFL_HALFOP))
+        return;  /* No redundant mode changes */
+
+      DelMemberFlag(member, CHFL_HALFOP);
+      break;
+  }
 
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
   mode_changes[mode_count++].dir = dir;
-
-  if (dir == MODE_ADD)
-    AddMemberFlag(member, CHFL_HALFOP);
-  else
-    DelMemberFlag(member, CHFL_HALFOP);
 }
 
 static void
@@ -898,30 +907,32 @@ chm_op(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
     return;
 
-  /* no redundant mode changes */
-  if (dir == MODE_ADD &&  has_member_flags(member, CHFL_CHANOP))
-    return;
+  switch (dir)
+  {
+    case MODE_ADD:
+      if (has_member_flags(member, CHFL_CHANOP))
+        return;  /* No redundant mode changes */
 
-  if (dir == MODE_DEL && !has_member_flags(member, CHFL_CHANOP))
-    return;
+      AddMemberFlag(member, CHFL_CHANOP);
+      break;
+    case MODE_DEL:
+      if (!has_member_flags(member, CHFL_CHANOP))
+        return;  /* No redundant mode changes */
+
+      DelMemberFlag(member, CHFL_CHANOP);
+      break;
+  }
 
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
   mode_changes[mode_count++].dir = dir;
-
-  if (dir == MODE_ADD)
-    AddMemberFlag(member, CHFL_CHANOP);
-  else
-    DelMemberFlag(member, CHFL_CHANOP);
 }
 
 static void
 chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
           char **parv, int *errors, int alev, int dir, char c, unsigned int d)
 {
-  int limit = 0;
-
   if (alev < CHACCESS_HALFOP)
   {
     if (!(*errors & SM_ERR_NOOPS))
@@ -938,6 +949,7 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if (dir == MODE_ADD && parc > *parn)
   {
     char *const lstr = parv[(*parn)++];
+    int limit = 0;
 
     if (EmptyString(lstr) || (limit = atoi(lstr)) <= 0)
       return;
@@ -1110,7 +1122,7 @@ const struct ChannelMode ModeTable[256] =
   { chm_nosuch,  0 },                   /* Q */
   { chm_simple, MODE_REGONLY},          /* R */
   { chm_simple, MODE_SSLONLY},          /* S */
-  { chm_nosuch,  0 },                   /* T */
+  { chm_simple, MODE_NONOTICE},         /* T */
   { chm_nosuch,  0 },                   /* U */
   { chm_nosuch,  0 },                   /* V */
   { chm_nosuch,  0 },                   /* W */
@@ -1334,8 +1346,8 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
   parabuf[0] = '\0';
   parptr = parabuf;
 
-  mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %lu %s ", source_p->id,
-                 (unsigned long)chptr->creationtime, chptr->name);
+  mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ", source_p->id,
+                 chptr->creationtime, chptr->name);
 
   /* Loop the list of modes we have */
   for (unsigned int i = 0; i < mode_count; ++i)
@@ -1367,8 +1379,8 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
       nc = 0;
       mc = 0;
 
-      mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %lu %s ", source_p->id,
-                     (unsigned long)chptr->creationtime, chptr->name);
+      mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %ju %s ", source_p->id,
+                     chptr->creationtime, chptr->name);
 
       pbl = 0;
       parabuf[0] = '\0';
@@ -1452,7 +1464,7 @@ send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
         modebuf[mbl - 1] = '\0';
 
       if (nc)
-        sendto_channel_local(0, chptr, "%s %s", modebuf, parabuf);
+        sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
 
       nc = 0;
       mc = 0;
@@ -1494,7 +1506,7 @@ send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
     parabuf[pbl - 1] = '\0';
 
   if (nc)
-    sendto_channel_local(0, chptr, "%s %s", modebuf, parabuf);
+    sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
 }
 
 /*
