@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id: conf.c 5782 2015-04-05 15:00:54Z michael $
+ * \version $Id: conf.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -55,6 +55,7 @@
 #include "conf_class.h"
 #include "motd.h"
 #include "ipcache.h"
+#include "isupport.h"
 
 
 struct config_channel_entry ConfigChannel;
@@ -69,9 +70,9 @@ struct conf_parser_context conf_parser_ctx;
 dlink_list service_items;
 dlink_list server_items;
 dlink_list cluster_items;
-dlink_list oconf_items;
-dlink_list uconf_items;
-dlink_list xconf_items;
+dlink_list operator_items;
+dlink_list shared_items;
+dlink_list gecos_items;
 dlink_list nresv_items;
 dlink_list cresv_items;
 
@@ -136,10 +137,10 @@ map_to_list(enum maskitem_type type)
   switch (type)
   {
     case CONF_XLINE:
-      return &xconf_items;
+      return &gecos_items;
       break;
-    case CONF_ULINE:
-      return &uconf_items;
+    case CONF_SHARED:
+      return &shared_items;
       break;
     case CONF_NRESV:
       return &nresv_items;
@@ -148,7 +149,7 @@ map_to_list(enum maskitem_type type)
       return &cresv_items;
       break;
     case CONF_OPER:
-      return &oconf_items;
+      return &operator_items;
       break;
     case CONF_SERVER:
       return &server_items;
@@ -167,7 +168,7 @@ map_to_list(enum maskitem_type type)
 struct MaskItem *
 conf_make(enum maskitem_type type)
 {
-  struct MaskItem *const conf = MyCalloc(sizeof(*conf));
+  struct MaskItem *const conf = xcalloc(sizeof(*conf));
   dlink_list *list = NULL;
 
   conf->type   = type;
@@ -188,7 +189,7 @@ conf_free(struct MaskItem *conf)
   if ((list = map_to_list(conf->type)))
     dlinkFindDelete(list, conf);
 
-  MyFree(conf->name);
+  xfree(conf->name);
 
   if (conf->dns_pending)
     delete_resolver_queries(conf);
@@ -199,29 +200,29 @@ conf_free(struct MaskItem *conf)
 
   conf->class = NULL;
 
-  MyFree(conf->passwd);
-  MyFree(conf->spasswd);
-  MyFree(conf->reason);
-  MyFree(conf->certfp);
-  MyFree(conf->whois);
-  MyFree(conf->user);
-  MyFree(conf->host);
+  xfree(conf->passwd);
+  xfree(conf->spasswd);
+  xfree(conf->reason);
+  xfree(conf->certfp);
+  xfree(conf->whois);
+  xfree(conf->user);
+  xfree(conf->host);
 #ifdef HAVE_LIBCRYPTO
-  MyFree(conf->cipher_list);
+  xfree(conf->cipher_list);
 
   if (conf->rsa_public_key)
     RSA_free(conf->rsa_public_key);
 #endif
   DLINK_FOREACH_SAFE(node, node_next, conf->hub_list.head)
   {
-    MyFree(node->data);
+    xfree(node->data);
     dlinkDelete(node, &conf->hub_list);
     free_dlink_node(node);
   }
 
   DLINK_FOREACH_SAFE(node, node_next, conf->leaf_list.head)
   {
-    MyFree(node->data);
+    xfree(node->data);
     dlinkDelete(node, &conf->leaf_list);
     free_dlink_node(node);
   }
@@ -231,13 +232,13 @@ conf_free(struct MaskItem *conf)
     struct exempt *exptr = node->data;
 
     dlinkDelete(node, &conf->exempt_list);
-    MyFree(exptr->name);
-    MyFree(exptr->user);
-    MyFree(exptr->host);
-    MyFree(exptr);
+    xfree(exptr->name);
+    xfree(exptr->user);
+    xfree(exptr->host);
+    xfree(exptr);
   }
 
-  MyFree(conf);
+  xfree(conf);
 }
 
 /* attach_iline()
@@ -259,8 +260,8 @@ attach_iline(struct Client *client_p, struct MaskItem *conf)
   ip_found->count++;
   AddFlag(client_p, FLAGS_IPHASH);
 
-  count_user_host(client_p->username, client_p->host,
-                  &global, &local, &ident);
+  userhost_count(client_p->username, client_p->host,
+                 &global, &local, &ident);
 
   /* XXX blah. go down checking the various silly limits
    * setting a_limit_reached if any limit is reached.
@@ -301,7 +302,7 @@ verify_access(struct Client *client_p)
 {
   struct MaskItem *conf = NULL;
 
-  if (IsGotId(client_p))
+  if (HasFlag(client_p, FLAGS_GOTID))
   {
     conf = find_address_conf(client_p->host, client_p->username,
                              &client_p->connection->ip,
@@ -319,41 +320,35 @@ verify_access(struct Client *client_p)
                              client_p->connection->password);
   }
 
-  if (conf)
+  if (!conf)
+    return NOT_AUTHORIZED;
+
+  assert(IsConfClient(conf) || IsConfKill(conf));
+
+  if (IsConfClient(conf))
   {
-    if (IsConfClient(conf))
+    if (IsConfRedir(conf))
     {
-      if (IsConfRedir(conf))
-      {
-        sendto_one_numeric(client_p, &me, RPL_REDIR,
-                           conf->name ? conf->name : "",
-                           conf->port);
-        return NOT_AUTHORIZED;
-      }
-
-      /* Thanks for spoof idea amm */
-      if (IsConfDoSpoofIp(conf))
-      {
-        if (IsConfSpoofNotice(conf))
-          sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE, "%s spoofing: %s as %s",
-                               client_p->name, client_p->host, conf->name);
-
-        strlcpy(client_p->host, conf->name, sizeof(client_p->host));
-      }
-
-      return attach_iline(client_p, conf);
+      sendto_one_numeric(client_p, &me, RPL_REDIR,
+                         conf->name ? conf->name : "",
+                         conf->port);
+      return NOT_AUTHORIZED;
     }
-    else if (IsConfKill(conf) || (ConfigGeneral.glines && IsConfGline(conf)))
+
+    if (IsConfDoSpoofIp(conf))
     {
-      if (IsConfGline(conf))
-        sendto_one_notice(client_p, &me, ":*** G-lined");
+      if (IsConfSpoofNotice(conf))
+        sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE, "%s spoofing: %s as %s",
+                             client_p->name, client_p->host, conf->name);
 
-      sendto_one_notice(client_p, &me, ":*** Banned: %s", conf->reason);
-      return BANNED_CLIENT;
+      strlcpy(client_p->host, conf->name, sizeof(client_p->host));
     }
+
+    return attach_iline(client_p, conf);
   }
 
-  return NOT_AUTHORIZED;
+  sendto_one_notice(client_p, &me, ":*** Banned: %s", conf->reason);
+  return BANNED_CLIENT;
 }
 
 /* check_client()
@@ -594,7 +589,7 @@ find_matching_name_conf(enum maskitem_type type, const char *name, const char *u
     break;
 
   case CONF_XLINE:
-  case CONF_ULINE:
+  case CONF_SHARED:
   case CONF_NRESV:
   case CONF_CRESV:
     DLINK_FOREACH(node, list->head)
@@ -655,7 +650,7 @@ find_exact_name_conf(enum maskitem_type type, const struct Client *who, const ch
   switch(type)
   {
   case CONF_XLINE:
-  case CONF_ULINE:
+  case CONF_SHARED:
   case CONF_NRESV:
   case CONF_CRESV:
 
@@ -784,13 +779,8 @@ set_default_conf(void)
 
   SSL_CTX_set_cipher_list(ConfigServerInfo.server_ctx, "EECDH+HIGH:EDH+HIGH:HIGH:!aNULL");
   ConfigServerInfo.message_digest_algorithm = EVP_sha256();
-  ConfigServerInfo.rsa_private_key = NULL;
-  ConfigServerInfo.rsa_private_key_file = NULL;
 #endif
 
-  /* ConfigServerInfo.name is not rehashable */
-  /* ConfigServerInfo.name = ConfigServerInfo.name; */
-  ConfigServerInfo.description = NULL;
   ConfigServerInfo.network_name = xstrdup(NETWORK_NAME_DEFAULT);
   ConfigServerInfo.network_desc = xstrdup(NETWORK_DESC_DEFAULT);
 
@@ -804,10 +794,6 @@ set_default_conf(void)
   ConfigServerInfo.max_topic_length = 80;
   ConfigServerInfo.hub = 0;
 
-  ConfigAdminInfo.name = NULL;
-  ConfigAdminInfo.email = NULL;
-  ConfigAdminInfo.description = NULL;
-
   log_del_all();
 
   ConfigLog.use_logging = 1;
@@ -815,6 +801,7 @@ set_default_conf(void)
   ConfigChannel.disable_fake_channels = 0;
   ConfigChannel.invite_client_count = 10;
   ConfigChannel.invite_client_time = 300;
+  ConfigChannel.invite_delay_channel = 5;
   ConfigChannel.knock_client_count = 1;
   ConfigChannel.knock_client_time = 300;
   ConfigChannel.knock_delay_channel = 60;
@@ -822,13 +809,9 @@ set_default_conf(void)
   ConfigChannel.max_bans = 25;
   ConfigChannel.default_join_flood_count = 18;
   ConfigChannel.default_join_flood_time = 6;
-  ConfigChannel.default_split_user_count = 0;
-  ConfigChannel.default_split_server_count = 0;
-  ConfigChannel.no_join_on_split = 0;
-  ConfigChannel.no_create_on_split = 0;
 
   ConfigServerHide.flatten_links = 0;
-  ConfigServerHide.links_delay = 300;
+  ConfigServerHide.flatten_links_delay = 300;
   ConfigServerHide.hidden = 0;
   ConfigServerHide.hide_servers = 0;
   ConfigServerHide.hide_services = 0;
@@ -838,13 +821,12 @@ set_default_conf(void)
 
   ConfigGeneral.away_count = 2;
   ConfigGeneral.away_time = 10;
-  ConfigGeneral.max_watch = WATCHSIZE_DEFAULT;
+  ConfigGeneral.max_watch = 50;
   ConfigGeneral.cycle_on_host_change = 1;
-  ConfigGeneral.glines = 0;
-  ConfigGeneral.gline_time = 12 * 3600;
-  ConfigGeneral.gline_request_time = GLINE_REQUEST_EXPIRE_DEFAULT;
-  ConfigGeneral.gline_min_cidr = 16;
-  ConfigGeneral.gline_min_cidr6 = 48;
+  ConfigGeneral.dline_min_cidr = 16;
+  ConfigGeneral.dline_min_cidr6 = 48;
+  ConfigGeneral.kline_min_cidr = 16;
+  ConfigGeneral.kline_min_cidr6 = 48;
   ConfigGeneral.invisible_on_connect = 1;
   ConfigGeneral.tkline_expire_notices = 1;
   ConfigGeneral.ignore_bogus_ts = 0;
@@ -855,13 +837,13 @@ set_default_conf(void)
   ConfigGeneral.dots_in_ident = 0;
   ConfigGeneral.min_nonwildcard = 4;
   ConfigGeneral.min_nonwildcard_simple = 3;
-  ConfigGeneral.max_accept = 20;
+  ConfigGeneral.max_accept = 50;
   ConfigGeneral.anti_nick_flood = 0;
   ConfigGeneral.max_nick_time = 20;
   ConfigGeneral.max_nick_changes = 5;
   ConfigGeneral.anti_spam_exit_message_time = 0;
-  ConfigGeneral.ts_warn_delta = TS_WARN_DELTA_DEFAULT;
-  ConfigGeneral.ts_max_delta = TS_MAX_DELTA_DEFAULT;
+  ConfigGeneral.ts_warn_delta = 30;
+  ConfigGeneral.ts_max_delta = 600;
   ConfigGeneral.warn_no_connect_block = 1;
   ConfigGeneral.stats_e_disabled = 0;
   ConfigGeneral.stats_i_oper_only = 1;  /* 1 = masked */
@@ -877,7 +859,6 @@ set_default_conf(void)
   ConfigGeneral.short_motd = 0;
   ConfigGeneral.ping_cookie = 0;
   ConfigGeneral.no_oper_flood = 0;
-  ConfigGeneral.oper_pass_resv = 1;
   ConfigGeneral.max_targets = MAX_TARGETS_DEFAULT;
   ConfigGeneral.oper_only_umodes = UMODE_DEBUG | UMODE_LOCOPS | UMODE_HIDDEN | UMODE_FARCONNECT |
                                    UMODE_UNAUTH | UMODE_EXTERNAL | UMODE_BOTS | UMODE_NCHANGE |
@@ -890,19 +871,11 @@ set_default_conf(void)
 static void
 validate_conf(void)
 {
-  if (ConfigGeneral.ts_warn_delta < TS_WARN_DELTA_MIN)
-    ConfigGeneral.ts_warn_delta = TS_WARN_DELTA_DEFAULT;
-
-  if (ConfigGeneral.ts_max_delta < TS_MAX_DELTA_MIN)
-    ConfigGeneral.ts_max_delta = TS_MAX_DELTA_DEFAULT;
-
   if (EmptyString(ConfigServerInfo.network_name))
     ConfigServerInfo.network_name = xstrdup(NETWORK_NAME_DEFAULT);
 
   if (EmptyString(ConfigServerInfo.network_desc))
     ConfigServerInfo.network_desc = xstrdup(NETWORK_DESC_DEFAULT);
-
-  ConfigGeneral.max_watch = IRCD_MAX(ConfigGeneral.max_watch, WATCHSIZE_MIN);
 }
 
 /* read_conf()
@@ -939,7 +912,7 @@ void
 conf_rehash(int sig)
 {
   if (sig)
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Got signal SIGHUP, reloading configuration file(s)");
 
   restart_resolver();
@@ -1000,14 +973,15 @@ int
 conf_connect_allowed(struct irc_ssaddr *addr, int aftype)
 {
   struct ip_entry *ip_found = NULL;
-  struct MaskItem *const conf = find_dline_conf(addr, aftype);
-
-  /* DLINE exempt also gets you out of static limits/pacing... */
-  if (conf && (conf->type == CONF_EXEMPT))
-    return 0;
+  const struct MaskItem *conf = find_dline_conf(addr, aftype);
 
   if (conf)
+  {
+    /* DLINE exempt also gets you out of static limits/pacing... */
+    if (conf->type == CONF_EXEMPT)
+      return 0;
     return BANNED_CLIENT;
+  }
 
   ip_found = ipcache_find_or_add_address(addr);
 
@@ -1043,20 +1017,10 @@ expire_tklines(dlink_list *list)
     if (!conf->until || conf->until > CurrentTime)
       continue;
 
-    if (conf->type == CONF_XLINE)
-    {
-      if (ConfigGeneral.tkline_expire_notices)
-        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                             "Temporary X-line for [%s] expired", conf->name);
-      conf_free(conf);
-    }
-    else if (conf->type == CONF_NRESV || conf->type == CONF_CRESV)
-    {
-      if (ConfigGeneral.tkline_expire_notices)
-        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                             "Temporary RESV for [%s] expired", conf->name);
-      conf_free(conf);
-    }
+    if (ConfigGeneral.tkline_expire_notices)
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "Temporary %s for [%s] expired",
+                           (conf->type == CONF_XLINE) ? "X-line" : "RESV", conf->name);
+    conf_free(conf);
   }
 }
 
@@ -1071,7 +1035,7 @@ void
 cleanup_tklines(void *unused)
 {
   hostmask_expire_temporary();
-  expire_tklines(&xconf_items);
+  expire_tklines(&gecos_items);
   expire_tklines(&nresv_items);
   expire_tklines(&cresv_items);
 }
@@ -1088,19 +1052,33 @@ static const struct oper_privs
   const unsigned char c;
 } flag_list[] = {
   { OPER_FLAG_ADMIN,          'A' },
-  { OPER_FLAG_REMOTEBAN,      'B' },
-  { OPER_FLAG_DIE,            'D' },
-  { OPER_FLAG_GLINE,          'G' },
-  { OPER_FLAG_REHASH,         'H' },
+  { OPER_FLAG_CLOSE,          'B' },
+  { OPER_FLAG_CONNECT,        'C' },
+  { OPER_FLAG_CONNECT_REMOTE, 'D' },
+  { OPER_FLAG_DIE,            'E' },
+  { OPER_FLAG_DLINE,          'F' },
+  { OPER_FLAG_GLOBOPS,        'G' },
+  { OPER_FLAG_JOIN_RESV,      'H' },
+  { OPER_FLAG_KILL,           'I' },
+  { OPER_FLAG_KILL_REMOTE,    'J' },
   { OPER_FLAG_KLINE,          'K' },
-  { OPER_FLAG_KILL,           'N' },
-  { OPER_FLAG_KILL_REMOTE,    'O' },
-  { OPER_FLAG_CONNECT,        'P' },
-  { OPER_FLAG_CONNECT_REMOTE, 'Q' },
-  { OPER_FLAG_SQUIT,          'R' },
-  { OPER_FLAG_SQUIT_REMOTE,   'S' },
-  { OPER_FLAG_UNKLINE,        'U' },
-  { OPER_FLAG_XLINE,          'X' },
+  { OPER_FLAG_LOCOPS,         'L' },
+  { OPER_FLAG_MODULE,         'M' },
+  { OPER_FLAG_NICK_RESV,      'N' },
+  { OPER_FLAG_OPME,           'O' },
+  { OPER_FLAG_REHASH,         'P' },
+  { OPER_FLAG_REMOTEBAN,      'Q' },
+  { OPER_FLAG_RESTART,        'R' },
+  { OPER_FLAG_RESV,           'S' },
+  { OPER_FLAG_SET,            'T' },
+  { OPER_FLAG_SQUIT,          'U' },
+  { OPER_FLAG_SQUIT_REMOTE,   'V' },
+  { OPER_FLAG_UNDLINE,        'W' },
+  { OPER_FLAG_UNKLINE,        'X' },
+  { OPER_FLAG_UNRESV,         'Y' },
+  { OPER_FLAG_UNXLINE,        'Z' },
+  { OPER_FLAG_WALLOPS,        'a' },
+  { OPER_FLAG_XLINE,          'b' },
   { 0, '\0' }
 };
 
@@ -1111,12 +1089,11 @@ oper_privs_as_string(const unsigned int port)
   char *privs_ptr = privs_out;
 
   for (const struct oper_privs *opriv = flag_list; opriv->flag; ++opriv)
-  {
     if (port & opriv->flag)
       *privs_ptr++ = opriv->c;
-    else
-      *privs_ptr++ = ToLower(opriv->c);
-  }
+
+  if (privs_ptr == privs_out)
+    *privs_ptr++ = '0';
 
   *privs_ptr = '\0';
 
@@ -1176,8 +1153,8 @@ clear_out_old_conf(void)
 {
   dlink_node *node = NULL, *node_next = NULL;
   dlink_list *free_items [] = {
-    &server_items,   &oconf_items,
-     &uconf_items,   &xconf_items,
+    &server_items,   &operator_items,
+     &shared_items,   &gecos_items,
      &nresv_items, &cluster_items,  &service_items, &cresv_items, NULL
   };
 
@@ -1194,21 +1171,14 @@ clear_out_old_conf(void)
       struct MaskItem *conf = node->data;
 
       conf->active = 0;
-      dlinkDelete(&conf->node, *iterator);
 
-      /* XXX This is less than pretty */
-      if (conf->type == CONF_SERVER || conf->type == CONF_OPER)
+      if (!IsConfDatabase(conf))
       {
+        dlinkDelete(&conf->node, *iterator);
+
         if (!conf->ref_count)
           conf_free(conf);
       }
-      else if (conf->type == CONF_XLINE)
-      {
-        if (!conf->until)
-          conf_free(conf);
-      }
-      else
-        conf_free(conf);
     }
   }
 
@@ -1228,11 +1198,11 @@ clear_out_old_conf(void)
   pseudo_clear();
 
   /* Clean out ConfigServerInfo */
-  MyFree(ConfigServerInfo.description);
+  xfree(ConfigServerInfo.description);
   ConfigServerInfo.description = NULL;
-  MyFree(ConfigServerInfo.network_name);
+  xfree(ConfigServerInfo.network_name);
   ConfigServerInfo.network_name = NULL;
-  MyFree(ConfigServerInfo.network_desc);
+  xfree(ConfigServerInfo.network_desc);
   ConfigServerInfo.network_desc = NULL;
 #ifdef HAVE_LIBCRYPTO
   if (ConfigServerInfo.rsa_private_key)
@@ -1241,20 +1211,23 @@ clear_out_old_conf(void)
     ConfigServerInfo.rsa_private_key = NULL;
   }
 
-  MyFree(ConfigServerInfo.rsa_private_key_file);
+  xfree(ConfigServerInfo.rsa_private_key_file);
   ConfigServerInfo.rsa_private_key_file = NULL;
 #endif
 
   /* Clean out ConfigAdminInfo */
-  MyFree(ConfigAdminInfo.name);
+  xfree(ConfigAdminInfo.name);
   ConfigAdminInfo.name = NULL;
-  MyFree(ConfigAdminInfo.email);
+  xfree(ConfigAdminInfo.email);
   ConfigAdminInfo.email = NULL;
-  MyFree(ConfigAdminInfo.description);
+  xfree(ConfigAdminInfo.description);
   ConfigAdminInfo.description = NULL;
 
+  xfree(ConfigServerHide.flatten_links_file);
+  ConfigServerHide.flatten_links_file = NULL;
+
   /* Clean out listeners */
-  close_listeners();
+  listener_close_marked();
 }
 
 /* read_conf_files()
@@ -1287,11 +1260,11 @@ read_conf_files(int cold)
     {
       ilog(LOG_TYPE_IRCD, "Unable to read configuration file '%s': %s",
            filename, strerror(errno));
-      exit(-1);
+      exit(EXIT_FAILURE);
     }
     else
     {
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                            "Unable to read configuration file '%s': %s",
                            filename, strerror(errno));
       return;
@@ -1306,27 +1279,27 @@ read_conf_files(int cold)
 
   log_reopen_all();
 
-  add_isupport("NICKLEN", NULL, ConfigServerInfo.max_nick_length);
-  add_isupport("NETWORK", ConfigServerInfo.network_name, -1);
+  isupport_add("NICKLEN", NULL, ConfigServerInfo.max_nick_length);
+  isupport_add("NETWORK", ConfigServerInfo.network_name, -1);
 
-  snprintf(chanmodes, sizeof(chanmodes), "beI:%d", ConfigChannel.max_bans);
-  add_isupport("MAXLIST", chanmodes, -1);
-  add_isupport("MAXTARGETS", NULL, ConfigGeneral.max_targets);
-  add_isupport("CHANTYPES", "#", -1);
+  snprintf(chanmodes, sizeof(chanmodes), "beI:%u", ConfigChannel.max_bans);
+  isupport_add("MAXLIST", chanmodes, -1);
+  isupport_add("MAXTARGETS", NULL, ConfigGeneral.max_targets);
+  isupport_add("CHANTYPES", "#", -1);
 
-  snprintf(chanlimit, sizeof(chanlimit), "#:%d",
+  snprintf(chanlimit, sizeof(chanlimit), "#:%u",
            ConfigChannel.max_channels);
-  add_isupport("CHANLIMIT", chanlimit, -1);
-  snprintf(chanmodes, sizeof(chanmodes), "%s", "beI,k,l,cimnprstCMORS");
-  add_isupport("CHANNELLEN", NULL, CHANNELLEN);
-  add_isupport("TOPICLEN", NULL, ConfigServerInfo.max_topic_length);
-  add_isupport("CHANMODES", chanmodes, -1);
+  isupport_add("CHANLIMIT", chanlimit, -1);
+  snprintf(chanmodes, sizeof(chanmodes), "%s", "beI,k,l,cimnprstCMORST");
+  isupport_add("CHANNELLEN", NULL, CHANNELLEN);
+  isupport_add("TOPICLEN", NULL, ConfigServerInfo.max_topic_length);
+  isupport_add("CHANMODES", chanmodes, -1);
 
   /*
    * message_locale may have changed.  rebuild isupport since it relies
    * on strlen(form_str(RPL_ISUPPORT))
    */
-  rebuild_isupport_message_line();
+  isupport_rebuild();
 }
 
 /* conf_add_class_to_conf()
@@ -1336,36 +1309,21 @@ read_conf_files(int cold)
  * side effects - Add a class pointer to a conf
  */
 void
-conf_add_class_to_conf(struct MaskItem *conf, const char *class_name)
+conf_add_class_to_conf(struct MaskItem *conf, const char *name)
 {
-  if (class_name == NULL)
+  if (EmptyString(name) || (conf->class = class_find(name, 1)) == NULL)
   {
     conf->class = class_default;
 
     if (conf->type == CONF_CLIENT || conf->type == CONF_OPER)
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                            "Warning *** Defaulting to default class for %s@%s",
                            conf->user, conf->host);
     else
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                            "Warning *** Defaulting to default class for %s",
                            conf->name);
   }
-  else
-    conf->class = class_find(class_name, 1);
-
-  if (conf->class == NULL)
-  {
-    if (conf->type == CONF_CLIENT || conf->type == CONF_OPER)
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "Warning *** Defaulting to default class for %s@%s",
-                           conf->user, conf->host);
-    else
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "Warning *** Defaulting to default class for %s",
-                           conf->name);
-    conf->class = class_default;
-  }
 }
 
 /* yyerror()
@@ -1383,7 +1341,7 @@ yyerror(const char *msg)
     return;
 
   strip_tabs(newlinebuf, linebuf, sizeof(newlinebuf));
-  sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                        "\"%s\", line %u: %s: %s",
                        conffilebuf, lineno + 1, msg, newlinebuf);
   ilog(LOG_TYPE_IRCD, "\"%s\", line %u: %s: %s",
@@ -1396,7 +1354,7 @@ conf_error_report(const char *msg)
   char newlinebuf[IRCD_BUFSIZE];
 
   strip_tabs(newlinebuf, linebuf, sizeof(newlinebuf));
-  sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                        "\"%s\", line %u: %s: %s",
                        conffilebuf, lineno + 1, msg, newlinebuf);
   ilog(LOG_TYPE_IRCD, "\"%s\", line %u: %s: %s",
@@ -1463,7 +1421,7 @@ valid_wild_card_simple(const char *data)
 {
   const unsigned char *p = (const unsigned char *)data;
   unsigned char tmpch = '\0';
-  unsigned int nonwild = 0;
+  unsigned int nonwild = 0, wild = 0;
 
   while ((tmpch = *p++))
   {
@@ -1478,9 +1436,11 @@ valid_wild_card_simple(const char *data)
       if (++nonwild >= ConfigGeneral.min_nonwildcard_simple)
         return 1;
     }
+    else
+      ++wild;
   }
 
-  return 0;
+  return !wild;
 }
 
 /* valid_wild_card()
@@ -1492,7 +1452,7 @@ valid_wild_card_simple(const char *data)
  * side effects - NOTICE is given to source_p if warn is 1
  */
 int
-valid_wild_card(struct Client *source_p, int warn, int count, ...)
+valid_wild_card(struct Client *source_p, int count, ...)
 {
   unsigned char tmpch = '\0';
   unsigned int nonwild = 0;
@@ -1535,7 +1495,7 @@ valid_wild_card(struct Client *source_p, int warn, int count, ...)
     }
   }
 
-  if (warn)
+  if (IsClient(source_p))
     sendto_one_notice(source_p, &me,
                       ":Please include at least %u non-wildcard characters with the mask",
                       ConfigGeneral.min_nonwildcard);
@@ -1599,7 +1559,7 @@ find_user_host(struct Client *source_p, char *user_host_or_nick,
         find_chasing(source_p, user_host_or_nick)) == NULL)
       return 0;  /* find_chasing sends ERR_NOSUCHNICK */
 
-    if (IsExemptKline(target_p))
+    if (HasFlag(target_p, FLAGS_EXEMPTKLINE))
     {
       if (IsClient(source_p))
         sendto_one_notice(source_p, &me, ":%s is E-lined", target_p->name);
@@ -1615,10 +1575,7 @@ find_user_host(struct Client *source_p, char *user_host_or_nick,
     if (target_p->username[0] == '~')
       luser[0] = '*';
 
-    if (!strcmp(target_p->sockhost, "0"))
-      strlcpy(lhost, target_p->host, HOSTLEN*4 + 1);
-    else
-      strlcpy(lhost, target_p->sockhost, HOSTLEN*4 + 1);
+    strlcpy(lhost, target_p->sockhost, HOSTLEN*4 + 1);
     return 1;
   }
 
@@ -1662,7 +1619,7 @@ parse_aline(const char *cmd, struct Client *source_p,
             char **target_server, char **reason)
 {
   int found_tkline_time=0;
-  static char def_reason[] = CONF_NOREASON;
+  static char default_reason[] = CONF_NOREASON;
   static char user[USERLEN*4+1];
   static char host[HOSTLEN*4+1];
 
@@ -1712,12 +1669,6 @@ parse_aline(const char *cmd, struct Client *source_p,
       parc--;
       parv++;
 
-      if (target_server == NULL)
-      {
-        sendto_one_notice(source_p, &me, ":ON server not supported by %s", cmd);
-        return 0;
-      }
-
       if (!HasOFlag(source_p, OPER_FLAG_REMOTEBAN))
       {
         sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "remoteban");
@@ -1752,46 +1703,24 @@ parse_aline(const char *cmd, struct Client *source_p,
       return 0;
     }
 
-    if ((parse_flags & AWILD) && !valid_wild_card(source_p, 1, 2, *up_p, *h_p))
+    if ((parse_flags & AWILD) && !valid_wild_card(source_p, 2, *up_p, *h_p))
       return 0;
   }
   else
-    if ((parse_flags & AWILD) && !valid_wild_card(source_p, 1, 1, *up_p))
+    if ((parse_flags & AWILD) && !valid_wild_card(source_p, 1, *up_p))
       return 0;
 
   if (reason)
   {
     if (parc && !EmptyString(*parv))
-    {
       *reason = *parv;
-
-      if (!valid_comment(source_p, *reason, 1))
-        return 0;
-    }
     else
-      *reason = def_reason;
+      *reason = default_reason;
   }
 
   return 1;
 }
 
-/* valid_comment()
- *
- * inputs	- pointer to client
- *              - pointer to comment
- * output       - 0 if no valid comment,
- *              - 1 if valid
- * side effects - truncates reason where necessary
- */
-int
-valid_comment(struct Client *source_p, char *comment, int warn)
-{
-  if (strlen(comment) > REASONLEN)
-    comment[REASONLEN-1] = '\0';
-
-  return 1;
-}
-
 /* match_conf_password()
  *
  * inputs       - pointer to given password
@@ -1820,7 +1749,7 @@ match_conf_password(const char *password, const struct MaskItem *conf)
  *
  * inputs	- client sending the cluster
  *		- command name "KLINE" "XLINE" etc.
- *		- capab -- CAP_KLN etc. from server.h
+ *		- capab -- CAPAB_KLN etc. from server.h
  *		- cluster type -- CLUSTER_KLINE etc. from conf.h
  *		- pattern and args to send along
  * output	- none
@@ -1844,7 +1773,7 @@ cluster_a_line(struct Client *source_p, const char *command, unsigned int capab,
     const struct MaskItem *conf = node->data;
 
     if (conf->flags & cluster_type)
-      sendto_match_servs(source_p, conf->name, CAP_CLUSTER | capab,
+      sendto_match_servs(source_p, conf->name, CAPAB_CLUSTER | capab,
                          "%s %s %s", command, conf->name, buffer);
   }
 }
