@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (C) 1996-2009 by Andrew Church <achurch@achurch.org>
- *  Copyright (c) 2012-2014 ircd-hybrid development team
+ *  Copyright (c) 2012-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file conf_db.c
  * \brief Includes file utilities for database handling
- * \version $Id: conf_db.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: conf_db.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 
@@ -44,7 +44,7 @@
  * \param f dbFile Struct Member
  * \return int 0 if failure, 1 > is the version number
  */
-uint32_t
+static uint32_t
 get_file_version(struct dbFILE *f)
 {
   uint32_t version = 0;
@@ -71,7 +71,7 @@ get_file_version(struct dbFILE *f)
  * \param version Database version
  * \return 0 on error, 1 on success.
  */
-int
+static int
 write_file_version(struct dbFILE *f, uint32_t version)
 {
   if (write_uint32(version, f) == -1)
@@ -91,7 +91,7 @@ write_file_version(struct dbFILE *f, uint32_t version)
 static struct dbFILE *
 open_db_read(const char *filename)
 {
-  struct dbFILE *f = MyCalloc(sizeof(*f));
+  struct dbFILE *f = xcalloc(sizeof(*f));
   FILE *fp = NULL;
 
   strlcpy(f->filename, filename, sizeof(f->filename));
@@ -106,7 +106,7 @@ open_db_read(const char *filename)
     if (errno != ENOENT)
       ilog(LOG_TYPE_IRCD, "Cannot read database file %s", f->filename);
 
-    MyFree(f);
+    xfree(f);
     errno = errno_save;
     return NULL;
   }
@@ -123,7 +123,7 @@ open_db_read(const char *filename)
 static struct dbFILE *
 open_db_write(const char *filename, uint32_t version)
 {
-  struct dbFILE *f = MyCalloc(sizeof(*f));
+  struct dbFILE *f = xcalloc(sizeof(*f));
   int fd = 0;
 
   strlcpy(f->filename, filename, sizeof(f->filename));
@@ -137,7 +137,7 @@ open_db_write(const char *filename, uint32_t version)
   {
     ilog(LOG_TYPE_IRCD, "Opening database file %s for write: Filename too long",
          filename);
-    MyFree(f);
+    xfree(f);
     errno = ENAMETOOLONG;
     return NULL;
   }
@@ -155,7 +155,7 @@ open_db_write(const char *filename, uint32_t version)
     static int walloped = 0;
 
     if (!walloped++)
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "Cannot create temporary database file %s",
                            f->tempname);
 
@@ -167,7 +167,7 @@ open_db_write(const char *filename, uint32_t version)
       fclose(f->fp);
 
     remove(f->tempname);
-    MyFree(f);
+    xfree(f);
 
     errno = errno_save;
     return NULL;
@@ -189,7 +189,7 @@ open_db_write(const char *filename, uint32_t version)
  * \param version Database version
  * \return dbFile struct
  */
-struct dbFILE *
+static struct dbFILE *
 open_db(const char *filename, const char *mode, uint32_t version)
 {
   switch (*mode)
@@ -213,7 +213,7 @@ open_db(const char *filename, const char *mode, uint32_t version)
  *
  * \param dbFile struct
  */
-void
+static void
 restore_db(struct dbFILE *f)
 {
   int errno_save = errno;
@@ -223,7 +223,7 @@ restore_db(struct dbFILE *f)
   if (f->mode == 'w' && f->tempname[0])
     remove(f->tempname);
 
-  MyFree(f);
+  xfree(f);
   errno = errno_save;
 }
 
@@ -234,7 +234,7 @@ restore_db(struct dbFILE *f)
  * \param dbFile struct
  * \return -1 on error, 0 on success.
  */
-int
+static int
 close_db(struct dbFILE *f)
 {
   int res;
@@ -257,7 +257,7 @@ close_db(struct dbFILE *f)
     {
       int errno_save = errno;
 
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE, "Unable to move new "
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "Unable to move new "
                            "data to database file %s; new data NOT saved.",
                            f->filename);
       errno = errno_save;
@@ -267,54 +267,19 @@ close_db(struct dbFILE *f)
     }
   }
 
-  MyFree(f);
+  xfree(f);
   return 0;
 }
 
 /*
- * Read and write 2-, 4- and 8-byte quantities, pointers, and strings.  All
- * multibyte values are stored in big-endian order (most significant byte
- * first).  A pointer is stored as a byte, either 0 if NULL or 1 if not,
- * and read pointers are returned as either (void *)0 or (void *)1.  A
- * string is stored with a 2-byte unsigned length (including the trailing
+ * Read and write 2-, 4- and 8-byte quantities, and strings. All multibyte
+ * values are stored in big-endian order (most significant byte first).
+ * A string is stored with a 2-byte unsigned length (including the trailing
  * \0) first; a length of 0 indicates that the string pointer is NULL.
  * Written strings are truncated silently at 4294967294 bytes, and are always
  * null-terminated.
  */
 
-/*! \brief Read a unsigned 8bit integer
- *
- * \param ret 8bit integer to read
- * \param dbFile struct
- * \return -1 on error, 0 otherwise.
- */
-int
-read_uint8(uint8_t*ret, struct dbFILE *f)
-{
-  int c = fgetc(f->fp);
-
-  if (c == EOF)
-    return -1;
-
-  *ret = c;
-  return 0;
-}
-
-/*! \brief Write a 8bit integer
- *
- * \param val 8bit integer to write
- * \param dbFile struct
- * \return -1 on error, 0 otherwise.
- */
-int
-write_uint8(uint8_t val, struct dbFILE *f)
-{
-  if (fputc(val, f->fp) == EOF)
-    return -1;
-
-  return 0;
-}
-
 /*! \brief Read a unsigned 8bit integer
  *
  * \param ret 16bit integer to read
@@ -448,39 +413,6 @@ write_uint64(uint64_t val, struct dbFILE *f)
   return 0;
 }
 
-/*! \brief Read Pointer
- *
- * \param ret pointer to read
- * \param dbFile struct
- * \return -1 on error, 0 otherwise.
- */
-int
-read_ptr(void **ret, struct dbFILE *f)
-{
-  int c = fgetc(f->fp);
-
-  if (c == EOF)
-    return -1;
-
-  *ret = (c ? (void *)1 : (void *)0);
-  return 0;
-}
-
-
-/*! \brief Write Pointer
- *
- * \param ptr pointer to write
- * \param dbFile struct
- * \return -1 on error, 0 otherwise.
- */
-int
-write_ptr(const void *ptr, struct dbFILE *f)
-{
-  if (fputc(ptr ? 1 : 0, f->fp) == EOF)
-    return -1;
-  return 0;
-}
-
 /*! \brief Read String
  *
  * \param ret string
@@ -502,11 +434,11 @@ read_string(char **ret, struct dbFILE *f)
     return 0;
   }
 
-  s = MyCalloc(len);
+  s = xcalloc(len);
 
   if (len != fread(s, 1, len, f->fp))
   {
-    MyFree(s);
+    xfree(s);
     return -1;
   }
 
@@ -557,14 +489,14 @@ write_string(const char *s, struct dbFILE *f)
 } while (0)
 
 void
-save_kline_database(void)
+save_kline_database(const char *filename)
 {
   uint32_t i = 0;
   uint32_t records = 0;
   struct dbFILE *f = NULL;
   dlink_node *ptr = NULL;
 
-  if (!(f = open_db(KPATH, "w", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
     return;
 
   for (i = 0; i < ATABLE_SIZE; ++i)
@@ -578,7 +510,7 @@ save_kline_database(void)
     }
   }
 
-  SAFE_WRITE(write_uint32(records, f), KPATH);
+  SAFE_WRITE(write_uint32(records, f), filename);
 
   for (i = 0; i < ATABLE_SIZE; ++i)
   {
@@ -588,11 +520,11 @@ save_kline_database(void)
 
       if (arec->type == CONF_KLINE && IsConfDatabase(arec->conf))
       {
-        SAFE_WRITE(write_string(arec->conf->user, f), KPATH);
-        SAFE_WRITE(write_string(arec->conf->host, f), KPATH);
-        SAFE_WRITE(write_string(arec->conf->reason, f), KPATH);
-        SAFE_WRITE(write_uint64(arec->conf->setat, f), KPATH);
-        SAFE_WRITE(write_uint64(arec->conf->until, f), KPATH);
+        SAFE_WRITE(write_string(arec->conf->user, f), filename);
+        SAFE_WRITE(write_string(arec->conf->host, f), filename);
+        SAFE_WRITE(write_string(arec->conf->reason, f), filename);
+        SAFE_WRITE(write_uint64(arec->conf->setat, f), filename);
+        SAFE_WRITE(write_uint64(arec->conf->until, f), filename);
       }
     }
   }
@@ -601,7 +533,7 @@ save_kline_database(void)
 }
 
 void
-load_kline_database(void)
+load_kline_database(const char *filename)
 {
   struct dbFILE *f = NULL;
   struct MaskItem *conf = NULL;
@@ -613,7 +545,7 @@ load_kline_database(void)
   uint64_t field_4 = 0;
   uint64_t field_5 = 0;
 
-  if (!(f = open_db(KPATH, "r", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
     return;
 
   if (get_file_version(f) < 1)
@@ -647,14 +579,14 @@ load_kline_database(void)
 }
 
 void
-save_dline_database(void)
+save_dline_database(const char *filename)
 {
   uint32_t i = 0;
   uint32_t records = 0;
   struct dbFILE *f = NULL;
   dlink_node *ptr = NULL;
 
-  if (!(f = open_db(DLPATH, "w", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
     return;
 
   for (i = 0; i < ATABLE_SIZE; ++i)
@@ -668,7 +600,7 @@ save_dline_database(void)
     }
   }
 
-  SAFE_WRITE(write_uint32(records, f), DLPATH);
+  SAFE_WRITE(write_uint32(records, f), filename);
 
   for (i = 0; i < ATABLE_SIZE; ++i)
   {
@@ -678,10 +610,10 @@ save_dline_database(void)
 
       if (arec->type == CONF_DLINE && IsConfDatabase(arec->conf))
       {
-        SAFE_WRITE(write_string(arec->conf->host, f), DLPATH);
-        SAFE_WRITE(write_string(arec->conf->reason, f), DLPATH);
-        SAFE_WRITE(write_uint64(arec->conf->setat, f), DLPATH);
-        SAFE_WRITE(write_uint64(arec->conf->until, f), DLPATH);
+        SAFE_WRITE(write_string(arec->conf->host, f), filename);
+        SAFE_WRITE(write_string(arec->conf->reason, f), filename);
+        SAFE_WRITE(write_uint64(arec->conf->setat, f), filename);
+        SAFE_WRITE(write_uint64(arec->conf->until, f), filename);
       }
     }
   }
@@ -690,7 +622,7 @@ save_dline_database(void)
 }
 
 void
-load_dline_database(void)
+load_dline_database(const char *filename)
 {
   struct dbFILE *f = NULL;
   struct MaskItem *conf = NULL;
@@ -701,7 +633,7 @@ load_dline_database(void)
   uint64_t field_3 = 0;
   uint64_t field_4 = 0;
 
-  if (!(f = open_db(DLPATH, "r", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
     return;
 
   if (get_file_version(f) < 1)
@@ -733,104 +665,14 @@ load_dline_database(void)
 }
 
 void
-save_gline_database(void)
-{
-  uint32_t i = 0;
-  uint32_t records = 0;
-  struct dbFILE *f = NULL;
-  dlink_node *ptr = NULL;
-
-  if (!(f = open_db(GPATH, "w", KLINE_DB_VERSION)))
-    return;
-
-  for (i = 0; i < ATABLE_SIZE; ++i)
-  {
-    DLINK_FOREACH(ptr, atable[i].head)
-    {
-      struct AddressRec *arec = ptr->data;
-
-      if (arec->type == CONF_GLINE && IsConfDatabase(arec->conf))
-        ++records;
-    }
-  }
-
-  SAFE_WRITE(write_uint32(records, f), GPATH);
-
-  for (i = 0; i < ATABLE_SIZE; ++i)
-  {
-    DLINK_FOREACH(ptr, atable[i].head)
-    {
-      struct AddressRec *arec = ptr->data;
-
-      if (arec->type == CONF_GLINE && IsConfDatabase(arec->conf))
-      {
-        SAFE_WRITE(write_string(arec->conf->user, f), GPATH);
-        SAFE_WRITE(write_string(arec->conf->host, f), GPATH);
-        SAFE_WRITE(write_string(arec->conf->reason, f), GPATH);
-        SAFE_WRITE(write_uint64(arec->conf->setat, f), GPATH);
-        SAFE_WRITE(write_uint64(arec->conf->until, f), GPATH);
-      }
-    }
-  }
-
-  close_db(f);
-}
-
-void
-load_gline_database(void)
-{
-  struct dbFILE *f = NULL;
-  struct MaskItem *conf = NULL;
-  char *field_1 = NULL;
-  char *field_2 = NULL;
-  char *field_3 = NULL;
-  uint32_t i = 0;
-  uint32_t records = 0;
-  uint64_t field_4 = 0;
-  uint64_t field_5 = 0;
-
-  if (!(f = open_db(GPATH, "r", KLINE_DB_VERSION)))
-    return;
-
-  if (get_file_version(f) < 1)
-  {
-    close_db(f);
-    return;
-  }
-
-  read_uint32(&records, f);
-
-  for (i = 0; i < records; ++i)
-  {
-    SAFE_READ(read_string(&field_1, f));
-    SAFE_READ(read_string(&field_2, f));
-    SAFE_READ(read_string(&field_3, f));
-    SAFE_READ(read_uint64(&field_4, f));
-    SAFE_READ(read_uint64(&field_5, f));
-
-    conf = conf_make(CONF_GLINE);
-    conf->user = field_1;
-    conf->host = field_2;
-    conf->reason = field_3;
-    conf->setat = field_4;
-    conf->until = field_5;
-    SetConfDatabase(conf);
-
-    add_conf_by_address(CONF_GLINE, conf);
-  }
-
-  close_db(f);
-}
-
-void
-save_resv_database(void)
+save_resv_database(const char *filename)
 {
   uint32_t records = 0;
   struct dbFILE *f = NULL;
   dlink_node *ptr = NULL;
   struct MaskItem *conf = NULL;
 
-  if (!(f = open_db(RESVPATH, "w", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
     return;
 
   DLINK_FOREACH(ptr, cresv_items.head)
@@ -849,7 +691,7 @@ save_resv_database(void)
       ++records;
   }
 
-  SAFE_WRITE(write_uint32(records, f), RESVPATH);
+  SAFE_WRITE(write_uint32(records, f), filename);
 
   DLINK_FOREACH(ptr, cresv_items.head)
   {
@@ -858,10 +700,10 @@ save_resv_database(void)
     if (!IsConfDatabase(conf))
       continue;
 
-    SAFE_WRITE(write_string(conf->name, f), RESVPATH);
-    SAFE_WRITE(write_string(conf->reason, f), RESVPATH);
-    SAFE_WRITE(write_uint64(conf->setat, f), RESVPATH);
-    SAFE_WRITE(write_uint64(conf->until, f), RESVPATH);
+    SAFE_WRITE(write_string(conf->name, f), filename);
+    SAFE_WRITE(write_string(conf->reason, f), filename);
+    SAFE_WRITE(write_uint64(conf->setat, f), filename);
+    SAFE_WRITE(write_uint64(conf->until, f), filename);
   }
 
   DLINK_FOREACH(ptr, nresv_items.head)
@@ -871,17 +713,17 @@ save_resv_database(void)
     if (!IsConfDatabase(conf))
       continue;
 
-    SAFE_WRITE(write_string(conf->name, f), RESVPATH);
-    SAFE_WRITE(write_string(conf->reason, f), RESVPATH);
-    SAFE_WRITE(write_uint64(conf->setat, f), RESVPATH);
-    SAFE_WRITE(write_uint64(conf->until, f), RESVPATH);
+    SAFE_WRITE(write_string(conf->name, f), filename);
+    SAFE_WRITE(write_string(conf->reason, f), filename);
+    SAFE_WRITE(write_uint64(conf->setat, f), filename);
+    SAFE_WRITE(write_uint64(conf->until, f), filename);
   }
 
   close_db(f);
 }
 
 void
-load_resv_database(void)
+load_resv_database(const char *filename)
 {
   uint32_t i = 0;
   uint32_t records = 0;
@@ -891,7 +733,7 @@ load_resv_database(void)
   char *reason = NULL;
   struct MaskItem *conf = NULL;
 
-  if (!(f = open_db(RESVPATH, "r", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
     return;
 
   if (get_file_version(f) < 1)
@@ -916,25 +758,25 @@ load_resv_database(void)
     conf->until = tmp64_hold;
     SetConfDatabase(conf);
 
-    MyFree(name);
-    MyFree(reason);
+    xfree(name);
+    xfree(reason);
   }
 
   close_db(f);
 }
 
 void
-save_xline_database(void)
+save_xline_database(const char *filename)
 {
   uint32_t records = 0;
   struct dbFILE *f = NULL;
   dlink_node *ptr = NULL;
   struct MaskItem *conf = NULL;
 
-  if (!(f = open_db(XPATH, "w", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
     return;
 
-  DLINK_FOREACH(ptr, xconf_items.head)
+  DLINK_FOREACH(ptr, gecos_items.head)
   {
     conf = ptr->data;
 
@@ -942,26 +784,26 @@ save_xline_database(void)
       ++records;
   }
 
-  SAFE_WRITE(write_uint32(records, f), XPATH);
+  SAFE_WRITE(write_uint32(records, f), filename);
 
-  DLINK_FOREACH(ptr, xconf_items.head)
+  DLINK_FOREACH(ptr, gecos_items.head)
   {
     conf = ptr->data;
 
     if (!IsConfDatabase(conf))
       continue;
 
-    SAFE_WRITE(write_string(conf->name, f), XPATH);
-    SAFE_WRITE(write_string(conf->reason, f), XPATH);
-    SAFE_WRITE(write_uint64(conf->setat, f), XPATH);
-    SAFE_WRITE(write_uint64(conf->until, f), XPATH);
+    SAFE_WRITE(write_string(conf->name, f), filename);
+    SAFE_WRITE(write_string(conf->reason, f), filename);
+    SAFE_WRITE(write_uint64(conf->setat, f), filename);
+    SAFE_WRITE(write_uint64(conf->until, f), filename);
   }
 
   close_db(f);
 }
 
 void
-load_xline_database(void)
+load_xline_database(const char *filename)
 {
   uint32_t i = 0;
   uint32_t records = 0;
@@ -971,7 +813,7 @@ load_xline_database(void)
   char *reason = NULL;
   struct MaskItem *conf = NULL;
 
-  if (!(f = open_db(XPATH, "r", KLINE_DB_VERSION)))
+  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
     return;
 
   if (get_file_version(f) < 1)
@@ -1005,9 +847,8 @@ load_xline_database(void)
 void
 save_all_databases(void *unused)
 {
-  save_kline_database();
-  save_dline_database();
-  save_gline_database();
-  save_xline_database();
-  save_resv_database();
+  save_kline_database(ConfigGeneral.klinefile);
+  save_dline_database(ConfigGeneral.dlinefile);
+  save_xline_database(ConfigGeneral.xlinefile);
+  save_resv_database(ConfigGeneral.resvfile);
 }
