@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_pseudo.c
  * \brief Handles with pseudo commands/service aliases.
- * \version $Id: conf_pseudo.c 4299 2014-07-20 13:51:28Z michael $
+ * \version $Id: conf_pseudo.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -96,7 +96,7 @@ pseudo_register(const char *name, const char *nick,
   if (find_command(command))
     return;
 
-  cmd = MyCalloc(sizeof(*cmd));
+  cmd = xcalloc(sizeof(*cmd));
   cmd->name = xstrdup(name);
   cmd->nick = xstrdup(nick);
   cmd->serv = xstrdup(serv);
@@ -105,14 +105,13 @@ pseudo_register(const char *name, const char *nick,
 
   cmd->msg.cmd = cmd->command;
   cmd->msg.args_max = 2;
-  cmd->msg.flags = MFLG_EXTRA | MFLG_SLOW;
+  cmd->msg.flags = MFLG_EXTRA;
   cmd->msg.extra = cmd;
   cmd->msg.handlers[UNREGISTERED_HANDLER] = m_unregistered;
   cmd->msg.handlers[CLIENT_HANDLER] = m_pseudo;
   cmd->msg.handlers[SERVER_HANDLER] = m_ignore;
   cmd->msg.handlers[ENCAP_HANDLER] = m_ignore;
   cmd->msg.handlers[OPER_HANDLER] = m_pseudo;
-  cmd->msg.handlers[DUMMY_HANDLER] = m_ignore;
   dlinkAdd(cmd, &cmd->node, &pseudo_cmd_list);
 
   mod_add_cmd(&cmd->msg);
@@ -131,11 +130,11 @@ pseudo_clear(void)
     mod_del_cmd(&cmd->msg);
     dlinkDelete(&cmd->node, &pseudo_cmd_list);
 
-    MyFree(cmd->name);
-    MyFree(cmd->nick);
-    MyFree(cmd->serv);
-    MyFree(cmd->prep);
-    MyFree(cmd->command);
-    MyFree(cmd);
+    xfree(cmd->name);
+    xfree(cmd->nick);
+    xfree(cmd->serv);
+    xfree(cmd->prep);
+    xfree(cmd->command);
+    xfree(cmd);
   }
 }
