@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file dbuf.c
  * \brief Supports dynamic data buffers.
- * \version $Id: dbuf.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: dbuf.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -30,6 +30,7 @@
 #include "memory.h"
 #include "mempool.h"
 
+
 static mp_pool_t *dbuf_pool;
 
 void
@@ -111,8 +112,12 @@ dbuf_put_args(struct dbuf_block *dbuf, const char *data, va_list args)
   assert(dbuf->refs == 1);
 
   dbuf->size += vsnprintf(dbuf->data + dbuf->size, sizeof(dbuf->data) - dbuf->size, data, args);
+
+  /*
+   * As per C99, (v)snprintf returns the length the resulting string would be
+   */
   if (dbuf->size > sizeof(dbuf->data))
-    dbuf->size = sizeof(dbuf->data); /* required by some versions of vsnprintf */
+    dbuf->size = sizeof(dbuf->data);
 }
 
 void
