@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file event.c
  * \brief Timer based event execution
- * \version $Id: event.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: event.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -33,7 +33,14 @@
 #include "numeric.h"
 #include "rng_mt.h"
 
-static dlink_list events;
+
+static dlink_list event_list;
+
+const dlink_list *
+event_get_list(void)
+{
+  return &event_list;
+}
 
 void
 event_add(struct event *ev, void *data)
@@ -44,20 +51,20 @@ event_add(struct event *ev, void *data)
 
   ev->data = data;
   ev->next = CurrentTime + ev->when;
-  ev->enabled = 1;
+  ev->active = 1;
 
-  DLINK_FOREACH(node, events.head)
+  DLINK_FOREACH(node, event_list.head)
   {
     struct event *e = node->data;
 
     if (e->next > ev->next)
     {
-      dlinkAddBefore(node, ev, &ev->node, &events);
+      dlinkAddBefore(node, ev, &ev->node, &event_list);
       return;
     }
   }
 
-  dlinkAddTail(ev, &ev->node, &events);
+  dlinkAddTail(ev, &ev->node, &event_list);
 }
 
 void
@@ -76,11 +83,11 @@ event_addish(struct event *ev, void *data)
 void
 event_delete(struct event *ev)
 {
-  if (!ev->enabled)
+  if (!ev->active)
     return;
 
-  dlinkDelete(&ev->node, &events);
-  ev->enabled = 0;
+  dlinkDelete(&ev->node, &event_list);
+  ev->active = 0;
 }
 
 void
@@ -93,10 +100,10 @@ event_run(void)
     return;
   last = CurrentTime;
 
-  len = dlink_list_length(&events);
-  while (len-- && dlink_list_length(&events))
+  len = dlink_list_length(&event_list);
+  while (len-- && dlink_list_length(&event_list))
   {
-    struct event *e = events.head->data;
+    struct event *e = event_list.head->data;
 
     if (e->next > CurrentTime)
       break;
@@ -111,48 +118,19 @@ event_run(void)
 }
 
 /*
- * void set_back_events(time_t by)
+ * void event_set_back_events(time_t by)
  * Input: Time to set back events by.
  * Output: None.
  * Side-effects: Sets back all events by "by" seconds.
  */
 void
-set_back_events(time_t by)
+event_set_back_events(time_t by)
 {
   dlink_node *node;
 
-  DLINK_FOREACH(node, events.head)
+  DLINK_FOREACH(node, event_list.head)
   {
     struct event *ev = node->data;
     ev->next -= by;
   }
 }
-
-/*
- * void show_events(struct Client *source_p)
- *
- * Input: Client requesting the event
- * Output: List of events
- * Side Effects: None
- */
-void
-show_events(struct Client *source_p)
-{
-  const dlink_node *node;
-
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG|SND_EXPLICIT,
-                     "E :Operation                      Next Execution");
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG|SND_EXPLICIT,
-                     "E :---------------------------------------------");
-
-  DLINK_FOREACH(node, events.head)
-  {
-    const struct event *ev = node->data;
-
-    sendto_one_numeric(source_p, &me, RPL_STATSDEBUG|SND_EXPLICIT,
-                       "E :%-30s %-4d seconds",
-                       ev->name,
-                       (int)(ev->next - CurrentTime));
-  }
-}
-
