@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file fdlist.c
  * \brief Maintains a list of file descriptors.
- * \version $Id: fdlist.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: fdlist.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -44,8 +44,8 @@ int number_fd = LEAKED_FDS;
 int hard_fdlimit = 0;
 
 
-static int
-set_fdlimit(void)
+void
+fdlist_init(void)
 {
   int fdmax;
   struct rlimit limit;
@@ -65,14 +65,6 @@ set_fdlimit(void)
   /* under no condition shall this raise over 65536
    * for example user ip heap is sized 2*hard_fdlimit */
   hard_fdlimit = IRCD_MIN(fdmax, 65536);
-
-  return -1;
-}
-
-void
-fdlist_init(void)
-{
-  set_fdlimit();
 }
 
 static inline unsigned int
@@ -101,7 +93,9 @@ void
 fd_open(fde_t *F, int fd, int is_socket, const char *desc)
 {
   unsigned int hashv = hash_fd(fd);
+
   assert(fd >= 0);
+  assert(!F->flags.open);
 
   F->fd = fd;
   F->comm_index = -1;
@@ -125,6 +119,8 @@ fd_close(fde_t *F)
 {
   unsigned int hashv = hash_fd(F->fd);
 
+  assert(F->flags.open);
+
   if (F == fd_next_in_loop)
     fd_next_in_loop = F->hnext;
 
@@ -165,7 +161,7 @@ fd_dump(struct Client *source_p, int parc, char *parv[])
 {
   for (unsigned int i = 0; i < FD_HASH_SIZE; ++i)
     for (fde_t *F = fd_hash[i]; F; F = F->hnext)
-      sendto_one_numeric(source_p, &me, RPL_STATSDEBUG|SND_EXPLICIT,
+      sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                          "F :fd %-5d desc '%s'", F->fd, F->desc);
 }
 
@@ -201,7 +197,7 @@ close_standard_fds(void)
     close(i);
 
     if (open("/dev/null", O_RDWR) < 0)
-      exit(-1); /* we're hosed if we can't even open /dev/null */
+      exit(EXIT_FAILURE); /* we're hosed if we can't even open /dev/null */
   }
 }
 
