@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hash.c
  * \brief Hash table management.
- * \version $Id: hash.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: hash.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -32,6 +32,7 @@
 #include "client.h"
 #include "modules.h"
 #include "hash.h"
+#include "id.h"
 #include "resv.h"
 #include "rng_mt.h"
 #include "userhost.h"
@@ -45,10 +46,7 @@
 #include "user.h"
 
 
-static mp_pool_t *userhost_pool = NULL;
-static mp_pool_t *namehost_pool = NULL;
-
-static unsigned int hashf_xor_key = 0;
+static unsigned int hashf_xor_key;
 
 /* The actual hash tables, They MUST be of the same HASHSIZE, variable
  * size tables could be supported but the rehash routine should also
@@ -61,7 +59,7 @@ static struct Channel *channelTable[HASHSIZE];
 static struct UserHost *userhostTable[HASHSIZE];
 
 
-/* init_hash()
+/* hash_init()
  *
  * inputs       - NONE
  * output       - NONE
@@ -71,10 +69,9 @@ static struct UserHost *userhostTable[HASHSIZE];
 void
 hash_init(void)
 {
-  userhost_pool = mp_pool_new(sizeof(struct UserHost), MP_CHUNK_SIZE_USERHOST);
-  namehost_pool = mp_pool_new(sizeof(struct NameHost), MP_CHUNK_SIZE_NAMEHOST);
-
-  hashf_xor_key = genrand_int32() % 256;  /* better than nothing --adx */
+  do
+    hashf_xor_key = genrand_int32() % 256;  /* better than nothing --adx */
+  while (!hashf_xor_key);
 }
 
 /*
@@ -92,7 +89,8 @@ strhash(const char *name)
 
   if (EmptyString(p))
     return 0;
-  for (; *p != '\0'; ++p)
+
+  for (; *p; ++p)
   {
     hval += (hval << 1) + (hval <<  4) + (hval << 7) +
             (hval << 8) + (hval << 24);
@@ -124,7 +122,7 @@ strhash(const char *name)
 void
 hash_add_client(struct Client *client_p)
 {
-  unsigned int hashv = strhash(client_p->name);
+  const unsigned int hashv = strhash(client_p->name);
 
   client_p->hnext = clientTable[hashv];
   clientTable[hashv] = client_p;
@@ -143,7 +141,7 @@ hash_add_client(struct Client *client_p)
 void
 hash_add_channel(struct Channel *chptr)
 {
-  unsigned int hashv = strhash(chptr->chname);
+  const unsigned int hashv = strhash(chptr->name);
 
   chptr->hnextch = channelTable[hashv];
   channelTable[hashv] = chptr;
@@ -152,7 +150,7 @@ hash_add_channel(struct Channel *chptr)
 void
 hash_add_userhost(struct UserHost *userhost)
 {
-  unsigned int hashv = strhash(userhost->host);
+  const unsigned int hashv = strhash(userhost->host);
 
   userhost->next = userhostTable[hashv];
   userhostTable[hashv] = userhost;
@@ -161,7 +159,7 @@ hash_add_userhost(struct UserHost *userhost)
 void
 hash_add_id(struct Client *client_p)
 {
-  unsigned int hashv = strhash(client_p->id);
+  const unsigned int hashv = strhash(client_p->id);
 
   client_p->idhnext = idTable[hashv];
   idTable[hashv] = client_p;
@@ -176,7 +174,7 @@ hash_add_id(struct Client *client_p)
 void
 hash_del_id(struct Client *client_p)
 {
-  unsigned int hashv = strhash(client_p->id);
+  const unsigned int hashv = strhash(client_p->id);
   struct Client *tmp = idTable[hashv];
 
   if (tmp)
@@ -207,7 +205,7 @@ hash_del_id(struct Client *client_p)
 void
 hash_del_client(struct Client *client_p)
 {
-  unsigned int hashv = strhash(client_p->name);
+  const unsigned int hashv = strhash(client_p->name);
   struct Client *tmp = clientTable[hashv];
 
   if (tmp)
@@ -238,7 +236,7 @@ hash_del_client(struct Client *client_p)
 void
 hash_del_userhost(struct UserHost *userhost)
 {
-  unsigned int hashv = strhash(userhost->host);
+  const unsigned int hashv = strhash(userhost->host);
   struct UserHost *tmp = userhostTable[hashv];
 
   if (tmp)
@@ -270,7 +268,7 @@ hash_del_userhost(struct UserHost *userhost)
 void
 hash_del_channel(struct Channel *chptr)
 {
-  unsigned int hashv = strhash(chptr->chname);
+  const unsigned int hashv = strhash(chptr->name);
   struct Channel *tmp = channelTable[hashv];
 
   if (tmp)
@@ -303,7 +301,7 @@ hash_del_channel(struct Channel *chptr)
 struct Client *
 hash_find_client(const char *name)
 {
-  unsigned int hashv = strhash(name);
+  const unsigned int hashv = strhash(name);
   struct Client *client_p;
 
   if ((client_p = clientTable[hashv]))
@@ -331,7 +329,7 @@ hash_find_client(const char *name)
 struct Client *
 hash_find_id(const char *name)
 {
-  unsigned int hashv = strhash(name);
+  const unsigned int hashv = strhash(name);
   struct Client *client_p;
 
   if ((client_p = idTable[hashv]))
@@ -359,7 +357,7 @@ hash_find_id(const char *name)
 struct Client *
 hash_find_server(const char *name)
 {
-  unsigned int hashv = strhash(name);
+  const unsigned int hashv = strhash(name);
   struct Client *client_p = NULL;
 
   if (IsDigit(*name) && strlen(name) == IRC_MAXSID)
@@ -400,18 +398,18 @@ hash_find_server(const char *name)
 struct Channel *
 hash_find_channel(const char *name)
 {
-  unsigned int hashv = strhash(name);
+  const unsigned int hashv = strhash(name);
   struct Channel *chptr = NULL;
 
   if ((chptr = channelTable[hashv]))
   {
-    if (irccmp(name, chptr->chname))
+    if (irccmp(name, chptr->name))
     {
       struct Channel *prev;
 
       while (prev = chptr, (chptr = chptr->hnextch))
       {
-        if (!irccmp(name, chptr->chname))
+        if (!irccmp(name, chptr->name))
         {
           prev->hnextch = chptr->hnextch;
           chptr->hnextch = channelTable[hashv];
@@ -425,48 +423,10 @@ hash_find_channel(const char *name)
   return chptr;
 }
 
-/* hash_get_bucket(int type, unsigned int hashv)
- *
- * inputs       - hash value (must be between 0 and HASHSIZE - 1)
- * output       - NONE
- * returns      - pointer to first channel in channelTable[hashv]
- *                if that exists;
- *                NULL if there is no channel in that place;
- *                NULL if hashv is an invalid number.
- * side effects - NONE
- */
-void *
-hash_get_bucket(int type, unsigned int hashv)
-{
-  assert(hashv < HASHSIZE);
-  if (hashv >= HASHSIZE)
-      return NULL;
-
-  switch (type)
-  {
-    case HASH_TYPE_ID:
-      return idTable[hashv];
-      break;
-    case HASH_TYPE_CHANNEL:
-      return channelTable[hashv];
-      break;
-    case HASH_TYPE_CLIENT:
-      return clientTable[hashv];
-      break;
-    case HASH_TYPE_USERHOST:
-      return userhostTable[hashv];
-      break;
-    default:
-      assert(0);
-  }
-
-  return NULL;
-}
-
 struct UserHost *
 hash_find_userhost(const char *host)
 {
-  unsigned int hashv = strhash(host);
+  const unsigned int hashv = strhash(host);
   struct UserHost *userhost;
 
   if ((userhost = userhostTable[hashv]))
@@ -491,182 +451,43 @@ hash_find_userhost(const char *host)
   return userhost;
 }
 
-/* count_user_host()
+/* hash_get_bucket(int type, unsigned int hashv)
  *
- * inputs	- user name
- *		- hostname
- *		- int flag 1 if global, 0 if local
- * 		- pointer to where global count should go
- *		- pointer to where local count should go
- *		- pointer to where identd count should go (local clients only)
- * output	- none
- * side effects	-
+ * inputs       - hash value (must be between 0 and HASHSIZE - 1)
+ * output       - NONE
+ * returns      - pointer to first channel in channelTable[hashv]
+ *                if that exists;
+ *                NULL if there is no channel in that place;
+ *                NULL if hashv is an invalid number.
+ * side effects - NONE
  */
-void
-count_user_host(const char *user, const char *host, unsigned int *global_p,
-                unsigned int *local_p, unsigned int *icount_p)
+void *
+hash_get_bucket(int type, unsigned int hashv)
 {
-  dlink_node *ptr;
-  struct UserHost *found_userhost;
-  struct NameHost *nameh;
+  assert(hashv < HASHSIZE);
 
-  if ((found_userhost = hash_find_userhost(host)) == NULL)
-    return;
+  if (hashv >= HASHSIZE)
+    return NULL;
 
-  DLINK_FOREACH(ptr, found_userhost->list.head)
+  switch (type)
   {
-    nameh = ptr->data;
-
-    if (!irccmp(user, nameh->name))
-    {
-      if (global_p)
-        *global_p = nameh->gcount;
-      if (local_p)
-        *local_p  = nameh->lcount;
-      if (icount_p)
-        *icount_p = nameh->icount;
-      return;
-    }
-  }
-}
-
-/* find_or_add_userhost()
- *
- * inputs       - host name
- * output       - none
- * side effects - find UserHost * for given host name
- */
-static struct UserHost *
-find_or_add_userhost(const char *host)
-{
-  struct UserHost *userhost = NULL;
-
-  if ((userhost = hash_find_userhost(host)))
-    return userhost;
-
-  userhost = mp_pool_get(userhost_pool);
-
-  strlcpy(userhost->host, host, sizeof(userhost->host));
-  hash_add_userhost(userhost);
-
-  return userhost;
-}
-
-/* add_user_host()
- *
- * inputs	- user name
- *		- hostname
- *		- int flag 1 if global, 0 if local
- * output	- none
- * side effects	- add given user@host to hash tables
- */
-void
-add_user_host(const char *user, const char *host, int global)
-{
-  dlink_node *ptr;
-  struct UserHost *found_userhost;
-  struct NameHost *nameh;
-  unsigned int hasident = 1;
-
-  if (*user == '~')
-  {
-    hasident = 0;
-    ++user;
+    case HASH_TYPE_ID:
+      return idTable[hashv];
+      break;
+    case HASH_TYPE_CHANNEL:
+      return channelTable[hashv];
+      break;
+    case HASH_TYPE_CLIENT:
+      return clientTable[hashv];
+      break;
+    case HASH_TYPE_USERHOST:
+      return userhostTable[hashv];
+      break;
+    default:
+      assert(0);
   }
 
-  if ((found_userhost = find_or_add_userhost(host)) == NULL)
-    return;
-
-  DLINK_FOREACH(ptr, found_userhost->list.head)
-  {
-    nameh = ptr->data;
-
-    if (!irccmp(user, nameh->name))
-    {
-      nameh->gcount++;
-
-      if (!global)
-      {
-        if (hasident)
-          nameh->icount++;
-        nameh->lcount++;
-      }
-
-      return;
-    }
-  }
-
-  nameh = mp_pool_get(namehost_pool);
-
-  strlcpy(nameh->name, user, sizeof(nameh->name));
-
-  nameh->gcount = 1;
-
-  if (!global)
-  {
-    if (hasident)
-      nameh->icount = 1;
-    nameh->lcount = 1;
-  }
-
-  dlinkAdd(nameh, &nameh->node, &found_userhost->list);
-}
-
-/* delete_user_host()
- *
- * inputs	- user name
- *		- hostname
- *		- int flag 1 if global, 0 if local
- * output	- none
- * side effects	- delete given user@host to hash tables
- */
-void
-delete_user_host(const char *user, const char *host, int global)
-{
-  dlink_node *ptr = NULL;
-  struct UserHost *found_userhost = NULL;
-  unsigned int hasident = 1;
-
-  if (*user == '~')
-  {
-    hasident = 0;
-    ++user;
-  }
-
-  if ((found_userhost = hash_find_userhost(host)) == NULL)
-    return;
-
-  DLINK_FOREACH(ptr, found_userhost->list.head)
-  {
-    struct NameHost *nameh = ptr->data;
-
-    if (!irccmp(user, nameh->name))
-    {
-      if (nameh->gcount > 0)
-        nameh->gcount--;
-      if (!global)
-      {
-        if (nameh->lcount > 0)
-          nameh->lcount--;
-        if (hasident && nameh->icount > 0)
-          nameh->icount--;
-      }
-
-      if (nameh->gcount == 0 && nameh->lcount == 0)
-      {
-        dlinkDelete(&nameh->node, &found_userhost->list);
-        mp_pool_release(nameh);
-      }
-
-      if (dlink_list_length(&found_userhost->list) == 0)
-      {
-        hash_del_userhost(found_userhost);
-        mp_pool_release(found_userhost);
-      }
-
-      return;
-    }
-  }
+  return NULL;
 }
 
 /*
@@ -694,7 +515,7 @@ delete_user_host(const char *user, const char *host, int global)
 static int
 exceeding_sendq(const struct Client *to)
 {
-  if (dbuf_length(&to->localClient->buf_sendq) > (get_sendq(&to->localClient->confs) / 2))
+  if (dbuf_length(&to->connection->buf_sendq) > (get_sendq(&to->connection->confs) / 2))
     return 1;
   else
     return 0;
@@ -703,28 +524,25 @@ exceeding_sendq(const struct Client *to)
 void
 free_list_task(struct Client *source_p)
 {
-  struct ListTask *lt = source_p->localClient->list_task;
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  struct ListTask *const lt = source_p->connection->list_task;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  if ((ptr = dlinkFindDelete(&listing_client_list, source_p)))
-    free_dlink_node(ptr);
+  dlinkDelete(&lt->node, &listing_client_list);
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, lt->show_mask.head)
+  DLINK_FOREACH_SAFE(node, node_next, lt->show_mask.head)
   {
-    MyFree(ptr->data);
-    free_dlink_node(ptr);
+    xfree(node->data);
+    free_dlink_node(node);
   }
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, lt->hide_mask.head)
+  DLINK_FOREACH_SAFE(node, node_next, lt->hide_mask.head)
   {
-    MyFree(ptr->data);
-    free_dlink_node(ptr);
+    xfree(node->data);
+    free_dlink_node(node);
   }
 
-  MyFree(lt);
-
-  if (MyConnect(source_p))
-    source_p->localClient->list_task = NULL;
+  xfree(lt);
+  source_p->connection->list_task = NULL;
 }
 
 /* list_allow_channel()
@@ -736,16 +554,16 @@ free_list_task(struct Client *source_p)
  * side effects -
  */
 static int
-list_allow_channel(const char *chname, const struct ListTask *lt)
+list_allow_channel(const char *name, const struct ListTask *lt)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, lt->show_mask.head)
-    if (match(ptr->data, chname) != 0)
+  DLINK_FOREACH(node, lt->show_mask.head)
+    if (match(node->data, name) != 0)
       return 0;
 
-  DLINK_FOREACH(ptr, lt->hide_mask.head)
-    if (match(ptr->data, chname) == 0)
+  DLINK_FOREACH(node, lt->hide_mask.head)
+    if (match(node->data, name) == 0)
       return 0;
 
   return 1;
@@ -762,7 +580,7 @@ list_allow_channel(const char *chname, const struct ListTask *lt)
 static void
 list_one_channel(struct Client *source_p, struct Channel *chptr)
 {
-  const struct ListTask *lt = source_p->localClient->list_task;
+  const struct ListTask *const lt = source_p->connection->list_task;
   char listbuf[MODEBUFLEN] = "";
   char modebuf[MODEBUFLEN] = "";
   char parabuf[MODEBUFLEN] = "";
@@ -770,11 +588,12 @@ list_one_channel(struct Client *source_p, struct Channel *chptr)
   if (SecretChannel(chptr) &&
       !(HasUMode(source_p, UMODE_ADMIN) || IsMember(source_p, chptr)))
     return;
+
   if (dlink_list_length(&chptr->members) < lt->users_min ||
       dlink_list_length(&chptr->members) > lt->users_max ||
-      (chptr->channelts != 0 &&
-       ((unsigned int)chptr->channelts < lt->created_min ||
-        (unsigned int)chptr->channelts > lt->created_max)) ||
+      (chptr->creationtime != 0 &&
+       ((unsigned int)chptr->creationtime < lt->created_min ||
+        (unsigned int)chptr->creationtime > lt->created_max)) ||
       (unsigned int)chptr->topic_time < lt->topicts_min ||
       (chptr->topic_time ? (unsigned int)chptr->topic_time : UINT_MAX) >
       lt->topicts_max)
@@ -783,7 +602,7 @@ list_one_channel(struct Client *source_p, struct Channel *chptr)
   if (lt->topic[0] && match(lt->topic, chptr->topic))
     return;
 
-  if (!list_allow_channel(chptr->chname, lt))
+  if (!list_allow_channel(chptr->name, lt))
     return;
 
   channel_modes(chptr, source_p, modebuf, parabuf);
@@ -793,7 +612,7 @@ list_one_channel(struct Client *source_p, struct Channel *chptr)
   else
     snprintf(listbuf, sizeof(listbuf), "[%s]",  modebuf);
 
-  sendto_one_numeric(source_p, &me, RPL_LIST, chptr->chname,
+  sendto_one_numeric(source_p, &me, RPL_LIST, chptr->name,
                      dlink_list_length(&chptr->members),
                      listbuf, chptr->topic);
 }
@@ -812,7 +631,7 @@ list_one_channel(struct Client *source_p, struct Channel *chptr)
 void
 safe_list_channels(struct Client *source_p, int only_unmasked_channels)
 {
-  struct ListTask *lt = source_p->localClient->list_task;
+  struct ListTask *const lt = source_p->connection->list_task;
   struct Channel *chptr = NULL;
 
   if (!only_unmasked_channels)
@@ -831,10 +650,10 @@ safe_list_channels(struct Client *source_p, int only_unmasked_channels)
   }
   else
   {
-    dlink_node *ptr = NULL;
+    dlink_node *node = NULL;
 
-    DLINK_FOREACH(ptr, lt->show_mask.head)
-      if ((chptr = hash_find_channel(ptr->data)))
+    DLINK_FOREACH(node, lt->show_mask.head)
+      if ((chptr = hash_find_channel(node->data)))
         list_one_channel(source_p, chptr);
   }
 
