@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2015 ircd-hybrid development team
+ *  Copyright (c) 2001-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hostmask.c
  * \brief Code to efficiently find IP & hostmask based configs.
- * \version $Id: hostmask.c 5459 2015-02-03 22:24:23Z michael $
+ * \version $Id: hostmask.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -56,10 +56,6 @@ dlink_list atable[ATABLE_SIZE];
  * Side effects: None
  * Comments: Called from parse_netmask
  */
-/* Fixed so ::/0 (any IPv6 address) is valid
-   Also a bug in DigitParse above.
-   -Gozem 2002-07-19 gozem@linux.nu
-*/
 static int
 try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 {
@@ -92,10 +88,13 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
       }
       else
       {
-        /* If there were less than 4 hex digits, e.g. :ABC: shift right
-         * so we don't interpret it as ABC0 -A1kmm */
+        /*
+         * If there were less than 4 hex digits, e.g. :ABC: shift right
+         * so we don't interpret it as ABC0 -A1kmm
+         */
         d[dp] = d[dp] >> 4 * nyble;
         nyble = 4;
+
         if (++dp >= 8)
           return HM_HOST;
       }
@@ -195,7 +194,7 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
     }
     else if (c == '*')
     {
-      if (*(p + 1) || n == 0 || *(p - 1) != '.')
+      if (*(p + 1) || n == 1 || *(p - 1) != '.')
         return HM_HOST;
 
       bits = (n - 1) * 8;
@@ -436,7 +435,7 @@ get_mask_hash(const char *text)
  * should always be true (i.e. conf->flags & CONF_FLAGS_NEED_PASSWORD == 0)
  */
 struct MaskItem *
-find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int type,
+find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned int type,
                      int fam, const char *username, const char *password, int do_match)
 {
   unsigned int hprecv = 0;
@@ -552,7 +551,7 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
  * Side-effects: None
  */
 struct MaskItem *
-find_address_conf(const char *host, const char *user, struct irc_ssaddr *ip,
+find_address_conf(const char *host, const char *user, const struct irc_ssaddr *ip,
                   int aftype, const char *password)
 {
   struct MaskItem *authcnf = NULL, *killcnf = NULL;
@@ -571,18 +570,11 @@ find_address_conf(const char *host, const char *user, struct irc_ssaddr *ip,
 
   /*
    * If they are K-lined, return the K-line. Otherwise, return the
-   * auth{} block. -A1kmm
+   * auth {} block. -A1kmm
    */
   if (killcnf)
     return killcnf;
 
-  if (IsConfExemptGline(authcnf))
-    return authcnf;
-
-  killcnf = find_conf_by_address(host, ip, CONF_GLINE, aftype, user, NULL, 1);
-  if (killcnf)
-    return killcnf;
-
   return authcnf;
 }
 
@@ -593,7 +585,7 @@ find_address_conf(const char *host, const char *user, struct irc_ssaddr *ip,
  * Side effects: None.
  */
 struct MaskItem *
-find_dline_conf(struct irc_ssaddr *addr, int aftype)
+find_dline_conf(const struct irc_ssaddr *addr, int aftype)
 {
   struct MaskItem *eline;
 
@@ -615,12 +607,12 @@ add_conf_by_address(const unsigned int type, struct MaskItem *conf)
   struct AddressRec *arec = NULL;
   const char *const hostname = conf->host;
   const char *const username = conf->user;
-  static unsigned int prec_value = 0xFFFFFFFF;
+  static unsigned int prec_value = UINT_MAX;
   int bits = 0;
 
   assert(type && !EmptyString(hostname));
 
-  arec = MyCalloc(sizeof(struct AddressRec));
+  arec = xcalloc(sizeof(struct AddressRec));
   arec->masktype = parse_netmask(hostname, &arec->Mask.ipa.addr, &bits);
   arec->Mask.ipa.bits = bits;
   arec->username = username;
@@ -691,7 +683,7 @@ delete_one_address_conf(const char *address, struct MaskItem *conf)
       if (!conf->ref_count)
         conf_free(conf);
 
-      MyFree(arec);
+      xfree(arec);
       return;
     }
   }
@@ -716,10 +708,9 @@ clear_out_address_conf(void)
       struct AddressRec *arec = node->data;
 
       /*
-       * We keep the temporary K-lines and destroy the permanent ones,
-       * just to be confusing :) -A1kmm
+       * Destroy the ircd.conf items and keep those that are in the databases
        */
-      if (arec->conf->until || IsConfDatabase(arec->conf))
+      if (IsConfDatabase(arec->conf))
         continue;
 
       dlinkDelete(&arec->node, &atable[i]);
@@ -727,7 +718,7 @@ clear_out_address_conf(void)
 
       if (!arec->conf->ref_count)
         conf_free(arec->conf);
-      MyFree(arec);
+      xfree(arec);
     }
   }
 }
@@ -735,7 +726,7 @@ clear_out_address_conf(void)
 static void
 hostmask_send_expiration(const struct AddressRec *const arec)
 {
-  char ban_type = '\0';
+  char ban_type = '?';
 
   if (!ConfigGeneral.tkline_expire_notices)
     return;
@@ -748,13 +739,10 @@ hostmask_send_expiration(const struct AddressRec *const arec)
     case CONF_DLINE:
       ban_type = 'D';
       break;
-    case CONF_GLINE:
-      ban_type = 'G';
-      break;
     default: break;
   }
 
-  sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                        "Temporary %c-line for [%s@%s] expired", ban_type,
                        (arec->conf->user) ? arec->conf->user : "*",
                        (arec->conf->host) ? arec->conf->host : "*");
@@ -778,12 +766,11 @@ hostmask_expire_temporary(void)
       {
         case CONF_KLINE:
         case CONF_DLINE:
-        case CONF_GLINE:
           hostmask_send_expiration(arec);
 
           dlinkDelete(&arec->node, &atable[i]);
           conf_free(arec->conf);
-          MyFree(arec);
+          xfree(arec);
           break;
         default: break;
       }
