@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ipcache.c
  * \brief Routines to count connections from particular IP addresses.
- * \version $Id: ipcache.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: ipcache.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -37,7 +37,6 @@ static dlink_list ip_hash_table[IP_HASH_SIZE];
 static mp_pool_t *ip_entry_pool;
 
 
-
 /* ipcache_hash_address()
  *
  * input        - pointer to an irc_inaddr
@@ -49,7 +48,7 @@ ipcache_hash_address(const struct irc_ssaddr *addr)
 {
   if (addr->ss.ss_family == AF_INET)
   {
-    const struct sockaddr_in *v4 = (const struct sockaddr_in *)addr;
+    const struct sockaddr_in *const v4 = (const struct sockaddr_in *)addr;
     uint32_t hash = 0, ip = ntohl(v4->sin_addr.s_addr);
 
     hash = ((ip >> 12) + ip) & (IP_HASH_SIZE - 1);
@@ -57,8 +56,8 @@ ipcache_hash_address(const struct irc_ssaddr *addr)
   }
   else
   {
-    const struct sockaddr_in6 *v6 = (const struct sockaddr_in6 *)addr;
-    uint32_t hash = 0, *ip = (uint32_t *)&v6->sin6_addr.s6_addr;
+    const struct sockaddr_in6 *const v6 = (const struct sockaddr_in6 *)addr;
+    uint32_t hash = 0, *const ip = (uint32_t *)&v6->sin6_addr.s6_addr;
 
     hash  = ip[0] ^ ip[3];
     hash ^= hash >> 16;
@@ -78,30 +77,30 @@ ipcache_hash_address(const struct irc_ssaddr *addr)
  * count set to 0.
  */
 struct ip_entry *
-ipcache_find_or_add_address(struct irc_ssaddr *addr)
+ipcache_find_or_add_address(const struct irc_ssaddr *addr)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   struct ip_entry *iptr = NULL;
-  uint32_t hash_index = ipcache_hash_address(addr);
-  struct sockaddr_in *v4 = (struct sockaddr_in *)addr, *ptr_v4;
-  struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)addr, *ptr_v6;
+  const uint32_t hash_index = ipcache_hash_address(addr);
+  const struct sockaddr_in *v4 = (const struct sockaddr_in *)addr, *ptr_v4;
+  const struct sockaddr_in6 *v6 = (const struct sockaddr_in6 *)addr, *ptr_v6;
 
-  DLINK_FOREACH(ptr, ip_hash_table[hash_index].head)
+  DLINK_FOREACH(node, ip_hash_table[hash_index].head)
   {
-    iptr = ptr->data;
+    iptr = node->data;
 
     if (iptr->ip.ss.ss_family != addr->ss.ss_family)
       continue;
 
     if (addr->ss.ss_family == AF_INET6)
     {
-      ptr_v6 = (struct sockaddr_in6 *)&iptr->ip;
+      ptr_v6 = (const struct sockaddr_in6 *)&iptr->ip;
       if (!memcmp(&v6->sin6_addr, &ptr_v6->sin6_addr, sizeof(struct in6_addr)))
         return iptr;  /* Found entry already in hash, return it. */
     }
     else
     {
-      ptr_v4 = (struct sockaddr_in *)&iptr->ip;
+      ptr_v4 = (const struct sockaddr_in *)&iptr->ip;
       if (!memcmp(&v4->sin_addr, &ptr_v4->sin_addr, sizeof(struct in_addr)))
         return iptr;  /* Found entry already in hash, return it. */
     }
@@ -125,29 +124,29 @@ ipcache_find_or_add_address(struct irc_ssaddr *addr)
  *                 the struct ip_entry is returned to the ip_entry_heap
  */
 void
-ipcache_remove_address(struct irc_ssaddr *addr)
+ipcache_remove_address(const struct irc_ssaddr *addr)
 {
-  dlink_node *ptr = NULL;
-  uint32_t hash_index = ipcache_hash_address(addr);
-  struct sockaddr_in *v4 = (struct sockaddr_in *)addr, *ptr_v4;
-  struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)addr, *ptr_v6;
+  dlink_node *node = NULL;
+  const uint32_t hash_index = ipcache_hash_address(addr);
+  const struct sockaddr_in *v4 = (const struct sockaddr_in *)addr, *ptr_v4;
+  const struct sockaddr_in6 *v6 = (const struct sockaddr_in6 *)addr, *ptr_v6;
 
-  DLINK_FOREACH(ptr, ip_hash_table[hash_index].head)
+  DLINK_FOREACH(node, ip_hash_table[hash_index].head)
   {
-    struct ip_entry *iptr = ptr->data;
+    struct ip_entry *iptr = node->data;
 
     if (iptr->ip.ss.ss_family != addr->ss.ss_family)
       continue;
 
     if (addr->ss.ss_family == AF_INET6)
     {
-      ptr_v6 = (struct sockaddr_in6 *)&iptr->ip;
+      ptr_v6 = (const struct sockaddr_in6 *)&iptr->ip;
       if (memcmp(&v6->sin6_addr, &ptr_v6->sin6_addr, sizeof(struct in6_addr)))
         continue;
     }
     else
     {
-      ptr_v4 = (struct sockaddr_in *)&iptr->ip;
+      ptr_v4 = (const struct sockaddr_in *)&iptr->ip;
       if (memcmp(&v4->sin_addr, &ptr_v4->sin_addr, sizeof(struct in_addr)))
         continue;
     }
@@ -173,13 +172,13 @@ ipcache_remove_address(struct irc_ssaddr *addr)
 static void
 ipcache_remove_expired_entries(void *unused)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
   for (unsigned int i = 0; i < IP_HASH_SIZE; ++i)
   {
-    DLINK_FOREACH_SAFE(ptr, ptr_next, ip_hash_table[i].head)
+    DLINK_FOREACH_SAFE(node, node_next, ip_hash_table[i].head)
     {
-      struct ip_entry *iptr = ptr->data;
+      struct ip_entry *iptr = node->data;
 
       if (iptr->count == 0 &&
           (CurrentTime - iptr->last_attempt) >= ConfigGeneral.throttle_time)
@@ -202,7 +201,7 @@ ipcache_remove_expired_entries(void *unused)
  * used in the hash.
  */
 void
-ipcache_get_stats(unsigned int *const number_ips_stored, uint64_t *const mem_ips_stored)
+ipcache_get_stats(unsigned int *const number_ips_stored, size_t *const mem_ips_stored)
 {
   for (unsigned int i = 0; i < IP_HASH_SIZE; ++i)
     *number_ips_stored += dlink_list_length(&ip_hash_table[i]);
