@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file irc_string.c
  * \brief IRC string functions.
- * \version $Id: irc_string.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: irc_string.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "config.h"
@@ -70,13 +70,13 @@ strip_tabs(char *dest, const char *src, size_t len)
 }
 
 /*
- * strtoken - walk through a string of tokens, using a set of separators
+ * strtok_r - walk through a string of tokens, using a set of separators
  *   argv 9/90
  *
  */
 #ifndef HAVE_STRTOK_R
 char *
-strtoken(char **save, char *str, const char *fs)
+strtok_r(char *str, const char *fs, char **save)
 {
   char *pos = *save;  /* keep last position across calls */
   char *tmp = NULL;
