@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.c
  * \brief Starts up and runs the ircd.
- * \version $Id: ircd.c 5736 2015-03-29 11:10:50Z michael $
+ * \version $Id: ircd.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -33,9 +33,9 @@
 #include "event.h"
 #include "fdlist.h"
 #include "hash.h"
+#include "id.h"
 #include "irc_string.h"
 #include "ircd_signal.h"
-#include "gline.h"
 #include "motd.h"
 #include "conf.h"
 #include "hostmask.h"
@@ -46,7 +46,7 @@
 #include "auth.h"
 #include "s_bsd.h"
 #include "log.h"
-#include "server.h"      /* try_connections */
+#include "server.h"
 #include "send.h"
 #include "whowas.h"
 #include "modules.h"
@@ -57,6 +57,8 @@
 #include "conf_db.h"
 #include "conf_class.h"
 #include "ipcache.h"
+#include "isupport.h"
+#include "userhost.h"
 
 
 #ifdef HAVE_LIBGEOIP
@@ -77,17 +79,31 @@ const char *pidFileName = PPATH;
 
 unsigned int dorehash;
 unsigned int doremotd;
-unsigned int default_server_capabs;
-unsigned int splitmode;
-unsigned int splitchecking;
-unsigned int split_users;
-unsigned int split_servers;
 
-static struct event event_cleanup_glines =
+static int printVersion;
+
+static struct lgetopt myopts[] =
 {
-  .name = "cleanup_glines",
-  .handler = cleanup_glines,
-  .when = CLEANUP_GLINES_TIME
+  { "configfile", &ConfigGeneral.configfile,
+   STRING, "File to use for ircd.conf" },
+  { "klinefile",  &ConfigGeneral.klinefile,
+   STRING, "File to use for kline database" },
+  { "dlinefile",  &ConfigGeneral.dlinefile,
+   STRING, "File to use for dline database" },
+  { "xlinefile",  &ConfigGeneral.xlinefile,
+   STRING, "File to use for xline database" },
+  { "resvfile",   &ConfigGeneral.resvfile,
+   STRING, "File to use for resv database" },
+  { "logfile",    &logFileName,
+   STRING, "File to use for ircd.log" },
+  { "pidfile",    &pidFileName,
+   STRING, "File to use for process ID" },
+  { "foreground", &server_state.foreground,
+   YESNO, "Run in foreground (don't detach)" },
+  { "version",    &printVersion,
+   YESNO, "Print version and exit" },
+  { "help", NULL, USAGE, "Print this text" },
+  { NULL, NULL, STRING, NULL },
 };
 
 static struct event event_cleanup_tklines =
@@ -125,65 +141,6 @@ struct event event_write_links_file =
 };
 
 
-/*
- * print_startup - print startup information
- */
-static void
-print_startup(int pid)
-{
-  printf("ircd: version %s(%s)\n", ircd_version, serno);
-  printf("ircd: pid %d\n", pid);
-  printf("ircd: running in %s mode from %s\n", !server_state.foreground ? "background"
-         : "foreground", ConfigGeneral.dpath);
-}
-
-static void
-make_daemon(void)
-{
-  int pid;
-
-  if ((pid = fork()) < 0)
-  {
-    perror("fork");
-    exit(EXIT_FAILURE);
-  }
-  else if (pid > 0)
-  {
-    print_startup(pid);
-    exit(EXIT_SUCCESS);
-  }
-
-  setsid();
-}
-
-static int printVersion = 0;
-
-static struct lgetopt myopts[] =
-{
-  {"configfile", &ConfigGeneral.configfile,
-   STRING, "File to use for ircd.conf"},
-  {"glinefile",  &ConfigGeneral.glinefile,
-   STRING, "File to use for gline database"},
-  {"klinefile",  &ConfigGeneral.klinefile,
-   STRING, "File to use for kline database"},
-  {"dlinefile",  &ConfigGeneral.dlinefile,
-   STRING, "File to use for dline database"},
-  {"xlinefile",  &ConfigGeneral.xlinefile,
-   STRING, "File to use for xline database"},
-  {"resvfile",  &ConfigGeneral.resvfile,
-   STRING, "File to use for resv database"},
-  {"logfile",    &logFileName,
-   STRING, "File to use for ircd.log"},
-  {"pidfile",    &pidFileName,
-   STRING, "File to use for process ID"},
-  {"foreground", &server_state.foreground,
-   YESNO, "Run in foreground (don't detach)"},
-  {"version",    &printVersion,
-   YESNO, "Print version and exit"},
-  {"help", NULL, USAGE, "Print this text"},
-  {NULL, NULL, STRING, NULL},
-};
-
 void
 set_time(void)
 {
@@ -191,26 +148,24 @@ set_time(void)
 
   if (gettimeofday(&newtime, NULL) == -1)
   {
-    ilog(LOG_TYPE_IRCD, "Clock Failure (%s), TS can be corrupted",
-         strerror(errno));
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "Clock Failure (%s), TS can be corrupted",
-                         strerror(errno));
-    server_die("Clock Failure", 1);
+    char buf[IRCD_BUFSIZE];
+
+    snprintf(buf, sizeof(buf), "Clock failure, TS can be corrupted: %s",
+             strerror(errno));
+    server_die(buf, SERVER_SHUTDOWN);
   }
 
   if (newtime.tv_sec < CurrentTime)
   {
-    ilog(LOG_TYPE_IRCD, "System clock is running backwards - (%lu < %lu)",
-         (unsigned long)newtime.tv_sec, (unsigned long)CurrentTime);
+    ilog(LOG_TYPE_IRCD, "System clock is running backwards - (%ju < %ju)",
+         newtime.tv_sec, CurrentTime);
     sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                         "System clock is running backwards - (%lu < %lu)",
-                         (unsigned long)newtime.tv_sec,
-                         (unsigned long)CurrentTime);
-    set_back_events(CurrentTime - newtime.tv_sec);
+                         "System clock is running backwards - (%ju < %ju)",
+                         newtime.tv_sec, CurrentTime);
+    event_set_back_events(CurrentTime - newtime.tv_sec);
   }
 
-  SystemTime.tv_sec  = newtime.tv_sec;
+  SystemTime.tv_sec = newtime.tv_sec;
   SystemTime.tv_usec = newtime.tv_usec;
 }
 
@@ -233,7 +188,7 @@ io_loop(void)
     exit_aborted_clients();
     free_exited_clients();
 
-    /* Check to see whether we have to rehash the configuration .. */
+    /* Check to see whether we have to rehash the configuration. */
     if (dorehash)
     {
       conf_rehash(1);
@@ -243,7 +198,7 @@ io_loop(void)
     if (doremotd)
     {
       motd_recache();
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "Got signal SIGUSR1, reloading motd file(s)");
       doremotd = 0;
     }
@@ -266,17 +221,6 @@ initialize_global_set_options(void)
   GlobalSetOptions.floodcount = ConfigGeneral.default_floodcount;
   GlobalSetOptions.joinfloodcount = ConfigChannel.default_join_flood_count;
   GlobalSetOptions.joinfloodtime = ConfigChannel.default_join_flood_time;
-
-  split_servers = ConfigChannel.default_split_server_count;
-  split_users   = ConfigChannel.default_split_user_count;
-
-  if (split_users && split_servers && (ConfigChannel.no_create_on_split ||
-                                       ConfigChannel.no_join_on_split))
-  {
-    splitmode     = 1;
-    splitchecking = 1;
-  }
-
   GlobalSetOptions.ident_timeout = IDENT_TIMEOUT;
 }
 
@@ -288,13 +232,12 @@ initialize_global_set_options(void)
 static void
 initialize_server_capabs(void)
 {
-  add_capability("QS", CAP_QS, 1);
-  add_capability("EOB", CAP_EOB, 1);
-  add_capability("TS6", CAP_TS6, 0);
-  add_capability("CLUSTER", CAP_CLUSTER, 1);
-  add_capability("SVS", CAP_SVS, 1);
-  add_capability("CHW", CAP_CHW, 1);
-  add_capability("HOPS", CAP_HOPS, 1);
+  add_capability("QS", CAPAB_QS);
+  add_capability("EOB", CAPAB_EOB);
+  add_capability("CLUSTER", CAPAB_CLUSTER);
+  add_capability("SVS", CAPAB_SVS);
+  add_capability("CHW", CAPAB_CHW);
+  add_capability("HOPS", CAPAB_HOPS);
 }
 
 /* write_pidfile()
@@ -310,12 +253,12 @@ write_pidfile(const char *filename)
 
   if ((fb = fopen(filename, "w")))
   {
-    char buff[IRCD_BUFSIZE];
+    char buf[IRCD_BUFSIZE];
     unsigned int pid = (unsigned int)getpid();
 
-    snprintf(buff, sizeof(buff), "%u\n", pid);
+    snprintf(buf, sizeof(buf), "%u\n", pid);
 
-    if (fputs(buff, fb) == -1)
+    if (fputs(buf, fb) == -1)
       ilog(LOG_TYPE_IRCD, "Error writing to pid file %s: %s",
            filename, strerror(errno));
 
@@ -338,36 +281,30 @@ static void
 check_pidfile(const char *filename)
 {
   FILE *fb;
-  char buff[IRCD_BUFSIZE];
-  pid_t pidfromfile;
+  char buf[IRCD_BUFSIZE];
 
-  /* Don't do logging here, since we don't have log() initialised */
   if ((fb = fopen(filename, "r")))
   {
-    if (!fgets(buff, 20, fb))
-    {
-      /* log(L_ERROR, "Error reading from pid file %s (%s)", filename,
-       * strerror(errno));
-       */
-    }
+    if (!fgets(buf, 20, fb))
+      ilog(LOG_TYPE_IRCD, "Error reading from pid file %s: %s",
+           filename, strerror(errno));
     else
     {
-      pidfromfile = atoi(buff);
+      pid_t pid = atoi(buf);
 
-      if (!kill(pidfromfile, 0))
+      if (!kill(pid, 0))
       {
         /* log(L_ERROR, "Server is already running"); */
         printf("ircd: daemon is already running\n");
-        exit(-1);
+        exit(EXIT_FAILURE);
       }
     }
 
     fclose(fb);
   }
   else if (errno != ENOENT)
-  {
-    /* log(L_ERROR, "Error opening pid file %s", filename); */
-  }
+    ilog(LOG_TYPE_IRCD, "Error opening pid file %s: %s",
+         filename, strerror(errno));
 }
 
 /* setup_corefile()
@@ -400,7 +337,7 @@ always_accept_verify_cb(int preverify_ok, X509_STORE_CTX *x509_ctx)
 }
 #endif
 
-/* init_ssl()
+/* ssl_init()
  *
  * inputs       - nothing
  * output       - nothing
@@ -462,6 +399,37 @@ ssl_init(void)
 #endif /* HAVE_LIBCRYPTO */
 }
 
+/*
+ * print_startup - print startup information
+ */
+static void
+print_startup(int pid)
+{
+  printf("ircd: version %s(%s)\n", ircd_version, serno);
+  printf("ircd: pid %d\n", pid);
+  printf("ircd: running in %s mode from %s\n", !server_state.foreground ? "background"
+         : "foreground", ConfigGeneral.dpath);
+}
+
+static void
+make_daemon(void)
+{
+  int pid;
+
+  if ((pid = fork()) < 0)
+  {
+    perror("fork");
+    exit(EXIT_FAILURE);
+  }
+  else if (pid > 0)
+  {
+    print_startup(pid);
+    exit(EXIT_SUCCESS);
+  }
+
+  setsid();
+}
+
 int
 main(int argc, char *argv[])
 {
@@ -481,14 +449,11 @@ main(int argc, char *argv[])
   /* It's not random, but it ought to be a little harder to guess */
   init_genrand(SystemTime.tv_sec ^ (SystemTime.tv_usec | (getpid() << 20)));
 
-  dlinkAdd(&me, &me.node, &global_client_list);
-
   ConfigGeneral.dpath      = DPATH;
   ConfigGeneral.spath      = SPATH;
   ConfigGeneral.mpath      = MPATH;
   ConfigGeneral.configfile = CPATH;    /* Server configuration file */
   ConfigGeneral.klinefile  = KPATH;    /* Server kline file         */
-  ConfigGeneral.glinefile  = GPATH;    /* Server gline file         */
   ConfigGeneral.xlinefile  = XPATH;    /* Server xline file         */
   ConfigGeneral.dlinefile  = DLPATH;   /* dline file                */
   ConfigGeneral.resvfile   = RESVPATH; /* resv file                 */
@@ -533,9 +498,10 @@ main(int argc, char *argv[])
 
   mp_pool_init();
   init_dlink_nodes();
-  init_isupport();
+  isupport_init();
   dbuf_init();
   hash_init();
+  userhost_init();
   ipcache_init();
   client_init();
   class_init();
@@ -545,25 +511,16 @@ main(int argc, char *argv[])
   init_resolver();      /* Needs to be setup before the io loop */
   modules_init();
   read_conf_files(1);   /* cold start init conf files */
-  init_uid();
   initialize_server_capabs();   /* Set up default_server_capabs */
   initialize_global_set_options();  /* Has to be called after read_conf_files() */
   channel_init();
   read_links_file();
   motd_init();
-  user_usermodes_init();
+  user_modes_init();
 #ifdef HAVE_LIBGEOIP
   geoip_ctx = GeoIP_new(GEOIP_MEMORY_CACHE);
 #endif
 
-  if (EmptyString(ConfigServerInfo.sid))
-  {
-    ilog(LOG_TYPE_IRCD, "ERROR: No server id specified in serverinfo block.");
-    exit(EXIT_FAILURE);
-  }
-
-  strlcpy(me.id, ConfigServerInfo.sid, sizeof(me.id));
-
   if (EmptyString(ConfigServerInfo.name))
   {
     ilog(LOG_TYPE_IRCD, "ERROR: No server name specified in serverinfo block.");
@@ -572,7 +529,7 @@ main(int argc, char *argv[])
 
   strlcpy(me.name, ConfigServerInfo.name, sizeof(me.name));
 
-  /* serverinfo{} description must exist.  If not, error out.*/
+  /* serverinfo {} description must exist.  If not, error out.*/
   if (EmptyString(ConfigServerInfo.description))
   {
     ilog(LOG_TYPE_IRCD, "ERROR: No server description specified in serverinfo block.");
@@ -581,6 +538,16 @@ main(int argc, char *argv[])
 
   strlcpy(me.info, ConfigServerInfo.description, sizeof(me.info));
 
+  if (EmptyString(ConfigServerInfo.sid))
+  {
+    ilog(LOG_TYPE_IRCD, "Generating server ID");
+    generate_sid();
+  }
+  else
+    strlcpy(me.id, ConfigServerInfo.sid, sizeof(me.id));
+
+  init_uid();
+
   me.from = &me;
   me.servptr = &me;
   me.connection->lasttime = CurrentTime;
@@ -594,12 +561,12 @@ main(int argc, char *argv[])
   hash_add_client(&me);
 
   dlinkAdd(&me, make_dlink_node(), &global_server_list);
+  dlinkAdd(&me, &me.node, &global_client_list);
 
-  load_kline_database();
-  load_dline_database();
-  load_gline_database();
-  load_xline_database();
-  load_resv_database();
+  load_kline_database(ConfigGeneral.klinefile);
+  load_dline_database(ConfigGeneral.dlinefile);
+  load_xline_database(ConfigGeneral.xlinefile);
+  load_resv_database(ConfigGeneral.resvfile);
 
   load_all_modules(1);
   load_conf_modules();
@@ -607,9 +574,6 @@ main(int argc, char *argv[])
 
   write_pidfile(pidFileName);
 
-  ilog(LOG_TYPE_IRCD, "Server Ready");
-
-  event_addish(&event_cleanup_glines, NULL);
   event_addish(&event_cleanup_tklines, NULL);
 
   /* We want try_connections to be called as soon as possible now! -- adrian */
@@ -621,17 +585,14 @@ main(int argc, char *argv[])
 
   event_addish(&event_save_all_databases, NULL);
 
-  if (ConfigServerHide.links_delay > 0)
+  if (ConfigServerHide.flatten_links_delay && event_write_links_file.active == 0)
   {
-    event_write_links_file.when = ConfigServerHide.links_delay;
-    event_addish(&event_write_links_file, NULL);
+    event_write_links_file.when = ConfigServerHide.flatten_links_delay;
+    event_add(&event_write_links_file, NULL);
   }
-  else
-    ConfigServerHide.links_disabled = 1;
-
-  if (splitmode)
-    event_addish(&splitmode_event, NULL);
 
+  ilog(LOG_TYPE_IRCD, "Server Ready");
   io_loop();
+
   return 0;
 }
