@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd_signal.c
  * \brief responsible for ircd's signal handling.
- * \version $Id: ircd_signal.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: ircd_signal.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -36,7 +36,7 @@
 static void
 sigterm_handler(int sig)
 {
-  server_die("received signal SIGTERM", 0);
+  server_die("received signal SIGTERM", SERVER_SHUTDOWN);
 }
 
 /*
@@ -80,7 +80,7 @@ sigchld_handler(int sig)
 static void
 sigint_handler(int sig)
 {
-  server_die("received signal SIGINT", !server_state.foreground);
+  server_die("received signal SIGINT", server_state.foreground ? SERVER_SHUTDOWN : SERVER_RESTART);
 }
 
 /*
