@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2014 ircd-hybrid development team
+ *  Copyright (c) 1999-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file listener.c
  * \brief Implementation for handling listening sockets.
- * \version $Id: listener.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: listener.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -33,20 +33,26 @@
 #include "ircd.h"
 #include "ircd_defs.h"
 #include "s_bsd.h"
-#include "numeric.h"
 #include "conf.h"
 #include "send.h"
 #include "memory.h"
 
 #define TOOFAST_WARNING "ERROR :Your host is trying to (re)connect too fast -- throttled.\r\n"
 #define DLINE_WARNING "ERROR :You have been D-lined.\r\n"
+#define ALLINUSE_WARNING "ERROR :All connections in use\r\n"
 
 static dlink_list listener_list;
 
-static struct Listener *
-make_listener(const int port, const struct irc_ssaddr *addr)
+const dlink_list *
+listener_get_list(void)
 {
-  struct Listener *listener = MyCalloc(sizeof(struct Listener));
+  return &listener_list;
+}
+
+static struct Listener *
+listener_make(const int port, const struct irc_ssaddr *addr)
+{
+  struct Listener *listener = xcalloc(sizeof(struct Listener));
 
   listener->port = port;
   memcpy(&listener->addr, addr, sizeof(struct irc_ssaddr));
@@ -54,21 +60,19 @@ make_listener(const int port, const struct irc_ssaddr *addr)
   return listener;
 }
 
-void
-free_listener(struct Listener *listener)
+static void
+listener_free(struct Listener *listener)
 {
-  assert(listener);
-
   dlinkDelete(&listener->node, &listener_list);
-  MyFree(listener);
+  xfree(listener);
 }
 
 /*
- * get_listener_name - return displayable listener name and port
+ * listener_get_name - return displayable listener name and port
  * returns "host.foo.org/6667" for a given listener
  */
 const char *
-get_listener_name(const struct Listener *const listener)
+listener_get_name(const struct Listener *const listener)
 {
   static char buf[HOSTLEN + HOSTIPLEN + PORTNAMELEN + 4];  /* +4 for [,/,],\0 */
 
@@ -77,51 +81,6 @@ get_listener_name(const struct Listener *const listener)
   return buf;
 }
 
-/* show_ports()
- *
- * inputs       - pointer to client to show ports to
- * output       - none
- * side effects - send port listing to a client
- */
-void
-show_ports(struct Client *source_p)
-{
-  char buf[IRCD_BUFSIZE] = "";
-  char *p = NULL;
-  const dlink_node *ptr = NULL;
-
-  DLINK_FOREACH(ptr, listener_list.head)
-  {
-    const struct Listener *listener = ptr->data;
-    p = buf;
-
-    if (listener->flags & LISTENER_HIDDEN)
-    {
-      if (!HasUMode(source_p, UMODE_ADMIN))
-        continue;
-      *p++ = 'H';
-    }
-
-    if (listener->flags & LISTENER_SERVER)
-      *p++ = 'S';
-    if (listener->flags & LISTENER_SSL)
-      *p++ = 's';
-    *p = '\0';
-
-
-    if (HasUMode(source_p, UMODE_ADMIN) &&
-        (MyClient(source_p) || !ConfigServerHide.hide_server_ips))
-      sendto_one_numeric(source_p, &me, RPL_STATSPLINE, 'P', listener->port,
-                         listener->name,
-                         listener->ref_count, buf,
-                         listener->active ? "active" : "disabled");
-    else
-      sendto_one_numeric(source_p, &me, RPL_STATSPLINE, 'P', listener->port,
-                         me.name, listener->ref_count, buf,
-                         listener->active ? "active" : "disabled");
-  }
-}
-
 static void
 listener_accept_connection(fde_t *pfd, void *data)
 {
@@ -129,7 +88,7 @@ listener_accept_connection(fde_t *pfd, void *data)
   struct irc_ssaddr addr;
   int fd;
   int pe;
-  struct Listener *listener = data;
+  struct Listener *const listener = data;
 
   assert(listener);
 
@@ -152,10 +111,10 @@ listener_accept_connection(fde_t *pfd, void *data)
     {
       ++ServerStats.is_ref;
       sendto_realops_flags_ratelimited(&rate, "All connections in use. (%s)",
-                                       get_listener_name(listener));
+                                       listener_get_name(listener));
 
       if (!(listener->flags & LISTENER_SSL))
-        send(fd, "ERROR :All connections in use\r\n", 32, 0);
+        send(fd, ALLINUSE_WARNING, sizeof(ALLINUSE_WARNING) - 1, 0);
 
       close(fd);
       break;    /* jump out and re-register a new io request */
@@ -218,7 +177,7 @@ inetport(struct Listener *listener)
   memset(&lsin, 0, sizeof(lsin));
   memcpy(&lsin, &listener->addr, sizeof(lsin));
 
-  getnameinfo((struct sockaddr *)&lsin, lsin.ss_len, listener->name,
+  getnameinfo((const struct sockaddr *)&lsin, lsin.ss_len, listener->name,
               sizeof(listener->name), NULL, 0, NI_NUMERICHOST);
 
   /*
@@ -228,14 +187,14 @@ inetport(struct Listener *listener)
                 "Listener socket") == -1)
   {
     report_error(L_ALL, "opening listener socket %s:%s",
-                 get_listener_name(listener), errno);
+                 listener_get_name(listener), errno);
     return 0;
   }
 
   if (setsockopt(listener->fd.fd, SOL_SOCKET, SO_REUSEADDR, &opt, sizeof(opt)))
   {
     report_error(L_ALL, "setting SO_REUSEADDR for listener %s:%s",
-                 get_listener_name(listener), errno);
+                 listener_get_name(listener), errno);
     fd_close(&listener->fd);
     return 0;
   }
@@ -249,7 +208,7 @@ inetport(struct Listener *listener)
   if (bind(listener->fd.fd, (struct sockaddr *)&lsin, lsin.ss_len))
   {
     report_error(L_ALL, "binding listener socket %s:%s",
-                 get_listener_name(listener), errno);
+                 listener_get_name(listener), errno);
     fd_close(&listener->fd);
     return 0;
   }
@@ -257,7 +216,7 @@ inetport(struct Listener *listener)
   if (listen(listener->fd.fd, HYBRID_SOMAXCONN))
   {
     report_error(L_ALL, "listen failed for %s:%s",
-                 get_listener_name(listener), errno);
+                 listener_get_name(listener), errno);
     fd_close(&listener->fd);
     return 0;
   }
@@ -269,15 +228,15 @@ inetport(struct Listener *listener)
 }
 
 static struct Listener *
-find_listener(int port, struct irc_ssaddr *addr)
+listener_find(int port, struct irc_ssaddr *addr)
 {
-  dlink_node *ptr;
+  dlink_node *node;
   struct Listener *listener    = NULL;
   struct Listener *last_closed = NULL;
 
-  DLINK_FOREACH(ptr, listener_list.head)
+  DLINK_FOREACH(node, listener_list.head)
   {
-    listener = ptr->data;
+    listener = node->data;
 
     if ((port == listener->port) &&
         (!memcmp(addr, &listener->addr, sizeof(struct irc_ssaddr))))
@@ -297,13 +256,8 @@ find_listener(int port, struct irc_ssaddr *addr)
  * close_listener - close a single listener
  */
 static void
-close_listener(struct Listener *listener)
+listener_close(struct Listener *listener)
 {
-  assert(listener != NULL);
-
-  if (listener == NULL)
-    return;
-
   if (listener->fd.flags.open)
     fd_close(&listener->fd);
 
@@ -312,20 +266,20 @@ close_listener(struct Listener *listener)
   if (listener->ref_count)
     return;
 
-  free_listener(listener);
+  listener_free(listener);
 }
 
 /*
- * close_listeners - close and free all listeners that are not being used
+ * listener_close_marked - close and free all listeners that are not being used
  */
 void
-close_listeners(void)
+listener_close_marked(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
   /* close all 'extra' listening ports we have */
-  DLINK_FOREACH_SAFE(ptr, ptr_next, listener_list.head)
-    close_listener(ptr->data);
+  DLINK_FOREACH_SAFE(node, node_next, listener_list.head)
+    listener_close(node->data);
 }
 
 void
@@ -334,17 +288,17 @@ listener_release(struct Listener *listener)
   assert(listener->ref_count > 0);
 
   if (--listener->ref_count == 0 && !listener->active)
-    close_listener(listener);
+    listener_close(listener);
 }
 
 /*
- * add_listener- create a new listener
+ * listener_add- create a new listener
  * port - the port number to listen on
  * vhost_ip - if non-null must contain a valid IP address string in
  * the format "255.255.255.255"
  */
 void
-add_listener(int port, const char *vhost_ip, unsigned int flags)
+listener_add(int port, const char *vhost_ip, unsigned int flags)
 {
   struct Listener *listener;
   struct irc_ssaddr vaddr;
@@ -373,7 +327,8 @@ add_listener(int port, const char *vhost_ip, unsigned int flags)
   snprintf(portname, sizeof(portname), "%d", port);
   getaddrinfo("::", portname, &hints, &res);
   vaddr.ss.ss_family = AF_INET6;
-  assert(res != NULL);
+
+  assert(res);
 
   memcpy((struct sockaddr*)&vaddr, res->ai_addr, res->ai_addrlen);
   vaddr.ss_port = port;
@@ -407,12 +362,12 @@ add_listener(int port, const char *vhost_ip, unsigned int flags)
   {
     /* add the ipv4 listener if we havent already */
     pass = 1;
-    add_listener(port, "0.0.0.0", flags);
+    listener_add(port, "0.0.0.0", flags);
   }
 
   pass = 0;
 
-  if ((listener = find_listener(port, &vaddr)))
+  if ((listener = listener_find(port, &vaddr)))
   {
     listener->flags = flags;
 
@@ -421,7 +376,7 @@ add_listener(int port, const char *vhost_ip, unsigned int flags)
   }
   else
   {
-    listener = make_listener(port, &vaddr);
+    listener = listener_make(port, &vaddr);
     dlinkAdd(listener, &listener->node, &listener_list);
     listener->flags = flags;
   }
@@ -429,5 +384,5 @@ add_listener(int port, const char *vhost_ip, unsigned int flags)
   if (inetport(listener))
     listener->active = 1;
   else
-    close_listener(listener);
+    listener_close(listener);
 }
