@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file log.c
  * \brief Logger functions.
- * \version $Id: log.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: log.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -94,11 +94,7 @@ log_exceed_size(unsigned int type)
 static void
 log_write(enum log_type type, const char *message)
 {
-  char buf[IRCD_BUFSIZE] = "";
-
-  strftime(buf, sizeof(buf), "[%FT%H:%M:%S%z]", localtime(&CurrentTime));
-
-  fprintf(log_type_table[type].file, "%s %s\n", buf, message);
+  fprintf(log_type_table[type].file, "[%s] %s\n", date_iso8601(0), message);
   fflush(log_type_table[type].file);
 }
 
