@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file match.c
  * \brief Functions to match/compare strings.
- * \version $Id: match.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: match.c 7008 2016-01-01 13:08:13Z michael $
  */
 
 #include "stdinc.h"
@@ -49,18 +49,21 @@ match(const char *mask, const char *name)
     switch (*m)
     {
       case '\0':
-        if (!*n)
+        if (*n == '\0')
           return 0;
   backtrack:
         if (m_tmp == mask)
           return 1;
+
         m = m_tmp;
         n = ++n_tmp;
+
         if (*n == '\0')
           return 1;
         break;
       case '\\':
         ++m;
+
         /* allow escaping to force capitalization */
         if (*m++ != *n++)
           goto backtrack;
@@ -73,7 +76,7 @@ match(const char *mask, const char *name)
             star = 1;
           else if (*m == '?')
           {
-            if (!*n++)
+            if (*n++ == '\0')
               goto backtrack;
           }
           else
@@ -82,12 +85,13 @@ match(const char *mask, const char *name)
 
         if (star)
         {
-          if (!*m)
+          if (*m == '\0')
             return 0;
           else if (*m == '\\')
           {
             m_tmp = ++m;
-            if (!*m)
+
+            if (*m == '\0')
               return 1;
             for (n_tmp = n; *n && *n != *m; ++n)
               ;
@@ -101,7 +105,7 @@ match(const char *mask, const char *name)
         }
         /* and fall through */
       default:
-        if (!*n)
+        if (*n == '\0')
           return *m != '\0';
         if (ToLower(*m) != ToLower(*n))
           goto backtrack;
@@ -233,7 +237,7 @@ const unsigned char ToLowerTab[] =
   ':', ';', '<', '=', '>', '?',
   '@', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i',
   'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's',
-  't', 'u', 'v', 'w', 'x', 'y', 'z', '{', '|', '}', '~',
+  't', 'u', 'v', 'w', 'x', 'y', 'z', '[', '\\', ']', '^',
   '_',
   '`', 'a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i',
   'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's',
@@ -273,7 +277,7 @@ const unsigned char ToUpperTab[] =
   0x5f,
   '`', 'A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I',
   'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S',
-  'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '[', '\\', ']', '^',
+  'T', 'U', 'V', 'W', 'X', 'Y', 'Z', '{', '|', '}', '~',
   0x7f,
   0x80, 0x81, 0x82, 0x83, 0x84, 0x85, 0x86, 0x87, 0x88, 0x89,
   0x8a, 0x8b, 0x8c, 0x8d, 0x8e, 0x8f,
@@ -296,7 +300,7 @@ const unsigned char ToUpperTab[] =
 /*
  * CharAttrs table
  *
- * NOTE: RFC 1459 sez: anything but a ^G, comma, or space is allowed
+ * NOTE: RFC 1459 says: anything but a ^G, comma, or space is allowed
  * for channel names
  */
 const unsigned int CharAttrs[] =
@@ -334,7 +338,7 @@ const unsigned int CharAttrs[] =
 /* 30 */     CNTRL_C|CHAN_C|VCHAN_C|NONEOS_C,
 /* 31 */     CNTRL_C|CHAN_C|NONEOS_C,
 /* SP */     PRINT_C|SPACE_C,
-/* ! */      PRINT_C|KWILD_C|CHAN_C|VCHAN_C|NONEOS_C,
+/* ! */      PRINT_C|CHAN_C|VCHAN_C|NONEOS_C,
 /* " */      PRINT_C|CHAN_C|VCHAN_C|NONEOS_C,
 /* # */      PRINT_C|CHANPFX_C|CHAN_C|VCHAN_C|NONEOS_C,
 /* $ */      PRINT_C|CHAN_C|VCHAN_C|NONEOS_C|USER_C,
@@ -365,7 +369,7 @@ const unsigned int CharAttrs[] =
 /* = */      PRINT_C|CHAN_C|VCHAN_C|NONEOS_C,
 /* > */      PRINT_C|CHAN_C|VCHAN_C|NONEOS_C,
 /* ? */      PRINT_C|KWILD_C|MWILD_C|CHAN_C|VCHAN_C|NONEOS_C,
-/* @ */      PRINT_C|KWILD_C|CHAN_C|VCHAN_C|NONEOS_C,
+/* @ */      PRINT_C|CHAN_C|VCHAN_C|NONEOS_C,
 /* A */      PRINT_C|ALPHA_C|NICK_C|CHAN_C|VCHAN_C|NONEOS_C|USER_C|HOST_C,
 /* B */      PRINT_C|ALPHA_C|NICK_C|CHAN_C|VCHAN_C|NONEOS_C|USER_C|HOST_C,
 /* C */      PRINT_C|ALPHA_C|NICK_C|CHAN_C|VCHAN_C|NONEOS_C|USER_C|HOST_C,
