@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,22 +21,20 @@
 
 /*! \file memory.c
  * \brief Memory utilities.
- * \version $Id: memory.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: memory.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
-#include "ircd_defs.h"
 #include "irc_string.h"
 #include "memory.h"
-#include "log.h"
 #include "restart.h"
 
 
 /*
- * MyCalloc - allocate memory, call outofmemory on failure
+ * xcalloc - allocate memory, call outofmemory on failure
  */
 void *
-MyCalloc(size_t size)
+xcalloc(size_t size)
 {
   void *ret = calloc(1, size);
 
@@ -47,10 +45,10 @@ MyCalloc(size_t size)
 }
 
 /*
- * MyRealloc - reallocate memory, call outofmemory on failure
+ * xrealloc - reallocate memory, call outofmemory on failure
  */
 void *
-MyRealloc(void *x, size_t y)
+xrealloc(void *x, size_t y)
 {
   void *ret = realloc(x, y);
 
@@ -61,10 +59,9 @@ MyRealloc(void *x, size_t y)
 }
 
 void
-MyFree(void *x)
+xfree(void *x)
 {
-  if (x)
-    free(x);
+  free(x);
 }
 
 void *
@@ -108,6 +105,5 @@ outofmemory(void)
   if (was_here++)
     abort();
 
-  ilog(LOG_TYPE_IRCD, "Out of memory: restarting server...");
-  server_die("Out of Memory", 1);
+  server_die("out of memory", SERVER_RESTART);
 }
