@@ -1,6 +1,6 @@
 /*
  * Copyright (c) 2007-2012, The Tor Project, Inc.
- * Copyright (c) 2012-2014 ircd-hybrid development team
+ * Copyright (c) 2012-2016 ircd-hybrid development team
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -33,7 +33,7 @@
 
 /*! \file mempool.c
  * \brief A pooling allocator
- * \version $Id: mempool.c 4438 2014-08-09 18:33:17Z michael $
+ * \version $Id: mempool.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -42,6 +42,7 @@
 #include "log.h"
 #include "mempool.h"
 
+
 /** Returns floor(log2(u64)).  If u64 is 0, (incorrectly) returns 0. */
 static int
 tor_log2(uint64_t u64)
@@ -251,7 +252,7 @@ static mp_chunk_t *
 mp_chunk_new(mp_pool_t *pool)
 {
   size_t sz = pool->new_chunk_capacity * pool->item_alloc_size;
-  mp_chunk_t *chunk = MyCalloc(CHUNK_OVERHEAD + sz);
+  mp_chunk_t *chunk = xcalloc(CHUNK_OVERHEAD + sz);
 
 #ifdef MEMPOOL_STATS
   ++pool->total_chunks_allocated;
@@ -457,7 +458,7 @@ mp_pool_new(size_t item_size, size_t chunk_capacity)
   assert(chunk_capacity < SIZE_T_CEILING);
   assert(SIZE_T_CEILING / item_size > chunk_capacity);
 */
-  pool = MyCalloc(sizeof(mp_pool_t));
+  pool = xcalloc(sizeof(mp_pool_t));
   /*
    * First, we figure out how much space to allow per item. We'll want to
    * use make sure we have enough for the overhead plus the item size.
@@ -507,9 +508,9 @@ mp_pool_new(size_t item_size, size_t chunk_capacity)
   pool->next = mp_allocated_pools;
   mp_allocated_pools = pool;
 
-  ilog(LOG_TYPE_DEBUG, "Capacity is %lu, item size is %lu, alloc size is %lu",
+  ilog(LOG_TYPE_DEBUG, "Capacity is %lu, item size is %zu, alloc size is %lu",
        (unsigned long)pool->new_chunk_capacity,
-       (unsigned long)pool->item_alloc_size,
+       pool->item_alloc_size,
        (unsigned long)(pool->new_chunk_capacity*pool->item_alloc_size));
 
   return pool;
@@ -544,7 +545,7 @@ mp_pool_sort_used_chunks(mp_pool_t *pool)
   if (!inverted)
     return;
 
-  chunks = MyCalloc(sizeof(mp_chunk_t *) * n);
+  chunks = xcalloc(sizeof(mp_chunk_t *) * n);
 
   for (i = 0, chunk = pool->used_chunks; chunk; chunk = chunk->next)
     chunks[i++] = chunk;
@@ -560,7 +561,7 @@ mp_pool_sort_used_chunks(mp_pool_t *pool)
   }
 
   chunks[n - 1]->next = NULL;
-  MyFree(chunks);
+  xfree(chunks);
   mp_pool_assert_ok(pool);
 }
 
@@ -607,7 +608,7 @@ mp_pool_clean(mp_pool_t *pool, int n_to_keep, int keep_recently_used)
   {
     mp_chunk_t *next = chunk->next;
     chunk->magic = 0xdeadbeef;
-    MyFree(chunk);
+    xfree(chunk);
 #ifdef MEMPOOL_STATS
     ++pool->total_chunks_freed;
 #endif
@@ -629,7 +630,7 @@ destroy_chunks(mp_chunk_t *chunk)
   while (chunk) {
     chunk->magic = 0xd3adb33f;
     next = chunk->next;
-    MyFree(chunk);
+    xfree(chunk);
     chunk = next;
   }
 }
@@ -715,7 +716,7 @@ mp_pool_log_status(mp_pool_t *pool)
   for (chunk = pool->empty_chunks; chunk; chunk = chunk->next)
     bytes_allocated += chunk->mem_size;
 
-  ilog(LOG_TYPE_DEBUG, "%llu bytes in %d empty chunks",
+  ilog(LOG_TYPE_DEBUG, "%ju bytes in %d empty chunks",
        bytes_allocated, pool->n_empty_chunks);
   for (chunk = pool->used_chunks; chunk; chunk = chunk->next)
   {
@@ -727,7 +728,7 @@ mp_pool_log_status(mp_pool_t *pool)
          chunk->n_allocated);
   }
 
-  ilog(LOG_TYPE_DEBUG, "%llu/%llu bytes in %d partially full chunks",
+  ilog(LOG_TYPE_DEBUG, "%ju/%ju bytes in %d partially full chunks",
        bu, ba, n_used);
   bytes_used += bu;
   bytes_allocated += ba;
@@ -740,19 +741,19 @@ mp_pool_log_status(mp_pool_t *pool)
     ba += chunk->mem_size;
   }
 
-  ilog(LOG_TYPE_DEBUG, "%llu/%llu bytes in %d full chunks",
+  ilog(LOG_TYPE_DEBUG, "%ju/%ju bytes in %d full chunks",
        bu, ba, n_full);
   bytes_used += bu;
   bytes_allocated += ba;
 
-  ilog(LOG_TYPE_DEBUG, "Total: %llu/%llu bytes allocated "
+  ilog(LOG_TYPE_DEBUG, "Total: %ju/%ju bytes allocated "
        "for cell pools are full.",
        bytes_used, bytes_allocated);
 
 #ifdef MEMPOOL_STATS
-  ilog(LOG_TYPE_DEBUG, "%llu cell allocations ever; "
-       "%llu chunk allocations ever; "
-       "%llu chunk frees ever.",
+  ilog(LOG_TYPE_DEBUG, "%ju cell allocations ever; "
+       "%ju chunk allocations ever; "
+       "%ju chunk frees ever.",
        pool->total_items_allocated,
        pool->total_chunks_allocated,
        pool->total_chunks_freed);
