@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_misc.c
  * \brief Yet another miscellaneous functions file.
- * \version $Id: misc.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: misc.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -30,79 +30,38 @@
 #include "ircd.h"
 
 
-static const char *const months[] =
-{
-  "January",   "February", "March",   "April",
-  "May",       "June",     "July",    "August",
-  "September", "October",  "November","December"
-};
-
-static const char *const weekdays[] =
-{
-  "Sunday",   "Monday", "Tuesday", "Wednesday",
-  "Thursday", "Friday", "Saturday"
-};
-
 const char *
 date(time_t lclock)
 {
-  static char buf[80], plus;
-  struct tm *lt, *gm;
-  struct tm gmbuf;
-  int minswest;
+  static char buf[80];
+  static time_t lclock_last;
 
   if (!lclock)
     lclock = CurrentTime;
 
-  gm = gmtime(&lclock);
-  memcpy(&gmbuf, gm, sizeof(gmbuf));
-  gm = &gmbuf;
-  lt = localtime(&lclock);
-
-  /*
-   * There is unfortunately no clean portable way to extract time zone
-   * offset information, so do ugly things.
-   */
-  minswest = (gm->tm_hour - lt->tm_hour) * 60 + (gm->tm_min - lt->tm_min);
-
-  if (lt->tm_yday != gm->tm_yday)
+  if (lclock_last != lclock)
   {
-    if ((lt->tm_yday > gm->tm_yday && lt->tm_year == gm->tm_year) ||
-        (lt->tm_yday < gm->tm_yday && lt->tm_year != gm->tm_year))
-      minswest -= 24 * 60;
-    else
-      minswest += 24 * 60;
+    lclock_last = lclock;
+    strftime(buf, sizeof(buf), "%A %B %-e %Y -- %T %z", localtime(&lclock));
   }
 
-  plus = (minswest > 0) ? '-' : '+';
-  if (minswest < 0)
-    minswest = -minswest;
-
-  snprintf(buf, sizeof(buf), "%s %s %d %d -- %02u:%02u:%02u %c%02u:%02u",
-           weekdays[lt->tm_wday], months[lt->tm_mon],lt->tm_mday,
-           lt->tm_year + 1900, lt->tm_hour, lt->tm_min, lt->tm_sec,
-           plus, minswest/60, minswest%60);
   return buf;
 }
 
 const char *
-smalldate(time_t lclock)
+date_iso8601(time_t lclock)
 {
   static char buf[MAX_DATE_STRING];
-  struct tm *lt, *gm;
-  struct tm gmbuf;
+  static time_t lclock_last;
 
   if (!lclock)
     lclock = CurrentTime;
 
-  gm = gmtime(&lclock);
-  memcpy(&gmbuf, gm, sizeof(gmbuf));
-  gm = &gmbuf;
-  lt = localtime(&lclock);
-
-  snprintf(buf, sizeof(buf), "%d/%d/%d %02d.%02d",
-           lt->tm_year + 1900, lt->tm_mon + 1, lt->tm_mday,
-           lt->tm_hour, lt->tm_min);
+  if (lclock_last != lclock)
+  {
+    lclock_last = lclock;
+    strftime(buf, sizeof(buf), "%FT%T%z", localtime(&lclock));
+  }
 
   return buf;
 }
@@ -120,15 +79,51 @@ smalldate(time_t lclock)
  * Thu Nov 24 18:22:48 1986
  */
 const char *
-myctime(time_t value)
+date_ctime(time_t lclock)
 {
-  static char buf[32];
-  char *p;
+  static char buf[MAX_DATE_STRING];
+  static time_t lclock_last;
 
-  strlcpy(buf, ctime(&value), sizeof(buf));
+  if (!lclock)
+    lclock = CurrentTime;
 
-  if ((p = strchr(buf, '\n')))
-    *p = '\0';
+  if (lclock_last != lclock)
+  {
+    lclock_last = lclock;
+    strftime(buf, sizeof(buf), "%a %b %-e %T %Y", localtime(&lclock));
+  }
+
+  return buf;
+}
+
+const char *
+time_dissect(time_t duration)
+{
+  static char buf[32];  /* 32 = sizeof("9999999999999999 days, 23:59:59") */
+  unsigned int days = 0, hours = 0, minutes = 0, seconds = 0;
+
+  while (duration >= 60 * 60 * 24)
+  {
+    duration -= 60 * 60 * 24;
+    ++days;
+  }
+
+  while (duration >= 60 * 60)
+  {
+    duration -= 60 * 60;
+    ++hours;
+  }
+
+  while (duration >= 60)
+  {
+    duration -= 60;
+    ++minutes;
+  }
+
+  seconds = duration;
+
+  snprintf(buf, sizeof(buf), "%u day%s, %02u:%02u:%02u",
+           days, days == 1 ? "" : "s", hours, minutes, seconds);
   return buf;
 }
 
@@ -141,7 +136,7 @@ ssl_get_cipher(const SSL *ssl)
 
   SSL_CIPHER_get_bits(SSL_get_current_cipher(ssl), &bits);
 
-  snprintf(buffer, sizeof(buffer), "%s %s-%d", SSL_get_version(ssl),
+  snprintf(buffer, sizeof(buffer), "%s-%s-%d", SSL_get_version(ssl),
            SSL_get_cipher(ssl), bits);
   return buffer;
 }
