@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file modules.c
  * \brief A module loader.
- * \version $Id: modules.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: modules.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "ltdl.h"
@@ -45,8 +45,8 @@ static dlink_list modules_list;
 static dlink_list modules_path;
 static dlink_list modules_conf;
 
-static const char *unknown_ver = "<unknown>";
-static const char *core_module_table[] =
+static const char *const unknown_ver = "<unknown>";
+static const char *const core_module_table[] =
 {
   "m_bmask.la",
   "m_die.la",
@@ -99,14 +99,14 @@ unload_one_module(const char *name, int warn)
 
   assert(dlink_list_length(&modules_list) > 0);
   dlinkDelete(&modp->node, &modules_list);
-  MyFree(modp->name);
+  xfree(modp->name);
 
   lt_dlclose(modp->handle);
 
   if (warn == 1)
   {
     ilog(LOG_TYPE_IRCD, "Module %s unloaded", name);
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Module %s unloaded", name);
   }
 
@@ -133,7 +133,7 @@ load_a_module(const char *path, int warn)
   {
     const char *err = ((err = lt_dlerror())) ? err : "<unknown>";
 
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error loading module %s: %s",
                          mod_basename, err);
     ilog(LOG_TYPE_IRCD, "Error loading module %s: %s", mod_basename, err);
@@ -144,7 +144,7 @@ load_a_module(const char *path, int warn)
   {
     const char *err = ((err = lt_dlerror())) ? err : "<unknown>";
 
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error loading module %s: %s",
                          mod_basename, err);
     ilog(LOG_TYPE_IRCD, "Error loading module %s: %s", mod_basename, err);
@@ -165,7 +165,7 @@ load_a_module(const char *path, int warn)
 
   if (warn == 1)
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Module %s [version: %s handle: %p] loaded.",
                          modp->name, modp->version, tmpptr);
     ilog(LOG_TYPE_IRCD, "Module %s [version: %s handle: %p] loaded.",
@@ -189,7 +189,7 @@ modules_init(void)
   {
     ilog(LOG_TYPE_IRCD, "Couldn't initialize the libltdl run time dynamic"
          " link library. Exiting.");
-    exit(0);
+    exit(EXIT_FAILURE);
   }
 }
 
@@ -202,11 +202,11 @@ modules_init(void)
 static struct module_path *
 mod_find_path(const char *path)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, modules_path.head)
+  DLINK_FOREACH(node, modules_path.head)
   {
-    struct module_path *mpath = ptr->data;
+    struct module_path *mpath = node->data;
 
     if (!strcmp(path, mpath->path))
       return mpath;
@@ -229,7 +229,7 @@ mod_add_path(const char *path)
   if (mod_find_path(path))
     return;
 
-  pathst = MyCalloc(sizeof(struct module_path));
+  pathst = xcalloc(sizeof(struct module_path));
 
   strlcpy(pathst->path, path, sizeof(pathst->path));
   dlinkAdd(pathst, &pathst->node, &modules_path);
@@ -246,7 +246,7 @@ add_conf_module(const char *name)
 {
   struct module_path *pathst;
 
-  pathst = MyCalloc(sizeof(struct module_path));
+  pathst = xcalloc(sizeof(struct module_path));
 
   strlcpy(pathst->path, name, sizeof(pathst->path));
   dlinkAdd(pathst, &pathst->node, &modules_conf);
@@ -261,18 +261,18 @@ add_conf_module(const char *name)
 void
 mod_clear_paths(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, modules_path.head)
+  DLINK_FOREACH_SAFE(node, node_next, modules_path.head)
   {
-    dlinkDelete(ptr, &modules_path);
-    MyFree(ptr->data);
+    dlinkDelete(node, &modules_path);
+    xfree(node->data);
   }
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, modules_conf.head)
+  DLINK_FOREACH_SAFE(node, node_next, modules_conf.head)
   {
-    dlinkDelete(ptr, &modules_conf);
-    MyFree(ptr->data);
+    dlinkDelete(node, &modules_conf);
+    xfree(node->data);
   }
 }
 
@@ -285,11 +285,11 @@ mod_clear_paths(void)
 struct module *
 findmodule_byname(const char *name)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, modules_list.head)
+  DLINK_FOREACH(node, modules_list.head)
   {
-    struct module *modp = ptr->data;
+    struct module *modp = node->data;
 
     if (!strcmp(modp->name, name))
       return modp;
@@ -340,11 +340,11 @@ load_all_modules(int warn)
 void
 load_conf_modules(void)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, modules_conf.head)
+  DLINK_FOREACH(node, modules_conf.head)
   {
-    struct module_path *mpath = ptr->data;
+    struct module_path *mpath = node->data;
 
     if (findmodule_byname(mpath->path) == NULL)
       load_one_module(mpath->path);
@@ -386,13 +386,13 @@ load_core_modules(int warn)
 int
 load_one_module(const char *name)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   char path[HYB_PATH_MAX + 1];
   struct stat statbuf;
 
-  DLINK_FOREACH(ptr, modules_path.head)
+  DLINK_FOREACH(node, modules_path.head)
   {
-    const struct module_path *mpath = ptr->data;
+    const struct module_path *mpath = node->data;
 
     snprintf(path, sizeof(path), "%s/%s", mpath->path, name);
 
@@ -406,7 +406,7 @@ load_one_module(const char *name)
           return load_a_module(path, 1);
   }
 
-  sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                        "Cannot locate module %s", name);
   ilog(LOG_TYPE_IRCD, "Cannot locate module %s", name);
   return -1;
