@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 2000 Kevin L. Mitchell <klmitch@mit.edu>
- *  Copyright (c) 2013-2014 ircd-hybrid development team
+ *  Copyright (c) 2013-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file motd.c
  * \brief Message-of-the-day manipulation implementation.
- * \version $Id: motd.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: motd.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -37,6 +37,7 @@
 #include "log.h"
 #include "motd.h"
 #include "hostmask.h"
+#include "misc.h"
 
 
 /** Global list of messages of the day. */
@@ -56,35 +57,35 @@ static struct
 static struct Motd *
 motd_create(const char *mask, const char *path)
 {
-  struct Motd *tmp = MyCalloc(sizeof(struct Motd));
+  struct Motd *motd = xcalloc(sizeof(struct Motd));
 
   if (EmptyString(mask))
-    tmp->type = MOTD_UNIVERSAL;
+    motd->type = MOTD_UNIVERSAL;
   else if (class_find(mask, 1))
-    tmp->type = MOTD_CLASS;
+    motd->type = MOTD_CLASS;
   else
   {
-    switch (parse_netmask(mask, &tmp->address, &tmp->addrbits))
+    switch (parse_netmask(mask, &motd->address, &motd->addrbits))
     {
       case HM_IPV4:
-      tmp->type = MOTD_IPMASKV4;
-      break;
-    case HM_IPV6:
-      tmp->type = MOTD_IPMASKV6;
-      break;
-    default: /* HM_HOST */
-      tmp->type = MOTD_HOSTMASK;
-      break;
+        motd->type = MOTD_IPMASKV4;
+        break;
+      case HM_IPV6:
+        motd->type = MOTD_IPMASKV6;
+        break;
+      default:  /* HM_HOST */
+        motd->type = MOTD_HOSTMASK;
+        break;
     }
   }
 
   if (mask)
-    tmp->mask = xstrdup(mask);
+    motd->mask = xstrdup(mask);
 
-  tmp->path = xstrdup(path);
-  tmp->maxcount = MOTD_MAXLINES;
+  motd->path = xstrdup(path);
+  motd->maxcount = MOTD_MAXLINES;
 
-  return tmp;
+  return motd;
 }
 
 /*! brief\ This function reads a motd out of a file (if needed) and caches it.
@@ -102,7 +103,7 @@ motd_cache(struct Motd *motd)
   char line[MOTD_LINESIZE + 2];  /* +2 for \r\n */
   char *tmp = NULL;
   unsigned int i = 0;
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   assert(motd);
   assert(motd->path);
@@ -111,9 +112,9 @@ motd_cache(struct Motd *motd)
     return motd->cache;
 
   /* Try to find it in the list of cached files */
-  DLINK_FOREACH(ptr, MotdList.cachelist.head)
+  DLINK_FOREACH(node, MotdList.cachelist.head)
   {
-    cache = ptr->data;
+    cache = node->data;
 
     if (!strcmp(cache->path, motd->path) && cache->maxcount == motd->maxcount)
     {
@@ -140,11 +141,11 @@ motd_cache(struct Motd *motd)
   }
 
   /* Ok, allocate a structure; we'll realloc later to trim memory */
-  cache = MyCalloc(sizeof(struct MotdCache) + (MOTD_LINESIZE * MOTD_MAXLINES));
+  cache = xcalloc(sizeof(struct MotdCache) + (MOTD_LINESIZE * MOTD_MAXLINES));
   cache->ref = 1;
   cache->path = xstrdup(motd->path);
   cache->maxcount = motd->maxcount;
-  cache->modtime = *localtime((const time_t *)&sb.st_mtime);  /* Store modtime */
+  cache->modtime = sb.st_mtime;  /* Store modtime */
 
   while (cache->count < cache->maxcount && fgets(line, sizeof(line), file))
   {
@@ -159,11 +160,11 @@ motd_cache(struct Motd *motd)
   fclose(file);  /* Close the file */
 
   /* Trim memory usage a little */
-  motd->cache = MyCalloc(sizeof(struct MotdCache) +
+  motd->cache = xcalloc(sizeof(struct MotdCache) +
                          (MOTD_LINESIZE * cache->count));
   memcpy(motd->cache, cache, sizeof(struct MotdCache) +
          (MOTD_LINESIZE * cache->count));
-  MyFree(cache);
+  xfree(cache);
 
   /* Now link it in */
   dlinkAdd(motd->cache, &motd->cache->node, &MotdList.cachelist);
@@ -190,8 +191,8 @@ motd_decache(struct Motd *motd)
   if (--cache->ref == 0)  /* Reduce reference count */
   {
     dlinkDelete(&cache->node, &MotdList.cachelist);
-    MyFree(cache->path);  /* Free path info */
-    MyFree(cache);  /* Very simple for a reason */
+    xfree(cache->path);  /* Free path info */
+    xfree(cache);  /* Very simple for a reason */
   }
 }
 
@@ -207,9 +208,9 @@ motd_destroy(struct Motd *motd)
   if (motd->cache)  /* Drop the cache */
     motd_decache(motd);
 
-  MyFree(motd->path);  /* We always must have a path */
-  MyFree(motd->mask);
-  MyFree(motd);
+  xfree(motd->path);  /* We always must have a path */
+  xfree(motd->mask);
+  xfree(motd);
 }
 
 /*! \brief Find the first matching MOTD block for a user.
@@ -223,7 +224,7 @@ motd_destroy(struct Motd *motd)
 static struct Motd *
 motd_lookup(const struct Client *client_p)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   const struct ClassItem *class = NULL;
 
   assert(client_p);
@@ -231,13 +232,13 @@ motd_lookup(const struct Client *client_p)
   if (!MyConnect(client_p))  /* Not my user, always return remote motd */
     return MotdList.remote;
 
-  class = get_class_ptr(&client_p->localClient->confs);
+  class = get_class_ptr(&client_p->connection->confs);
   assert(class);
 
   /* Check the motd blocks first */
-  DLINK_FOREACH(ptr, MotdList.other.head)
+  DLINK_FOREACH(node, MotdList.other.head)
   {
-    struct Motd *motd = ptr->data;
+    struct Motd *motd = node->data;
 
     switch (motd->type)
     {
@@ -246,17 +247,17 @@ motd_lookup(const struct Client *client_p)
           return motd;
         break;
       case MOTD_HOSTMASK:
-        if (!match(motd->mask, client_p->host))
+        if (!match(motd->mask, client_p->host) || !match(motd->mask, client_p->sockhost))
           return motd;
         break;
       case MOTD_IPMASKV4:
-          if (client_p->localClient->aftype == AF_INET)
-            if (match_ipv4(&client_p->localClient->ip, &motd->address, motd->addrbits))
+          if (client_p->connection->aftype == AF_INET)
+            if (match_ipv4(&client_p->connection->ip, &motd->address, motd->addrbits))
               return motd;
         break;
       case MOTD_IPMASKV6:
-          if (client_p->localClient->aftype == AF_INET6)
-            if (match_ipv6(&client_p->localClient->ip, &motd->address, motd->addrbits))
+          if (client_p->connection->aftype == AF_INET6)
+            if (match_ipv6(&client_p->connection->ip, &motd->address, motd->addrbits))
               return motd;
         break;
       default: break;
@@ -268,24 +269,25 @@ motd_lookup(const struct Client *client_p)
 
 /*! \brief Send the content of a MotdCache to a user.
  * If \a cache is NULL, simply send ERR_NOMOTD to the client.
- * \param source_p Client to send MOTD to.
+ * \param client_p Client to send MOTD to.
  * \param cache MOTD body to send to client.
  */
 static void
-motd_forward(struct Client *source_p, const struct MotdCache *cache)
+motd_forward(struct Client *client_p, const struct MotdCache *cache)
 {
   if (!cache)  /* No motd to send */
   {
-    sendto_one_numeric(source_p, &me, ERR_NOMOTD);
+    sendto_one_numeric(client_p, &me, ERR_NOMOTD);
     return;
   }
 
   /* Send the motd */
-  sendto_one_numeric(source_p, &me, RPL_MOTDSTART, me.name);
+  sendto_one_numeric(client_p, &me, RPL_MOTDSTART, me.name);
 
   for (unsigned int i = 0; i < cache->count; ++i)
-    sendto_one_numeric(source_p, &me, RPL_MOTD, cache->motd[i]);
-  sendto_one_numeric(source_p, &me, RPL_ENDOFMOTD);
+    sendto_one_numeric(client_p, &me, RPL_MOTD, cache->motd[i]);
+
+  sendto_one_numeric(client_p, &me, RPL_ENDOFMOTD);
 }
 
 /*! \brief Find the MOTD for a client and send it.
@@ -303,28 +305,23 @@ motd_send(struct Client *client_p)
  * If general::short_motd is true and a matching MOTD exists for the
  * user, direct the client to type /MOTD to read it. Otherwise, call
  * motd_forward() for the user.
- * \param source_p Client that has just connected.
+ * \param client_p Client that has just connected.
  */
 void
-motd_signon(struct Client *source_p)
+motd_signon(struct Client *client_p)
 {
-  const struct MotdCache *cache = motd_cache(motd_lookup(source_p));
+  const struct MotdCache *cache = motd_cache(motd_lookup(client_p));
 
   if (!ConfigGeneral.short_motd || !cache)
-    motd_forward(source_p, cache);
+    motd_forward(client_p, cache);
   else
   {
-    sendto_one_notice(source_p, &me, ":*** Notice -- motd was last changed at %d/%d/%d %d:%02d",
-                      cache->modtime.tm_year + 1900,
-                      cache->modtime.tm_mon + 1,
-                      cache->modtime.tm_mday,
-                      cache->modtime.tm_hour,
-                      cache->modtime.tm_min);
-    sendto_one_notice(source_p, &me, ":*** Notice -- Please read the motd if you haven't read it");
-    sendto_one_numeric(source_p, &me, RPL_MOTDSTART, me.name);
-    sendto_one_numeric(source_p, &me, RPL_MOTD,
-                       "*** This is the short motd ***");
-    sendto_one_numeric(source_p, &me, RPL_ENDOFMOTD);
+    sendto_one_notice(client_p, &me, ":*** Notice -- motd was last changed at %s",
+                      date_iso8601(cache->modtime));
+    sendto_one_notice(client_p, &me, ":*** Notice -- Please read the motd if you haven't read it");
+    sendto_one_numeric(client_p, &me, RPL_MOTDSTART, me.name);
+    sendto_one_numeric(client_p, &me, RPL_MOTD, "*** This is the short motd ***");
+    sendto_one_numeric(client_p, &me, RPL_ENDOFMOTD);
   }
 }
 
@@ -334,13 +331,13 @@ motd_signon(struct Client *source_p)
 void
 motd_recache(void)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   motd_decache(MotdList.local);  /* Decache local and remote MOTDs */
   motd_decache(MotdList.remote);
 
-  DLINK_FOREACH(ptr, MotdList.other.head)  /* Now all the others */
-    motd_decache(ptr->data);
+  DLINK_FOREACH(node, MotdList.other.head)  /* Now all the others */
+    motd_decache(node->data);
 
   /* Now recache local and remote MOTDs */
   motd_cache(MotdList.local);
@@ -386,15 +383,15 @@ motd_add(const char *mask, const char *path)
 void
 motd_clear(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
   motd_decache(MotdList.local);  /* Decache local and remote MOTDs */
   motd_decache(MotdList.remote);
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, MotdList.other.head)  /* Destroy other MOTDs */
+  DLINK_FOREACH_SAFE(node, node_next, MotdList.other.head)  /* Destroy other MOTDs */
   {
-    dlinkDelete(ptr, &MotdList.other);
-    motd_destroy(ptr->data);
+    dlinkDelete(node, &MotdList.other);
+    motd_destroy(node->data);
   }
 
   /* Now recache local and remote MOTDs */
@@ -403,29 +400,29 @@ motd_clear(void)
 }
 
 /*! \brief Report list of non-default MOTDs.
- * \param source_p Client requesting statistics.
+ * \param client_p Client requesting statistics.
  */
 void
-motd_report(struct Client *source_p, int parc, char *parv[])
+motd_report(struct Client *client_p, int parc, char *parv[])
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, MotdList.other.head)
+  DLINK_FOREACH(node, MotdList.other.head)
   {
-    const struct Motd *motd = ptr->data;
+    const struct Motd *motd = node->data;
 
-    sendto_one_numeric(source_p, &me, RPL_STATSTLINE,
+    sendto_one_numeric(client_p, &me, RPL_STATSTLINE,
                        motd->mask, motd->path);
   }
 }
 
 /*! \brief Report MOTD memory usage to a client.
- * \param source_p Client requesting memory usage.
+ * \param client_p Client requesting memory usage.
  */
 void
-motd_memory_count(struct Client *source_p)
+motd_memory_count(struct Client *client_p)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
   unsigned int mt  = 0;  /* Motd count */
   unsigned int mtc = 0;  /* Motd cache count */
   size_t mtm  = 0;  /* Memory consumed by motd */
@@ -433,36 +430,36 @@ motd_memory_count(struct Client *source_p)
 
   if (MotdList.local)
   {
-    mt++;
+    ++mt;
     mtm += sizeof(struct Motd);
     mtm += MotdList.local->path ? (strlen(MotdList.local->path) + 1) : 0;
   }
 
   if (MotdList.remote)
   {
-    mt++;
+    ++mt;
     mtm += sizeof(struct Motd);
     mtm += MotdList.remote->path ? (strlen(MotdList.remote->path) + 1) : 0;
   }
 
-  DLINK_FOREACH(ptr, MotdList.other.head)
+  DLINK_FOREACH(node, MotdList.other.head)
   {
-    const struct Motd *motd = ptr->data;
+    const struct Motd *motd = node->data;
 
-    mt++;
+    ++mt;
     mtm += sizeof(struct Motd);
     mtm += motd->path ? (strlen(motd->path) + 1) : 0;
   }
 
-  DLINK_FOREACH(ptr, MotdList.cachelist.head)
+  DLINK_FOREACH(node, MotdList.cachelist.head)
   {
-    const struct MotdCache *cache = ptr->data;
+    const struct MotdCache *cache = node->data;
 
-    mtc++;
+    ++mtc;
     mtcm += sizeof(struct MotdCache) + (MOTD_LINESIZE * (cache->count - 1));
   }
 
-  sendto_one_numeric(source_p, &me, RPL_STATSDEBUG|SND_EXPLICIT,
-                     "z :Motds %u(%u) Cache %u(%u)",
+  sendto_one_numeric(client_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
+                     "z :Motds %u(%zu) Cache %u(%zu)",
                      mt, mtm, mtc, mtcm);
 }
