@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file parse.c
  * \brief The message parser.
- * \version $Id: parse.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: parse.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -29,6 +29,7 @@
 #include "parse.h"
 #include "channel.h"
 #include "hash.h"
+#include "id.h"
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
@@ -82,7 +83,7 @@
  * For a small parser like this, this is a good compromise and does
  * make it somewhat faster. - Dianora
  */
-#define MAXPTRLEN 32
+enum { MAXPTRLEN = 32 };
 
 
 static struct MessageTree
@@ -121,7 +122,7 @@ parse_remove_unknown(struct Client *client_p, const char *lsender, char *lbuffer
                          lbuffer, get_client_name(client_p, SHOW_IP), lsender);
     sendto_realops_flags(UMODE_DEBUG, L_OPER, SEND_NOTICE,
                          "Unknown prefix (%s) from %s, Squitting %s",
-                         lbuffer, client_p->name, lsender);
+                         lbuffer, get_client_name(client_p, MASK_IP), lsender);
     sendto_one(client_p, ":%s SQUIT %s :(Unknown prefix (%s) from %s)",
                me.id, lsender, lbuffer, client_p->name);
   }
@@ -130,41 +131,6 @@ parse_remove_unknown(struct Client *client_p, const char *lsender, char *lbuffer
                me.id, lsender, me.name);
 }
 
-/* cancel_clients()
- *
- * inputs       -
- * output       -
- * side effects -
- */
-static void
-parse_cancel_clients(struct Client *client_p, struct Client *source_p, char *cmd)
-{
-  if (IsServer(source_p) || IsMe(source_p))
-  {
-    sendto_realops_flags(UMODE_DEBUG, L_ADMIN, SEND_NOTICE,
-                         "Message for %s[%s] from %s",
-                         source_p->name, source_p->from->name,
-                         get_client_name(client_p, SHOW_IP));
-    sendto_realops_flags(UMODE_DEBUG, L_OPER, SEND_NOTICE,
-                         "Message for %s[%s] from %s",
-                         source_p->name, source_p->from->name,
-                         get_client_name(client_p, MASK_IP));
-    sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                         "Not dropping server %s (%s) for Fake Direction",
-                         client_p->name, source_p->name);
-    return;
-  }
-
-  sendto_realops_flags(UMODE_DEBUG, L_ADMIN, SEND_NOTICE,
-                       "Message for %s[%s@%s!%s] from %s (TS, ignored)",
-                       source_p->name, source_p->username, source_p->host,
-                       source_p->from->name, get_client_name(client_p, SHOW_IP));
-  sendto_realops_flags(UMODE_DEBUG, L_OPER, SEND_NOTICE,
-                       "Message for %s[%s@%s!%s] from %s (TS, ignored)",
-                       source_p->name, source_p->username, source_p->host,
-                       source_p->from->name, get_client_name(client_p, MASK_IP));
-}
-
 /*
  *
  *      parc    number of arguments ('sender' counted as one!)
@@ -210,7 +176,7 @@ parse_handle_numeric(unsigned int numeric, struct Client *source_p, int parc, ch
   else
     target_p = find_person(source_p, parv[1]);
 
-  if (((!target_p) || (target_p->from == source_p->from)) && !chptr)
+  if ((!target_p || target_p->from == source_p->from) && !chptr)
     return;
 
   /*
@@ -230,13 +196,13 @@ parse_handle_numeric(unsigned int numeric, struct Client *source_p, int parc, ch
     /* Fake it for server hiding, if it's our client */
     if ((ConfigServerHide.hide_servers || IsHidden(source_p)) && MyConnect(target_p) &&
         !HasUMode(target_p, UMODE_OPER))
-      sendto_one_numeric(target_p, &me, numeric|SND_EXPLICIT, "%s", parv[2]);
+      sendto_one_numeric(target_p, &me, numeric | SND_EXPLICIT, "%s", parv[2]);
     else
-      sendto_one_numeric(target_p, source_p, numeric|SND_EXPLICIT, "%s", parv[2]);
+      sendto_one_numeric(target_p, source_p, numeric | SND_EXPLICIT, "%s", parv[2]);
   }
   else
     sendto_channel_butone(source_p, source_p, chptr, 0, "%u %s %s",
-                          numeric, chptr->chname, parv[2]);
+                          numeric, chptr->name, parv[2]);
 }
 
 /* handle_command()
@@ -250,19 +216,19 @@ parse_handle_numeric(unsigned int numeric, struct Client *source_p, int parc, ch
  * side effects -
  */
 static void
-parse_handle_command(struct Message *mptr, struct Client *source_p,
+parse_handle_command(struct Message *message, struct Client *source_p,
                      unsigned int i, char *para[])
 {
   if (IsServer(source_p->from))
-    ++mptr->rcount;
+    ++message->rcount;
 
-  ++mptr->count;
+  ++message->count;
 
   /* Check right amount of parameters is passed... --is */
-  if (i < mptr->args_min)
-    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, mptr->cmd);
+  if (i < message->args_min)
+    sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, message->cmd);
   else
-    mptr->handlers[source_p->from->handler](source_p, i, para);
+    message->handlers[source_p->from->handler](source_p, i, para);
 }
 
 /*
@@ -274,7 +240,7 @@ void
 parse(struct Client *client_p, char *pbuffer, char *bufend)
 {
   struct Client *from = client_p;
-  struct Message *msg_ptr = NULL;
+  struct Message *message = NULL;
   char *para[MAXPARA + 2];  /* <command> + <parameters> + NULL */
   char *ch = NULL;
   char *s = NULL;
@@ -285,7 +251,7 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
   if (IsDefunct(client_p))
     return;
 
-  assert(client_p->localClient->fd.flags.open);
+  assert(client_p->connection->fd.flags.open);
   assert((bufend - pbuffer) < IRCD_BUFSIZE);
 
   for (ch = pbuffer; *ch == ' '; ++ch)  /* Skip spaces */
@@ -297,7 +263,7 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
      * Copy the prefix to 'sender' assuming it terminates
      * with SPACE (or NULL, which is an error, though).
      */
-    const char *sender = ++ch;
+    const char *const sender = ++ch;
 
     if ((s = strchr(ch, ' ')))
     {
@@ -325,7 +291,14 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
       if (from->from != client_p)
       {
         ++ServerStats.is_wrdi;
-        parse_cancel_clients(client_p, from, pbuffer);
+        sendto_realops_flags(UMODE_DEBUG, L_ADMIN, SEND_NOTICE,
+                             "Fake direction: dropped message from %s[%s] via %s",
+                             from->name, from->from->name,
+                             get_client_name(client_p, SHOW_IP));
+        sendto_realops_flags(UMODE_DEBUG, L_OPER, SEND_NOTICE,
+                             "Fake direction: dropped message from %s[%s] via %s",
+                             from->name, from->from->name,
+                             get_client_name(client_p, MASK_IP));
         return;
       }
     }
@@ -360,12 +333,12 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
   }
   else
   {
-    unsigned int ii = 0;
+    unsigned int length = 0;
 
     if ((s = strchr(ch, ' ')))
       *s++ = '\0';
 
-    if ((msg_ptr = find_command(ch)) == NULL)
+    if ((message = find_command(ch)) == NULL)
     {
       /*
        * Note: Give error message *only* to recognized
@@ -386,11 +359,11 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
       return;
     }
 
-    assert(msg_ptr->cmd);
+    assert(message->cmd);
 
-    paramcount = msg_ptr->args_max;
-    ii = bufend - ((s) ? s : ch);
-    msg_ptr->bytes += ii;
+    paramcount = message->args_max;
+    length = bufend - ((s) ? s : ch);
+    message->bytes += length;
   }
 
   /*
@@ -404,12 +377,12 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
 
   para[parc] = ch;
 
-  if (msg_ptr && (msg_ptr->flags & MFLG_EXTRA))
+  if (message && (message->flags & MFLG_EXTRA))
   {
     /*
      * XXX: This will have to go away after the command handler rewrite
      */
-    para[++parc] = msg_ptr->extra;
+    para[++parc] = message->extra;
   }
 
   if (s)
@@ -427,7 +400,7 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
 
        if (*s == ':')
        {
-         /* The rest is a single parameter */
+         /* The rest is single parameter--can include blanks also. */
          para[++parc] = s + (!numeric);  /* Keep the colon if it's a numeric */
          break;
        }
@@ -444,8 +417,8 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
 
   para[++parc] = NULL;
 
-  if (msg_ptr)
-    parse_handle_command(msg_ptr, from, parc, para);
+  if (message)
+    parse_handle_command(message, from, parc, para);
   else
     parse_handle_numeric(numeric, from, parc, para);
 }
@@ -491,7 +464,7 @@ add_msg_element(struct MessageTree *mtree_p, struct Message *msg_p,
      */
     if ((ntree_p = mtree_p->pointers[*cmd & (MAXPTRLEN - 1)]) == NULL)
     {
-      ntree_p = MyCalloc(sizeof(struct MessageTree));
+      ntree_p = xcalloc(sizeof(struct MessageTree));
       mtree_p->pointers[*cmd & (MAXPTRLEN - 1)] = ntree_p;
 
       mtree_p->links++;  /* Have new pointer, so up ref count */
@@ -549,7 +522,7 @@ del_msg_element(struct MessageTree *mtree_p, const char *cmd)
       {
         mtree_p->pointers[*cmd & (MAXPTRLEN - 1)] = NULL;
         mtree_p->links--;
-        MyFree(ntree_p);
+        xfree(ntree_p);
       }
     }
   }
@@ -567,7 +540,7 @@ msg_tree_parse(const char *cmd)
 {
   struct MessageTree *mtree = &msg_tree;
 
-  assert(cmd && *cmd);
+  assert(!EmptyString(cmd));
 
   while (IsAlpha(*cmd) && (mtree = mtree->pointers[*cmd & (MAXPTRLEN - 1)]))
     if (*++cmd == '\0')
@@ -585,7 +558,8 @@ msg_tree_parse(const char *cmd)
 void
 mod_add_cmd(struct Message *msg)
 {
-  assert(msg && msg->cmd);
+  assert(msg);
+  assert(msg->cmd);
 
   /* Command already added? */
   if (msg_tree_parse(msg->cmd))
@@ -603,7 +577,8 @@ mod_add_cmd(struct Message *msg)
 void
 mod_del_cmd(struct Message *msg)
 {
-  assert(msg && msg->cmd);
+  assert(msg);
+  assert(msg->cmd);
 
   if (!msg_tree_parse(msg->cmd))
     return;
@@ -646,7 +621,7 @@ recurse_report_messages(struct Client *source_p, const struct MessageTree *mtree
 void
 report_messages(struct Client *source_p)
 {
-  const struct MessageTree *mtree = &msg_tree;
+  const struct MessageTree *const mtree = &msg_tree;
 
   for (unsigned int i = 0; i < MAXPTRLEN; ++i)
     if (mtree->pointers[i])
