@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file res.c
  * \brief ircd resolver functions
- * \version $Id: res.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: res.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 /*
@@ -45,18 +45,13 @@
 
 #include "stdinc.h"
 #include "list.h"
-#include "client.h"
 #include "event.h"
 #include "irc_string.h"
 #include "ircd.h"
-#include "numeric.h"
 #include "rng_mt.h"
 #include "fdlist.h"
 #include "s_bsd.h"
-#include "log.h"
 #include "misc.h"
-#include "send.h"
-#include "memory.h"
 #include "mempool.h"
 #include "res.h"
 #include "reslib.h"
@@ -220,11 +215,11 @@ restart_resolver(void)
 void
 delete_resolver_queries(const void *vptr)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, request_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, request_list.head)
   {
-    struct reslist *request = ptr->data;
+    struct reslist *request = node->data;
 
     if (request->callback_ctx == vptr)
       rem_request(request);
@@ -267,11 +262,11 @@ send_res_msg(const unsigned char *msg, int len, unsigned int rcount)
 static struct reslist *
 find_id(int id)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, request_list.head)
+  DLINK_FOREACH(node, request_list.head)
   {
-    struct reslist *request = ptr->data;
+    struct reslist *request = node->data;
 
     if (request->id == id)
       return request;
@@ -636,20 +631,6 @@ res_readreply(fde_t *fd, void *data)
   comm_setselect(fd, COMM_SELECT_READ, res_readreply, NULL, 0);
 }
 
-void
-report_dns_servers(struct Client *source_p)
-{
-  char ipaddr[HOSTIPLEN + 1] = "";
-
-  for (unsigned int i = 0; i < irc_nscount; ++i)
-  {
-    getnameinfo((struct sockaddr *)&(irc_nsaddr_list[i]),
-                irc_nsaddr_list[i].ss_len, ipaddr,
-                sizeof(ipaddr), NULL, 0, NI_NUMERICHOST);
-    sendto_one_numeric(source_p, &me, RPL_STATSALINE, ipaddr);
-  }
-}
-
 /*
  * timeout_query_list - Remove queries from the list which have been
  * there too long without being resolved.
@@ -657,14 +638,14 @@ report_dns_servers(struct Client *source_p)
 static time_t
 timeout_query_list(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
   struct reslist *request = NULL;
   time_t next_time = 0;
   time_t timeout   = 0;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, request_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, request_list.head)
   {
-    request = ptr->data;
+    request = node->data;
     timeout = request->sentat + request->timeout;
 
     if (CurrentTime >= timeout)
