@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file restart.c
  * \brief Functions to allow the ircd to restart.
- * \version $Id: restart.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: restart.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -36,27 +36,28 @@
 #include "memory.h"
 #include "conf_db.h"
 
+
 void
-server_die(const char *message, int rboot)
+server_die(const char *message, int action)
 {
   char buffer[IRCD_BUFSIZE] = "";
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   static int was_here = 0;
 
-  if (rboot && was_here++)
+  if (action == SERVER_RESTART && was_here++)
     abort();
 
   if (EmptyString(message))
     snprintf(buffer, sizeof(buffer), "Server %s",
-             rboot ? "Restarting" : "Terminating");
+             action == SERVER_RESTART ? "Restarting" : "Terminating");
   else
     snprintf(buffer, sizeof(buffer), "Server %s: %s",
-             rboot ? "Restarting" : "Terminating", message);
+             action == SERVER_RESTART ? "Restarting" : "Terminating", message);
 
-  DLINK_FOREACH(ptr, local_client_list.head)
-    sendto_one_notice(ptr->data, &me, ":%s", buffer);
+  DLINK_FOREACH(node, local_client_list.head)
+    sendto_one_notice(node->data, &me, ":%s", buffer);
 
-  sendto_server(NULL, NOCAPS, NOCAPS, ":%s ERROR :%s", me.id, buffer);
+  sendto_server(NULL, 0, 0, ":%s ERROR :%s", me.id, buffer);
 
   ilog(LOG_TYPE_IRCD, "%s", buffer);
 
@@ -67,11 +68,11 @@ server_die(const char *message, int rboot)
 
   unlink(pidFileName);
 
-  if (rboot)
+  if (action == SERVER_RESTART)
   {
     execv(SPATH, myargv);
-    exit(1);
+    exit(EXIT_FAILURE);
   }
   else
-    exit(0);
+    exit(EXIT_SUCCESS);
 }
