@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2015 ircd-hybrid development team
+ *  Copyright (c) 2001-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,24 +21,19 @@
 
 /*! \file resv.c
  * \brief Functions to reserve(jupe) a nick/channel.
- * \version $Id: resv.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: resv.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
 #include "list.h"
-#include "ircd.h"
 #include "send.h"
 #include "client.h"
 #include "memory.h"
-#include "numeric.h"
 #include "resv.h"
-#include "hash.h"
 #include "irc_string.h"
 #include "ircd_defs.h"
 #include "misc.h"
 #include "conf.h"
-#include "conf_db.h"
-#include "channel.h"
 #include "hostmask.h"
 
 
@@ -86,7 +81,7 @@ create_resv(const char *name, const char *reason, const dlink_list *list)
       if (strlen(s) == 2 && IsAlpha(*(s + 1) && IsAlpha(*(s + 2))))
       {
 #ifdef HAVE_LIBGEOIP
-        exptr = MyCalloc(sizeof(*exptr));
+        exptr = xcalloc(sizeof(*exptr));
         exptr->name = xstrdup(s);
         exptr->country_id = GeoIP_id_by_code(s);
         dlinkAdd(exptr, &exptr->node, &conf->exempt_list);
@@ -105,7 +100,7 @@ create_resv(const char *name, const char *reason, const dlink_list *list)
 
         split_nuh(&nuh);
 
-        exptr = MyCalloc(sizeof(*exptr));
+        exptr = xcalloc(sizeof(*exptr));
         exptr->name = xstrdup(nick);
         exptr->user = xstrdup(user);
         exptr->host = xstrdup(host);
@@ -119,7 +114,7 @@ create_resv(const char *name, const char *reason, const dlink_list *list)
 }
 
 int
-resv_find_exempt(const struct Client *who, const struct MaskItem *conf)
+resv_find_exempt(const struct Client *client_p, const struct MaskItem *conf)
 {
   const dlink_node *node = NULL;
 
@@ -129,25 +124,25 @@ resv_find_exempt(const struct Client *who, const struct MaskItem *conf)
 
     if (exptr->country_id)
     {
-      if (exptr->country_id == who->connection->country_id)
+      if (exptr->country_id == client_p->connection->country_id)
         return 1;
     }
-    else if (!match(exptr->name, who->name) && !match(exptr->user, who->username))
+    else if (!match(exptr->name, client_p->name) && !match(exptr->user, client_p->username))
     {
       switch (exptr->type)
       {
         case HM_HOST:
-          if (!match(exptr->host, who->host) || !match(exptr->host, who->sockhost))
+          if (!match(exptr->host, client_p->host) || !match(exptr->host, client_p->sockhost))
             return 1;
           break;
         case HM_IPV4:
-          if (who->connection->aftype == AF_INET)
-            if (match_ipv4(&who->connection->ip, &exptr->addr, exptr->bits))
+          if (client_p->connection->aftype == AF_INET)
+            if (match_ipv4(&client_p->connection->ip, &exptr->addr, exptr->bits))
               return 1;
           break;
         case HM_IPV6:
-          if (who->connection->aftype == AF_INET6)
-            if (match_ipv6(&who->connection->ip, &exptr->addr, exptr->bits))
+          if (client_p->connection->aftype == AF_INET6)
+            if (match_ipv6(&client_p->connection->ip, &exptr->addr, exptr->bits))
               return 1;
           break;
         default:
