@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2015 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file rsa.c
  * \brief Functions for use with RSA public key cryptography.
- * \version $Id: rsa.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: rsa.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -65,46 +65,4 @@ binary_to_hex(const unsigned char *bin, char *hex, unsigned int length)
 
   *hex = '\0';
 }
-
-int
-get_randomness(unsigned char *buf, int length)
-{
-  return RAND_bytes(buf, length);
-}
-
-int
-generate_challenge(char **r_challenge, char **r_response, RSA *rsa)
-{
-  unsigned char secret[32], *tmp = NULL;
-  unsigned long length = 0;
-  int ret = -1;
-
-  if (!rsa)
-    return -1;
-
-  if (!get_randomness(secret, 32))
-  {
-    report_crypto_errors();
-    return -1;
-  }
-
-  *r_response = MyCalloc(65);
-  binary_to_hex(secret, *r_response, 32);
-
-  length = RSA_size(rsa);
-  tmp = MyCalloc(length);
-  ret = RSA_public_encrypt(32, secret, tmp, rsa, RSA_PKCS1_PADDING);
-
-  *r_challenge = MyCalloc((length << 1) + 1);
-  binary_to_hex(tmp, *r_challenge, length);
-  MyFree(tmp);
-
-  if (ret < 0)
-  {
-    report_crypto_errors();
-    return -1;
-  }
-
-  return 0;
-}
 #endif
