@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd.c
  * \brief Network functions.
- * \version $Id: s_bsd.c 5582 2015-02-15 14:42:58Z michael $
+ * \version $Id: s_bsd.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -53,9 +53,15 @@
 #include "user.h"
 
 
-static const char *comm_err_str[] = { "Comm OK", "Error during bind()",
-  "Error during DNS lookup", "connect timeout", "Error during connect()",
-  "Comm Error" };
+static const char *const comm_err_str[] =
+{
+  [COMM_OK] = "Comm OK",
+  [COMM_ERR_BIND] = "Error during bind()",
+  [COMM_ERR_DNS] = "Error during DNS lookup",
+  [COMM_ERR_TIMEOUT] = "connect timeout",
+  [COMM_ERR_CONNECT] = "Error during connect()",
+  [COMM_ERROR] = "Comm Error"
+};
 
 static void comm_connect_callback(fde_t *, int);
 static void comm_connect_timeout(fde_t *, void *);
@@ -205,7 +211,7 @@ close_connection(struct Client *client_p)
   dbuf_clear(&client_p->connection->buf_sendq);
   dbuf_clear(&client_p->connection->buf_recvq);
 
-  MyFree(client_p->connection->password);
+  xfree(client_p->connection->password);
   client_p->connection->password = NULL;
 
   detach_conf(client_p, CONF_CLIENT | CONF_OPER | CONF_SERVER);
@@ -474,7 +480,7 @@ comm_checktimeouts(void *unused)
 void
 comm_connect_tcp(fde_t *fd, const char *host, unsigned short port, struct sockaddr *clocal,
                  int socklen, void (*callback)(fde_t *, int, void *), void *data,
-                 int aftype, int timeout)
+                 int aftype, time_t timeout)
 {
   struct addrinfo hints, *res;
   char portname[PORTNAMELEN + 1];
@@ -497,13 +503,9 @@ comm_connect_tcp(fde_t *fd, const char *host, unsigned short port, struct sockad
   {
     /* Failure, call the callback with COMM_ERR_BIND */
     comm_connect_callback(fd, COMM_ERR_BIND);
-    /* ... and quit */
-    return;
+    return;  /* ... and quit */
   }
 
-  /* Next, if we have been given an IP, get the addr and skip the
-   * DNS check (and head direct to comm_connect_tryconnect().
-   */
   memset(&hints, 0, sizeof(hints));
   hints.ai_family = AF_UNSPEC;
   hints.ai_socktype = SOCK_STREAM;
@@ -511,6 +513,10 @@ comm_connect_tcp(fde_t *fd, const char *host, unsigned short port, struct sockad
 
   snprintf(portname, sizeof(portname), "%d", port);
 
+  /*
+   * Next, if we have been given an IP address, get the address and skip the
+   * DNS check (and head direct to comm_connect_tryconnect()).
+   */
   if (getaddrinfo(host, portname, &hints, &res))
   {
     /* Send the DNS request, for the next level */
