@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2015 ircd-hybrid development team
+ *  Copyright (c) 2001-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_devpoll.c
  * \brief /dev/poll compatible network routines.
- * \version $Id: s_bsd_devpoll.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: s_bsd_devpoll.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -57,9 +57,9 @@ init_netio(void)
 
   if ((fd = open("/dev/poll", O_RDWR)) < 0)
   {
-    ilog(LOG_TYPE_IRCD, "init_netio: Couldn't open /dev/poll - %d: %s",
-         errno, strerror(errno));
-    exit(115); /* Whee! */
+    ilog(LOG_TYPE_IRCD, "init_netio: couldn't open /dev/poll: %s",
+         strerror(errno));
+    exit(EXIT_FAILURE); /* Whee! */
   }
 
   fd_open(&dpfd, fd, 0, "/dev/poll file descriptor");
@@ -155,9 +155,8 @@ comm_select(void)
 
   if (num < 0)
   {
-#ifdef HAVE_USLEEP
-    usleep(50000);  /* avoid 99% CPU in comm_select */
-#endif
+    const struct timespec req = { .tv_sec = 0, .tv_nsec = 50000000 };
+    nanosleep(&req, NULL);  /* Avoid 99% CPU in comm_select */
     return;
   }
 
