@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2005-2014 ircd-hybrid development team
+ *  Copyright (c) 2005-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_epoll.c
  * \brief Linux epoll() compatible network routines.
- * \version $Id: s_bsd_epoll.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: s_bsd_epoll.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -49,9 +49,9 @@ init_netio(void)
 
   if ((fd = epoll_create(hard_fdlimit)) < 0)
   {
-    ilog(LOG_TYPE_IRCD, "init_netio: Couldn't open epoll fd - %d: %s",
-         errno, strerror(errno));
-    exit(115); /* Whee! */
+    ilog(LOG_TYPE_IRCD, "init_netio: couldn't open epoll fd: %s",
+         strerror(errno));
+    exit(EXIT_FAILURE); /* Whee! */
   }
 
   fd_open(&efd, fd, 0, "epoll file descriptor");
@@ -134,9 +134,8 @@ comm_select(void)
 
   if (num < 0)
   {
-#ifdef HAVE_USLEEP
-    usleep(50000);  /* avoid 99% CPU in comm_select */
-#endif
+    const struct timespec req = { .tv_sec = 0, .tv_nsec = 50000000 };
+    nanosleep(&req, NULL);  /* Avoid 99% CPU in comm_select */
     return;
   }
 
@@ -148,7 +147,7 @@ comm_select(void)
 
     if ((ep_fdlist[i].events & (EPOLLIN | EPOLLHUP | EPOLLERR)))
     {
-      if ((hdl = F->read_handler) != NULL)
+      if ((hdl = F->read_handler))
       {
         F->read_handler = NULL;
         hdl(F, F->read_data);
@@ -159,7 +158,7 @@ comm_select(void)
 
     if ((ep_fdlist[i].events & (EPOLLOUT | EPOLLHUP | EPOLLERR)))
     {
-      if ((hdl = F->write_handler) != NULL)
+      if ((hdl = F->write_handler))
       {
         F->write_handler = NULL;
         hdl(F, F->write_data);
