@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_kqueue.c
  * \brief kqueue() compatible network routines.
- * \version $Id: s_bsd_kqueue.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: s_bsd_kqueue.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -32,7 +32,7 @@
 #include "s_bsd.h"
 #include "log.h"
 
-#define KE_LENGTH 128
+enum { KE_LENGTH = 128 };
 
 static fde_t kqfd;
 static struct kevent kq_fdlist[KE_LENGTH];  /* kevent buffer */
@@ -52,8 +52,8 @@ init_netio(void)
 
   if ((fd = kqueue()) < 0)
   {
-    ilog(LOG_TYPE_IRCD, "init_netio: Couldn't open kqueue fd!");
-    exit(115); /* Whee! */
+    ilog(LOG_TYPE_IRCD, "init_netio: couldn't open kqueue fd: %s", strerror(errno));
+    exit(EXIT_FAILURE); /* Whee! */
   }
 
   fd_open(&kqfd, fd, 0, "kqueue() file descriptor");
@@ -157,9 +157,8 @@ comm_select(void)
 
   if (num < 0)
   {
-#ifdef HAVE_USLEEP
-    usleep(50000);  /* avoid 99% CPU in comm_select */
-#endif
+    const struct timespec req = { .tv_sec = 0, .tv_nsec = 50000000 };
+    nanosleep(&req, NULL);  /* Avoid 99% CPU in comm_select */
     return;
   }
 
