@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2015 ircd-hybrid development team
+ *  Copyright (c) 2000-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_poll.c
  * \brief POSIX poll() compatible network routines.
- * \version $Id: s_bsd_poll.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: s_bsd_poll.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -57,7 +57,7 @@ void
 init_netio(void)
 {
   pollfds_size = hard_fdlimit;
-  pollfds = MyCalloc(sizeof(struct pollfd) * pollfds_size);
+  pollfds = xcalloc(sizeof(struct pollfd) * pollfds_size);
 }
 
 /*
@@ -120,7 +120,7 @@ comm_setselect(fde_t *F, unsigned int type, void (*handler)(fde_t *, void *),
         if (pollnum >= pollfds_size)
         {
           pollfds_size *= 2;
-          pollfds = MyRealloc(pollfds, sizeof(struct pollfd) * pollfds_size);
+          pollfds = xrealloc(pollfds, sizeof(struct pollfd) * pollfds_size);
         }
 
         F->comm_index = pollnum++;
@@ -156,9 +156,8 @@ comm_select(void)
 
   if (num < 0)
   {
-#ifdef HAVE_USLEEP
-    usleep(50000);  /* avoid 99% CPU in comm_select */
-#endif
+    const struct timespec req = { .tv_sec = 0, .tv_nsec = 50000000 };
+    nanosleep(&req, NULL);  /* Avoid 99% CPU in comm_select */
     return;
   }
 
@@ -177,7 +176,7 @@ comm_select(void)
 
     if (revents & (POLLRDNORM | POLLIN | POLLHUP | POLLERR))
     {
-      if ((hdl = F->read_handler) != NULL)
+      if ((hdl = F->read_handler))
       {
         F->read_handler = NULL;
         hdl(F, F->read_data);
@@ -188,7 +187,7 @@ comm_select(void)
 
     if (revents & (POLLWRNORM | POLLOUT | POLLHUP | POLLERR))
     {
-      if ((hdl = F->write_handler) != NULL)
+      if ((hdl = F->write_handler))
       {
         F->write_handler = NULL;
         hdl(F, F->write_data);
