@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.c
  * \brief Functions for sending messages.
- * \version $Id: send.c 5346 2015-01-11 12:41:14Z michael $
+ * \version $Id: send.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -38,7 +38,7 @@
 #include "log.h"
 
 
-static uint64_t current_serial;
+static uintmax_t current_serial;
 
 
 /* send_format()
@@ -89,14 +89,14 @@ send_message(struct Client *to, struct dbuf_block *buf)
   if (dbuf_length(&to->connection->buf_sendq) + buf->size > get_sendq(&to->connection->confs))
   {
     if (IsServer(to))
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "Max SendQ limit exceeded for %s: %lu > %u",
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                           "Max SendQ limit exceeded for %s: %zu > %u",
                            get_client_name(to, HIDE_IP),
-                           (unsigned long)(dbuf_length(&to->connection->buf_sendq) + buf->size),
+                           (dbuf_length(&to->connection->buf_sendq) + buf->size),
                            get_sendq(&to->connection->confs));
 
     if (IsClient(to))
-      SetSendQExceeded(to);
+      AddFlag(to, FLAGS_SENDQEX);
 
     dead_link_on_write(to, 0);
     return;
@@ -135,7 +135,7 @@ send_message_remote(struct Client *to, struct Client *from, struct dbuf_block *b
 
   if (to == from->from)
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Send message to %s dropped from %s (Fake Dir)",
                          to->name, from->name);
     return;
@@ -181,7 +181,7 @@ send_queued_write(struct Client *to)
   {
     do
     {
-      struct dbuf_block *first = to->connection->buf_sendq.blocks.head->data;
+      const struct dbuf_block *first = to->connection->buf_sendq.blocks.head->data;
 
 #ifdef HAVE_LIBCRYPTO
       if (to->connection->fd.ssl)
@@ -490,8 +490,8 @@ sendto_server(struct Client *one,
  *		  used by m_nick.c and exit_one_client.
  */
 void
-sendto_common_channels_local(struct Client *user, int touser, unsigned int cap,
-                             const char *pattern, ...)
+sendto_common_channels_local(struct Client *user, int touser, unsigned int poscap,
+                             unsigned int negcap, const char *pattern, ...)
 {
   va_list args;
   dlink_node *uptr;
@@ -520,7 +520,10 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int cap,
           target_p->connection->serial == current_serial)
         continue;
 
-      if (HasCap(target_p, cap) != cap)
+      if (poscap && HasCap(target_p, poscap) != poscap)
+        continue;
+
+      if (negcap && HasCap(target_p, negcap))
         continue;
 
       target_p->connection->serial = current_serial;
@@ -530,24 +533,23 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int cap,
 
   if (touser && MyConnect(user) && !IsDead(user) &&
       user->connection->serial != current_serial)
-    if (HasCap(user, cap) == cap)
+    if (HasCap(user, poscap) == poscap)
       send_message(user, buffer);
 
   dbuf_ref_free(buffer);
 }
 
-/* sendto_channel_local()
- *
- * inputs	- member status mask, e.g. CHFL_CHANOP | CHFL_VOICE
- *              - pointer to channel to send to
- *              - var args pattern
- * output	- NONE
- * side effects - Send a message to all members of a channel that are
- *		  locally connected to this server.
+/*! \brief Send a message to members of a channel that are locally connected to this server.
+ * \param one      Client to skip; can be NULL
+ * \param chptr    Destination channel
+ * \param status   Channel member status flags clients must have
+ * \param poscap   Positive client capabilities flags (CAP)
+ * \param negcap   Negative client capabilities flags (CAP)
+ * \param pattern  Format string for command arguments
  */
 void
-sendto_channel_local(unsigned int type, struct Channel *chptr,
-                     const char *pattern, ...)
+sendto_channel_local(const struct Client *one, struct Channel *chptr, unsigned int status,
+                     unsigned int poscap, unsigned int negcap, const char *pattern, ...)
 {
   va_list args;
   dlink_node *node = NULL;
@@ -562,51 +564,13 @@ sendto_channel_local(unsigned int type, struct Channel *chptr,
     struct Membership *member = node->data;
     struct Client *target_p = member->client_p;
 
-    if (type && (member->flags & type) == 0)
-      continue;
-
     if (IsDefunct(target_p))
       continue;
 
-    send_message(target_p, buffer);
-  }
-
-  dbuf_ref_free(buffer);
-}
-
-/* sendto_channel_local_butone()
- *
- * inputs       - pointer to client to NOT send message to
- *              - member status mask, e.g. CHFL_CHANOP | CHFL_VOICE
- *              - pointer to channel to send to
- *              - var args pattern
- * output       - NONE
- * side effects - Send a message to all members of a channel that are
- *                locally connected to this server except one.
- *
- * WARNING - +D clients are omitted
- */
-void
-sendto_channel_local_butone(struct Client *one, unsigned int poscap, unsigned int negcap,
-                            struct Channel *chptr, const char *pattern, ...)
-{
-  va_list args;
-  dlink_node *node = NULL;
-  struct dbuf_block *buffer = dbuf_alloc();
-
-  va_start(args, pattern);
-  send_format(buffer, pattern, args);
-  va_end(args);
-
-  DLINK_FOREACH(node, chptr->locmembers.head)
-  {
-    struct Membership *member = node->data;
-    struct Client *target_p = member->client_p;
-
     if (one && target_p == one->from)
       continue;
 
-    if (IsDefunct(target_p))
+    if (status && (member->flags & status) == 0)
       continue;
 
     if (poscap && HasCap(target_p, poscap) != poscap)
@@ -891,7 +855,7 @@ sendto_realops_flags_ratelimited(time_t *rate, const char *pattern, ...)
   vsnprintf(buffer, sizeof(buffer), pattern, args);
   va_end(args);
 
-  sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE, "%s", buffer);
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "%s", buffer);
   ilog(LOG_TYPE_IRCD, "%s", buffer);
 }
 
