@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2015 ircd-hybrid development team
+ *  Copyright (c) 1997-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_serv.c
  * \brief Server related functions.
- * \version $Id: server.c 5775 2015-04-04 17:31:06Z michael $
+ * \version $Id: server.c 7033 2016-01-03 14:37:29Z michael $
  */
 
 #include "stdinc.h"
@@ -48,10 +48,9 @@
 #include "channel.h"
 #include "parse.h"
 
-#define MIN_CONN_FREQ 300
 
 dlink_list flatten_links;
-static dlink_list cap_list;
+static dlink_list server_capabilities_list;
 static void serv_connect_callback(fde_t *, int, void *);
 
 
@@ -70,13 +69,20 @@ write_links_file(void *unused)
   dlink_node *node = NULL, *node_next = NULL;
   char buff[IRCD_BUFSIZE] = "";
 
-  if ((file = fopen(LIPATH, "w")) == NULL)
+  if (EmptyString(ConfigServerHide.flatten_links_file))
     return;
 
+  if ((file = fopen(ConfigServerHide.flatten_links_file, "w")) == NULL)
+  {
+    ilog(LOG_TYPE_IRCD, "Couldn't open \"%s\": %s", ConfigServerHide.flatten_links_file,
+         strerror(errno));
+    return;
+  }
+
   DLINK_FOREACH_SAFE(node, node_next, flatten_links.head)
   {
     dlinkDelete(node, &flatten_links);
-    MyFree(node->data);
+    xfree(node->data);
     free_dlink_node(node);
   }
 
@@ -119,9 +125,16 @@ read_links_file(void)
   char *p = NULL;
   char buff[IRCD_BUFSIZE] = "";
 
-  if ((file = fopen(LIPATH, "r")) == NULL)
+  if (EmptyString(ConfigServerHide.flatten_links_file))
     return;
 
+  if ((file = fopen(ConfigServerHide.flatten_links_file, "r")) == NULL)
+  {
+    ilog(LOG_TYPE_IRCD, "Couldn't open \"%s\": %s", ConfigServerHide.flatten_links_file,
+         strerror(errno));
+    return;
+  }
+
   while (fgets(buff, sizeof(buff), file))
   {
     if ((p = strchr(buff, '\n')))
@@ -177,11 +190,11 @@ hunt_server(struct Client *source_p, const char *command,
 
   if (!target_p && has_wildcards(parv[server]))
   {
-    DLINK_FOREACH(node, global_client_list.head)
+    DLINK_FOREACH(node, global_server_list.head)
     {
       struct Client *tmp = node->data;
 
-      assert(IsMe(tmp) || IsServer(tmp) || IsClient(tmp));
+      assert(IsMe(tmp) || IsServer(tmp));
       if (!match(parv[server], tmp->name))
       {
         if (tmp->from == source_p->from && !MyConnect(tmp))
@@ -191,6 +204,24 @@ hunt_server(struct Client *source_p, const char *command,
         break;
       }
     }
+
+    if (!target_p)
+    {
+      DLINK_FOREACH(node, global_client_list.head)
+      {
+        struct Client *tmp = node->data;
+
+        assert(IsMe(tmp) || IsServer(tmp) || IsClient(tmp));
+        if (!match(parv[server], tmp->name))
+        {
+          if (tmp->from == source_p->from && !MyConnect(tmp))
+            continue;
+
+          target_p = node->data;
+          break;
+        }
+      }
+    }
   }
 
   if (target_p)
@@ -224,9 +255,7 @@ void
 try_connections(void *unused)
 {
   dlink_node *node = NULL;
-  int confrq = 0;
 
-  /* TODO: change this to set active flag to 0 when added to event! --Habeeb */
   if (GlobalSetOptions.autoconn == 0)
     return;
 
@@ -236,13 +265,12 @@ try_connections(void *unused)
 
     assert(conf->type == CONF_SERVER);
 
-    /* Also when already connecting! (update holdtimes) --SRB
-     */
+    /* Also when already connecting! (update holdtimes) --SRB */
     if (!conf->port || !IsConfAllowAutoConn(conf))
       continue;
 
-
-    /* Skip this entry if the use of it is still on hold until
+    /*
+     * Skip this entry if the use of it is still on hold until
      * future. Otherwise handle this entry (and set it on hold
      * until next time). Will reset only hold times, if already
      * made one successfull connection... [this algorithm is
@@ -253,11 +281,7 @@ try_connections(void *unused)
 
     assert(conf->class);
 
-    confrq = conf->class->con_freq;
-    if (confrq < MIN_CONN_FREQ)
-      confrq = MIN_CONN_FREQ;
-
-    conf->until = CurrentTime + confrq;
+    conf->until = CurrentTime + conf->class->con_freq;
 
     /*
      * Found a CONNECT config with port specified, scan clients
@@ -268,7 +292,7 @@ try_connections(void *unused)
 
     if (conf->class->ref_count < conf->class->max_total)
     {
-      /* Go to the end of the list, if not already last */
+      /* Move this entry to the end of the list, if not already last */
       if (node->next)
       {
         dlinkDelete(node, &server_items);
@@ -288,11 +312,11 @@ try_connections(void *unused)
        *   -- adrian
        */
       if (ConfigServerHide.hide_server_ips)
-        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+        sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                              "Connection to %s activated.",
                              conf->name);
       else
-        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+        sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                              "Connection to %s[%s] activated.",
                              conf->name, conf->host);
 
@@ -331,7 +355,7 @@ check_server(const char *name, struct Client *client_p)
 
   assert(client_p);
 
-  /* loop through looking for all possible connect items that might work */
+  /* Loop through looking for all possible connect items that might work */
   DLINK_FOREACH(node, server_items.head)
   {
     conf = node->data;
@@ -341,8 +365,6 @@ check_server(const char *name, struct Client *client_p)
 
     error = -3;
 
-    /* XXX: Fix me for IPv6                    */
-    /* XXX sockhost is the IPv4 ip as a string */
     if (!match(conf->host, client_p->host) ||
         !match(conf->host, client_p->sockhost))
     {
@@ -364,26 +386,23 @@ check_server(const char *name, struct Client *client_p)
 
   attach_conf(client_p, server_conf);
 
-
-  if (server_conf)
+  switch (server_conf->aftype)
   {
-    struct sockaddr_in *v4;
-    struct sockaddr_in6 *v6;
-
-    switch (server_conf->aftype)
+    case AF_INET6:
     {
-      case AF_INET6:
-        v6 = (struct sockaddr_in6 *)&server_conf->addr;
+      const struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)&server_conf->addr;
 
-        if (IN6_IS_ADDR_UNSPECIFIED(&v6->sin6_addr))
-          memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
-        break;
-      case AF_INET:
-        v4 = (struct sockaddr_in *)&server_conf->addr;
+      if (IN6_IS_ADDR_UNSPECIFIED(&v6->sin6_addr))
+        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
+      break;
+    }
+    case AF_INET:
+    {
+      const struct sockaddr_in *v4 = (struct sockaddr_in *)&server_conf->addr;
 
-        if (v4->sin_addr.s_addr == INADDR_NONE)
-          memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
-        break;
+      if (v4->sin_addr.s_addr == INADDR_NONE)
+        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
+      break;
     }
   }
 
@@ -400,16 +419,13 @@ check_server(const char *name, struct Client *client_p)
  *		  modules to dynamically add or subtract their capability.
  */
 void
-add_capability(const char *capab_name, int cap_flag, int add_to_default)
+add_capability(const char *name, unsigned int flag)
 {
-  struct Capability *cap = MyCalloc(sizeof(*cap));
+  struct Capability *cap = xcalloc(sizeof(*cap));
 
-  cap->name = xstrdup(capab_name);
-  cap->cap = cap_flag;
-  dlinkAdd(cap, &cap->node, &cap_list);
-
-  if (add_to_default)
-    default_server_capabs |= cap_flag;
+  cap->name = xstrdup(name);
+  cap->cap = flag;
+  dlinkAdd(cap, &cap->node, &server_capabilities_list);
 }
 
 /* delete_capability()
@@ -419,23 +435,19 @@ add_capability(const char *capab_name, int cap_flag, int add_to_default)
  * side effects	- delete given capability from ones known.
  */
 void
-delete_capability(const char *capab_name)
+delete_capability(const char *name)
 {
   dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(node, node_next, cap_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, server_capabilities_list.head)
   {
     struct Capability *cap = node->data;
 
-    if (cap->cap)
+    if (!irccmp(cap->name, name))
     {
-      if (!irccmp(cap->name, capab_name))
-      {
-        default_server_capabs &= ~(cap->cap);
-        dlinkDelete(node, &cap_list);
-        MyFree(cap->name);
-        MyFree(cap);
-      }
+      dlinkDelete(node, &server_capabilities_list);
+      xfree(cap->name);
+      xfree(cap);
     }
   }
 }
@@ -448,15 +460,15 @@ delete_capability(const char *capab_name)
  * side effects	- none
  */
 unsigned int
-find_capability(const char *capab)
+find_capability(const char *name)
 {
   const dlink_node *node = NULL;
 
-  DLINK_FOREACH(node, cap_list.head)
+  DLINK_FOREACH(node, server_capabilities_list.head)
   {
     const struct Capability *cap = node->data;
 
-    if (cap->cap && !irccmp(cap->name, capab))
+    if (!irccmp(cap->name, name))
       return cap->cap;
   }
 
@@ -472,21 +484,19 @@ find_capability(const char *capab)
  *
  */
 void
-send_capabilities(struct Client *client_p, int cap_can_send)
+send_capabilities(struct Client *client_p)
 {
   char buf[IRCD_BUFSIZE] = "";
   const dlink_node *node = NULL;
 
-  DLINK_FOREACH(node, cap_list.head)
+  DLINK_FOREACH(node, server_capabilities_list.head)
   {
     const struct Capability *cap = node->data;
 
-    if (cap->cap & (cap_can_send|default_server_capabs))
-    {
-      strlcat(buf, cap->name, sizeof(buf));
-      if (node->next)
-        strlcat(buf, " ", sizeof(buf));
-    }
+    strlcat(buf, cap->name, sizeof(buf));
+
+    if (node->next)
+      strlcat(buf, " ", sizeof(buf));
   }
 
   sendto_one(client_p, "CAPAB :%s", buf);
@@ -507,7 +517,7 @@ show_capabilities(const struct Client *target_p)
 
   strlcpy(msgbuf, "TS", sizeof(msgbuf));
 
-  DLINK_FOREACH(node, cap_list.head)
+  DLINK_FOREACH(node, server_capabilities_list.head)
   {
     const struct Capability *cap = node->data;
 
@@ -532,7 +542,7 @@ struct Server *
 make_server(struct Client *client_p)
 {
   if (client_p->serv == NULL)
-    client_p->serv = MyCalloc(sizeof(struct Server));
+    client_p->serv = xcalloc(sizeof(struct Server));
 
   return client_p->serv;
 }
@@ -578,7 +588,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   /* Still processing a DNS lookup? -> exit */
   if (conf->dns_pending)
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error connecting to %s: DNS lookup for connect{} in progress.",
                          conf->name);
     return 0;
@@ -586,21 +596,22 @@ serv_connect(struct MaskItem *conf, struct Client *by)
 
   if (conf->dns_failed)
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error connecting to %s: DNS lookup for connect{} failed.",
                          conf->name);
     return 0;
   }
 
-  /* Make sure this server isn't already connected
-   * Note: conf should ALWAYS be a valid C: line
+  /*
+   * Make sure this server isn't already connected.
+   * Note: conf should ALWAYS be a valid connect {} block
    */
   if ((client_p = hash_find_server(conf->name)))
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Server %s already present from %s",
                          conf->name, get_client_name(client_p, SHOW_IP));
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Server %s already present from %s",
                          conf->name, get_client_name(client_p, MASK_IP));
     if (by && IsClient(by) && !MyClient(by))
@@ -619,7 +630,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   /* We already converted the ip once, so lets use it - stu */
   strlcpy(client_p->sockhost, buf, sizeof(client_p->sockhost));
 
-  /* create a socket for the server connection */
+  /* Create a socket for the server connection */
   if (comm_open(&client_p->connection->fd, conf->addr.ss.ss_family, SOCK_STREAM, 0, NULL) < 0)
   {
     /* Eek, failure to create the socket */
@@ -630,15 +641,16 @@ serv_connect(struct MaskItem *conf, struct Client *by)
     return 0;
   }
 
-  /* servernames are always guaranteed under HOSTLEN chars */
-  fd_note(&client_p->connection->fd, "Server: %s", conf->name);
+  /* Server names are always guaranteed under HOSTLEN chars */
+  fd_note(&client_p->connection->fd, "Server: %s", client_p->name);
 
-  /* Attach config entries to client here rather than in
-   * serv_connect_callback(). This to avoid null pointer references.
+  /*
+   * Attach config entries to client here rather than in serv_connect_callback().
+   * This to avoid null pointer references.
    */
   if (!attach_connect_block(client_p, conf->name, conf->host))
   {
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Host %s is not enabled for connecting: no connect {} block",
                          conf->name);
     if (by && IsClient(by) && !MyClient(by))
@@ -649,9 +661,10 @@ serv_connect(struct MaskItem *conf, struct Client *by)
     return 0;
   }
 
-  /* at this point we have a connection in progress and C/N lines
-   * attached to the client, the socket info should be saved in the
-   * client and it should either be resolved or have a valid address.
+  /*
+   * At this point we have a connection in progress and a connect {} block
+   * attached to the client, the socket info should be saved in the client
+   * and it should either be resolved or have a valid address.
    *
    * The socket has been connected or connect is in progress.
    */
@@ -755,9 +768,9 @@ finish_ssl_server_handshake(struct Client *client_p)
                         client_p->name, CONF_SERVER);
   if (conf == NULL)
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-                         "Lost connect{} block for %s", get_client_name(client_p, HIDE_IP));
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "Lost connect{} block for %s", get_client_name(client_p, SHOW_IP));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Lost connect{} block for %s", get_client_name(client_p, MASK_IP));
 
     exit_client(client_p, "Lost connect{} block");
@@ -766,24 +779,23 @@ finish_ssl_server_handshake(struct Client *client_p)
 
   sendto_one(client_p, "PASS %s TS %d %s", conf->spasswd, TS_CURRENT, me.id);
 
-  send_capabilities(client_p, 0);
+  send_capabilities(client_p);
 
   sendto_one(client_p, "SERVER %s 1 :%s%s",
              me.name, ConfigServerHide.hidden ? "(H) " : "",
              me.info);
 
-  /* If we've been marked dead because a send failed, just exit
+  /*
+   * If we've been marked dead because a send failed, just exit
    * here now and save everyone the trouble of us ever existing.
    */
   if (IsDead(client_p))
   {
-      sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-                           "%s[%s] went dead during handshake",
-                           client_p->name,
-                           client_p->host);
-      sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
-                           "%s went dead during handshake", client_p->name);
-      return;
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "%s went dead during handshake", get_client_name(client_p, SHOW_IP));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+                         "%s went dead during handshake", get_client_name(client_p, MASK_IP));
+    return;
   }
 
   /* don't move to serv_list yet -- we haven't sent a burst! */
@@ -819,7 +831,7 @@ ssl_server_handshake(fde_t *fd, void *data)
       default:
       {
         const char *sslerr = ERR_error_string(ERR_get_error(), NULL);
-        sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+        sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                              "Error connecting to %s: %s", client_p->name,
                              sslerr ? sslerr : "unknown SSL error");
         exit_client(client_p, "Error during SSL handshake");
@@ -858,7 +870,7 @@ ssl_server_handshake(fde_t *fd, void *data)
 }
 
 static void
-ssl_connect_init(struct Client *client_p, struct MaskItem *conf, fde_t *fd)
+ssl_connect_init(struct Client *client_p, const struct MaskItem *conf, fde_t *fd)
 {
   if ((client_p->connection->fd.ssl = SSL_new(ConfigServerInfo.client_ctx)) == NULL)
   {
@@ -889,8 +901,8 @@ ssl_connect_init(struct Client *client_p, struct MaskItem *conf, fde_t *fd)
 static void
 serv_connect_callback(fde_t *fd, int status, void *data)
 {
-  struct Client *client_p = data;
-  struct MaskItem *conf = NULL;
+  struct Client *const client_p = data;
+  const struct MaskItem *conf = NULL;
 
   /* First, make sure it's a real client! */
   assert(client_p);
@@ -903,27 +915,20 @@ serv_connect_callback(fde_t *fd, int status, void *data)
   /* Check the status */
   if (status != COMM_OK)
   {
-    /* We have an error, so report it and quit
-     * Admins get to see any IP, mere opers don't *sigh*
+    /* We have an error, so report it and quit */
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "Error connecting to %s: %s",
+                         get_client_name(client_p, SHOW_IP), comm_errstr(status));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+                         "Error connecting to %s: %s",
+                         get_client_name(client_p, MASK_IP), comm_errstr(status));
+
+    /*
+     * If a fd goes bad, call dead_link() the socket is no
+     * longer valid for reading or writing.
      */
-     if (ConfigServerHide.hide_server_ips)
-       sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-                            "Error connecting to %s: %s",
-                            client_p->name, comm_errstr(status));
-     else
-       sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-                            "Error connecting to %s[%s]: %s", client_p->name,
-                            client_p->host, comm_errstr(status));
-
-     sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
-                          "Error connecting to %s: %s",
-                          client_p->name, comm_errstr(status));
-
-     /* If a fd goes bad, call dead_link() the socket is no
-      * longer valid for reading or writing.
-      */
-     dead_link_on_write(client_p, 0);
-     return;
+    dead_link_on_write(client_p, 0);
+    return;
   }
 
   /* COMM_OK, so continue the connection procedure */
@@ -932,9 +937,9 @@ serv_connect_callback(fde_t *fd, int status, void *data)
                         client_p->name, CONF_SERVER);
   if (conf == NULL)
   {
-    sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-                         "Lost connect{} block for %s", get_client_name(client_p, HIDE_IP));
-    sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "Lost connect{} block for %s", get_client_name(client_p, SHOW_IP));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
                          "Lost connect{} block for %s", get_client_name(client_p, MASK_IP));
 
     exit_client(client_p, "Lost connect{} block");
@@ -954,23 +959,22 @@ serv_connect_callback(fde_t *fd, int status, void *data)
 
   sendto_one(client_p, "PASS %s TS %d %s", conf->spasswd, TS_CURRENT, me.id);
 
-  send_capabilities(client_p, 0);
+  send_capabilities(client_p);
 
   sendto_one(client_p, "SERVER %s 1 :%s%s", me.name,
              ConfigServerHide.hidden ? "(H) " : "", me.info);
 
-  /* If we've been marked dead because a send failed, just exit
+  /*
+   * If we've been marked dead because a send failed, just exit
    * here now and save everyone the trouble of us ever existing.
    */
   if (IsDead(client_p))
   {
-      sendto_realops_flags(UMODE_ALL, L_ADMIN, SEND_NOTICE,
-                           "%s[%s] went dead during handshake",
-                           client_p->name,
-                           client_p->host);
-      sendto_realops_flags(UMODE_ALL, L_OPER, SEND_NOTICE,
-                           "%s went dead during handshake", client_p->name);
-      return;
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                         "%s went dead during handshake", get_client_name(client_p, SHOW_IP));
+    sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+                         "%s went dead during handshake", get_client_name(client_p, MASK_IP));
+    return;
   }
 
   /* don't move to serv_list yet -- we haven't sent a burst! */
