@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1997 Jukka Santala (Donwulff)
- *  Copyright (c) 2005-2014 ircd-hybrid development team
+ *  Copyright (c) 2005-2016 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file watch.c
  * \brief File including functions for WATCH support
- * \version $Id: watch.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: watch.c 7007 2016-01-01 00:09:08Z michael $
  */
 
 #include "stdinc.h"
@@ -65,7 +65,7 @@ watch_init(void)
 /*! \brief Counts up memory used by watch list headers
  */
 void
-watch_count_memory(unsigned int *const count, uint64_t *const bytes)
+watch_count_memory(unsigned int *const count, size_t *const bytes)
 {
   for (unsigned int i = 0; i < HASHSIZE; ++i)
     (*count) += dlink_list_length(&watchTable[i]);
@@ -79,24 +79,24 @@ watch_count_memory(unsigned int *const count, uint64_t *const bytes)
  * \param reply Numeric to send. Either RPL_LOGON or RPL_LOGOFF
  */
 void
-watch_check_hash(struct Client *client_p, const enum irc_numerics reply)
+watch_check_hash(const struct Client *client_p, const enum irc_numerics reply)
 {
-  struct Watch *anptr = NULL;
-  dlink_node *ptr = NULL;
+  struct Watch *watch = NULL;
+  dlink_node *node = NULL;
 
   assert(IsClient(client_p));
 
-  if ((anptr = watch_find_hash(client_p->name)) == NULL)
+  if ((watch = watch_find_hash(client_p->name)) == NULL)
     return;  /* This nick isn't on watch */
 
   /* Update the time of last change to item */
-  anptr->lasttime = CurrentTime;
+  watch->lasttime = CurrentTime;
 
   /* Send notifies out to everybody on the list in header */
-  DLINK_FOREACH(ptr, anptr->watched_by.head)
-    sendto_one_numeric(ptr->data, &me, reply, client_p->name,
+  DLINK_FOREACH(node, watch->watched_by.head)
+    sendto_one_numeric(node->data, &me, reply, client_p->name,
                        client_p->username, client_p->host,
-                       anptr->lasttime, client_p->info);
+                       watch->lasttime, client_p->info);
 }
 
 /*! \brief Looks up the watch table for a given nick
@@ -105,14 +105,14 @@ watch_check_hash(struct Client *client_p, const enum irc_numerics reply)
 struct Watch *
 watch_find_hash(const char *name)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, watchTable[strhash(name)].head)
+  DLINK_FOREACH(node, watchTable[strhash(name)].head)
   {
-    struct Watch *anptr = ptr->data;
+    struct Watch *watch = node->data;
 
-    if (!irccmp(anptr->nick, name))
-      return anptr;
+    if (!irccmp(watch->nick, name))
+      return watch;
   }
 
   return NULL;
@@ -125,30 +125,30 @@ watch_find_hash(const char *name)
 void
 watch_add_to_hash_table(const char *nick, struct Client *client_p)
 {
-  struct Watch *anptr = NULL;
-  dlink_node *ptr = NULL;
+  struct Watch *watch = NULL;
+  dlink_node *node = NULL;
 
   /* If found NULL (no header for this nick), make one... */
-  if ((anptr = watch_find_hash(nick)) == NULL)
+  if ((watch = watch_find_hash(nick)) == NULL)
   {
-    anptr = mp_pool_get(watch_pool);
+    watch = mp_pool_get(watch_pool);
 
-    anptr->lasttime = CurrentTime;
-    strlcpy(anptr->nick, nick, sizeof(anptr->nick));
+    watch->lasttime = CurrentTime;
+    strlcpy(watch->nick, nick, sizeof(watch->nick));
 
-    dlinkAdd(anptr, &anptr->node, &watchTable[strhash(anptr->nick)]);
+    dlinkAdd(watch, &watch->node, &watchTable[strhash(watch->nick)]);
   }
   else
   {
     /* Is this client already on the watch-list? */
-    ptr = dlinkFind(&anptr->watched_by, client_p);
+    node = dlinkFind(&watch->watched_by, client_p);
   }
 
-  if (ptr == NULL)
+  if (node == NULL)
   {
-    /* No it isn't, so add it in the bucket and client addint it */
-    dlinkAdd(client_p, make_dlink_node(), &anptr->watched_by);
-    dlinkAdd(anptr, make_dlink_node(), &client_p->localClient->watches);
+    /* No it isn't, so add it in the bucket and client adding it */
+    dlinkAdd(client_p, make_dlink_node(), &watch->watched_by);
+    dlinkAdd(watch, make_dlink_node(), &client_p->connection->watches);
   }
 }
 
@@ -159,27 +159,27 @@ watch_add_to_hash_table(const char *nick, struct Client *client_p)
 void
 watch_del_from_hash_table(const char *nick, struct Client *client_p)
 {
-  struct Watch *anptr = NULL;
-  dlink_node *ptr = NULL;
+  struct Watch *watch = NULL;
+  dlink_node *node = NULL;
 
-  if ((anptr = watch_find_hash(nick)) == NULL)
+  if ((watch = watch_find_hash(nick)) == NULL)
     return;  /* No header found for that nick. i.e. it's not being watched */
 
-  if ((ptr = dlinkFind(&anptr->watched_by, client_p)) == NULL)
+  if ((node = dlinkFind(&watch->watched_by, client_p)) == NULL)
     return;  /* This nick isn't being watched by client_p */
 
-  dlinkDelete(ptr, &anptr->watched_by);
-  free_dlink_node(ptr);
+  dlinkDelete(node, &watch->watched_by);
+  free_dlink_node(node);
 
-  if ((ptr = dlinkFindDelete(&client_p->localClient->watches, anptr)))
-    free_dlink_node(ptr);
+  if ((node = dlinkFindDelete(&client_p->connection->watches, watch)))
+    free_dlink_node(node);
 
   /* In case this header is now empty of notices, remove it */
-  if (anptr->watched_by.head == NULL)
+  if (watch->watched_by.head == NULL)
   {
-    assert(dlinkFind(&watchTable[strhash(anptr->nick)], anptr));
-    dlinkDelete(&anptr->node, &watchTable[strhash(anptr->nick)]);
-    mp_pool_release(anptr);
+    assert(dlinkFind(&watchTable[strhash(watch->nick)], watch));
+    dlinkDelete(&watch->node, &watchTable[strhash(watch->nick)]);
+    mp_pool_release(watch);
   }
 }
 
@@ -190,31 +190,31 @@ watch_del_from_hash_table(const char *nick, struct Client *client_p)
 void
 watch_del_watch_list(struct Client *client_p)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
-  dlink_node *tmp = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
+  dlink_node *temp = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, client_p->localClient->watches.head)
+  DLINK_FOREACH_SAFE(node, node_next, client_p->connection->watches.head)
   {
-    struct Watch *anptr = ptr->data;
+    struct Watch *watch = node->data;
 
-    assert(dlinkFind(&anptr->watched_by, client_p));
+    assert(dlinkFind(&watch->watched_by, client_p));
 
-    if ((tmp = dlinkFindDelete(&anptr->watched_by, client_p)))
-      free_dlink_node(tmp);
+    if ((temp = dlinkFindDelete(&watch->watched_by, client_p)))
+      free_dlink_node(temp);
 
     /* If this leaves a header without notifies, remove it. */
-    if (anptr->watched_by.head == NULL)
+    if (watch->watched_by.head == NULL)
     {
-      assert(dlinkFind(&watchTable[strhash(anptr->nick)], anptr));
-      dlinkDelete(&anptr->node, &watchTable[strhash(anptr->nick)]);
+      assert(dlinkFind(&watchTable[strhash(watch->nick)], watch));
+      dlinkDelete(&watch->node, &watchTable[strhash(watch->nick)]);
 
-      mp_pool_release(anptr);
+      mp_pool_release(watch);
     }
 
-    dlinkDelete(ptr, &client_p->localClient->watches);
-    free_dlink_node(ptr);
+    dlinkDelete(node, &client_p->connection->watches);
+    free_dlink_node(node);
   }
 
-  assert(client_p->localClient->watches.head == NULL);
-  assert(client_p->localClient->watches.tail == NULL);
+  assert(client_p->connection->watches.head == NULL);
+  assert(client_p->connection->watches.tail == NULL);
 }
